<template>
  <div class="content">
    <div class="container-fluid">
      <div class="row mt-3">
        <div class="col-md-12">
          <b-card title="404 Not Found">
            <b-card-text class="mt-4">
                <p>The page you are trying to access does not exist</p>
            </b-card-text>
          </b-card>
        </div>
      </div>
    </div>
  </div>
</template>
