.vue-notifyjs.notifications .list-move{-webkit-transition:opacity .4s,-webkit-transform .3s;transition:opacity .4s,-webkit-transform .3s;transition:transform .3s,opacity .4s;transition:transform .3s,opacity .4s,-webkit-transform .3s}.vue-notifyjs.notifications .list-item{display:inline-block;margin-right:10px}.vue-notifyjs.notifications .list-enter-active{-webkit-transition:opacity .4s ease-in,-webkit-transform .2s ease-in;transition:opacity .4s ease-in,-webkit-transform .2s ease-in;transition:transform .2s ease-in,opacity .4s ease-in;transition:transform .2s ease-in,opacity .4s ease-in,-webkit-transform .2s ease-in}.vue-notifyjs.notifications .list-leave-active{-webkit-transition:opacity .4s ease-out,-webkit-transform 1s ease-out;transition:opacity .4s ease-out,-webkit-transform 1s ease-out;transition:transform 1s ease-out,opacity .4s ease-out;transition:transform 1s ease-out,opacity .4s ease-out,-webkit-transform 1s ease-out}.vue-notifyjs.notifications .list-enter{opacity:0;-webkit-transform:scale(1.1);transform:scale(1.1)}.vue-notifyjs.notifications .list-leave-to{opacity:0;-webkit-transform:scale(1.2,.7);transform:scale(1.2,.7)}.dropdown .dropdown-toggle[data-v-1b11b073]{cursor:pointer}.sidebar .sidebar-wrapper{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.sidebar .nav-main__links{-webkit-box-flex:1;-ms-flex:1;flex:1}.sidebar .sidebar-wrapper .logo .logo__container{padding-left:10px}

/*!

 =========================================================
 * Vue Light Bootstrap Dashboard - v2.0.0 (Bootstrap 4)
 =========================================================

 * Product Page: http://www.creative-tim.com/product/light-bootstrap-dashboard
 * Copyright 2019 Creative Tim (http://www.creative-tim.com)
 * Licensed under MIT (https://github.com/creativetimofficial/light-bootstrap-dashboard/blob/master/LICENSE.md)

 =========================================================

 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

 */@keyframes spin{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}@-webkit-keyframes spin{0%{-webkit-transform:rotate(0deg)}to{-webkit-transform:rotate(1turn)}}.alert,.brand,.btn-simple,.h1,.h2,.h3,.h4,.h5,.h6,.navbar,.td-name,a,body,button.close,h1,h2,h3,h4,h5,h6,p,td{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:Roboto,Helvetica Neue,Arial,sans-serif;font-weight:400}.h1,.h2,.h3,.h4,h1,h2,h3,h4{font-weight:300;margin:30px 0 15px}.h1,h1{font-size:52px}.h2,h2{font-size:36px}.h3,h3{font-size:28px;margin:20px 0 10px}.h4,h4{font-size:22px;line-height:30px}.h5,h5{font-size:16px;margin-bottom:15px}.h6,h6{font-size:14px;font-weight:600;text-transform:uppercase}p{font-size:16px;line-height:1.5}.h1 .small,.h1 small,.h2 .small,.h2 small,.h3 .small,.h3 small,.h4 .small,.h4 small,.h5 .small,.h5 small,.h6 .small,.h6 small,h1 .small,h1 small,h2 .small,h2 small,h3 .small,h3 small,h4 .small,h4 small,h5 .small,h5 small,h6 .small,h6 small{color:#9a9a9a;font-weight:300;line-height:1.5}h1 .small,h1 small,h2 .small,h2 small,h3 .small,h3 small{font-size:60%}h1 .subtitle{display:block;margin:0 0 30px}.text-muted{color:#9a9a9a}.text-primary,.text-primary:hover{color:#1d62f0!important}.text-info,.text-info:hover{color:#1dc7ea!important}.text-success,.text-success:hover{color:#87cb16!important}.text-warning,.text-warning:hover{color:#ff9500!important}.text-danger,.text-danger:hover{color:#ff4a55!important}.wrapper,body{min-height:100vh;position:relative}a{color:#1dc7ea}a:focus,a:hover{color:#42d0ed;text-decoration:none}a:active,a:focus,button::-moz-focus-inner,input::-moz-focus-inner,input[type=button]::-moz-focus-inner,input[type=file]>input[type=button]::-moz-focus-inner,input[type=reset]::-moz-focus-inner,input[type=submit]::-moz-focus-inner,select::-moz-focus-inner{outline:0}.navbar-toggle,.ui-slider-handle:focus,input:focus{outline:0!important}.form-control,.input-group-addon,.navbar,.navbar .alert,.tagsinput{-webkit-transition:all .3s linear;transition:all .3s linear}.sidebar .nav a,.table>tbody>tr .td-actions .btn{-webkit-transition:all .15s ease-in;transition:all .15s ease-in}.btn{-webkit-transition:all .1s ease-in;transition:all .1s ease-in}.fa{width:18px;text-align:center}.margin-top{margin-top:50px}.wrapper{position:relative;top:0;height:100vh}.page-header .page-header-image{background-position:50%;background-size:cover;overflow:hidden;width:100%;z-index:1}.page-header .title-container{color:#fff;position:relative;top:250px;z-index:3}.page-header .filter:after{background:transparent -webkit-gradient(linear,left top,left bottom,from(#9368e9),to(#943bea)) repeat scroll 0 0/150% 150%;background:transparent linear-gradient(180deg,#9368e9 0,#943bea) repeat scroll 0 0/150% 150%;content:"";display:block;height:100%;left:0;opacity:.77;position:absolute;top:0;width:100%;z-index:2}.documentation .page-header,.documentation .page-header-image,.documentation .page-header-image .filter:after{height:100vh}.documentation .footer{z-index:3}.documentation .wrapper{margin-top:-61px;height:100vh}.documentation .navbar{z-index:21}.card-tasks .card-body .table td,.card-tasks .card-body .table td .btn{font-size:14px}.card-tasks .card-body .table td .btn-info{margin-top:3px;padding-right:0}.card-tasks .card-body .table td:last-child{padding-right:0}.sidebar,body>.navbar-collapse{position:fixed;height:100vh;top:0;bottom:0;left:0;width:260px;display:block;z-index:1;color:#fff;font-weight:200;background-size:cover;background-position:50%}.sidebar .sidebar-wrapper,body>.navbar-collapse .sidebar-wrapper{position:relative;max-height:calc(100vh - 75px);min-height:100%;overflow:auto;width:260px;z-index:4;padding-bottom:20px}.sidebar .sidebar-background,body>.navbar-collapse .sidebar-background{position:absolute;z-index:1;height:100%;width:100%;display:block;top:0;left:0;background-size:cover;background-position:50%}.sidebar .logo,body>.navbar-collapse .logo{padding:10px 15px 9px 15px;position:relative;z-index:4}.sidebar .logo .simple-text .logo-img,body>.navbar-collapse .logo .simple-text .logo-img{width:100%;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:40px;margin-left:0;margin-right:10px}.sidebar .logo .simple-text .logo-img img,body>.navbar-collapse .logo .simple-text .logo-img img{max-width:100%}.sidebar .nav,body>.navbar-collapse .nav{margin-top:20px;float:none;display:block}.sidebar .nav li .nav-link,body>.navbar-collapse .nav li .nav-link{color:#fff;margin:5px 15px;opacity:.86;border-radius:4px;display:block;padding:10px 15px}.sidebar .nav li .nav-link:hover,body>.navbar-collapse .nav li .nav-link:hover{background:hsla(0,0%,100%,.13);opacity:1}.sidebar .nav li .nav-link p,body>.navbar-collapse .nav li .nav-link p{margin:0;line-height:31px;font-size:12px;font-weight:600;text-transform:uppercase;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex}.sidebar .nav li .nav-link i,body>.navbar-collapse .nav li .nav-link i{font-size:28px;margin-right:15px;width:30px;text-align:center;vertical-align:middle;float:left}.sidebar .nav li:hover .nav-link,body>.navbar-collapse .nav li:hover .nav-link{background:hsla(0,0%,100%,.13);opacity:1}.sidebar .nav li.active .nav-link,body>.navbar-collapse .nav li.active .nav-link{color:#fff;opacity:1;background:hsla(0,0%,100%,.23)}.sidebar .nav li.separator,body>.navbar-collapse .nav li.separator{margin:15px 0;border-bottom:1px solid hsla(0,0%,100%,.2)}.sidebar .nav li.separator+.nav-item,body>.navbar-collapse .nav li.separator+.nav-item{margin-top:31px}.sidebar .nav .caret,body>.navbar-collapse .nav .caret{margin-top:13px;position:absolute;right:30px}.sidebar .nav .active-pro,body>.navbar-collapse .nav .active-pro{position:absolute;width:100%;bottom:10px}.sidebar .nav .active-pro a,body>.navbar-collapse .nav .active-pro a{color:#fff!important}.sidebar .nav .nav-link,body>.navbar-collapse .nav .nav-link{color:#fff;margin:5px 15px;opacity:.86;border-radius:4px;text-transform:uppercase;line-height:30px;font-size:12px;font-weight:600}.sidebar .logo,body>.navbar-collapse .logo{padding:10px 15px;border-bottom:1px solid hsla(0,0%,100%,.2)}.sidebar .logo p,body>.navbar-collapse .logo p{float:left;font-size:20px;margin:10px 10px;color:#fff;line-height:20px;font-family:Helvetica Neue,Helvetica,Arial,sans-serif}.sidebar .logo .simple-text,body>.navbar-collapse .logo .simple-text{padding:5px 0;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;font-size:18px;color:#fff;text-align:center;font-weight:400;line-height:30px}.sidebar .logo-tim,body>.navbar-collapse .logo-tim{border-radius:50%;border:1px solid #333;display:block;height:61px;width:61px;float:left;overflow:hidden}.sidebar .logo-tim img,body>.navbar-collapse .logo-tim img{width:60px;height:60px}.sidebar:after,.sidebar:before,body>.navbar-collapse:after,body>.navbar-collapse:before{display:block;content:"";position:absolute;width:100%;height:100%;top:0;left:0;z-index:2}.sidebar:before,body>.navbar-collapse:before{opacity:.33;background:#000}.sidebar:after,body>.navbar-collapse:after{background:#9368e9;background:-webkit-gradient(linear,left top,left bottom,from(#9368e9),to(#943bea));background:linear-gradient(180deg,#9368e9 0,#943bea);background-size:150% 150%;z-index:3;opacity:1}.sidebar.has-image:after,.sidebar[data-image]:after,body>.navbar-collapse.has-image:after,body>.navbar-collapse[data-image]:after{opacity:.77}.sidebar[data-color=black]:after,body>.navbar-collapse[data-color=black]:after{background:#292929;background:-webkit-gradient(linear,left top,left bottom,from(#292929),to(#0e0e0e));background:linear-gradient(180deg,#292929 0,#0e0e0e);background-size:150% 150%}.sidebar[data-color=blue]:after,body>.navbar-collapse[data-color=blue]:after{background:#1f77d0;background:-webkit-gradient(linear,left top,left bottom,from(#1f77d0),to(#533ce1));background:linear-gradient(180deg,#1f77d0 0,#533ce1);background-size:150% 150%}.sidebar[data-color=azure]:after,body>.navbar-collapse[data-color=azure]:after{background:#1dc7ea;background:-webkit-gradient(linear,left top,left bottom,from(#1dc7ea),to(#4091ff));background:linear-gradient(180deg,#1dc7ea 0,#4091ff);background-size:150% 150%}.sidebar[data-color=green]:after,body>.navbar-collapse[data-color=green]:after{background:#87cb16;background:-webkit-gradient(linear,left top,left bottom,from(#87cb16),to(#6dc030));background:linear-gradient(180deg,#87cb16 0,#6dc030);background-size:150% 150%}.sidebar[data-color=orange]:after,body>.navbar-collapse[data-color=orange]:after{background:#ffa534;background:-webkit-gradient(linear,left top,left bottom,from(#ffa534),to(#ff5221));background:linear-gradient(180deg,#ffa534 0,#ff5221);background-size:150% 150%}.sidebar[data-color=red]:after,body>.navbar-collapse[data-color=red]:after{background:#fb404b;background:-webkit-gradient(linear,left top,left bottom,from(#fb404b),to(#bb0502));background:linear-gradient(180deg,#fb404b 0,#bb0502);background-size:150% 150%}.sidebar[data-color=purple]:after,body>.navbar-collapse[data-color=purple]:after{background:#9368e9;background:-webkit-gradient(linear,left top,left bottom,from(#9368e9),to(#943bea));background:linear-gradient(180deg,#9368e9 0,#943bea);background-size:150% 150%}.main-panel{background:rgba(203,203,210,.15);position:relative;float:right;width:calc(100% - 260px);min-height:100%}.main-panel>.content{padding:30px 15px;min-height:calc(100% - 123px)}.main-panel>.footer{border-top:1px solid #e7e7e7}.main-panel .navbar{margin-bottom:0}.main-panel,.sidebar{max-height:100%;height:100%;-webkit-transition-property:top,bottom;transition-property:top,bottom;-webkit-transition-duration:.2s,.2s;transition-duration:.2s,.2s;-webkit-transition-timing-function:linear,linear;transition-timing-function:linear,linear;-webkit-overflow-scrolling:touch}.fixed-plugin .dropdown .dropdown-menu{border-radius:10px}.fixed-plugin .dropdown .dropdown-menu li.adjustments-line{border-bottom:1px solid #ddd}.fixed-plugin .dropdown .dropdown-menu li{padding:5px 2px!important}.fixed-plugin .dropdown .dropdown-menu .button-container a{font-size:14px}.fixed-plugin .dropdown .dropdown-menu .button-container.show{-webkit-transform:translateZ(0)!important;transform:translateZ(0)!important;-webkit-transform-origin:0 0;transform-origin:0 0;left:-303px!important}.fixed-plugin .dropdown .dropdown-menu{-webkit-transform:translate3d(0,-5%,0)!important;transform:translate3d(0,-5%,0)!important;top:-40px!important;left:-303px!important}.fixed-plugin .dropdown.show .dropdown-menu{-webkit-transform:translateZ(0)!important;transform:translateZ(0)!important;left:-303px!important}.modal.show .modal-dialog{-webkit-transform:translateY(30%);transform:translateY(30%)}.modal.modal-mini .modal-dialog{max-width:255px;margin:0 auto}.modal .modal-content .modal-header{border-bottom:none;padding-top:24px;padding-right:24px;padding-bottom:0;padding-left:24px}.modal .modal-content .modal-header .modal-profile{width:80px;height:80px;border-radius:50%;text-align:center;line-height:5.7;-webkit-box-shadow:0 5px 20px 0 rgba(0,0,0,.3);box-shadow:0 5px 20px 0 rgba(0,0,0,.3)}.modal .modal-content .modal-header .modal-profile i{font-size:32px;padding-top:24px}.modal .modal-content .modal-body{padding-top:24px;padding-right:24px;padding-bottom:16px;padding-left:24px;line-height:1.9}.modal .modal-content .modal-body+.modal-footer{padding-top:0}.modal .modal-content .modal-footer{border-top:none;padding-right:24px;padding-bottom:16px;padding-left:24px;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.modal .modal-content .modal-footer .btn{margin:0;padding-left:16px;padding-right:16px;width:auto}.modal .modal-content .modal-footer .btn:hover,.modal .modal-content .modal-footer .btnfocus{text-decoration:none}.nav .nav-item .nav-link:focus,.nav .nav-item .nav-link:hover{background-color:transparent}.navbar{border:0;font-size:16px;border-radius:0;min-height:50px;background-color:hsla(0,0%,100%,.96);border-bottom:1px solid rgba(0,0,0,.1);padding:5px 15px}.navbar .navbar-brand{font-weight:400;margin:5px 0;font-size:20px;color:#888}.navbar .navbar-brand:hover{color:#5e5e5e}.navbar .navbar-toggler{width:37px;height:27px;vertical-align:middle;outline:0;cursor:pointer}.navbar .navbar-toggler.navbar-toggler-left{position:relative;left:0;padding-left:0}.navbar .navbar-toggler .navbar-toggler-bar{width:3px;height:3px;border-radius:50%;margin:0 auto}.navbar .navbar-toggler .burger-lines{display:block;position:relative;background-color:#888;width:24px;height:2px;border-radius:1px;margin:4px auto}.navbar .dropdown.nav-item .dropdown-toggle:after{margin-top:8px}.navbar .navbar-nav{-webkit-box-align:center;-ms-flex-align:center;align-items:center}.navbar .navbar-nav .nav-item .nav-link{color:#888;padding:10px 15px;position:relative;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;line-height:1.2}.navbar .navbar-nav .nav-item .nav-link.btn{margin:15px 3px;padding:8px 16px}.navbar .navbar-nav .nav-item .nav-link.btn-round{margin:16px 3px}.navbar .navbar-nav .nav-item .nav-link [class^=fa]{font-size:19px;position:relative;line-height:40px;top:1px}.navbar .navbar-nav .nav-item .nav-link:hover{color:#1dc7ea}.navbar .navbar-nav .nav-item .dropdown-menu{border-radius:10px;margin-top:-5px}.navbar .navbar-nav .nav-item .dropdown-menu .dropdown-item:first-child{border-top-left-radius:10px;border-top-right-radius:10px}.navbar .navbar-nav .nav-item .dropdown-menu .dropdown-item:last-child{border-bottom-left-radius:10px;border-bottom-right-radius:10px}.navbar .navbar-nav .nav-item .dropdown-menu .divider{height:1px;margin:5px 0;overflow:hidden;background-color:#e5e5e5}.navbar .navbar-nav .notification{position:absolute;background-color:#fb404b;text-align:center;border-radius:10px;min-width:18px;padding:0 5px;height:18px;font-size:12px;color:#fff;font-weight:700;line-height:18px;top:0;left:7px}.navbar .navbar-nav .dropdown-toggle:after{display:inline-block;width:0;height:0;margin-left:5px;margin-top:12px;vertical-align:middle;border-top:4px dashed;border-top:4px solid\9;border-right:4px solid transparent;border-left:4px solid transparent}.navbar .btn{margin:15px 3px;font-size:14px}.navbar .btn-simple{font-size:16px}.navbar.fixed{width:260px;right:0;left:auto;border-radius:0}.navbar .nc-icon{font-weight:700}.navbar-transparent .navbar-brand,[class*=navbar-ct] .navbar-brand{color:#fff;opacity:.9;filter:alpha(opacity=90)}.navbar-transparent .navbar-brand:focus,.navbar-transparent .navbar-brand:hover,[class*=navbar-ct] .navbar-brand:focus,[class*=navbar-ct] .navbar-brand:hover{background-color:transparent;opacity:1;filter:alpha(opacity=100);color:#fff}.navbar-transparent .navbar-nav .nav-item .nav-link:not(.btn),[class*=navbar-ct] .navbar-nav .nav-item .nav-link:not(.btn){color:#fff;border-color:#fff;opacity:.8;filter:alpha(opacity=80)}.navbar-transparent .navbar-nav .active .nav-link:focus:not(.btn),.navbar-transparent .navbar-nav .active .nav-link:hover:not(.btn),.navbar-transparent .navbar-nav .active .nav-link:not(.btn),.navbar-transparent .navbar-nav .nav-item .nav-link:focus:not(.btn),.navbar-transparent .navbar-nav .nav-item .nav-link:hover:not(.btn),.navbar-transparent .navbar-nav .nav-item .nav-link:not(.btn),[class*=navbar-ct] .navbar-nav .active .nav-link:focus:not(.btn),[class*=navbar-ct] .navbar-nav .active .nav-link:hover:not(.btn),[class*=navbar-ct] .navbar-nav .active .nav-link:not(.btn),[class*=navbar-ct] .navbar-nav .nav-item .nav-link:focus:not(.btn),[class*=navbar-ct] .navbar-nav .nav-item .nav-link:hover:not(.btn),[class*=navbar-ct] .navbar-nav .nav-item .nav-link:not(.btn){background-color:transparent;border-radius:3px;color:#fff;opacity:1;filter:alpha(opacity=100)}.navbar-transparent .navbar-nav .nav .nav-item .nav-link.btn:hover,[class*=navbar-ct] .navbar-nav .nav .nav-item .nav-link.btn:hover{background-color:transparent}.navbar-transparent .navbar-nav .show .nav-link,.navbar-transparent .navbar-nav .show .nav-link:focus,.navbar-transparent .navbar-nav .show .nav-link:hover,[class*=navbar-ct] .navbar-nav .show .nav-link,[class*=navbar-ct] .navbar-nav .show .nav-link:focus,[class*=navbar-ct] .navbar-nav .show .nav-link:hover{background-color:transparent;color:#fff;opacity:1;filter:alpha(opacity=100)}.navbar-transparent .btn-default,[class*=navbar-ct] .btn-default{color:#fff;border-color:#fff}.navbar-transparent .btn-default.btn-fill,[class*=navbar-ct] .btn-default.btn-fill{color:#9a9a9a;background-color:#fff;opacity:.9;filter:alpha(opacity=90)}.navbar-transparent .btn-default.btn-fill.active,.navbar-transparent .btn-default.btn-fill:active,.navbar-transparent .btn-default.btn-fill:focus,.navbar-transparent .btn-default.btn-fill:hover,.navbar-transparent .show .dropdown-toggle.btn-fill.btn-default,[class*=navbar-ct] .btn-default.btn-fill.active,[class*=navbar-ct] .btn-default.btn-fill:active,[class*=navbar-ct] .btn-default.btn-fill:focus,[class*=navbar-ct] .btn-default.btn-fill:hover,[class*=navbar-ct] .show .dropdown-toggle.btn-fill.btn-default{border-color:#fff;opacity:1;filter:alpha(opacity=100)}.navbar-transparent .dropdown-menu .divider{background-color:hsla(0,0%,100%,.2)}.navbar-default{background-color:hsla(0,0%,100%,.96);border-bottom:1px solid rgba(0,0,0,.1)}.navbar-default .navbar-nav .nav-item .nav-link:not(.btn){color:#9a9a9a}.navbar-default .navbar-nav .active .nav-link,.navbar-default .navbar-nav .active .nav-link:not(.btn):focus,.navbar-default .navbar-nav .active .nav-link:not(.btn):hover,.navbar-default .navbar-nav .nav-item .nav-link:not(.btn):focus,.navbar-default .navbar-nav .nav-item .nav-link:not(.btn):hover{background-color:transparent;border-radius:3px;color:#1dc7ea;opacity:1;filter:alpha(opacity=100)}.navbar-default .navbar-nav .show .nav-link,.navbar-default .navbar-nav .show .nav-link:focus,.navbar-default .navbar-nav .show .nav-link:hover{background-color:transparent;color:#1dc7ea}.navbar-default .navbar-nav .navbar-toggle:focus,.navbar-default .navbar-nav .navbar-toggle:hover{background-color:transparent}.navbar-default:not(.navbar-transparent) .btn-default:hover{color:#1dc7ea;border-color:#1dc7ea}.navbar-default:not(.navbar-transparent) .btn-neutral,.navbar-default:not(.navbar-transparent) .btn-neutral:active,.navbar-default:not(.navbar-transparent) .btn-neutral:hover{color:#9a9a9a}.navbar-icons.navbar .navbar-brand{margin-top:12px;margin-bottom:12px}.navbar-icons .navbar-nav .nav-item .nav-link{text-align:center;padding:6px 15px;margin:6px 3px}.navbar-icons .navbar-nav [class^=pe]{font-size:30px;position:relative}.navbar-icons .navbar-nav p{margin:3px 0 0}.navbar-form{-webkit-box-shadow:none;box-shadow:none}.navbar-form .form-control{height:22px;font-size:16px;line-height:1.5;color:#e3e3e3}.navbar-transparent .navbar-form .form-control,[class*=navbar-ct] .navbar-form .form-control{color:#fff;border:0;border-bottom:1px solid hsla(0,0%,100%,.6)}.navbar-ct-blue{background-color:#4091e2}.navbar-ct-azure{background-color:#63d8f1}.navbar-ct-green{background-color:#a1e82c}.navbar-ct-orange{background-color:#ffbc67}.navbar-ct-red{background-color:#fc727a}.navbar-transparent{padding-top:15px;background-color:transparent;border-bottom:1px solid transparent}.navbar-toggle{margin-top:19px;margin-bottom:19px;border:0}.navbar-toggle .icon-bar{background-color:#fff}.navbar-toggle .navbar-collapse,.navbar-toggle .navbar-form{border-color:transparent}.navbar-toggle.navbar-default .navbar-toggle:focus,.navbar-toggle.navbar-default .navbar-toggle:hover{background-color:transparent}.footer{background-color:#fff}.footer .footer-menu{height:41px}.footer nav>ul{list-style:none;margin:0;padding:0;font-weight:400}.footer nav>ul a:not(.btn){color:#9a9a9a;display:block;margin-bottom:3px}.footer nav>ul a:not(.btn):focus,.footer nav>ul a:not(.btn):hover{color:#777}.footer .social-area{padding:15px 0}.footer .social-area h5{padding-bottom:15px}.footer .social-area>a:not(.btn){color:#9a9a9a;display:inline-block;vertical-align:top;padding:10px 5px;font-size:20px;font-weight:400;line-height:20px;text-align:center}.footer .social-area>a:not(.btn):focus,.footer .social-area>a:not(.btn):hover{color:#777}.footer .copyright{color:#777;padding:10px 15px;margin:10px 3px;line-height:20px;font-size:14px}.footer hr{border-color:#ddd}.footer .title{color:#777}.footer-default{background-color:#f5f5f5}.footer:not(.footer-big) nav>ul{font-size:14px}.footer:not(.footer-big) nav>ul li{margin-left:20px;float:left}.footer:not(.footer-big) nav>ul a{padding:10px 0;margin:10px 10px 10px 0}/*!
Animate.css - http://daneden.me/animate
Licensed under the MIT license - http://opensource.org/licenses/MIT

Copyright (c) 2015 Daniel Eden
*/.animated{-webkit-animation-duration:1s;animation-duration:1s;-webkit-animation-fill-mode:both;animation-fill-mode:both}.animated.infinite{-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite}.animated.hinge{-webkit-animation-duration:2s;animation-duration:2s}.animated.bounceIn,.animated.bounceOut,.animated.flipOutX,.animated.flipOutY{-webkit-animation-duration:.75s;animation-duration:.75s}@-webkit-keyframes shake{0%,to{-webkit-transform:translateZ(0);transform:translateZ(0)}10%,30%,50%,70%,90%{-webkit-transform:translate3d(-10px,0,0);transform:translate3d(-10px,0,0)}20%,40%,60%,80%{-webkit-transform:translate3d(10px,0,0);transform:translate3d(10px,0,0)}}@keyframes shake{0%,to{-webkit-transform:translateZ(0);transform:translateZ(0)}10%,30%,50%,70%,90%{-webkit-transform:translate3d(-10px,0,0);transform:translate3d(-10px,0,0)}20%,40%,60%,80%{-webkit-transform:translate3d(10px,0,0);transform:translate3d(10px,0,0)}}.shake{-webkit-animation-name:shake;animation-name:shake}@-webkit-keyframes fadeInDown{0%{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}to{opacity:1;-webkit-transform:none;transform:none}}@keyframes fadeInDown{0%{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}to{opacity:1;-webkit-transform:none;transform:none}}.fadeInDown{-webkit-animation-name:fadeInDown;animation-name:fadeInDown}@-webkit-keyframes fadeOut{0%{opacity:1}to{opacity:0}}@keyframes fadeOut{0%{opacity:1}to{opacity:0}}.fadeOut{-webkit-animation-name:fadeOut;animation-name:fadeOut}@-webkit-keyframes fadeOutDown{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}}@keyframes fadeOutDown{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}}.fadeOutDown{-webkit-animation-name:fadeOutDown;animation-name:fadeOutDown}@-webkit-keyframes fadeOutUp{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}}@keyframes fadeOutUp{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}}.fadeOutUp{-webkit-animation-name:fadeOutUp;animation-name:fadeOutUp}.ct-label{fill:rgba(0,0,0,.4);color:rgba(0,0,0,.4);font-size:1.3rem;line-height:1}.ct-chart-bar .ct-label,.ct-chart-line .ct-label{display:block;display:-webkit-box;display:-ms-flexbox;display:flex}.ct-label.ct-horizontal.ct-start{-webkit-box-align:flex-end;-ms-flex-align:flex-end;align-items:flex-end}.ct-label.ct-horizontal.ct-end,.ct-label.ct-horizontal.ct-start{-webkit-box-pack:flex-start;-ms-flex-pack:flex-start;justify-content:flex-start;text-align:left;text-anchor:start}.ct-label.ct-horizontal.ct-end{-webkit-box-align:flex-start;-ms-flex-align:flex-start;align-items:flex-start}.ct-label.ct-vertical.ct-start{-webkit-box-align:flex-end;-ms-flex-align:flex-end;align-items:flex-end;-webkit-box-pack:flex-end;-ms-flex-pack:flex-end;justify-content:flex-end;text-align:right;text-anchor:end}.ct-label.ct-vertical.ct-end{-webkit-box-pack:flex-start;-ms-flex-pack:flex-start;justify-content:flex-start;text-align:left}.ct-chart-bar .ct-label.ct-horizontal.ct-start,.ct-label.ct-vertical.ct-end{-webkit-box-align:flex-end;-ms-flex-align:flex-end;align-items:flex-end;text-anchor:start}.ct-chart-bar .ct-label.ct-horizontal.ct-end,.ct-chart-bar .ct-label.ct-horizontal.ct-start{-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;text-align:center}.ct-chart-bar .ct-label.ct-horizontal.ct-end{-webkit-box-align:flex-start;-ms-flex-align:flex-start;align-items:flex-start;text-anchor:start}.ct-chart-bar.ct-horizontal-bars .ct-label.ct-horizontal.ct-start{-webkit-box-align:flex-end;-ms-flex-align:flex-end;align-items:flex-end;-webkit-box-pack:flex-start;-ms-flex-pack:flex-start;justify-content:flex-start;text-align:left;text-anchor:start}.ct-chart-bar.ct-horizontal-bars .ct-label.ct-horizontal.ct-end{-webkit-box-align:flex-start;-ms-flex-align:flex-start;align-items:flex-start;-webkit-box-pack:flex-start;-ms-flex-pack:flex-start;justify-content:flex-start;text-align:left;text-anchor:start}.ct-chart-bar.ct-horizontal-bars .ct-label.ct-vertical.ct-start{-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:flex-end;-ms-flex-pack:flex-end;justify-content:flex-end;text-align:right;text-anchor:end}.ct-chart-bar.ct-horizontal-bars .ct-label.ct-vertical.ct-end{-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:flex-start;-ms-flex-pack:flex-start;justify-content:flex-start;text-align:left;text-anchor:end}.ct-grid{stroke:rgba(0,0,0,.2);stroke-width:1px;stroke-dasharray:2px}.ct-point{stroke-width:8px;stroke-linecap:round}.ct-line{fill:none;stroke-width:3px}.ct-area{stroke:none;fill-opacity:.8}.ct-bar{fill:none;stroke-width:10px}.ct-slice-donut{fill:none;stroke-width:60px}.ct-series-a .ct-bar,.ct-series-a .ct-line,.ct-series-a .ct-point,.ct-series-a .ct-slice-donut{stroke:#1dc7ea}.ct-series-a .ct-area,.ct-series-a .ct-slice-pie{fill:#1dc7ea}.ct-series-b .ct-bar,.ct-series-b .ct-line,.ct-series-b .ct-point,.ct-series-b .ct-slice-donut{stroke:#fb404b}.ct-series-b .ct-area,.ct-series-b .ct-slice-pie{fill:#fb404b}.ct-series-c .ct-bar,.ct-series-c .ct-line,.ct-series-c .ct-point,.ct-series-c .ct-slice-donut{stroke:#ffa534}.ct-series-c .ct-area,.ct-series-c .ct-slice-pie{fill:#ffa534}.ct-series-d .ct-bar,.ct-series-d .ct-line,.ct-series-d .ct-point,.ct-series-d .ct-slice-donut{stroke:#9368e9}.ct-series-d .ct-area,.ct-series-d .ct-slice-pie{fill:#9368e9}.ct-series-e .ct-bar,.ct-series-e .ct-line,.ct-series-e .ct-point,.ct-series-e .ct-slice-donut{stroke:#87cb16}.ct-series-e .ct-area,.ct-series-e .ct-slice-pie{fill:#87cb16}.ct-series-f .ct-bar,.ct-series-f .ct-line,.ct-series-f .ct-point,.ct-series-f .ct-slice-donut{stroke:#1f77d0}.ct-series-f .ct-area,.ct-series-f .ct-slice-pie{fill:#1f77d0}.ct-series-g .ct-bar,.ct-series-g .ct-line,.ct-series-g .ct-point,.ct-series-g .ct-slice-donut{stroke:#5e5e5e}.ct-series-g .ct-area,.ct-series-g .ct-slice-pie{fill:#5e5e5e}.ct-series-h .ct-bar,.ct-series-h .ct-line,.ct-series-h .ct-point,.ct-series-h .ct-slice-donut{stroke:#dd4b39}.ct-series-h .ct-area,.ct-series-h .ct-slice-pie{fill:#dd4b39}.ct-series-i .ct-bar,.ct-series-i .ct-line,.ct-series-i .ct-point,.ct-series-i .ct-slice-donut{stroke:#35465c}.ct-series-i .ct-area,.ct-series-i .ct-slice-pie{fill:#35465c}.ct-series-j .ct-bar,.ct-series-j .ct-line,.ct-series-j .ct-point,.ct-series-j .ct-slice-donut{stroke:#e52d27}.ct-series-j .ct-area,.ct-series-j .ct-slice-pie{fill:#e52d27}.ct-series-k .ct-bar,.ct-series-k .ct-line,.ct-series-k .ct-point,.ct-series-k .ct-slice-donut{stroke:#55acee}.ct-series-k .ct-area,.ct-series-k .ct-slice-pie{fill:#55acee}.ct-series-l .ct-bar,.ct-series-l .ct-line,.ct-series-l .ct-point,.ct-series-l .ct-slice-donut{stroke:#cc2127}.ct-series-l .ct-area,.ct-series-l .ct-slice-pie{fill:#cc2127}.ct-series-m .ct-bar,.ct-series-m .ct-line,.ct-series-m .ct-point,.ct-series-m .ct-slice-donut{stroke:#1769ff}.ct-series-m .ct-area,.ct-series-m .ct-slice-pie{fill:#1769ff}.ct-series-n .ct-bar,.ct-series-n .ct-line,.ct-series-n .ct-point,.ct-series-n .ct-slice-donut{stroke:#6188e2}.ct-series-n .ct-area,.ct-series-n .ct-slice-pie{fill:#6188e2}.ct-series-o .ct-bar,.ct-series-o .ct-line,.ct-series-o .ct-point,.ct-series-o .ct-slice-donut{stroke:#a748ca}.ct-series-o .ct-area,.ct-series-o .ct-slice-pie{fill:#a748ca}.ct-square{display:block;position:relative;width:100%}.ct-square:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:100%}.ct-square:after{content:"";display:table;clear:both}.ct-square>svg{display:block;position:absolute;top:0;left:0}.ct-minor-second{display:block;position:relative;width:100%}.ct-minor-second:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:93.75%}.ct-minor-second:after{content:"";display:table;clear:both}.ct-minor-second>svg{display:block;position:absolute;top:0;left:0}.ct-major-second{display:block;position:relative;width:100%}.ct-major-second:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:88.88889%}.ct-major-second:after{content:"";display:table;clear:both}.ct-major-second>svg{display:block;position:absolute;top:0;left:0}.ct-minor-third{display:block;position:relative;width:100%}.ct-minor-third:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:83.33333%}.ct-minor-third:after{content:"";display:table;clear:both}.ct-minor-third>svg{display:block;position:absolute;top:0;left:0}.ct-major-third{display:block;position:relative;width:100%}.ct-major-third:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:80%}.ct-major-third:after{content:"";display:table;clear:both}.ct-major-third>svg{display:block;position:absolute;top:0;left:0}.ct-perfect-fourth{display:block;position:relative;width:100%}.ct-perfect-fourth:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:75%}.ct-perfect-fourth:after{content:"";display:table;clear:both}.ct-perfect-fourth>svg{display:block;position:absolute;top:0;left:0}.ct-perfect-fifth{display:block;position:relative;width:100%}.ct-perfect-fifth:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:66.66667%}.ct-perfect-fifth:after{content:"";display:table;clear:both}.ct-perfect-fifth>svg{display:block;position:absolute;top:0;left:0}.ct-minor-sixth{display:block;position:relative;width:100%}.ct-minor-sixth:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:62.5%}.ct-minor-sixth:after{content:"";display:table;clear:both}.ct-minor-sixth>svg{display:block;position:absolute;top:0;left:0}.ct-golden-section{display:block;position:relative;width:100%}.ct-golden-section:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:61.8047%}.ct-golden-section:after{content:"";display:table;clear:both}.ct-golden-section>svg{display:block;position:absolute;top:0;left:0}.ct-major-sixth{display:block;position:relative;width:100%}.ct-major-sixth:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:60%}.ct-major-sixth:after{content:"";display:table;clear:both}.ct-major-sixth>svg{display:block;position:absolute;top:0;left:0}.ct-minor-seventh{display:block;position:relative;width:100%}.ct-minor-seventh:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:56.25%}.ct-minor-seventh:after{content:"";display:table;clear:both}.ct-minor-seventh>svg{display:block;position:absolute;top:0;left:0}.ct-major-seventh{display:block;position:relative;width:100%}.ct-major-seventh:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:53.33333%}.ct-major-seventh:after{content:"";display:table;clear:both}.ct-major-seventh>svg{display:block;position:absolute;top:0;left:0}.ct-octave{display:block;position:relative;width:100%}.ct-octave:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:50%}.ct-octave:after{content:"";display:table;clear:both}.ct-octave>svg{display:block;position:absolute;top:0;left:0}.ct-major-tenth{display:block;position:relative;width:100%}.ct-major-tenth:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:40%}.ct-major-tenth:after{content:"";display:table;clear:both}.ct-major-tenth>svg{display:block;position:absolute;top:0;left:0}.ct-major-eleventh{display:block;position:relative;width:100%}.ct-major-eleventh:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:37.5%}.ct-major-eleventh:after{content:"";display:table;clear:both}.ct-major-eleventh>svg{display:block;position:absolute;top:0;left:0}.ct-major-twelfth{display:block;position:relative;width:100%}.ct-major-twelfth:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:33.33333%}.ct-major-twelfth:after{content:"";display:table;clear:both}.ct-major-twelfth>svg{display:block;position:absolute;top:0;left:0}.ct-double-octave{display:block;position:relative;width:100%}.ct-double-octave:before{display:block;float:left;content:"";width:0;height:0;padding-bottom:25%}.ct-double-octave:after{content:"";display:table;clear:both}.ct-double-octave>svg{display:block;position:absolute;top:0;left:0}@media (min-width:992px){.navbar-form{margin-top:21px;margin-bottom:21px;padding-left:5px;padding-right:5px}.dropdown .dropdown-menu,.navbar-nav .nav-item .dropdown-menu{-webkit-transform:scale(0);transform:scale(0);-webkit-transition:all .37s cubic-bezier(.34,1.61,.7,1);transition:all .37s cubic-bezier(.34,1.61,.7,1)}.dropdown.show .dropdown-menu,.navbar-nav .nav-item.show .dropdown-menu{-webkit-transform:scale(1);transform:scale(1);-webkit-transform-origin:29px -50px;transform-origin:29px -50px}.close-layer,.nav-mobile-menu{display:none!important}.footer{height:60px}.footer .footer-menu{float:left}.footer .copyright{float:right}.navbar-nav .nav-item .dropdown-menu:before{border-bottom:11px solid rgba(0,0,0,.2);top:-11px}.navbar-nav .nav-item .dropdown-menu:after,.navbar-nav .nav-item .dropdown-menu:before{border-left:11px solid transparent;border-right:11px solid transparent;content:"";display:inline-block;position:absolute;left:12px}.navbar-nav .nav-item .dropdown-menu:after{border-bottom:11px solid #fff;top:-10px}.navbar-nav.navbar-right .nav-item .dropdown-menu:after,.navbar-nav.navbar-right .nav-item .dropdown-menu:before{left:auto;right:12px}.footer:not(.footer-big) nav>ul li:first-child{margin-left:0}.card form [class*=col-]{padding:6px}.card form [class*=col-]:first-child{padding-left:15px}.card form [class*=col-]:last-child{padding-right:15px}}@media (max-width:991px){.sidebar{right:0!important;left:auto;position:fixed;-webkit-transform:translate3d(262px,0,0);transform:translate3d(262px,0,0)!important}.nav-open .main-panel,.sidebar{-webkit-transition:all .5s cubic-bezier(.685,.0473,.346,1);transition:all .5s cubic-bezier(.685,.0473,.346,1)}.nav-open .main-panel{position:absolute;left:0;-webkit-transform:translate3d(-250px,0,0);transform:translate3d(-250px,0,0)!important}.nav-open .sidebar{-webkit-transform:translate3d(10px,0,0);transform:translate3d(10px,0,0)!important}.main-panel,.nav-open .sidebar{-webkit-transition:all .5s cubic-bezier(.685,.0473,.346,1);transition:all .5s cubic-bezier(.685,.0473,.346,1)}.main-panel{-webkit-transform:translateZ(0);transform:translateZ(0)!important}.nav-item.active-pro{position:relative!important}.nav-mobile-menu{border-bottom:1px solid hsla(0,0%,100%,.2);margin-bottom:15px;padding-bottom:15px;padding-top:5px}.nav-mobile-menu .dropdown .dropdown-menu{position:static!important;float:none;width:auto;color:#fff;margin-top:0;background-color:transparent;border:0;-webkit-box-shadow:none;box-shadow:none;-webkit-transition:all .5s cubic-bezier(.685,.0473,.346,1);transition:all .5s cubic-bezier(.685,.0473,.346,1)}.nav-mobile-menu .dropdown .dropdown-menu .dropdown-item{margin:5px 15px 0 40px;border-radius:4px;color:#fff;opacity:.86;padding:8px 50px}.nav-mobile-menu .dropdown .dropdown-menu .dropdown-item:hover{background-color:hsla(0,0%,100%,.23)}.nav-mobile-menu .nav-item .nav-link span{display:inline-block!important}.nav-mobile-menu .nav-item .nav-link .no-icon{padding-left:50px}.main-panel{width:100%}.navbar-transparent{padding-top:15px;background-color:rgba(0,0,0,.45)}body{position:relative}.wrapper{left:0;background-color:#fff}.navbar{padding-right:30px;padding-left:30px}.navbar-nav .nav-item{float:none;position:relative;display:block}body>.navbar-collapse{position:fixed;display:block;top:0;height:100%;right:0;left:auto;z-index:1032;visibility:visible;background-color:#999;overflow-y:visible;border-top:none;text-align:left;padding:0;-webkit-transform:translate3d(260px,0,0);transform:translate3d(260px,0,0);-webkit-transition:all .33s cubic-bezier(.685,.0473,.346,1);transition:all .33s cubic-bezier(.685,.0473,.346,1)}body>.navbar-collapse>ul{position:relative;z-index:4;overflow-y:scroll;height:calc(100vh - 61px);width:100%}body>.navbar-collapse:before{top:0;left:0;height:100%;width:100%;position:absolute;background-color:#282828;display:block;content:"";z-index:1}body>.navbar-collapse .logo{position:relative;z-index:4}body>.navbar-collapse .nav li>a{padding:10px 15px}.nav-show .navbar-collapse{-webkit-transform:translateZ(0);transform:translateZ(0)}.nav-show .navbar .container{left:-250px}.nav-show .wrapper{left:0;-webkit-transform:translate3d(-260px,0,0);transform:translate3d(-260px,0,0)}.navbar-toggle .icon-bar{display:block;position:relative;background:#fff;width:24px;height:2px;border-radius:1px;margin:0 auto}.navbar-header .navbar-toggle{margin:10px 15px 10px 0;width:40px;height:40px}.bar1,.bar2,.bar3{outline:1px solid transparent}.bar1{top:0;-webkit-animation:topbar-back .5s linear 0s;animation:topbar-back .5s 0s;-webkit-animation-fill-mode:forwards;animation-fill-mode:forwards}.bar2{opacity:1}.bar3{bottom:0;-webkit-animation:bottombar-back .5s linear 0s;animation:bottombar-back .5s 0s;-webkit-animation-fill-mode:forwards;animation-fill-mode:forwards}.toggled .bar1{top:6px;-webkit-animation:topbar-x .5s linear 0s;animation:topbar-x .5s 0s;-webkit-animation-fill-mode:forwards;animation-fill-mode:forwards}.toggled .bar2{opacity:0}.toggled .bar3{bottom:6px;-webkit-animation:bottombar-x .5s linear 0s;animation:bottombar-x .5s 0s;-webkit-animation-fill-mode:forwards;animation-fill-mode:forwards}@keyframes topbar-x{0%{top:0;-webkit-transform:rotate(0deg);transform:rotate(0deg)}45%{top:6px;-webkit-transform:rotate(145deg);transform:rotate(145deg)}75%{-webkit-transform:rotate(130deg);transform:rotate(130deg)}to{-webkit-transform:rotate(135deg);transform:rotate(135deg)}}@-webkit-keyframes topbar-x{0%{top:0;-webkit-transform:rotate(0deg)}45%{top:6px;-webkit-transform:rotate(145deg)}75%{-webkit-transform:rotate(130deg)}to{-webkit-transform:rotate(135deg)}}@keyframes topbar-back{0%{top:6px;-webkit-transform:rotate(135deg);transform:rotate(135deg)}45%{-webkit-transform:rotate(-10deg);transform:rotate(-10deg)}75%{-webkit-transform:rotate(5deg);transform:rotate(5deg)}to{top:0;-webkit-transform:rotate(0);transform:rotate(0)}}@-webkit-keyframes topbar-back{0%{top:6px;-webkit-transform:rotate(135deg)}45%{-webkit-transform:rotate(-10deg)}75%{-webkit-transform:rotate(5deg)}to{top:0;-webkit-transform:rotate(0)}}@keyframes bottombar-x{0%{bottom:0;-webkit-transform:rotate(0deg);transform:rotate(0deg)}45%{bottom:6px;-webkit-transform:rotate(-145deg);transform:rotate(-145deg)}75%{-webkit-transform:rotate(-130deg);transform:rotate(-130deg)}to{-webkit-transform:rotate(-135deg);transform:rotate(-135deg)}}@-webkit-keyframes bottombar-x{0%{bottom:0;-webkit-transform:rotate(0deg)}45%{bottom:6px;-webkit-transform:rotate(-145deg)}75%{-webkit-transform:rotate(-130deg)}to{-webkit-transform:rotate(-135deg)}}@keyframes bottombar-back{0%{bottom:6px;-webkit-transform:rotate(-135deg);transform:rotate(-135deg)}45%{-webkit-transform:rotate(10deg);transform:rotate(10deg)}75%{-webkit-transform:rotate(-5deg);transform:rotate(-5deg)}to{bottom:0;-webkit-transform:rotate(0);transform:rotate(0)}}@-webkit-keyframes bottombar-back{0%{bottom:6px;-webkit-transform:rotate(-135deg)}45%{-webkit-transform:rotate(10deg)}75%{-webkit-transform:rotate(-5deg)}to{bottom:0;-webkit-transform:rotate(0)}}@-webkit-keyframes fadeIn{0%{opacity:0}to{opacity:1}}@keyframes fadeIn{0%{opacity:0}to{opacity:1}}.dropdown-menu .divider{background-color:hsla(0,0%,89.8%,.15)}.navbar-nav{margin:1px 0}.navbar-nav .show .dropdown-menu .nav-item .nav-link{padding:10px 15px 10px 60px}[class*=navbar-] .navbar-nav .active>a,[class*=navbar-] .navbar-nav .active>a:focus,[class*=navbar-] .navbar-nav .active>a:hover,[class*=navbar-] .navbar-nav .show .dropdown-menu>li>a,[class*=navbar-] .navbar-nav .show .dropdown-menu>li>a:active,[class*=navbar-] .navbar-nav .show .dropdown-menu>li>a:focus,[class*=navbar-] .navbar-nav .show .dropdown-menu>li>a:hover,[class*=navbar-] .navbar-nav>li>a,[class*=navbar-] .navbar-nav>li>a:focus,[class*=navbar-] .navbar-nav>li>a:hover{color:#fff}[class*=navbar-] .navbar-nav>li>a,[class*=navbar-] .navbar-nav>li>a:focus,[class*=navbar-] .navbar-nav>li>a:hover{opacity:.7;background-color:transparent;outline:none}[class*=navbar-] .navbar-nav .show .dropdown-menu>li>a:focus,[class*=navbar-] .navbar-nav .show .dropdown-menu>li>a:hover{background-color:hsla(0,0%,100%,.1)}[class*=navbar-] .navbar-nav.navbar-nav .show .dropdown-menu>li>a:active{opacity:1}[class*=navbar-] .navbar-nav .dropdown>a:active .caret,[class*=navbar-] .navbar-nav .dropdown>a:hover .caret{border-bottom-color:#fff;border-top-color:#fff}.dropdown-menu{display:none}.navbar-fixed-top{-webkit-backface-visibility:hidden}#bodyClick{height:100%;width:100%;position:fixed;opacity:0;top:0;left:auto;right:250px;content:"";z-index:9999;overflow-x:hidden}.social-line .btn,.subscribe-line .form-control{margin:0 0 10px 0}.social-line.pull-right{float:none}.social-area.pull-right{float:none!important}.form-control+.form-control-feedback{margin-top:-8px}.navbar-toggle:focus,.navbar-toggle:hover{background-color:transparent!important}.btn.dropdown-toggle{margin-bottom:0}.media-post .author{width:20%;float:none!important;display:block;margin:0 auto 10px}.media-post .media-body{width:100%}.navbar-collapse.collapse{height:100%!important}.navbar-collapse.collapse.in{display:block}.navbar-header .collapse,.navbar-toggle{display:block!important}.navbar-header{float:none}.navbar-nav .show .dropdown-menu{position:static;float:none;width:auto;margin-top:0;background-color:transparent;border:0;-webkit-box-shadow:none;box-shadow:none}.navbar-collapse .navbar-nav p{line-height:40px!important;margin:0}.navbar-collapse [class^=pe-7s-]{float:left;font-size:20px;margin-right:10px}}@media (min-width:992px){.table-full-width{margin-left:-15px;margin-right:-15px}.table-responsive{overflow:visible}}@media (max-width:991px){.table-responsive{width:100%;margin-bottom:15px;overflow-x:scroll;overflow-y:hidden;-ms-overflow-style:-ms-autohiding-scrollbar;-webkit-overflow-scrolling:touch}}.bootstrap-switch{display:inline-block;direction:ltr;cursor:pointer;border-radius:30px;border:0;position:relative;text-align:left;overflow:hidden;margin-bottom:5px;margin-left:66px;line-height:8px;width:61px!important;height:26px;outline:none;z-index:0;margin-right:1px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;vertical-align:middle;-webkit-transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out;-webkit-transition:border-color .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;transition:border-color .15s ease-in-out,-webkit-box-shadow .15s ease-in-out;transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out;transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out,-webkit-box-shadow .15s ease-in-out}.bootstrap-switch .bootstrap-switch-container{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;top:0;height:26px;border-radius:4px;-webkit-transform:translateZ(0);transform:translateZ(0);width:100px!important}.bootstrap-switch .bootstrap-switch-handle-off,.bootstrap-switch .bootstrap-switch-handle-on,.bootstrap-switch .bootstrap-switch-label{-webkit-box-sizing:border-box;box-sizing:border-box;cursor:pointer;display:inline-block!important;height:100%;color:#fff;padding:6px 10px;font-size:11px;text-indent:-5px;line-height:15px;-webkit-transition:.25s ease-out;transition:.25s ease-out}.bootstrap-switch .bootstrap-switch-handle-off i,.bootstrap-switch .bootstrap-switch-handle-on i,.bootstrap-switch .bootstrap-switch-label i{font-size:12px;line-height:14px}.bootstrap-switch .bootstrap-switch-handle-off,.bootstrap-switch .bootstrap-switch-handle-on{text-align:center;z-index:1;float:left;width:50%!important;background-color:#1dc7ea}.bootstrap-switch .bootstrap-switch-label{text-align:center;z-index:100;color:#333;background:#fff;width:22px!important;height:22px;margin:2px -11px;border-radius:12px;position:relative;float:left;padding:0;background-color:#fff;-webkit-box-shadow:0 1px 1px #fff inset,0 1px 1px rgba(0,0,0,.25);box-shadow:inset 0 1px 1px #fff,0 1px 1px rgba(0,0,0,.25)}.bootstrap-switch .bootstrap-switch-handle-on{border-bottom-left-radius:3px;border-top-left-radius:3px}.bootstrap-switch .bootstrap-switch-handle-off{text-indent:6px}.bootstrap-switch input[type=checkbox],.bootstrap-switch input[type=radio]{position:absolute!important;top:0;left:0;opacity:0;filter:alpha(opacity=0);z-index:-1}.bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container{-webkit-transition:margin-left .5s;transition:margin-left .5s}.bootstrap-switch.bootstrap-switch-on .bootstrap-switch-container{margin-left:-2px!important}.bootstrap-switch.bootstrap-switch-off .bootstrap-switch-container{margin-left:-37px!important}.bootstrap-switch.bootstrap-switch-on:hover .bootstrap-switch-label{width:26px!important;margin:2px -15px}.bootstrap-switch.bootstrap-switch-off:hover .bootstrap-switch-label{width:26px!important;margin:2px -15px -13px -11px}@media (max-width:767px){.btn{display:block!important;width:100%;margin:3px 0}.clearfix .pull-left,.clearfix .pull-right{float:None}}.tim-row{margin-bottom:20px}.tim-white-buttons{background-color:#777}.typography-line{padding-left:15%;margin-bottom:35px;position:relative;display:block;width:100%}.typography-line span{bottom:10px;color:#9a9a9a;display:block;font-weight:400;font-size:14px;line-height:13px;left:5px;position:absolute;width:260px;text-transform:none}.tim-row{padding-top:60px}.tim-row h3{margin-top:0}#navbar-full .navbar{border-radius:0!important;margin-bottom:15px;z-index:2}#map{position:relative;width:100%;height:100%}.fixed-plugin .badge,.fixed-plugin li>a{transition:all .34s;-webkit-transition:all .34s;-moz-transition:all .34s}.fixed-plugin{position:fixed;top:200px;right:0;width:64px;background:rgba(0,0,0,.3);z-index:1031;border-radius:8px 0 0 8px;text-align:center}.fixed-plugin .fa-cog{color:#fff;padding:10px;border-radius:0 0 6px 6px;width:auto}.fixed-plugin .dropdown-menu{right:80px;left:auto;width:290px;border-radius:.1875rem;padding:0 10px}.fixed-plugin .dropdown-menu:after,.fixed-plugin .dropdown-menu:before{right:10px;margin-left:auto;left:auto}.fixed-plugin .fa-circle-thin{color:#fff}.fixed-plugin .active .fa-circle-thin{color:#0bf}.fixed-plugin .dropdown-menu>.active>a,.fixed-plugin .dropdown-menu>.active>a:focus,.fixed-plugin .dropdown-menu>.active>a:hover{color:#777;text-align:center}.fixed-plugin img{border-radius:0;width:100%;height:100px;margin:0 auto}.fixed-plugin .dropdown-menu li>a:focus,.fixed-plugin .dropdown-menu li>a:hover{-webkit-box-shadow:none;box-shadow:none}.fixed-plugin .badge{border:3px solid #fff;border-radius:50%;cursor:pointer;display:inline-block;height:23px;margin-right:5px;position:relative;width:23px}.fixed-plugin .badge.active,.fixed-plugin .badge:hover{border-color:#0bf}.fixed-plugin .badge-black{background-color:#777}.fixed-plugin .badge-azure{background-color:#2ca8ff}.fixed-plugin .badge-green{background-color:#18ce0f}.fixed-plugin .badge-orange{background-color:#f96332}.fixed-plugin .badge-yellow{background-color:#ffb236}.fixed-plugin .badge-red{background-color:#ff3636}.fixed-plugin .badge-purple{background-color:#9368e9}.fixed-plugin h5{font-size:14px;margin:10px}.fixed-plugin .dropdown-menu li{display:block;padding:18px 2px;width:25%;float:left}.fixed-plugin li.adjustments-line,.fixed-plugin li.button-container,.fixed-plugin li.header-title{width:100%;height:50px;min-height:inherit}.fixed-plugin li.button-container{height:auto}.fixed-plugin li.button-container div{margin-bottom:5px}.fixed-plugin #sharrreTitle{text-align:center;padding:10px 0;height:50px}.fixed-plugin li.header-title{height:30px;line-height:25px;font-size:12px;font-weight:600;text-transform:uppercase}.fixed-plugin .adjustments-line p{float:left;display:inline-block;margin-bottom:0;font-size:1em;color:#3c4858}.fixed-plugin .adjustments-line a .badge-colors{position:relative;top:-2px}.fixed-plugin .adjustments-line .togglebutton{float:right}.fixed-plugin .adjustments-line .togglebutton .toggle{margin-right:0}.fixed-plugin .dropdown-menu>li.adjustments-line>a{padding-right:0;padding-left:0;border-radius:0;margin:0}.fixed-plugin .dropdown-menu>li>a.img-holder{font-size:16px;text-align:center;border-radius:10px;background-color:#fff;border:3px solid #fff;padding-left:0;padding-right:0;opacity:1;cursor:pointer;display:block;max-height:100px;overflow:hidden;padding:0}.fixed-plugin .dropdown-menu>li>a.switch-trigger:focus,.fixed-plugin .dropdown-menu>li>a.switch-trigger:hover{background-color:transparent}.fixed-plugin .dropdown-menu>li:focus>a.img-holder,.fixed-plugin .dropdown-menu>li:hover>a.img-holder{border-color:rgba(0,187,255,.53)}.fixed-plugin .dropdown-menu>.active>a.img-holder{border-color:#0bf;background-color:#fff}.fixed-plugin .dropdown-menu>li>a img{margin-top:auto}.fixed-plugin .btn-social{width:50%;display:block;width:48%;float:left;font-weight:600}.fixed-plugin .btn-social i{margin-right:5px}.fixed-plugin .btn-social:first-child{margin-right:2%}.fixed-plugin .adjustments-line a,.fixed-plugin .adjustments-line a:focus,.fixed-plugin .adjustments-line a:hover{color:transparent}.fixed-plugin .dropdown .dropdown-menu{-webkit-transform:translateY(-15%);transform:translateY(-15%);top:27px;opacity:0;-webkit-transform-origin:0 0;transform-origin:0 0}.fixed-plugin .dropdown.show .dropdown-menu{opacity:1;-webkit-transform:translateY(-13%);transform:translateY(-13%);-webkit-transform-origin:0 0;transform-origin:0 0}.fixed-plugin .dropdown-menu:after,.fixed-plugin .dropdown-menu:before{content:"";display:inline-block;position:absolute;top:65px;width:16px;transform:translateY(-50%);-webkit-transform:translateY(-50%);-moz-transform:translateY(-50%)}.fixed-plugin .dropdown-menu:before{border-bottom:16px solid transparent;border-left:16px solid rgba(0,0,0,.2);border-top:16px solid transparent;right:-16px}.fixed-plugin .dropdown-menu:after{border-bottom:16px solid transparent;border-left:16px solid #fff;border-top:16px solid transparent;right:-15px}.wrapper-full-page~.fixed-plugin .dropdown.open .dropdown-menu{-webkit-transform:translateY(-17%);transform:translateY(-17%)}.wrapper-full-page~.fixed-plugin .dropdown .dropdown-menu{-webkit-transform:translateY(-19%);transform:translateY(-19%)}.places-buttons .btn{margin-bottom:30px}.map-container{width:100%;height:100vh;max-height:100vh}#menu-dropdown .navbar{border-radius:3px}#pagination-row .pagination-container{height:100%;max-height:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.all-icons .font-icon-detail{text-align:center;padding:45px 0 30px;border:1px solid #e5e5e5;border-radius:.1875rem;margin:15px 0;min-height:168px}.all-icons [class*=now-ui-icons]{font-size:32px}.all-icons .font-icon-detail p{margin:25px auto 0;width:100%;text-align:center;display:block;color:#b8b8b8;padding:0 10px;font-size:.7142em}#icons-row i.now-ui-icons{font-size:30px}.space{height:130px;display:block}.space-110{height:110px;display:block}.space-50{height:50px;display:block}.space-70{height:70px;display:block}.navigation-example .img-src{background-attachment:scroll}.navigation-example{background-position:50%;background-size:cover;margin-top:0;min-height:740px}#notifications{background-color:#fff;display:block;width:100%;position:relative}.tim-note{text-transform:capitalize}#buttons .btn,#javascriptComponents .btn{margin:0 0 10px}.space-100{height:100px;display:block;width:100%}.be-social{padding-bottom:20px;margin:0 auto 40px}.txt-white{color:#fff}.txt-gray{color:#ddd!important}.parallax{width:100%;height:570px;display:block;background-attachment:fixed;background-repeat:no-repeat;background-size:cover;background-position:50%}.logo-container .logo{overflow:hidden;border-radius:50%;border:1px solid #333;width:50px;float:left}.logo-container .brand{font-size:16px;color:#fff;line-height:18px;float:left;margin-left:10px;margin-top:7px;width:70px;height:40px;text-align:left}.logo-container .brand-material{font-size:18px;margin-top:15px;height:25px;width:auto}.logo-container .logo img{width:100%}.navbar-small .logo-container .brand{color:#333}.fixed-section{top:90px;max-height:80vh;overflow:scroll;position:sticky}.fixed-section ul{padding:0}.fixed-section ul li{list-style:none}.fixed-section li a{font-size:14px;padding:2px;display:block;color:#666}.fixed-section li a.active{color:#0bf}.fixed-section.float{position:fixed;top:100px;width:200px;margin-top:0}.parallax .parallax-image{width:100%;overflow:hidden;position:absolute}.parallax .parallax-image img{width:100%}@media (max-width:768px){.parallax .parallax-image{width:100%;height:640px;overflow:hidden}.parallax .parallax-image img{height:100%;width:auto}}.social-buttons-demo .btn{margin-right:5px;margin-bottom:7px}.img-container{width:100%;overflow:hidden}.img-container img,.lightbox img{width:100%}.lightbox .modal-content{overflow:hidden}.lightbox .modal-body{padding:0}@media screen and (min-width:991px){.lightbox .modal-dialog{width:960px}}@media (max-width:991px){.fixed-section.affix{position:relative;margin-bottom:100px}}@media (max-width:768px){.btn,.btn-morphing{margin-bottom:10px}.parallax .motto{top:170px;margin-top:0;font-size:60px;width:270px}}.logo-container .brand,.logo-container .logo,.presentation .front,.presentation .front .btn,.presentation .front:after{-webkit-transition:all .2s;transition:all .2s}#images h4{margin-bottom:30px}#javascriptComponents{padding-bottom:0}.layers-container{display:block;margin-top:50px;position:relative}.layers-container img{position:absolute;width:100%;height:auto;top:0;left:0;text-align:center}.animate{transition:1.5s ease-in-out;-moz-transition:1.5s ease-in-out;-webkit-transition:1.5s ease-in-out}.navbar-transparent.navbar-small .logo-container .brand{color:#fff}.navbar-default.navbar-small .logo-container .brand{color:#333}.sharing-area{margin-top:80px}.sharing-area .btn{margin:15px 4px 0}.section-notifications,.section-thin{padding:0}.section-navbars{padding-top:0}#navbar .navbar{margin-bottom:20px}#menu-dropdown .navbar-toggler,#navbar .navbar-toggler{pointer-events:none}.section-tabs{background:#eee}.section-pagination{padding-bottom:0}.section-download{padding-top:130px}.section-download .description{margin-bottom:60px}.section-download h4{margin-bottom:25px}.section-examples a{text-decoration:none}.section-examples a+a,.section-examples h5{margin-top:30px}.components-page .wrapper>.header,.tutorial-page .wrapper>.header{height:500px;padding-top:128px;background-size:cover;background-position:50%}.components-page .title,.tutorial-page .title{color:#fff}.brand .h1-seo{font-size:2.8em;text-transform:uppercase;font-weight:300}.brand .n-logo{max-width:100px;margin-bottom:40px}.invision-logo{max-width:70px;top:-2px;position:relative}.creative-tim-logo{max-width:140px;top:-2px;position:relative}.section-javascript .title{margin-bottom:0}.navbar .switch-background{display:block}.navbar-transparent .switch-background{display:none}.section-signup .col .btn{margin-top:30px}#buttons-row .btn{margin-bottom:10px}.section-navbars .navbar-collapse{display:none}.section-basic{padding-top:0}.section-images{padding-bottom:0}.documentation .dropdown .dropdown-menu{-webkit-transform:translateZ(0)!important;transform:translateZ(0)!important}.documentation .dropdown .dropdown-menu.show{-webkit-transform:translate3d(0,39px,0)!important;transform:translate3d(0,39px,0)!important}.card-title{margin-top:0}.websites-cards .card{height:100%}.nav-mobile-menu .nav-item .nav-link .no-icon{padding-left:0}.fade-enter-active,.fade-leave-active{-webkit-transition:opacity .1s;transition:opacity .1s}.fade-enter,.fade-leave-to{opacity:0}