self.__precacheManifest = [
  {
    "revision": "4dc358b06b293ba6c392",
    "url": "/static/unicms_editorial_board_vue/css/app.ff4279f4.css"
  },
  {
    "revision": "4dc358b06b293ba6c392",
    "url": "/static/unicms_editorial_board_vue/js/app.0ac957a1.js"
  },
  {
    "revision": "10975f810c997e9e6aa8",
    "url": "/static/unicms_editorial_board_vue/css/chunk-vendors.7c366b9d.css"
  },
  {
    "revision": "10975f810c997e9e6aa8",
    "url": "/static/unicms_editorial_board_vue/js/chunk-vendors.20e928aa.js"
  },
  {
    "revision": "c6dea38281c91398c2b5553ad1e2370a",
    "url": "/static/unicms_editorial_board_vue/index.html"
  },
  {
    "revision": "d41d8cd98f00b204e9800998ecf8427e",
    "url": "/static/unicms_editorial_board_vue/.gitkeep"
  },
  {
    "revision": "996d8248f580f8e26e6c45c67da9b5a6",
    "url": "/static/unicms_editorial_board_vue/favicon.png"
  },
  {
    "revision": "a9615bac158705203261e8348f574cc8",
    "url": "/static/unicms_editorial_board_vue/img/default-avatar.png"
  },
  {
    "revision": "be74132f42ae1d3502f9a9b9fff68ac1",
    "url": "/static/unicms_editorial_board_vue/Dashboard.PNG"
  },
  {
    "revision": "a9615bac158705203261e8348f574cc8",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-0.jpg"
  },
  {
    "revision": "99e58416b89637502b40ac8350eed85a",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-1.jpg"
  },
  {
    "revision": "0e953b1ea6d6e3addd7210e9c7c420a7",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-2.jpg"
  },
  {
    "revision": "ce7a6b79aa55041f7ae36f6ce22231fe",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-3.jpg"
  },
  {
    "revision": "0b68eb8f1cde1fc9987a9196df05b96a",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-4.jpg"
  },
  {
    "revision": "4ab22eca4053c14a34e4bdb6390deae9",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-5.jpg"
  },
  {
    "revision": "4b87e628f4ef9988718860890b2a682f",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-6.jpg"
  },
  {
    "revision": "bf1684a30a86ba1b222aab3acff16356",
    "url": "/static/unicms_editorial_board_vue/img/faces/face-7.jpg"
  },
  {
    "revision": "43b98081492ac3bcb4a1fac6cf709403",
    "url": "/static/unicms_editorial_board_vue/img/faces/tim_vector.jpe"
  },
  {
    "revision": "996d8248f580f8e26e6c45c67da9b5a6",
    "url": "/static/unicms_editorial_board_vue/img/favicon.png"
  },
  {
    "revision": "0a337c37f03c0462996b7b03758fa72b",
    "url": "/static/unicms_editorial_board_vue/img/loading-bubbles.svg"
  },
  {
    "revision": "d27fbc90c2e644dfdc9765640dc713b9",
    "url": "/static/unicms_editorial_board_vue/img/mask.png"
  },
  {
    "revision": "f575a04ebbb31b5798a4c54783e745a2",
    "url": "/static/unicms_editorial_board_vue/img/new_logo.png"
  },
  {
    "revision": "7a4ce7cc040fc1cb8176cde106e9232f",
    "url": "/static/unicms_editorial_board_vue/img/sidebar-2.jpg"
  },
  {
    "revision": "6be21e8a1b7d63048728851c6003e189",
    "url": "/static/unicms_editorial_board_vue/img/sidebar-1.jpg"
  },
  {
    "revision": "cd253e23ed052deeb80b42d2ed772183",
    "url": "/static/unicms_editorial_board_vue/img/sidebar-3.jpg"
  },
  {
    "revision": "897b4cf909210560a84398d36da51983",
    "url": "/static/unicms_editorial_board_vue/img/sidebar-4.jpg"
  },
  {
    "revision": "44bf13a71a4db6e15913fe8af9296711",
    "url": "/static/unicms_editorial_board_vue/img/tim_80x80.png"
  },
  {
    "revision": "c2a605fbc0e687b2e1b4b90a7c445cdd",
    "url": "/static/unicms_editorial_board_vue/img/vue-logo.png"
  },
  {
    "revision": "9ebea76ee1225f00d882b21547a7b49f",
    "url": "/static/unicms_editorial_board_vue/img/sidebar-5.jpg"
  },
  {
    "revision": "b6216d61c03e6ce0c9aea6ca7808f7ca",
    "url": "/static/unicms_editorial_board_vue/robots.txt"
  }
];