<!DOCTYPE html><html><head><meta charset="utf-8"><link rel="apple-touch-icon" sizes="76x76" href="/static/unicms_editorial_board_vue/apple-icon.png"><!--[if IE]><link rel="icon" type="image/png" sizes="96x96" href="/static/unicms_editorial_board_vue/favicon.png"><![endif]--><meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"><title>uniCMS - Editorial Board</title><meta name="viewport" content="width=device-width,initial-scale=1,maximum-scale=1,user-scalable=0"><link href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" rel="stylesheet"><link href="https://fonts.googleapis.com/css?family=Montserrat:400,700,200" rel="stylesheet"><link href="/static/unicms_editorial_board_vue/css/app.ff4279f4.css" rel="preload" as="style"><link href="/static/unicms_editorial_board_vue/css/chunk-vendors.7c366b9d.css" rel="preload" as="style"><link href="/static/unicms_editorial_board_vue/js/app.0ac957a1.js" rel="preload" as="script"><link href="/static/unicms_editorial_board_vue/js/chunk-vendors.20e928aa.js" rel="preload" as="script"><link href="/static/unicms_editorial_board_vue/css/chunk-vendors.7c366b9d.css" rel="stylesheet"><link href="/static/unicms_editorial_board_vue/css/app.ff4279f4.css" rel="stylesheet"><link rel="icon" type="image/png" sizes="32x32" href="/static/unicms_editorial_board_vue/img/icons/favicon-32x32.png"><link rel="icon" type="image/png" sizes="16x16" href="/static/unicms_editorial_board_vue/img/icons/favicon-16x16.png"><link rel="manifest" href="/static/unicms_editorial_board_vue/manifest.json"><meta name="theme-color" content="#344675"><meta name="apple-mobile-web-app-capable" content="yes"><meta name="apple-mobile-web-app-status-bar-style" content="#344675"><meta name="apple-mobile-web-app-title" content="uniCMS - Unical Editorial Board"><link rel="apple-touch-icon" href="/static/unicms_editorial_board_vue/img/icons/apple-touch-icon-152x152.png"><link rel="mask-icon" href="/static/unicms_editorial_board_vue/img/icons/safari-pinned-tab.svg" color="#344675"><meta name="msapplication-TileImage" content="/static/unicms_editorial_board_vue/img/icons/msapplication-icon-144x144.png"><meta name="msapplication-TileColor" content="#344675"></head><body><div id="app"></div><script src="/static/unicms_editorial_board_vue/js/chunk-vendors.20e928aa.js"></script><script src="/static/unicms_editorial_board_vue/js/app.0ac957a1.js"></script></body></html>