(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-vendors"],{"0561":function(t,e,n){(function(t,n){n(e)})(0,(function(t){"use strict";
/*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */var e=function(){return e=Object.assign||function(t){for(var e,n=1,r=arguments.length;n<r;n++)for(var i in e=arguments[n],e)Object.prototype.hasOwnProperty.call(e,i)&&(t[i]=e[i]);return t},e.apply(this,arguments)};function n(){for(var t=0,e=0,n=arguments.length;e<n;e++)t+=arguments[e].length;var r=Array(t),i=0;for(e=0;e<n;e++)for(var o=arguments[e],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r}var r=function(){function t(){}return t.prototype.install=function(t,r){void 0===r&&(r={}),r.template&&(r.render=void 0),Object.defineProperties(t.prototype,{$breadcrumbs:{get:function(){var t=this;function r(t,e){var n;void 0===e&&(e=[]);var i=this.$router.resolve({name:t}).route.matched,o=i.pop();if(o){e.unshift(o);var a=null===(n=o.meta)||void 0===n?void 0:n.breadcrumb;if("function"===typeof a&&(a=a.call(this,this.$route.params)),null===a||void 0===a?void 0:a.parent)return r.call(this,a.parent,e)}return i.concat(e)}return this.$route.matched.flatMap((function(e){var i,o=[e],a=null===(i=e.meta)||void 0===i?void 0:i.breadcrumb;if("function"===typeof a&&(a=a.call(t,t.$route.params)),null===a||void 0===a?void 0:a.parent){var s=r.call(t,a.parent,[]);o=n(s,o)}return o})).map((function(t){return 0===t.path.length?e(e({},t),{path:"/"}):t}))}}}),t.component("Breadcrumbs",t.extend(e({methods:{getBreadcrumb:function(t){var e=t;return"function"===typeof e&&(e=e.call(this,this.$route.params)),"object"===typeof e&&(e=e.label),e},getPath:function(t){for(var e=t.path,n=0,r=Object.entries(this.$route.params);n<r.length;n++){var i=r[n],o=i[0],a=i[1];e=e.replace(":"+o,a)}return e}},render:function(t){var e=this;return this.$breadcrumbs.length?t("ol",{class:{breadcrumb:!0}},this.$breadcrumbs.map((function(n,r){var i;if(null===(i=null===n||void 0===n?void 0:n.meta)||void 0===i?void 0:i.breadcrumb){var o=e.getBreadcrumb(n.meta.breadcrumb);if((null===o||void 0===o?void 0:o.length)>0)return t("li",{class:{"breadcrumb-item":!0},props:{key:r}},[t("router-link",{props:{to:{path:e.getPath(n)},tag:r!==e.$breadcrumbs.length-1?"a":"span"}}," "+o)])}return t()}))):t()}},r)))},t}(),i=new r;"undefined"!==typeof window&&window.Vue&&window.Vue.use(new r),t.default=i,Object.defineProperty(t,"__esModule",{value:!0})}))},"0759":function(t,e,n){"use strict";n.d(e,"a",(function(){return w}));var r=n("2b0e"),i=n("b42e"),o=n("c637"),a=n("a723"),s=n("992e"),c=n("d82f"),l=n("cf75"),u=n("fa73"),d=n("7386"),h=n("aa0d");function f(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function p(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?f(Object(n),!0).forEach((function(e){m(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):f(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function m(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var b=function t(e,n){if(!e)return null;var r=(e.$options||{}).components,i=r[n];return i||t(e.$parent,n)},g=Object(c["j"])(h["b"],["content"]),v=Object(l["d"])(Object(c["m"])(p(p({},g),{},{icon:Object(l["c"])(a["u"])})),o["lb"]),w=r["default"].extend({name:o["lb"],functional:!0,props:v,render:function(t,e){var n=e.data,r=e.props,o=e.parent,a=Object(u["e"])(Object(u["h"])(r.icon||"")).replace(s["q"],"");return t(a&&b(o,"BIcon".concat(a))||d["Fc"],Object(i["a"])(n,{props:Object(l["e"])(g,r)}))}})},"0a06":function(t,e,n){"use strict";var r=n("c532"),i=n("30b5"),o=n("f6b4"),a=n("5270"),s=n("4a7b");function c(t){this.defaults=t,this.interceptors={request:new o,response:new o}}c.prototype.request=function(t){"string"===typeof t?(t=arguments[1]||{},t.url=arguments[0]):t=t||{},t=s(this.defaults,t),t.method?t.method=t.method.toLowerCase():this.defaults.method?t.method=this.defaults.method.toLowerCase():t.method="get";var e=[a,void 0],n=Promise.resolve(t);this.interceptors.request.forEach((function(t){e.unshift(t.fulfilled,t.rejected)})),this.interceptors.response.forEach((function(t){e.push(t.fulfilled,t.rejected)}));while(e.length)n=n.then(e.shift(),e.shift());return n},c.prototype.getUri=function(t){return t=s(this.defaults,t),i(t.url,t.params,t.paramsSerializer).replace(/^\?/,"")},r.forEach(["delete","get","head","options"],(function(t){c.prototype[t]=function(e,n){return this.request(s(n||{},{method:t,url:e,data:(n||{}).data}))}})),r.forEach(["post","put","patch"],(function(t){c.prototype[t]=function(e,n,r){return this.request(s(r||{},{method:t,url:e,data:n}))}})),t.exports=c},"0df6":function(t,e,n){"use strict";t.exports=function(t){return function(e){return t.apply(null,e)}}},"1d2b":function(t,e,n){"use strict";t.exports=function(t,e){return function(){for(var n=new Array(arguments.length),r=0;r<n.length;r++)n[r]=arguments[r];return t.apply(e,n)}}},2106:function(t,e,n){"use strict";(function(n){var r,i;function o(t){return(o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function a(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function s(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function c(t,e,n){return e&&s(t.prototype,e),n&&s(t,n),t}function l(t,e){return u(t)||d(t,e)||h(t,e)||p()}function u(t){if(Array.isArray(t))return t}function d(t,e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(t)){var n=[],r=!0,i=!1,o=void 0;try{for(var a,s=t[Symbol.iterator]();!(r=(a=s.next()).done)&&(n.push(a.value),!e||n.length!==e);r=!0);}catch(t){i=!0,o=t}finally{try{r||null==s.return||s.return()}finally{if(i)throw o}}return n}}function h(t,e){if(t){if("string"==typeof t)return f(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?f(t,e):void 0}}function f(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function p(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function m(t,e){var n;if("undefined"==typeof Symbol||null==t[Symbol.iterator]){if(Array.isArray(t)||(n=h(t))||e&&t&&"number"==typeof t.length){n&&(t=n);var r=0;return{s:e=function(){},n:function(){return r>=t.length?{done:!0}:{done:!1,value:t[r++]}},e:function(t){throw t},f:e}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,o=!0,a=!1;return{s:function(){n=t[Symbol.iterator]()},n:function(){var t=n.next();return o=t.done,t},e:function(t){a=!0,i=t},f:function(){try{o||null==n.return||n.return()}finally{if(a)throw i}}}}function b(t,e,n){return t(n={path:e,exports:{},require:function(t,e){return g(t,null==e?n.path:e)}},n.exports),n.exports}function g(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}var v="2.0.0",w=256,y=Number.MAX_SAFE_INTEGER||9007199254740991,k=16,_={SEMVER_SPEC_VERSION:v,MAX_LENGTH:w,MAX_SAFE_INTEGER:y,MAX_SAFE_COMPONENT_LENGTH:k},O="object"===("undefined"==typeof n?"undefined":o(n))&&Object({NODE_ENV:"production",BASE_URL:"/static/unicms_editorial_board_vue/"})&&Object({NODE_ENV:"production",BASE_URL:"/static/unicms_editorial_board_vue/"}).NODE_DEBUG&&/\bsemver\b/i.test(Object({NODE_ENV:"production",BASE_URL:"/static/unicms_editorial_board_vue/"}).NODE_DEBUG)?function(){for(var t,e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];return(t=console).error.apply(t,["SEMVER"].concat(n))}:function(){},z=O,A=b((function(t,e){var n=_.MAX_SAFE_COMPONENT_LENGTH,r=(e=t.exports={}).re=[],i=e.src=[],o=e.t={},a=0;(t=function(t,e,n){var s=a++;z(s,e),o[t]=s,i[s]=e,r[s]=new RegExp(e,n?"g":void 0)})("NUMERICIDENTIFIER","0|[1-9]\\d*"),t("NUMERICIDENTIFIERLOOSE","[0-9]+"),t("NONNUMERICIDENTIFIER","\\d*[a-zA-Z-][a-zA-Z0-9-]*"),t("MAINVERSION","(".concat(i[o.NUMERICIDENTIFIER],")\\.")+"(".concat(i[o.NUMERICIDENTIFIER],")\\.")+"(".concat(i[o.NUMERICIDENTIFIER],")")),t("MAINVERSIONLOOSE","(".concat(i[o.NUMERICIDENTIFIERLOOSE],")\\.")+"(".concat(i[o.NUMERICIDENTIFIERLOOSE],")\\.")+"(".concat(i[o.NUMERICIDENTIFIERLOOSE],")")),t("PRERELEASEIDENTIFIER","(?:".concat(i[o.NUMERICIDENTIFIER],"|").concat(i[o.NONNUMERICIDENTIFIER],")")),t("PRERELEASEIDENTIFIERLOOSE","(?:".concat(i[o.NUMERICIDENTIFIERLOOSE],"|").concat(i[o.NONNUMERICIDENTIFIER],")")),t("PRERELEASE","(?:-(".concat(i[o.PRERELEASEIDENTIFIER],"(?:\\.").concat(i[o.PRERELEASEIDENTIFIER],")*))")),t("PRERELEASELOOSE","(?:-?(".concat(i[o.PRERELEASEIDENTIFIERLOOSE],"(?:\\.").concat(i[o.PRERELEASEIDENTIFIERLOOSE],")*))")),t("BUILDIDENTIFIER","[0-9A-Za-z-]+"),t("BUILD","(?:\\+(".concat(i[o.BUILDIDENTIFIER],"(?:\\.").concat(i[o.BUILDIDENTIFIER],")*))")),t("FULLPLAIN","v?".concat(i[o.MAINVERSION]).concat(i[o.PRERELEASE],"?").concat(i[o.BUILD],"?")),t("FULL","^".concat(i[o.FULLPLAIN],"$")),t("LOOSEPLAIN","[v=\\s]*".concat(i[o.MAINVERSIONLOOSE]).concat(i[o.PRERELEASELOOSE],"?").concat(i[o.BUILD],"?")),t("LOOSE","^".concat(i[o.LOOSEPLAIN],"$")),t("GTLT","((?:<|>)?=?)"),t("XRANGEIDENTIFIERLOOSE","".concat(i[o.NUMERICIDENTIFIERLOOSE],"|x|X|\\*")),t("XRANGEIDENTIFIER","".concat(i[o.NUMERICIDENTIFIER],"|x|X|\\*")),t("XRANGEPLAIN","[v=\\s]*(".concat(i[o.XRANGEIDENTIFIER],")")+"(?:\\.(".concat(i[o.XRANGEIDENTIFIER],")")+"(?:\\.(".concat(i[o.XRANGEIDENTIFIER],")")+"(?:".concat(i[o.PRERELEASE],")?").concat(i[o.BUILD],"?")+")?)?"),t("XRANGEPLAINLOOSE","[v=\\s]*(".concat(i[o.XRANGEIDENTIFIERLOOSE],")")+"(?:\\.(".concat(i[o.XRANGEIDENTIFIERLOOSE],")")+"(?:\\.(".concat(i[o.XRANGEIDENTIFIERLOOSE],")")+"(?:".concat(i[o.PRERELEASELOOSE],")?").concat(i[o.BUILD],"?")+")?)?"),t("XRANGE","^".concat(i[o.GTLT],"\\s*").concat(i[o.XRANGEPLAIN],"$")),t("XRANGELOOSE","^".concat(i[o.GTLT],"\\s*").concat(i[o.XRANGEPLAINLOOSE],"$")),t("COERCE","".concat("(^|[^\\d])(\\d{1,").concat(n,"})")+"(?:\\.(\\d{1,".concat(n,"}))?")+"(?:\\.(\\d{1,".concat(n,"}))?")+"(?:$|[^\\d])"),t("COERCERTL",i[o.COERCE],!0),t("LONETILDE","(?:~>?)"),t("TILDETRIM","(\\s*)".concat(i[o.LONETILDE],"\\s+"),!0),e.tildeTrimReplace="$1~",t("TILDE","^".concat(i[o.LONETILDE]).concat(i[o.XRANGEPLAIN],"$")),t("TILDELOOSE","^".concat(i[o.LONETILDE]).concat(i[o.XRANGEPLAINLOOSE],"$")),t("LONECARET","(?:\\^)"),t("CARETTRIM","(\\s*)".concat(i[o.LONECARET],"\\s+"),!0),e.caretTrimReplace="$1^",t("CARET","^".concat(i[o.LONECARET]).concat(i[o.XRANGEPLAIN],"$")),t("CARETLOOSE","^".concat(i[o.LONECARET]).concat(i[o.XRANGEPLAINLOOSE],"$")),t("COMPARATORLOOSE","^".concat(i[o.GTLT],"\\s*(").concat(i[o.LOOSEPLAIN],")$|^$")),t("COMPARATOR","^".concat(i[o.GTLT],"\\s*(").concat(i[o.FULLPLAIN],")$|^$")),t("COMPARATORTRIM","(\\s*)".concat(i[o.GTLT],"\\s*(").concat(i[o.LOOSEPLAIN],"|").concat(i[o.XRANGEPLAIN],")"),!0),e.comparatorTrimReplace="$1$2$3",t("HYPHENRANGE","^\\s*(".concat(i[o.XRANGEPLAIN],")")+"\\s+-\\s+"+"(".concat(i[o.XRANGEPLAIN],")")+"\\s*$"),t("HYPHENRANGELOOSE","^\\s*(".concat(i[o.XRANGEPLAINLOOSE],")")+"\\s+-\\s+"+"(".concat(i[o.XRANGEPLAINLOOSE],")")+"\\s*$"),t("STAR","(<|>)?=?\\s*\\*"),t("GTE0","^\\s*>=\\s*0.0.0\\s*$"),t("GTE0PRE","^\\s*>=\\s*0.0.0-0\\s*$")})),j=/^[0-9]+$/,M=function(t,e){var n=j.test(t),r=j.test(e);return n&&r&&(t=+t,e=+e),t===e?0:n&&!r||(!r||n)&&t<e?-1:1},C=function(t,e){return M(e,t)},V={compareIdentifiers:M,rcompareIdentifiers:C},S=_.MAX_LENGTH,x=_.MAX_SAFE_INTEGER,T=A.re,P=A.t,I=V.compareIdentifiers,E=function(){function t(e,n){if(a(this,t),n&&"object"===o(n)||(n={loose:!!n,includePrerelease:!1}),e instanceof t){if(e.loose===!!n.loose&&e.includePrerelease===!!n.includePrerelease)return e;e=e.version}else if("string"!=typeof e)throw new TypeError("Invalid Version: ".concat(e));if(e.length>S)throw new TypeError("version is longer than ".concat(S," characters"));if(z("SemVer",e,n),this.options=n,this.loose=!!n.loose,this.includePrerelease=!!n.includePrerelease,!(n=e.trim().match(n.loose?T[P.LOOSE]:T[P.FULL])))throw new TypeError("Invalid Version: ".concat(e));if(this.raw=e,this.major=+n[1],this.minor=+n[2],this.patch=+n[3],this.major>x||this.major<0)throw new TypeError("Invalid major version");if(this.minor>x||this.minor<0)throw new TypeError("Invalid minor version");if(this.patch>x||this.patch<0)throw new TypeError("Invalid patch version");n[4]?this.prerelease=n[4].split(".").map((function(t){if(/^[0-9]+$/.test(t)){var e=+t;if(0<=e&&e<x)return e}return t})):this.prerelease=[],this.build=n[5]?n[5].split("."):[],this.format()}return c(t,[{key:"format",value:function(){return this.version="".concat(this.major,".").concat(this.minor,".").concat(this.patch),this.prerelease.length&&(this.version+="-".concat(this.prerelease.join("."))),this.version}},{key:"toString",value:function(){return this.version}},{key:"compare",value:function(e){if(z("SemVer.compare",this.version,this.options,e),!(e instanceof t)){if("string"==typeof e&&e===this.version)return 0;e=new t(e,this.options)}return e.version===this.version?0:this.compareMain(e)||this.comparePre(e)}},{key:"compareMain",value:function(e){return e instanceof t||(e=new t(e,this.options)),I(this.major,e.major)||I(this.minor,e.minor)||I(this.patch,e.patch)}},{key:"comparePre",value:function(e){if(e instanceof t||(e=new t(e,this.options)),this.prerelease.length&&!e.prerelease.length)return-1;if(!this.prerelease.length&&e.prerelease.length)return 1;if(!this.prerelease.length&&!e.prerelease.length)return 0;var n=0;do{var r=this.prerelease[n],i=e.prerelease[n];if(z("prerelease compare",n,r,i),void 0===r&&void 0===i)return 0;if(void 0===i)return 1;if(void 0===r)return-1;if(r!==i)return I(r,i)}while(++n)}},{key:"compareBuild",value:function(e){e instanceof t||(e=new t(e,this.options));var n=0;do{var r=this.build[n],i=e.build[n];if(z("prerelease compare",n,r,i),void 0===r&&void 0===i)return 0;if(void 0===i)return 1;if(void 0===r)return-1;if(r!==i)return I(r,i)}while(++n)}},{key:"inc",value:function(t,e){switch(t){case"premajor":this.prerelease.length=0,this.patch=0,this.minor=0,this.major++,this.inc("pre",e);break;case"preminor":this.prerelease.length=0,this.patch=0,this.minor++,this.inc("pre",e);break;case"prepatch":this.prerelease.length=0,this.inc("patch",e),this.inc("pre",e);break;case"prerelease":0===this.prerelease.length&&this.inc("patch",e),this.inc("pre",e);break;case"major":0===this.minor&&0===this.patch&&0!==this.prerelease.length||this.major++,this.minor=0,this.patch=0,this.prerelease=[];break;case"minor":0===this.patch&&0!==this.prerelease.length||this.minor++,this.patch=0,this.prerelease=[];break;case"patch":0===this.prerelease.length&&this.patch++,this.prerelease=[];break;case"pre":if(0===this.prerelease.length)this.prerelease=[0];else{for(var n=this.prerelease.length;0<=--n;)"number"==typeof this.prerelease[n]&&(this.prerelease[n]++,n=-2);-1===n&&this.prerelease.push(0)}e&&(this.prerelease[0]!==e||isNaN(this.prerelease[1]))&&(this.prerelease=[e,0]);break;default:throw new Error("invalid increment argument: ".concat(t))}return this.format(),this.raw=this.version,this}}]),t}(),L=E,B=_.MAX_LENGTH,H=A.re,F=A.t,D=function(t,e){if(e&&"object"===o(e)||(e={loose:!!e,includePrerelease:!1}),t instanceof L)return t;if("string"!=typeof t)return null;if(t.length>B)return null;if(!(e.loose?H[F.LOOSE]:H[F.FULL]).test(t))return null;try{return new L(t,e)}catch(t){return null}},R=D,N=function(t,e){return(e=R(t,e))?e.version:null},$=N,U=function(t,e){return(e=R(t.trim().replace(/^[=v]+/,""),e))?e.version:null},q=U,W=function(t,e,n,r){"string"==typeof n&&(r=n,n=void 0);try{return new L(t,n).inc(e,r).version}catch(t){return null}},G=W,Y=function(t,e,n){return new L(t,n).compare(new L(e,n))},K=Y,Q=function(t,e,n){return 0===K(t,e,n)},X=Q,J=function(t,e){if(X(t,e))return null;var n,r=R(t),i=R(e),o=(e=r.prerelease.length||i.prerelease.length)?"pre":"";e=e?"prerelease":"";for(n in r)if(("major"===n||"minor"===n||"patch"===n)&&r[n]!==i[n])return o+n;return e},Z=J,tt=function(t,e){return new L(t,e).major},et=tt,nt=function(t,e){return new L(t,e).minor},rt=nt,it=function(t,e){return new L(t,e).patch},ot=it,at=function(t,e){return(e=R(t,e))&&e.prerelease.length?e.prerelease:null},st=at,ct=function(t,e,n){return K(e,t,n)},lt=ct,ut=function(t,e){return K(t,e,!0)},dt=ut,ht=function(t,e,n){return t=new L(t,n),n=new L(e,n),t.compare(n)||t.compareBuild(n)},ft=ht,pt=function(t,e){return t.sort((function(t,n){return ft(t,n,e)}))},mt=pt,bt=function(t,e){return t.sort((function(t,n){return ft(n,t,e)}))},gt=bt,vt=function(t,e,n){return 0<K(t,e,n)},wt=vt,yt=function(t,e,n){return K(t,e,n)<0},kt=yt,_t=function(t,e,n){return 0!==K(t,e,n)},Ot=_t,zt=function(t,e,n){return 0<=K(t,e,n)},At=zt,jt=function(t,e,n){return K(t,e,n)<=0},Mt=jt,Ct=function(t,e,n,r){switch(e){case"===":return"object"===o(t)&&(t=t.version),"object"===o(n)&&(n=n.version),t===n;case"!==":return"object"===o(t)&&(t=t.version),"object"===o(n)&&(n=n.version),t!==n;case"":case"=":case"==":return X(t,n,r);case"!=":return Ot(t,n,r);case">":return wt(t,n,r);case">=":return At(t,n,r);case"<":return kt(t,n,r);case"<=":return Mt(t,n,r);default:throw new TypeError("Invalid operator: ".concat(e))}},Vt=Ct,St=A.re,xt=A.t,Tt=function(t,e){if(t instanceof L)return t;if("number"==typeof t&&(t=String(t)),"string"!=typeof t)return null;var n,r=null;if((e=e||{}).rtl){for(;(n=St[xt.COERCERTL].exec(t))&&(!r||r.index+r[0].length!==t.length);)r&&n.index+n[0].length===r.index+r[0].length||(r=n),St[xt.COERCERTL].lastIndex=n.index+n[1].length+n[2].length;St[xt.COERCERTL].lastIndex=-1}else r=t.match(St[xt.COERCE]);return null===r?null:R("".concat(r[2],".").concat(r[3]||"0",".").concat(r[4]||"0"),e)},Pt=Tt,It=function(){function t(e,n){var r=this;if(a(this,t),n&&"object"===o(n)||(n={loose:!!n,includePrerelease:!1}),e instanceof t)return e.loose===!!n.loose&&e.includePrerelease===!!n.includePrerelease?e:new t(e.raw,n);if(e instanceof ne)return this.raw=e.value,this.set=[[e]],this.format(),this;if(this.options=n,this.loose=!!n.loose,this.includePrerelease=!!n.includePrerelease,this.raw=e,this.set=e.split(/\s*\|\|\s*/).map((function(t){return r.parseRange(t.trim())})).filter((function(t){return t.length})),!this.set.length)throw new TypeError("Invalid SemVer Range: ".concat(e));this.format()}return c(t,[{key:"format",value:function(){return this.range=this.set.map((function(t){return t.join(" ").trim()})).join("||").trim(),this.range}},{key:"toString",value:function(){return this.range}},{key:"parseRange",value:function(t){var e=this,n=this.options.loose;t=t.trim();var r=n?Lt[Bt.HYPHENRANGELOOSE]:Lt[Bt.HYPHENRANGE];t=t.replace(r,Jt(this.options.includePrerelease)),z("hyphen replace",t),t=t.replace(Lt[Bt.COMPARATORTRIM],Ht),z("comparator trim",t,Lt[Bt.COMPARATORTRIM]),t=(t=(t=t.replace(Lt[Bt.TILDETRIM],Ft)).replace(Lt[Bt.CARETTRIM],Dt)).split(/\s+/).join(" ");var i=n?Lt[Bt.COMPARATORLOOSE]:Lt[Bt.COMPARATOR];return t.split(" ").map((function(t){return Nt(t,e.options)})).join(" ").split(/\s+/).map((function(t){return Xt(t,e.options)})).filter(this.options.loose?function(t){return!!t.match(i)}:function(){return!0}).map((function(t){return new ne(t,e.options)}))}},{key:"intersects",value:function(e,n){if(!(e instanceof t))throw new TypeError("a Range is required");return this.set.some((function(t){return Rt(t,n)&&e.set.some((function(e){return Rt(e,n)&&t.every((function(t){return e.every((function(e){return t.intersects(e,n)}))}))}))}))}},{key:"test",value:function(t){if(!t)return!1;if("string"==typeof t)try{t=new L(t,this.options)}catch(t){return!1}for(var e=0;e<this.set.length;e++)if(Zt(this.set[e],t,this.options))return!0;return!1}}]),t}(),Et=It,Lt=A.re,Bt=A.t,Ht=A.comparatorTrimReplace,Ft=A.tildeTrimReplace,Dt=A.caretTrimReplace,Rt=function(t,e){for(var n=!0,r=t.slice(),i=r.pop();n&&r.length;)n=r.every((function(t){return i.intersects(t,e)})),i=r.pop();return n},Nt=function(t,e){return z("comp",t,e),t=Wt(t,e),z("caret",t),t=Ut(t,e),z("tildes",t),t=Yt(t,e),z("xrange",t),t=Qt(t,e),z("stars",t),t},$t=function(t){return!t||"x"===t.toLowerCase()||"*"===t},Ut=function(t,e){return t.trim().split(/\s+/).map((function(t){return qt(t,e)})).join(" ")},qt=function(t,e){return e=e.loose?Lt[Bt.TILDELOOSE]:Lt[Bt.TILDE],t.replace(e,(function(e,n,r,i,o){return z("tilde",t,e,n,r,i,o),r=$t(n)?"":$t(r)?">=".concat(n,".0.0 <").concat(+n+1,".0.0-0"):$t(i)?">=".concat(n,".").concat(r,".0 <").concat(n,".").concat(+r+1,".0-0"):o?(z("replaceTilde pr",o),">=".concat(n,".").concat(r,".").concat(i,"-").concat(o," <").concat(n,".").concat(+r+1,".0-0")):">=".concat(n,".").concat(r,".").concat(i," <").concat(n,".").concat(+r+1,".0-0"),z("tilde return",r),r}))},Wt=function(t,e){return t.trim().split(/\s+/).map((function(t){return Gt(t,e)})).join(" ")},Gt=function(t,e){z("caret",t,e);var n=e.loose?Lt[Bt.CARETLOOSE]:Lt[Bt.CARET],r=e.includePrerelease?"-0":"";return t.replace(n,(function(e,n,i,o,a){return z("caret",t,e,n,i,o,a),n=$t(n)?"":$t(i)?">=".concat(n,".0.0").concat(r," <").concat(+n+1,".0.0-0"):$t(o)?"0"===n?">=".concat(n,".").concat(i,".0").concat(r," <").concat(n,".").concat(+i+1,".0-0"):">=".concat(n,".").concat(i,".0").concat(r," <").concat(+n+1,".0.0-0"):a?(z("replaceCaret pr",a),"0"===n?"0"===i?">=".concat(n,".").concat(i,".").concat(o,"-").concat(a," <").concat(n,".").concat(i,".").concat(+o+1,"-0"):">=".concat(n,".").concat(i,".").concat(o,"-").concat(a," <").concat(n,".").concat(+i+1,".0-0"):">=".concat(n,".").concat(i,".").concat(o,"-").concat(a," <").concat(+n+1,".0.0-0")):(z("no pr"),"0"===n?"0"===i?">=".concat(n,".").concat(i,".").concat(o).concat(r," <").concat(n,".").concat(i,".").concat(+o+1,"-0"):">=".concat(n,".").concat(i,".").concat(o).concat(r," <").concat(n,".").concat(+i+1,".0-0"):">=".concat(n,".").concat(i,".").concat(o," <").concat(+n+1,".0.0-0")),z("caret return",n),n}))},Yt=function(t,e){return z("replaceXRanges",t,e),t.split(/\s+/).map((function(t){return Kt(t,e)})).join(" ")},Kt=function(t,e){t=t.trim();var n=e.loose?Lt[Bt.XRANGELOOSE]:Lt[Bt.XRANGE];return t.replace(n,(function(n,r,i,o,a,s){z("xRange",t,n,r,i,o,a,s);var c=$t(i),l=c||$t(o),u=l||$t(a);return"="===r&&u&&(r=""),s=e.includePrerelease?"-0":"",c?n=">"===r||"<"===r?"<0.0.0-0":"*":r&&u?(l&&(o=0),a=0,">"===r?(r=">=",a=l?(i=+i+1,o=0):(o=+o+1,0)):"<="===r&&(r="<",l?i=+i+1:o=+o+1),"<"===r&&(s="-0"),n="".concat(r+i,".").concat(o,".").concat(a).concat(s)):l?n=">=".concat(i,".0.0").concat(s," <").concat(+i+1,".0.0-0"):u&&(n=">=".concat(i,".").concat(o,".0").concat(s," <").concat(i,".").concat(+o+1,".0-0")),z("xRange return",n),n}))},Qt=function(t,e){return z("replaceStars",t,e),t.trim().replace(Lt[Bt.STAR],"")},Xt=function(t,e){return z("replaceGTE0",t,e),t.trim().replace(Lt[e.includePrerelease?Bt.GTE0PRE:Bt.GTE0],"")},Jt=function(t){return function(e,n,r,i,o,a,s,c,l,u,d,h,f){return n=$t(r)?"":$t(i)?">=".concat(r,".0.0").concat(t?"-0":""):$t(o)?">=".concat(r,".").concat(i,".0").concat(t?"-0":""):a?">=".concat(n):">=".concat(n).concat(t?"-0":""),c=$t(l)?"":$t(u)?"<".concat(+l+1,".0.0-0"):$t(d)?"<".concat(l,".").concat(+u+1,".0-0"):h?"<=".concat(l,".").concat(u,".").concat(d,"-").concat(h):t?"<".concat(l,".").concat(u,".").concat(+d+1,"-0"):"<=".concat(c),"".concat(n," ").concat(c).trim()}},Zt=function(t,e,n){for(var r=0;r<t.length;r++)if(!t[r].test(e))return!1;if(!e.prerelease.length||n.includePrerelease)return!0;for(var i=0;i<t.length;i++)if(z(t[i].semver),t[i].semver!==ne.ANY&&0<t[i].semver.prerelease.length){var o=t[i].semver;if(o.major===e.major&&o.minor===e.minor&&o.patch===e.patch)return!0}return!1},te=Symbol("SemVer ANY"),ee=function(){function t(e,n){if(a(this,t),n&&"object"===o(n)||(n={loose:!!n,includePrerelease:!1}),e instanceof t){if(e.loose===!!n.loose)return e;e=e.value}z("comparator",e,n),this.options=n,this.loose=!!n.loose,this.parse(e),this.semver===te?this.value="":this.value=this.operator+this.semver.version,z("comp",this)}return c(t,null,[{key:"ANY",get:function(){return te}}]),c(t,[{key:"parse",value:function(t){var e=this.options.loose?re[ie.COMPARATORLOOSE]:re[ie.COMPARATOR];if(!(e=t.match(e)))throw new TypeError("Invalid comparator: ".concat(t));this.operator=void 0!==e[1]?e[1]:"","="===this.operator&&(this.operator=""),e[2]?this.semver=new L(e[2],this.options.loose):this.semver=te}},{key:"toString",value:function(){return this.value}},{key:"test",value:function(t){if(z("Comparator.test",t,this.options.loose),this.semver===te||t===te)return!0;if("string"==typeof t)try{t=new L(t,this.options)}catch(t){return!1}return Vt(t,this.operator,this.semver,this.options)}},{key:"intersects",value:function(e,n){if(!(e instanceof t))throw new TypeError("a Comparator is required");if(n&&"object"===o(n)||(n={loose:!!n,includePrerelease:!1}),""===this.operator)return""===this.value||new Et(e.value,n).test(this.value);if(""===e.operator)return""===e.value||new Et(this.value,n).test(e.semver);var r=!(">="!==this.operator&&">"!==this.operator||">="!==e.operator&&">"!==e.operator),i=!("<="!==this.operator&&"<"!==this.operator||"<="!==e.operator&&"<"!==e.operator),a=this.semver.version===e.semver.version,s=!(">="!==this.operator&&"<="!==this.operator||">="!==e.operator&&"<="!==e.operator),c=Vt(this.semver,"<",e.semver,n)&&(">="===this.operator||">"===this.operator)&&("<="===e.operator||"<"===e.operator);e=Vt(this.semver,">",e.semver,n)&&("<="===this.operator||"<"===this.operator)&&(">="===e.operator||">"===e.operator);return r||i||a&&s||c||e}}]),t}(),ne=ee,re=A.re,ie=A.t,oe=function(t,e,n){try{e=new Et(e,n)}catch(t){return!1}return e.test(t)},ae=oe,se=function(t,e){return new Et(t,e).set.map((function(t){return t.map((function(t){return t.value})).join(" ").trim().split(" ")}))},ce=function(t,e,n){var r=null,i=null,o=null;try{o=new Et(e,n)}catch(t){return null}return t.forEach((function(t){o.test(t)&&(r&&-1!==i.compare(t)||(i=new L(r=t,n)))})),r},le=function(t,e,n){var r=null,i=null,o=null;try{o=new Et(e,n)}catch(t){return null}return t.forEach((function(t){o.test(t)&&(r&&1!==i.compare(t)||(i=new L(r=t,n)))})),r},ue=function(t,e){t=new Et(t,e);var n=new L("0.0.0");if(t.test(n))return n;if(n=new L("0.0.0-0"),t.test(n))return n;n=null;for(var r=0;r<t.set.length;++r)t.set[r].forEach((function(t){var e=new L(t.semver.version);switch(t.operator){case">":0===e.prerelease.length?e.patch++:e.prerelease.push(0),e.raw=e.format();case"":case">=":n&&!wt(n,e)||(n=e);break;case"<":case"<=":break;default:throw new Error("Unexpected operation: ".concat(t.operator))}}));return n&&t.test(n)?n:null},de=function(t,e){try{return new Et(t,e).range||"*"}catch(t){return null}},he=ne.ANY,fe=function(t,e,n,r){var i,a,s,c,l;switch(t=new L(t,r),e=new Et(e,r),n){case">":i=wt,a=Mt,s=kt,c=">",l=">=";break;case"<":i=kt,a=At,s=wt,c="<",l="<=";break;default:throw new TypeError('Must provide a hilo val of "<" or ">"')}if(ae(t,e,r))return!1;for(var u=0;u<e.set.length;++u){var d=function(n){n=e.set[n];var o=null,u=null;return n.forEach((function(t){t.semver===he&&(t=new ne(">=0.0.0")),o=o||t,u=u||t,i(t.semver,o.semver,r)?o=t:s(t.semver,u.semver,r)&&(u=t)})),o.operator===c||o.operator===l||(!u.operator||u.operator===c)&&a(t,u.semver)||u.operator===l&&s(t,u.semver)?{v:!1}:void 0}(u);if("object"===o(d))return d.v}return!0},pe=fe,me=function(t,e,n){return pe(t,e,">",n)},be=function(t,e,n){return pe(t,e,"<",n)},ge=function(t,e,n){return t=new Et(t,n),e=new Et(e,n),t.intersects(e)},ve=function(t,e,n){var r=[],i=null,o=null,a=t.sort((function(t,e){return K(t,e,n)})),s=m(a);try{for(s.s();!(c=s.n()).done;){var c=c.value;i=ae(c,e,n)?(o=c,i||c):(o&&r.push([i,o]),o=null)}}catch(t){s.e(t)}finally{s.f()}i&&r.push([i,null]);for(var u=[],d=0,h=r;d<h.length;d++){var f=l(h[d],2),p=f[0];p===(f=f[1])?u.push(p):f||p!==a[0]?f?p===a[0]?u.push("<=".concat(f)):u.push("".concat(p," - ").concat(f)):u.push(">=".concat(p)):u.push("*")}var b=u.join(" || ");t="string"==typeof e.raw?e.raw:String(e);return b.length<t.length?b:e},we=ne.ANY,ye=function(t,e,n){t=new Et(t,n),e=new Et(e,n);var r,i=!1,o=m(t.set);try{t:for(o.s();!(r=o.n()).done;){var a=r.value,s=m(e.set);try{for(s.s();!(c=s.n()).done;){var c=c.value;c=ke(a,c,n),i=i||null!==c;if(c)continue t}}catch(t){s.e(t)}finally{s.f()}if(i)return!1}}catch(t){o.e(t)}finally{o.f()}return!0},ke=function(t,e,n){if(1===t.length&&t[0].semver===we)return 1===e.length&&e[0].semver===we;var r,i,o,a=new Set,s=m(t);try{for(s.s();!(c=s.n()).done;){var c=c.value;">"===c.operator||">="===c.operator?r=_e(r,c,n):"<"===c.operator||"<="===c.operator?i=Oe(i,c,n):a.add(c.semver)}}catch(t){s.e(t)}finally{s.f()}if(1<a.size)return null;if(r&&i){if(0<(o=K(r.semver,i.semver,n)))return null;if(0===o&&(">="!==r.operator||"<="!==i.operator))return null}var l,u=m(a);try{for(u.s();!(l=u.n()).done;){var d=l.value;if(r&&!ae(d,String(r),n))return null;if(i&&!ae(d,String(i),n))return null;var h=m(e);try{for(h.s();!(f=h.n()).done;){var f=f.value;if(!ae(d,String(f),n))return!1}}catch(t){h.e(t)}finally{h.f()}return!0}}catch(t){u.e(t)}finally{u.f()}var p=m(e);try{for(p.s();!(b=p.n()).done;){var b=b.value,g=g||">"===b.operator||">="===b.operator,v=v||"<"===b.operator||"<="===b.operator;if(r)if(">"===b.operator||">="===b.operator){if(_e(r,b,n)===b)return!1}else if(">="===r.operator&&!ae(r.semver,String(b),n))return!1;if(i)if("<"===b.operator||"<="===b.operator){if(Oe(i,b,n)===b)return!1}else if("<="===i.operator&&!ae(i.semver,String(b),n))return!1;if(!b.operator&&(i||r)&&0!==o)return!1}}catch(t){p.e(t)}finally{p.f()}return!(r&&v&&!i&&0!==o||i&&g&&!r&&0!==o)},_e=function(t,e,n){return t&&(0<(n=K(t.semver,e.semver,n))||!(n<0||">"===e.operator&&">="===t.operator))?t:e},Oe=function(t,e,n){return t&&((n=K(t.semver,e.semver,n))<0||!(0<n||"<"===e.operator&&"<="===t.operator))?t:e},ze={re:A.re,src:A.src,tokens:A.t,SEMVER_SPEC_VERSION:_.SEMVER_SPEC_VERSION,SemVer:L,compareIdentifiers:V.compareIdentifiers,rcompareIdentifiers:V.rcompareIdentifiers,parse:R,valid:$,clean:q,inc:G,diff:Z,major:et,minor:rt,patch:ot,prerelease:st,compare:K,rcompare:lt,compareLoose:dt,compareBuild:ft,sort:mt,rsort:gt,gt:wt,lt:kt,eq:X,neq:Ot,gte:At,lte:Mt,cmp:Vt,coerce:Pt,Comparator:ne,Range:Et,satisfies:ae,toComparators:se,maxSatisfying:ce,minSatisfying:le,minVersion:ue,validRange:de,outside:pe,gtr:me,ltr:be,intersects:ge,simplifyRange:ve,subset:ye};!function(){function n(t,e){n.installed||(e?null!=ze.valid(t.version)?(n.installed=!0,ze.lt(t.version,"3.0.0")?Object.defineProperties(t.prototype,{axios:{get:function(){return e}},$http:{get:function(){return e}}}):(t.config.globalProperties.axios=e,t.config.globalProperties.$http=e),t.axios=e,t.$http=e):console.error("Unkown vue version"):console.error("You have to install axios"))}"object"==o(e)?t.exports=n:(r=[],i=function(){return n}.apply(e,r),void 0===i||(t.exports=i))}()}).call(this,n("4362"))},"228e":function(t,e,n){"use strict";n.d(e,"c",(function(){return l})),n.d(e,"a",(function(){return u})),n.d(e,"b",(function(){return f}));var r=n("2b0e"),i=n("50d3"),o=n("c9a9"),a=n("b508"),s=r["default"].prototype,c=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:void 0,n=s[i["c"]];return n?n.getConfigValue(t,e):Object(o["a"])(e)},l=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:void 0;return e?c("".concat(t,".").concat(e),n):c(t,{})},u=function(){return c("breakpoints",i["a"])},d=Object(a["a"])((function(){return u()})),h=function(){return Object(o["a"])(d())},f=Object(a["a"])((function(){var t=h();return t[0]="",t}))},2444:function(t,e,n){"use strict";(function(e){var r=n("c532"),i=n("c8af"),o={"Content-Type":"application/x-www-form-urlencoded"};function a(t,e){!r.isUndefined(t)&&r.isUndefined(t["Content-Type"])&&(t["Content-Type"]=e)}function s(){var t;return("undefined"!==typeof XMLHttpRequest||"undefined"!==typeof e&&"[object process]"===Object.prototype.toString.call(e))&&(t=n("b50d")),t}var c={adapter:s(),transformRequest:[function(t,e){return i(e,"Accept"),i(e,"Content-Type"),r.isFormData(t)||r.isArrayBuffer(t)||r.isBuffer(t)||r.isStream(t)||r.isFile(t)||r.isBlob(t)?t:r.isArrayBufferView(t)?t.buffer:r.isURLSearchParams(t)?(a(e,"application/x-www-form-urlencoded;charset=utf-8"),t.toString()):r.isObject(t)?(a(e,"application/json;charset=utf-8"),JSON.stringify(t)):t}],transformResponse:[function(t){if("string"===typeof t)try{t=JSON.parse(t)}catch(e){}return t}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,validateStatus:function(t){return t>=200&&t<300},headers:{common:{Accept:"application/json, text/plain, */*"}}};r.forEach(["delete","get","head"],(function(t){c.headers[t]={}})),r.forEach(["post","put","patch"],(function(t){c.headers[t]=r.merge(o)})),t.exports=c}).call(this,n("4362"))},2877:function(t,e,n){"use strict";function r(t,e,n,r,i,o,a,s){var c,l="function"===typeof t?t.options:t;if(e&&(l.render=e,l.staticRenderFns=n,l._compiled=!0),r&&(l.functional=!0),o&&(l._scopeId="data-v-"+o),a?(c=function(t){t=t||this.$vnode&&this.$vnode.ssrContext||this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext,t||"undefined"===typeof __VUE_SSR_CONTEXT__||(t=__VUE_SSR_CONTEXT__),i&&i.call(this,t),t&&t._registeredComponents&&t._registeredComponents.add(a)},l._ssrRegister=c):i&&(c=s?function(){i.call(this,(l.functional?this.parent:this).$root.$options.shadowRoot)}:i),c)if(l.functional){l._injectStyles=c;var u=l.render;l.render=function(t,e){return c.call(e),u(t,e)}}else{var d=l.beforeCreate;l.beforeCreate=d?[].concat(d,c):[c]}return{exports:t,options:l}}n.d(e,"a",(function(){return r}))},"2b0e":function(t,e,n){"use strict";n.r(e),function(t){
/*!
 * Vue.js v2.6.12
 * (c) 2014-2020 Evan You
 * Released under the MIT License.
 */
var n=Object.freeze({});function r(t){return void 0===t||null===t}function i(t){return void 0!==t&&null!==t}function o(t){return!0===t}function a(t){return!1===t}function s(t){return"string"===typeof t||"number"===typeof t||"symbol"===typeof t||"boolean"===typeof t}function c(t){return null!==t&&"object"===typeof t}var l=Object.prototype.toString;function u(t){return"[object Object]"===l.call(t)}function d(t){return"[object RegExp]"===l.call(t)}function h(t){var e=parseFloat(String(t));return e>=0&&Math.floor(e)===e&&isFinite(t)}function f(t){return i(t)&&"function"===typeof t.then&&"function"===typeof t.catch}function p(t){return null==t?"":Array.isArray(t)||u(t)&&t.toString===l?JSON.stringify(t,null,2):String(t)}function m(t){var e=parseFloat(t);return isNaN(e)?t:e}function b(t,e){for(var n=Object.create(null),r=t.split(","),i=0;i<r.length;i++)n[r[i]]=!0;return e?function(t){return n[t.toLowerCase()]}:function(t){return n[t]}}b("slot,component",!0);var g=b("key,ref,slot,slot-scope,is");function v(t,e){if(t.length){var n=t.indexOf(e);if(n>-1)return t.splice(n,1)}}var w=Object.prototype.hasOwnProperty;function y(t,e){return w.call(t,e)}function k(t){var e=Object.create(null);return function(n){var r=e[n];return r||(e[n]=t(n))}}var _=/-(\w)/g,O=k((function(t){return t.replace(_,(function(t,e){return e?e.toUpperCase():""}))})),z=k((function(t){return t.charAt(0).toUpperCase()+t.slice(1)})),A=/\B([A-Z])/g,j=k((function(t){return t.replace(A,"-$1").toLowerCase()}));function M(t,e){function n(n){var r=arguments.length;return r?r>1?t.apply(e,arguments):t.call(e,n):t.call(e)}return n._length=t.length,n}function C(t,e){return t.bind(e)}var V=Function.prototype.bind?C:M;function S(t,e){e=e||0;var n=t.length-e,r=new Array(n);while(n--)r[n]=t[n+e];return r}function x(t,e){for(var n in e)t[n]=e[n];return t}function T(t){for(var e={},n=0;n<t.length;n++)t[n]&&x(e,t[n]);return e}function P(t,e,n){}var I=function(t,e,n){return!1},E=function(t){return t};function L(t,e){if(t===e)return!0;var n=c(t),r=c(e);if(!n||!r)return!n&&!r&&String(t)===String(e);try{var i=Array.isArray(t),o=Array.isArray(e);if(i&&o)return t.length===e.length&&t.every((function(t,n){return L(t,e[n])}));if(t instanceof Date&&e instanceof Date)return t.getTime()===e.getTime();if(i||o)return!1;var a=Object.keys(t),s=Object.keys(e);return a.length===s.length&&a.every((function(n){return L(t[n],e[n])}))}catch(l){return!1}}function B(t,e){for(var n=0;n<t.length;n++)if(L(t[n],e))return n;return-1}function H(t){var e=!1;return function(){e||(e=!0,t.apply(this,arguments))}}var F="data-server-rendered",D=["component","directive","filter"],R=["beforeCreate","created","beforeMount","mounted","beforeUpdate","updated","beforeDestroy","destroyed","activated","deactivated","errorCaptured","serverPrefetch"],N={optionMergeStrategies:Object.create(null),silent:!1,productionTip:!1,devtools:!1,performance:!1,errorHandler:null,warnHandler:null,ignoredElements:[],keyCodes:Object.create(null),isReservedTag:I,isReservedAttr:I,isUnknownElement:I,getTagNamespace:P,parsePlatformTagName:E,mustUseProp:I,async:!0,_lifecycleHooks:R},$=/a-zA-Z\u00B7\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u037D\u037F-\u1FFF\u200C-\u200D\u203F-\u2040\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD/;function U(t){var e=(t+"").charCodeAt(0);return 36===e||95===e}function q(t,e,n,r){Object.defineProperty(t,e,{value:n,enumerable:!!r,writable:!0,configurable:!0})}var W=new RegExp("[^"+$.source+".$_\\d]");function G(t){if(!W.test(t)){var e=t.split(".");return function(t){for(var n=0;n<e.length;n++){if(!t)return;t=t[e[n]]}return t}}}var Y,K="__proto__"in{},Q="undefined"!==typeof window,X="undefined"!==typeof WXEnvironment&&!!WXEnvironment.platform,J=X&&WXEnvironment.platform.toLowerCase(),Z=Q&&window.navigator.userAgent.toLowerCase(),tt=Z&&/msie|trident/.test(Z),et=Z&&Z.indexOf("msie 9.0")>0,nt=Z&&Z.indexOf("edge/")>0,rt=(Z&&Z.indexOf("android"),Z&&/iphone|ipad|ipod|ios/.test(Z)||"ios"===J),it=(Z&&/chrome\/\d+/.test(Z),Z&&/phantomjs/.test(Z),Z&&Z.match(/firefox\/(\d+)/)),ot={}.watch,at=!1;if(Q)try{var st={};Object.defineProperty(st,"passive",{get:function(){at=!0}}),window.addEventListener("test-passive",null,st)}catch(Oa){}var ct=function(){return void 0===Y&&(Y=!Q&&!X&&"undefined"!==typeof t&&(t["process"]&&"server"===t["process"].env.VUE_ENV)),Y},lt=Q&&window.__VUE_DEVTOOLS_GLOBAL_HOOK__;function ut(t){return"function"===typeof t&&/native code/.test(t.toString())}var dt,ht="undefined"!==typeof Symbol&&ut(Symbol)&&"undefined"!==typeof Reflect&&ut(Reflect.ownKeys);dt="undefined"!==typeof Set&&ut(Set)?Set:function(){function t(){this.set=Object.create(null)}return t.prototype.has=function(t){return!0===this.set[t]},t.prototype.add=function(t){this.set[t]=!0},t.prototype.clear=function(){this.set=Object.create(null)},t}();var ft=P,pt=0,mt=function(){this.id=pt++,this.subs=[]};mt.prototype.addSub=function(t){this.subs.push(t)},mt.prototype.removeSub=function(t){v(this.subs,t)},mt.prototype.depend=function(){mt.target&&mt.target.addDep(this)},mt.prototype.notify=function(){var t=this.subs.slice();for(var e=0,n=t.length;e<n;e++)t[e].update()},mt.target=null;var bt=[];function gt(t){bt.push(t),mt.target=t}function vt(){bt.pop(),mt.target=bt[bt.length-1]}var wt=function(t,e,n,r,i,o,a,s){this.tag=t,this.data=e,this.children=n,this.text=r,this.elm=i,this.ns=void 0,this.context=o,this.fnContext=void 0,this.fnOptions=void 0,this.fnScopeId=void 0,this.key=e&&e.key,this.componentOptions=a,this.componentInstance=void 0,this.parent=void 0,this.raw=!1,this.isStatic=!1,this.isRootInsert=!0,this.isComment=!1,this.isCloned=!1,this.isOnce=!1,this.asyncFactory=s,this.asyncMeta=void 0,this.isAsyncPlaceholder=!1},yt={child:{configurable:!0}};yt.child.get=function(){return this.componentInstance},Object.defineProperties(wt.prototype,yt);var kt=function(t){void 0===t&&(t="");var e=new wt;return e.text=t,e.isComment=!0,e};function _t(t){return new wt(void 0,void 0,void 0,String(t))}function Ot(t){var e=new wt(t.tag,t.data,t.children&&t.children.slice(),t.text,t.elm,t.context,t.componentOptions,t.asyncFactory);return e.ns=t.ns,e.isStatic=t.isStatic,e.key=t.key,e.isComment=t.isComment,e.fnContext=t.fnContext,e.fnOptions=t.fnOptions,e.fnScopeId=t.fnScopeId,e.asyncMeta=t.asyncMeta,e.isCloned=!0,e}var zt=Array.prototype,At=Object.create(zt),jt=["push","pop","shift","unshift","splice","sort","reverse"];jt.forEach((function(t){var e=zt[t];q(At,t,(function(){var n=[],r=arguments.length;while(r--)n[r]=arguments[r];var i,o=e.apply(this,n),a=this.__ob__;switch(t){case"push":case"unshift":i=n;break;case"splice":i=n.slice(2);break}return i&&a.observeArray(i),a.dep.notify(),o}))}));var Mt=Object.getOwnPropertyNames(At),Ct=!0;function Vt(t){Ct=t}var St=function(t){this.value=t,this.dep=new mt,this.vmCount=0,q(t,"__ob__",this),Array.isArray(t)?(K?xt(t,At):Tt(t,At,Mt),this.observeArray(t)):this.walk(t)};function xt(t,e){t.__proto__=e}function Tt(t,e,n){for(var r=0,i=n.length;r<i;r++){var o=n[r];q(t,o,e[o])}}function Pt(t,e){var n;if(c(t)&&!(t instanceof wt))return y(t,"__ob__")&&t.__ob__ instanceof St?n=t.__ob__:Ct&&!ct()&&(Array.isArray(t)||u(t))&&Object.isExtensible(t)&&!t._isVue&&(n=new St(t)),e&&n&&n.vmCount++,n}function It(t,e,n,r,i){var o=new mt,a=Object.getOwnPropertyDescriptor(t,e);if(!a||!1!==a.configurable){var s=a&&a.get,c=a&&a.set;s&&!c||2!==arguments.length||(n=t[e]);var l=!i&&Pt(n);Object.defineProperty(t,e,{enumerable:!0,configurable:!0,get:function(){var e=s?s.call(t):n;return mt.target&&(o.depend(),l&&(l.dep.depend(),Array.isArray(e)&&Bt(e))),e},set:function(e){var r=s?s.call(t):n;e===r||e!==e&&r!==r||s&&!c||(c?c.call(t,e):n=e,l=!i&&Pt(e),o.notify())}})}}function Et(t,e,n){if(Array.isArray(t)&&h(e))return t.length=Math.max(t.length,e),t.splice(e,1,n),n;if(e in t&&!(e in Object.prototype))return t[e]=n,n;var r=t.__ob__;return t._isVue||r&&r.vmCount?n:r?(It(r.value,e,n),r.dep.notify(),n):(t[e]=n,n)}function Lt(t,e){if(Array.isArray(t)&&h(e))t.splice(e,1);else{var n=t.__ob__;t._isVue||n&&n.vmCount||y(t,e)&&(delete t[e],n&&n.dep.notify())}}function Bt(t){for(var e=void 0,n=0,r=t.length;n<r;n++)e=t[n],e&&e.__ob__&&e.__ob__.dep.depend(),Array.isArray(e)&&Bt(e)}St.prototype.walk=function(t){for(var e=Object.keys(t),n=0;n<e.length;n++)It(t,e[n])},St.prototype.observeArray=function(t){for(var e=0,n=t.length;e<n;e++)Pt(t[e])};var Ht=N.optionMergeStrategies;function Ft(t,e){if(!e)return t;for(var n,r,i,o=ht?Reflect.ownKeys(e):Object.keys(e),a=0;a<o.length;a++)n=o[a],"__ob__"!==n&&(r=t[n],i=e[n],y(t,n)?r!==i&&u(r)&&u(i)&&Ft(r,i):Et(t,n,i));return t}function Dt(t,e,n){return n?function(){var r="function"===typeof e?e.call(n,n):e,i="function"===typeof t?t.call(n,n):t;return r?Ft(r,i):i}:e?t?function(){return Ft("function"===typeof e?e.call(this,this):e,"function"===typeof t?t.call(this,this):t)}:e:t}function Rt(t,e){var n=e?t?t.concat(e):Array.isArray(e)?e:[e]:t;return n?Nt(n):n}function Nt(t){for(var e=[],n=0;n<t.length;n++)-1===e.indexOf(t[n])&&e.push(t[n]);return e}function $t(t,e,n,r){var i=Object.create(t||null);return e?x(i,e):i}Ht.data=function(t,e,n){return n?Dt(t,e,n):e&&"function"!==typeof e?t:Dt(t,e)},R.forEach((function(t){Ht[t]=Rt})),D.forEach((function(t){Ht[t+"s"]=$t})),Ht.watch=function(t,e,n,r){if(t===ot&&(t=void 0),e===ot&&(e=void 0),!e)return Object.create(t||null);if(!t)return e;var i={};for(var o in x(i,t),e){var a=i[o],s=e[o];a&&!Array.isArray(a)&&(a=[a]),i[o]=a?a.concat(s):Array.isArray(s)?s:[s]}return i},Ht.props=Ht.methods=Ht.inject=Ht.computed=function(t,e,n,r){if(!t)return e;var i=Object.create(null);return x(i,t),e&&x(i,e),i},Ht.provide=Dt;var Ut=function(t,e){return void 0===e?t:e};function qt(t,e){var n=t.props;if(n){var r,i,o,a={};if(Array.isArray(n)){r=n.length;while(r--)i=n[r],"string"===typeof i&&(o=O(i),a[o]={type:null})}else if(u(n))for(var s in n)i=n[s],o=O(s),a[o]=u(i)?i:{type:i};else 0;t.props=a}}function Wt(t,e){var n=t.inject;if(n){var r=t.inject={};if(Array.isArray(n))for(var i=0;i<n.length;i++)r[n[i]]={from:n[i]};else if(u(n))for(var o in n){var a=n[o];r[o]=u(a)?x({from:o},a):{from:a}}else 0}}function Gt(t){var e=t.directives;if(e)for(var n in e){var r=e[n];"function"===typeof r&&(e[n]={bind:r,update:r})}}function Yt(t,e,n){if("function"===typeof e&&(e=e.options),qt(e,n),Wt(e,n),Gt(e),!e._base&&(e.extends&&(t=Yt(t,e.extends,n)),e.mixins))for(var r=0,i=e.mixins.length;r<i;r++)t=Yt(t,e.mixins[r],n);var o,a={};for(o in t)s(o);for(o in e)y(t,o)||s(o);function s(r){var i=Ht[r]||Ut;a[r]=i(t[r],e[r],n,r)}return a}function Kt(t,e,n,r){if("string"===typeof n){var i=t[e];if(y(i,n))return i[n];var o=O(n);if(y(i,o))return i[o];var a=z(o);if(y(i,a))return i[a];var s=i[n]||i[o]||i[a];return s}}function Qt(t,e,n,r){var i=e[t],o=!y(n,t),a=n[t],s=te(Boolean,i.type);if(s>-1)if(o&&!y(i,"default"))a=!1;else if(""===a||a===j(t)){var c=te(String,i.type);(c<0||s<c)&&(a=!0)}if(void 0===a){a=Xt(r,i,t);var l=Ct;Vt(!0),Pt(a),Vt(l)}return a}function Xt(t,e,n){if(y(e,"default")){var r=e.default;return t&&t.$options.propsData&&void 0===t.$options.propsData[n]&&void 0!==t._props[n]?t._props[n]:"function"===typeof r&&"Function"!==Jt(e.type)?r.call(t):r}}function Jt(t){var e=t&&t.toString().match(/^\s*function (\w+)/);return e?e[1]:""}function Zt(t,e){return Jt(t)===Jt(e)}function te(t,e){if(!Array.isArray(e))return Zt(e,t)?0:-1;for(var n=0,r=e.length;n<r;n++)if(Zt(e[n],t))return n;return-1}function ee(t,e,n){gt();try{if(e){var r=e;while(r=r.$parent){var i=r.$options.errorCaptured;if(i)for(var o=0;o<i.length;o++)try{var a=!1===i[o].call(r,t,e,n);if(a)return}catch(Oa){re(Oa,r,"errorCaptured hook")}}}re(t,e,n)}finally{vt()}}function ne(t,e,n,r,i){var o;try{o=n?t.apply(e,n):t.call(e),o&&!o._isVue&&f(o)&&!o._handled&&(o.catch((function(t){return ee(t,r,i+" (Promise/async)")})),o._handled=!0)}catch(Oa){ee(Oa,r,i)}return o}function re(t,e,n){if(N.errorHandler)try{return N.errorHandler.call(null,t,e,n)}catch(Oa){Oa!==t&&ie(Oa,null,"config.errorHandler")}ie(t,e,n)}function ie(t,e,n){if(!Q&&!X||"undefined"===typeof console)throw t;console.error(t)}var oe,ae=!1,se=[],ce=!1;function le(){ce=!1;var t=se.slice(0);se.length=0;for(var e=0;e<t.length;e++)t[e]()}if("undefined"!==typeof Promise&&ut(Promise)){var ue=Promise.resolve();oe=function(){ue.then(le),rt&&setTimeout(P)},ae=!0}else if(tt||"undefined"===typeof MutationObserver||!ut(MutationObserver)&&"[object MutationObserverConstructor]"!==MutationObserver.toString())oe="undefined"!==typeof setImmediate&&ut(setImmediate)?function(){setImmediate(le)}:function(){setTimeout(le,0)};else{var de=1,he=new MutationObserver(le),fe=document.createTextNode(String(de));he.observe(fe,{characterData:!0}),oe=function(){de=(de+1)%2,fe.data=String(de)},ae=!0}function pe(t,e){var n;if(se.push((function(){if(t)try{t.call(e)}catch(Oa){ee(Oa,e,"nextTick")}else n&&n(e)})),ce||(ce=!0,oe()),!t&&"undefined"!==typeof Promise)return new Promise((function(t){n=t}))}var me=new dt;function be(t){ge(t,me),me.clear()}function ge(t,e){var n,r,i=Array.isArray(t);if(!(!i&&!c(t)||Object.isFrozen(t)||t instanceof wt)){if(t.__ob__){var o=t.__ob__.dep.id;if(e.has(o))return;e.add(o)}if(i){n=t.length;while(n--)ge(t[n],e)}else{r=Object.keys(t),n=r.length;while(n--)ge(t[r[n]],e)}}}var ve=k((function(t){var e="&"===t.charAt(0);t=e?t.slice(1):t;var n="~"===t.charAt(0);t=n?t.slice(1):t;var r="!"===t.charAt(0);return t=r?t.slice(1):t,{name:t,once:n,capture:r,passive:e}}));function we(t,e){function n(){var t=arguments,r=n.fns;if(!Array.isArray(r))return ne(r,null,arguments,e,"v-on handler");for(var i=r.slice(),o=0;o<i.length;o++)ne(i[o],null,t,e,"v-on handler")}return n.fns=t,n}function ye(t,e,n,i,a,s){var c,l,u,d;for(c in t)l=t[c],u=e[c],d=ve(c),r(l)||(r(u)?(r(l.fns)&&(l=t[c]=we(l,s)),o(d.once)&&(l=t[c]=a(d.name,l,d.capture)),n(d.name,l,d.capture,d.passive,d.params)):l!==u&&(u.fns=l,t[c]=u));for(c in e)r(t[c])&&(d=ve(c),i(d.name,e[c],d.capture))}function ke(t,e,n){var a;t instanceof wt&&(t=t.data.hook||(t.data.hook={}));var s=t[e];function c(){n.apply(this,arguments),v(a.fns,c)}r(s)?a=we([c]):i(s.fns)&&o(s.merged)?(a=s,a.fns.push(c)):a=we([s,c]),a.merged=!0,t[e]=a}function _e(t,e,n){var o=e.options.props;if(!r(o)){var a={},s=t.attrs,c=t.props;if(i(s)||i(c))for(var l in o){var u=j(l);Oe(a,c,l,u,!0)||Oe(a,s,l,u,!1)}return a}}function Oe(t,e,n,r,o){if(i(e)){if(y(e,n))return t[n]=e[n],o||delete e[n],!0;if(y(e,r))return t[n]=e[r],o||delete e[r],!0}return!1}function ze(t){for(var e=0;e<t.length;e++)if(Array.isArray(t[e]))return Array.prototype.concat.apply([],t);return t}function Ae(t){return s(t)?[_t(t)]:Array.isArray(t)?Me(t):void 0}function je(t){return i(t)&&i(t.text)&&a(t.isComment)}function Me(t,e){var n,a,c,l,u=[];for(n=0;n<t.length;n++)a=t[n],r(a)||"boolean"===typeof a||(c=u.length-1,l=u[c],Array.isArray(a)?a.length>0&&(a=Me(a,(e||"")+"_"+n),je(a[0])&&je(l)&&(u[c]=_t(l.text+a[0].text),a.shift()),u.push.apply(u,a)):s(a)?je(l)?u[c]=_t(l.text+a):""!==a&&u.push(_t(a)):je(a)&&je(l)?u[c]=_t(l.text+a.text):(o(t._isVList)&&i(a.tag)&&r(a.key)&&i(e)&&(a.key="__vlist"+e+"_"+n+"__"),u.push(a)));return u}function Ce(t){var e=t.$options.provide;e&&(t._provided="function"===typeof e?e.call(t):e)}function Ve(t){var e=Se(t.$options.inject,t);e&&(Vt(!1),Object.keys(e).forEach((function(n){It(t,n,e[n])})),Vt(!0))}function Se(t,e){if(t){for(var n=Object.create(null),r=ht?Reflect.ownKeys(t):Object.keys(t),i=0;i<r.length;i++){var o=r[i];if("__ob__"!==o){var a=t[o].from,s=e;while(s){if(s._provided&&y(s._provided,a)){n[o]=s._provided[a];break}s=s.$parent}if(!s)if("default"in t[o]){var c=t[o].default;n[o]="function"===typeof c?c.call(e):c}else 0}}return n}}function xe(t,e){if(!t||!t.length)return{};for(var n={},r=0,i=t.length;r<i;r++){var o=t[r],a=o.data;if(a&&a.attrs&&a.attrs.slot&&delete a.attrs.slot,o.context!==e&&o.fnContext!==e||!a||null==a.slot)(n.default||(n.default=[])).push(o);else{var s=a.slot,c=n[s]||(n[s]=[]);"template"===o.tag?c.push.apply(c,o.children||[]):c.push(o)}}for(var l in n)n[l].every(Te)&&delete n[l];return n}function Te(t){return t.isComment&&!t.asyncFactory||" "===t.text}function Pe(t,e,r){var i,o=Object.keys(e).length>0,a=t?!!t.$stable:!o,s=t&&t.$key;if(t){if(t._normalized)return t._normalized;if(a&&r&&r!==n&&s===r.$key&&!o&&!r.$hasNormal)return r;for(var c in i={},t)t[c]&&"$"!==c[0]&&(i[c]=Ie(e,c,t[c]))}else i={};for(var l in e)l in i||(i[l]=Ee(e,l));return t&&Object.isExtensible(t)&&(t._normalized=i),q(i,"$stable",a),q(i,"$key",s),q(i,"$hasNormal",o),i}function Ie(t,e,n){var r=function(){var t=arguments.length?n.apply(null,arguments):n({});return t=t&&"object"===typeof t&&!Array.isArray(t)?[t]:Ae(t),t&&(0===t.length||1===t.length&&t[0].isComment)?void 0:t};return n.proxy&&Object.defineProperty(t,e,{get:r,enumerable:!0,configurable:!0}),r}function Ee(t,e){return function(){return t[e]}}function Le(t,e){var n,r,o,a,s;if(Array.isArray(t)||"string"===typeof t)for(n=new Array(t.length),r=0,o=t.length;r<o;r++)n[r]=e(t[r],r);else if("number"===typeof t)for(n=new Array(t),r=0;r<t;r++)n[r]=e(r+1,r);else if(c(t))if(ht&&t[Symbol.iterator]){n=[];var l=t[Symbol.iterator](),u=l.next();while(!u.done)n.push(e(u.value,n.length)),u=l.next()}else for(a=Object.keys(t),n=new Array(a.length),r=0,o=a.length;r<o;r++)s=a[r],n[r]=e(t[s],s,r);return i(n)||(n=[]),n._isVList=!0,n}function Be(t,e,n,r){var i,o=this.$scopedSlots[t];o?(n=n||{},r&&(n=x(x({},r),n)),i=o(n)||e):i=this.$slots[t]||e;var a=n&&n.slot;return a?this.$createElement("template",{slot:a},i):i}function He(t){return Kt(this.$options,"filters",t,!0)||E}function Fe(t,e){return Array.isArray(t)?-1===t.indexOf(e):t!==e}function De(t,e,n,r,i){var o=N.keyCodes[e]||n;return i&&r&&!N.keyCodes[e]?Fe(i,r):o?Fe(o,t):r?j(r)!==e:void 0}function Re(t,e,n,r,i){if(n)if(c(n)){var o;Array.isArray(n)&&(n=T(n));var a=function(a){if("class"===a||"style"===a||g(a))o=t;else{var s=t.attrs&&t.attrs.type;o=r||N.mustUseProp(e,s,a)?t.domProps||(t.domProps={}):t.attrs||(t.attrs={})}var c=O(a),l=j(a);if(!(c in o)&&!(l in o)&&(o[a]=n[a],i)){var u=t.on||(t.on={});u["update:"+a]=function(t){n[a]=t}}};for(var s in n)a(s)}else;return t}function Ne(t,e){var n=this._staticTrees||(this._staticTrees=[]),r=n[t];return r&&!e||(r=n[t]=this.$options.staticRenderFns[t].call(this._renderProxy,null,this),Ue(r,"__static__"+t,!1)),r}function $e(t,e,n){return Ue(t,"__once__"+e+(n?"_"+n:""),!0),t}function Ue(t,e,n){if(Array.isArray(t))for(var r=0;r<t.length;r++)t[r]&&"string"!==typeof t[r]&&qe(t[r],e+"_"+r,n);else qe(t,e,n)}function qe(t,e,n){t.isStatic=!0,t.key=e,t.isOnce=n}function We(t,e){if(e)if(u(e)){var n=t.on=t.on?x({},t.on):{};for(var r in e){var i=n[r],o=e[r];n[r]=i?[].concat(i,o):o}}else;return t}function Ge(t,e,n,r){e=e||{$stable:!n};for(var i=0;i<t.length;i++){var o=t[i];Array.isArray(o)?Ge(o,e,n):o&&(o.proxy&&(o.fn.proxy=!0),e[o.key]=o.fn)}return r&&(e.$key=r),e}function Ye(t,e){for(var n=0;n<e.length;n+=2){var r=e[n];"string"===typeof r&&r&&(t[e[n]]=e[n+1])}return t}function Ke(t,e){return"string"===typeof t?e+t:t}function Qe(t){t._o=$e,t._n=m,t._s=p,t._l=Le,t._t=Be,t._q=L,t._i=B,t._m=Ne,t._f=He,t._k=De,t._b=Re,t._v=_t,t._e=kt,t._u=Ge,t._g=We,t._d=Ye,t._p=Ke}function Xe(t,e,r,i,a){var s,c=this,l=a.options;y(i,"_uid")?(s=Object.create(i),s._original=i):(s=i,i=i._original);var u=o(l._compiled),d=!u;this.data=t,this.props=e,this.children=r,this.parent=i,this.listeners=t.on||n,this.injections=Se(l.inject,i),this.slots=function(){return c.$slots||Pe(t.scopedSlots,c.$slots=xe(r,i)),c.$slots},Object.defineProperty(this,"scopedSlots",{enumerable:!0,get:function(){return Pe(t.scopedSlots,this.slots())}}),u&&(this.$options=l,this.$slots=this.slots(),this.$scopedSlots=Pe(t.scopedSlots,this.$slots)),l._scopeId?this._c=function(t,e,n,r){var o=dn(s,t,e,n,r,d);return o&&!Array.isArray(o)&&(o.fnScopeId=l._scopeId,o.fnContext=i),o}:this._c=function(t,e,n,r){return dn(s,t,e,n,r,d)}}function Je(t,e,r,o,a){var s=t.options,c={},l=s.props;if(i(l))for(var u in l)c[u]=Qt(u,l,e||n);else i(r.attrs)&&tn(c,r.attrs),i(r.props)&&tn(c,r.props);var d=new Xe(r,c,a,o,t),h=s.render.call(null,d._c,d);if(h instanceof wt)return Ze(h,r,d.parent,s,d);if(Array.isArray(h)){for(var f=Ae(h)||[],p=new Array(f.length),m=0;m<f.length;m++)p[m]=Ze(f[m],r,d.parent,s,d);return p}}function Ze(t,e,n,r,i){var o=Ot(t);return o.fnContext=n,o.fnOptions=r,e.slot&&((o.data||(o.data={})).slot=e.slot),o}function tn(t,e){for(var n in e)t[O(n)]=e[n]}Qe(Xe.prototype);var en={init:function(t,e){if(t.componentInstance&&!t.componentInstance._isDestroyed&&t.data.keepAlive){var n=t;en.prepatch(n,n)}else{var r=t.componentInstance=on(t,Sn);r.$mount(e?t.elm:void 0,e)}},prepatch:function(t,e){var n=e.componentOptions,r=e.componentInstance=t.componentInstance;En(r,n.propsData,n.listeners,e,n.children)},insert:function(t){var e=t.context,n=t.componentInstance;n._isMounted||(n._isMounted=!0,Fn(n,"mounted")),t.data.keepAlive&&(e._isMounted?Jn(n):Bn(n,!0))},destroy:function(t){var e=t.componentInstance;e._isDestroyed||(t.data.keepAlive?Hn(e,!0):e.$destroy())}},nn=Object.keys(en);function rn(t,e,n,a,s){if(!r(t)){var l=n.$options._base;if(c(t)&&(t=l.extend(t)),"function"===typeof t){var u;if(r(t.cid)&&(u=t,t=kn(u,l),void 0===t))return yn(u,e,n,a,s);e=e||{},kr(t),i(e.model)&&cn(t.options,e);var d=_e(e,t,s);if(o(t.options.functional))return Je(t,d,e,n,a);var h=e.on;if(e.on=e.nativeOn,o(t.options.abstract)){var f=e.slot;e={},f&&(e.slot=f)}an(e);var p=t.options.name||s,m=new wt("vue-component-"+t.cid+(p?"-"+p:""),e,void 0,void 0,void 0,n,{Ctor:t,propsData:d,listeners:h,tag:s,children:a},u);return m}}}function on(t,e){var n={_isComponent:!0,_parentVnode:t,parent:e},r=t.data.inlineTemplate;return i(r)&&(n.render=r.render,n.staticRenderFns=r.staticRenderFns),new t.componentOptions.Ctor(n)}function an(t){for(var e=t.hook||(t.hook={}),n=0;n<nn.length;n++){var r=nn[n],i=e[r],o=en[r];i===o||i&&i._merged||(e[r]=i?sn(o,i):o)}}function sn(t,e){var n=function(n,r){t(n,r),e(n,r)};return n._merged=!0,n}function cn(t,e){var n=t.model&&t.model.prop||"value",r=t.model&&t.model.event||"input";(e.attrs||(e.attrs={}))[n]=e.model.value;var o=e.on||(e.on={}),a=o[r],s=e.model.callback;i(a)?(Array.isArray(a)?-1===a.indexOf(s):a!==s)&&(o[r]=[s].concat(a)):o[r]=s}var ln=1,un=2;function dn(t,e,n,r,i,a){return(Array.isArray(n)||s(n))&&(i=r,r=n,n=void 0),o(a)&&(i=un),hn(t,e,n,r,i)}function hn(t,e,n,r,o){if(i(n)&&i(n.__ob__))return kt();if(i(n)&&i(n.is)&&(e=n.is),!e)return kt();var a,s,c;(Array.isArray(r)&&"function"===typeof r[0]&&(n=n||{},n.scopedSlots={default:r[0]},r.length=0),o===un?r=Ae(r):o===ln&&(r=ze(r)),"string"===typeof e)?(s=t.$vnode&&t.$vnode.ns||N.getTagNamespace(e),a=N.isReservedTag(e)?new wt(N.parsePlatformTagName(e),n,r,void 0,void 0,t):n&&n.pre||!i(c=Kt(t.$options,"components",e))?new wt(e,n,r,void 0,void 0,t):rn(c,n,t,r,e)):a=rn(e,n,t,r);return Array.isArray(a)?a:i(a)?(i(s)&&fn(a,s),i(n)&&pn(n),a):kt()}function fn(t,e,n){if(t.ns=e,"foreignObject"===t.tag&&(e=void 0,n=!0),i(t.children))for(var a=0,s=t.children.length;a<s;a++){var c=t.children[a];i(c.tag)&&(r(c.ns)||o(n)&&"svg"!==c.tag)&&fn(c,e,n)}}function pn(t){c(t.style)&&be(t.style),c(t.class)&&be(t.class)}function mn(t){t._vnode=null,t._staticTrees=null;var e=t.$options,r=t.$vnode=e._parentVnode,i=r&&r.context;t.$slots=xe(e._renderChildren,i),t.$scopedSlots=n,t._c=function(e,n,r,i){return dn(t,e,n,r,i,!1)},t.$createElement=function(e,n,r,i){return dn(t,e,n,r,i,!0)};var o=r&&r.data;It(t,"$attrs",o&&o.attrs||n,null,!0),It(t,"$listeners",e._parentListeners||n,null,!0)}var bn,gn=null;function vn(t){Qe(t.prototype),t.prototype.$nextTick=function(t){return pe(t,this)},t.prototype._render=function(){var t,e=this,n=e.$options,r=n.render,i=n._parentVnode;i&&(e.$scopedSlots=Pe(i.data.scopedSlots,e.$slots,e.$scopedSlots)),e.$vnode=i;try{gn=e,t=r.call(e._renderProxy,e.$createElement)}catch(Oa){ee(Oa,e,"render"),t=e._vnode}finally{gn=null}return Array.isArray(t)&&1===t.length&&(t=t[0]),t instanceof wt||(t=kt()),t.parent=i,t}}function wn(t,e){return(t.__esModule||ht&&"Module"===t[Symbol.toStringTag])&&(t=t.default),c(t)?e.extend(t):t}function yn(t,e,n,r,i){var o=kt();return o.asyncFactory=t,o.asyncMeta={data:e,context:n,children:r,tag:i},o}function kn(t,e){if(o(t.error)&&i(t.errorComp))return t.errorComp;if(i(t.resolved))return t.resolved;var n=gn;if(n&&i(t.owners)&&-1===t.owners.indexOf(n)&&t.owners.push(n),o(t.loading)&&i(t.loadingComp))return t.loadingComp;if(n&&!i(t.owners)){var a=t.owners=[n],s=!0,l=null,u=null;n.$on("hook:destroyed",(function(){return v(a,n)}));var d=function(t){for(var e=0,n=a.length;e<n;e++)a[e].$forceUpdate();t&&(a.length=0,null!==l&&(clearTimeout(l),l=null),null!==u&&(clearTimeout(u),u=null))},h=H((function(n){t.resolved=wn(n,e),s?a.length=0:d(!0)})),p=H((function(e){i(t.errorComp)&&(t.error=!0,d(!0))})),m=t(h,p);return c(m)&&(f(m)?r(t.resolved)&&m.then(h,p):f(m.component)&&(m.component.then(h,p),i(m.error)&&(t.errorComp=wn(m.error,e)),i(m.loading)&&(t.loadingComp=wn(m.loading,e),0===m.delay?t.loading=!0:l=setTimeout((function(){l=null,r(t.resolved)&&r(t.error)&&(t.loading=!0,d(!1))}),m.delay||200)),i(m.timeout)&&(u=setTimeout((function(){u=null,r(t.resolved)&&p(null)}),m.timeout)))),s=!1,t.loading?t.loadingComp:t.resolved}}function _n(t){return t.isComment&&t.asyncFactory}function On(t){if(Array.isArray(t))for(var e=0;e<t.length;e++){var n=t[e];if(i(n)&&(i(n.componentOptions)||_n(n)))return n}}function zn(t){t._events=Object.create(null),t._hasHookEvent=!1;var e=t.$options._parentListeners;e&&Cn(t,e)}function An(t,e){bn.$on(t,e)}function jn(t,e){bn.$off(t,e)}function Mn(t,e){var n=bn;return function r(){var i=e.apply(null,arguments);null!==i&&n.$off(t,r)}}function Cn(t,e,n){bn=t,ye(e,n||{},An,jn,Mn,t),bn=void 0}function Vn(t){var e=/^hook:/;t.prototype.$on=function(t,n){var r=this;if(Array.isArray(t))for(var i=0,o=t.length;i<o;i++)r.$on(t[i],n);else(r._events[t]||(r._events[t]=[])).push(n),e.test(t)&&(r._hasHookEvent=!0);return r},t.prototype.$once=function(t,e){var n=this;function r(){n.$off(t,r),e.apply(n,arguments)}return r.fn=e,n.$on(t,r),n},t.prototype.$off=function(t,e){var n=this;if(!arguments.length)return n._events=Object.create(null),n;if(Array.isArray(t)){for(var r=0,i=t.length;r<i;r++)n.$off(t[r],e);return n}var o,a=n._events[t];if(!a)return n;if(!e)return n._events[t]=null,n;var s=a.length;while(s--)if(o=a[s],o===e||o.fn===e){a.splice(s,1);break}return n},t.prototype.$emit=function(t){var e=this,n=e._events[t];if(n){n=n.length>1?S(n):n;for(var r=S(arguments,1),i='event handler for "'+t+'"',o=0,a=n.length;o<a;o++)ne(n[o],e,r,e,i)}return e}}var Sn=null;function xn(t){var e=Sn;return Sn=t,function(){Sn=e}}function Tn(t){var e=t.$options,n=e.parent;if(n&&!e.abstract){while(n.$options.abstract&&n.$parent)n=n.$parent;n.$children.push(t)}t.$parent=n,t.$root=n?n.$root:t,t.$children=[],t.$refs={},t._watcher=null,t._inactive=null,t._directInactive=!1,t._isMounted=!1,t._isDestroyed=!1,t._isBeingDestroyed=!1}function Pn(t){t.prototype._update=function(t,e){var n=this,r=n.$el,i=n._vnode,o=xn(n);n._vnode=t,n.$el=i?n.__patch__(i,t):n.__patch__(n.$el,t,e,!1),o(),r&&(r.__vue__=null),n.$el&&(n.$el.__vue__=n),n.$vnode&&n.$parent&&n.$vnode===n.$parent._vnode&&(n.$parent.$el=n.$el)},t.prototype.$forceUpdate=function(){var t=this;t._watcher&&t._watcher.update()},t.prototype.$destroy=function(){var t=this;if(!t._isBeingDestroyed){Fn(t,"beforeDestroy"),t._isBeingDestroyed=!0;var e=t.$parent;!e||e._isBeingDestroyed||t.$options.abstract||v(e.$children,t),t._watcher&&t._watcher.teardown();var n=t._watchers.length;while(n--)t._watchers[n].teardown();t._data.__ob__&&t._data.__ob__.vmCount--,t._isDestroyed=!0,t.__patch__(t._vnode,null),Fn(t,"destroyed"),t.$off(),t.$el&&(t.$el.__vue__=null),t.$vnode&&(t.$vnode.parent=null)}}}function In(t,e,n){var r;return t.$el=e,t.$options.render||(t.$options.render=kt),Fn(t,"beforeMount"),r=function(){t._update(t._render(),n)},new nr(t,r,P,{before:function(){t._isMounted&&!t._isDestroyed&&Fn(t,"beforeUpdate")}},!0),n=!1,null==t.$vnode&&(t._isMounted=!0,Fn(t,"mounted")),t}function En(t,e,r,i,o){var a=i.data.scopedSlots,s=t.$scopedSlots,c=!!(a&&!a.$stable||s!==n&&!s.$stable||a&&t.$scopedSlots.$key!==a.$key),l=!!(o||t.$options._renderChildren||c);if(t.$options._parentVnode=i,t.$vnode=i,t._vnode&&(t._vnode.parent=i),t.$options._renderChildren=o,t.$attrs=i.data.attrs||n,t.$listeners=r||n,e&&t.$options.props){Vt(!1);for(var u=t._props,d=t.$options._propKeys||[],h=0;h<d.length;h++){var f=d[h],p=t.$options.props;u[f]=Qt(f,p,e,t)}Vt(!0),t.$options.propsData=e}r=r||n;var m=t.$options._parentListeners;t.$options._parentListeners=r,Cn(t,r,m),l&&(t.$slots=xe(o,i.context),t.$forceUpdate())}function Ln(t){while(t&&(t=t.$parent))if(t._inactive)return!0;return!1}function Bn(t,e){if(e){if(t._directInactive=!1,Ln(t))return}else if(t._directInactive)return;if(t._inactive||null===t._inactive){t._inactive=!1;for(var n=0;n<t.$children.length;n++)Bn(t.$children[n]);Fn(t,"activated")}}function Hn(t,e){if((!e||(t._directInactive=!0,!Ln(t)))&&!t._inactive){t._inactive=!0;for(var n=0;n<t.$children.length;n++)Hn(t.$children[n]);Fn(t,"deactivated")}}function Fn(t,e){gt();var n=t.$options[e],r=e+" hook";if(n)for(var i=0,o=n.length;i<o;i++)ne(n[i],t,null,t,r);t._hasHookEvent&&t.$emit("hook:"+e),vt()}var Dn=[],Rn=[],Nn={},$n=!1,Un=!1,qn=0;function Wn(){qn=Dn.length=Rn.length=0,Nn={},$n=Un=!1}var Gn=0,Yn=Date.now;if(Q&&!tt){var Kn=window.performance;Kn&&"function"===typeof Kn.now&&Yn()>document.createEvent("Event").timeStamp&&(Yn=function(){return Kn.now()})}function Qn(){var t,e;for(Gn=Yn(),Un=!0,Dn.sort((function(t,e){return t.id-e.id})),qn=0;qn<Dn.length;qn++)t=Dn[qn],t.before&&t.before(),e=t.id,Nn[e]=null,t.run();var n=Rn.slice(),r=Dn.slice();Wn(),Zn(n),Xn(r),lt&&N.devtools&&lt.emit("flush")}function Xn(t){var e=t.length;while(e--){var n=t[e],r=n.vm;r._watcher===n&&r._isMounted&&!r._isDestroyed&&Fn(r,"updated")}}function Jn(t){t._inactive=!1,Rn.push(t)}function Zn(t){for(var e=0;e<t.length;e++)t[e]._inactive=!0,Bn(t[e],!0)}function tr(t){var e=t.id;if(null==Nn[e]){if(Nn[e]=!0,Un){var n=Dn.length-1;while(n>qn&&Dn[n].id>t.id)n--;Dn.splice(n+1,0,t)}else Dn.push(t);$n||($n=!0,pe(Qn))}}var er=0,nr=function(t,e,n,r,i){this.vm=t,i&&(t._watcher=this),t._watchers.push(this),r?(this.deep=!!r.deep,this.user=!!r.user,this.lazy=!!r.lazy,this.sync=!!r.sync,this.before=r.before):this.deep=this.user=this.lazy=this.sync=!1,this.cb=n,this.id=++er,this.active=!0,this.dirty=this.lazy,this.deps=[],this.newDeps=[],this.depIds=new dt,this.newDepIds=new dt,this.expression="","function"===typeof e?this.getter=e:(this.getter=G(e),this.getter||(this.getter=P)),this.value=this.lazy?void 0:this.get()};nr.prototype.get=function(){var t;gt(this);var e=this.vm;try{t=this.getter.call(e,e)}catch(Oa){if(!this.user)throw Oa;ee(Oa,e,'getter for watcher "'+this.expression+'"')}finally{this.deep&&be(t),vt(),this.cleanupDeps()}return t},nr.prototype.addDep=function(t){var e=t.id;this.newDepIds.has(e)||(this.newDepIds.add(e),this.newDeps.push(t),this.depIds.has(e)||t.addSub(this))},nr.prototype.cleanupDeps=function(){var t=this.deps.length;while(t--){var e=this.deps[t];this.newDepIds.has(e.id)||e.removeSub(this)}var n=this.depIds;this.depIds=this.newDepIds,this.newDepIds=n,this.newDepIds.clear(),n=this.deps,this.deps=this.newDeps,this.newDeps=n,this.newDeps.length=0},nr.prototype.update=function(){this.lazy?this.dirty=!0:this.sync?this.run():tr(this)},nr.prototype.run=function(){if(this.active){var t=this.get();if(t!==this.value||c(t)||this.deep){var e=this.value;if(this.value=t,this.user)try{this.cb.call(this.vm,t,e)}catch(Oa){ee(Oa,this.vm,'callback for watcher "'+this.expression+'"')}else this.cb.call(this.vm,t,e)}}},nr.prototype.evaluate=function(){this.value=this.get(),this.dirty=!1},nr.prototype.depend=function(){var t=this.deps.length;while(t--)this.deps[t].depend()},nr.prototype.teardown=function(){if(this.active){this.vm._isBeingDestroyed||v(this.vm._watchers,this);var t=this.deps.length;while(t--)this.deps[t].removeSub(this);this.active=!1}};var rr={enumerable:!0,configurable:!0,get:P,set:P};function ir(t,e,n){rr.get=function(){return this[e][n]},rr.set=function(t){this[e][n]=t},Object.defineProperty(t,n,rr)}function or(t){t._watchers=[];var e=t.$options;e.props&&ar(t,e.props),e.methods&&pr(t,e.methods),e.data?sr(t):Pt(t._data={},!0),e.computed&&ur(t,e.computed),e.watch&&e.watch!==ot&&mr(t,e.watch)}function ar(t,e){var n=t.$options.propsData||{},r=t._props={},i=t.$options._propKeys=[],o=!t.$parent;o||Vt(!1);var a=function(o){i.push(o);var a=Qt(o,e,n,t);It(r,o,a),o in t||ir(t,"_props",o)};for(var s in e)a(s);Vt(!0)}function sr(t){var e=t.$options.data;e=t._data="function"===typeof e?cr(e,t):e||{},u(e)||(e={});var n=Object.keys(e),r=t.$options.props,i=(t.$options.methods,n.length);while(i--){var o=n[i];0,r&&y(r,o)||U(o)||ir(t,"_data",o)}Pt(e,!0)}function cr(t,e){gt();try{return t.call(e,e)}catch(Oa){return ee(Oa,e,"data()"),{}}finally{vt()}}var lr={lazy:!0};function ur(t,e){var n=t._computedWatchers=Object.create(null),r=ct();for(var i in e){var o=e[i],a="function"===typeof o?o:o.get;0,r||(n[i]=new nr(t,a||P,P,lr)),i in t||dr(t,i,o)}}function dr(t,e,n){var r=!ct();"function"===typeof n?(rr.get=r?hr(e):fr(n),rr.set=P):(rr.get=n.get?r&&!1!==n.cache?hr(e):fr(n.get):P,rr.set=n.set||P),Object.defineProperty(t,e,rr)}function hr(t){return function(){var e=this._computedWatchers&&this._computedWatchers[t];if(e)return e.dirty&&e.evaluate(),mt.target&&e.depend(),e.value}}function fr(t){return function(){return t.call(this,this)}}function pr(t,e){t.$options.props;for(var n in e)t[n]="function"!==typeof e[n]?P:V(e[n],t)}function mr(t,e){for(var n in e){var r=e[n];if(Array.isArray(r))for(var i=0;i<r.length;i++)br(t,n,r[i]);else br(t,n,r)}}function br(t,e,n,r){return u(n)&&(r=n,n=n.handler),"string"===typeof n&&(n=t[n]),t.$watch(e,n,r)}function gr(t){var e={get:function(){return this._data}},n={get:function(){return this._props}};Object.defineProperty(t.prototype,"$data",e),Object.defineProperty(t.prototype,"$props",n),t.prototype.$set=Et,t.prototype.$delete=Lt,t.prototype.$watch=function(t,e,n){var r=this;if(u(e))return br(r,t,e,n);n=n||{},n.user=!0;var i=new nr(r,t,e,n);if(n.immediate)try{e.call(r,i.value)}catch(o){ee(o,r,'callback for immediate watcher "'+i.expression+'"')}return function(){i.teardown()}}}var vr=0;function wr(t){t.prototype._init=function(t){var e=this;e._uid=vr++,e._isVue=!0,t&&t._isComponent?yr(e,t):e.$options=Yt(kr(e.constructor),t||{},e),e._renderProxy=e,e._self=e,Tn(e),zn(e),mn(e),Fn(e,"beforeCreate"),Ve(e),or(e),Ce(e),Fn(e,"created"),e.$options.el&&e.$mount(e.$options.el)}}function yr(t,e){var n=t.$options=Object.create(t.constructor.options),r=e._parentVnode;n.parent=e.parent,n._parentVnode=r;var i=r.componentOptions;n.propsData=i.propsData,n._parentListeners=i.listeners,n._renderChildren=i.children,n._componentTag=i.tag,e.render&&(n.render=e.render,n.staticRenderFns=e.staticRenderFns)}function kr(t){var e=t.options;if(t.super){var n=kr(t.super),r=t.superOptions;if(n!==r){t.superOptions=n;var i=_r(t);i&&x(t.extendOptions,i),e=t.options=Yt(n,t.extendOptions),e.name&&(e.components[e.name]=t)}}return e}function _r(t){var e,n=t.options,r=t.sealedOptions;for(var i in n)n[i]!==r[i]&&(e||(e={}),e[i]=n[i]);return e}function Or(t){this._init(t)}function zr(t){t.use=function(t){var e=this._installedPlugins||(this._installedPlugins=[]);if(e.indexOf(t)>-1)return this;var n=S(arguments,1);return n.unshift(this),"function"===typeof t.install?t.install.apply(t,n):"function"===typeof t&&t.apply(null,n),e.push(t),this}}function Ar(t){t.mixin=function(t){return this.options=Yt(this.options,t),this}}function jr(t){t.cid=0;var e=1;t.extend=function(t){t=t||{};var n=this,r=n.cid,i=t._Ctor||(t._Ctor={});if(i[r])return i[r];var o=t.name||n.options.name;var a=function(t){this._init(t)};return a.prototype=Object.create(n.prototype),a.prototype.constructor=a,a.cid=e++,a.options=Yt(n.options,t),a["super"]=n,a.options.props&&Mr(a),a.options.computed&&Cr(a),a.extend=n.extend,a.mixin=n.mixin,a.use=n.use,D.forEach((function(t){a[t]=n[t]})),o&&(a.options.components[o]=a),a.superOptions=n.options,a.extendOptions=t,a.sealedOptions=x({},a.options),i[r]=a,a}}function Mr(t){var e=t.options.props;for(var n in e)ir(t.prototype,"_props",n)}function Cr(t){var e=t.options.computed;for(var n in e)dr(t.prototype,n,e[n])}function Vr(t){D.forEach((function(e){t[e]=function(t,n){return n?("component"===e&&u(n)&&(n.name=n.name||t,n=this.options._base.extend(n)),"directive"===e&&"function"===typeof n&&(n={bind:n,update:n}),this.options[e+"s"][t]=n,n):this.options[e+"s"][t]}}))}function Sr(t){return t&&(t.Ctor.options.name||t.tag)}function xr(t,e){return Array.isArray(t)?t.indexOf(e)>-1:"string"===typeof t?t.split(",").indexOf(e)>-1:!!d(t)&&t.test(e)}function Tr(t,e){var n=t.cache,r=t.keys,i=t._vnode;for(var o in n){var a=n[o];if(a){var s=Sr(a.componentOptions);s&&!e(s)&&Pr(n,o,r,i)}}}function Pr(t,e,n,r){var i=t[e];!i||r&&i.tag===r.tag||i.componentInstance.$destroy(),t[e]=null,v(n,e)}wr(Or),gr(Or),Vn(Or),Pn(Or),vn(Or);var Ir=[String,RegExp,Array],Er={name:"keep-alive",abstract:!0,props:{include:Ir,exclude:Ir,max:[String,Number]},created:function(){this.cache=Object.create(null),this.keys=[]},destroyed:function(){for(var t in this.cache)Pr(this.cache,t,this.keys)},mounted:function(){var t=this;this.$watch("include",(function(e){Tr(t,(function(t){return xr(e,t)}))})),this.$watch("exclude",(function(e){Tr(t,(function(t){return!xr(e,t)}))}))},render:function(){var t=this.$slots.default,e=On(t),n=e&&e.componentOptions;if(n){var r=Sr(n),i=this,o=i.include,a=i.exclude;if(o&&(!r||!xr(o,r))||a&&r&&xr(a,r))return e;var s=this,c=s.cache,l=s.keys,u=null==e.key?n.Ctor.cid+(n.tag?"::"+n.tag:""):e.key;c[u]?(e.componentInstance=c[u].componentInstance,v(l,u),l.push(u)):(c[u]=e,l.push(u),this.max&&l.length>parseInt(this.max)&&Pr(c,l[0],l,this._vnode)),e.data.keepAlive=!0}return e||t&&t[0]}},Lr={KeepAlive:Er};function Br(t){var e={get:function(){return N}};Object.defineProperty(t,"config",e),t.util={warn:ft,extend:x,mergeOptions:Yt,defineReactive:It},t.set=Et,t.delete=Lt,t.nextTick=pe,t.observable=function(t){return Pt(t),t},t.options=Object.create(null),D.forEach((function(e){t.options[e+"s"]=Object.create(null)})),t.options._base=t,x(t.options.components,Lr),zr(t),Ar(t),jr(t),Vr(t)}Br(Or),Object.defineProperty(Or.prototype,"$isServer",{get:ct}),Object.defineProperty(Or.prototype,"$ssrContext",{get:function(){return this.$vnode&&this.$vnode.ssrContext}}),Object.defineProperty(Or,"FunctionalRenderContext",{value:Xe}),Or.version="2.6.12";var Hr=b("style,class"),Fr=b("input,textarea,option,select,progress"),Dr=function(t,e,n){return"value"===n&&Fr(t)&&"button"!==e||"selected"===n&&"option"===t||"checked"===n&&"input"===t||"muted"===n&&"video"===t},Rr=b("contenteditable,draggable,spellcheck"),Nr=b("events,caret,typing,plaintext-only"),$r=function(t,e){return Yr(e)||"false"===e?"false":"contenteditable"===t&&Nr(e)?e:"true"},Ur=b("allowfullscreen,async,autofocus,autoplay,checked,compact,controls,declare,default,defaultchecked,defaultmuted,defaultselected,defer,disabled,enabled,formnovalidate,hidden,indeterminate,inert,ismap,itemscope,loop,multiple,muted,nohref,noresize,noshade,novalidate,nowrap,open,pauseonexit,readonly,required,reversed,scoped,seamless,selected,sortable,translate,truespeed,typemustmatch,visible"),qr="http://www.w3.org/1999/xlink",Wr=function(t){return":"===t.charAt(5)&&"xlink"===t.slice(0,5)},Gr=function(t){return Wr(t)?t.slice(6,t.length):""},Yr=function(t){return null==t||!1===t};function Kr(t){var e=t.data,n=t,r=t;while(i(r.componentInstance))r=r.componentInstance._vnode,r&&r.data&&(e=Qr(r.data,e));while(i(n=n.parent))n&&n.data&&(e=Qr(e,n.data));return Xr(e.staticClass,e.class)}function Qr(t,e){return{staticClass:Jr(t.staticClass,e.staticClass),class:i(t.class)?[t.class,e.class]:e.class}}function Xr(t,e){return i(t)||i(e)?Jr(t,Zr(e)):""}function Jr(t,e){return t?e?t+" "+e:t:e||""}function Zr(t){return Array.isArray(t)?ti(t):c(t)?ei(t):"string"===typeof t?t:""}function ti(t){for(var e,n="",r=0,o=t.length;r<o;r++)i(e=Zr(t[r]))&&""!==e&&(n&&(n+=" "),n+=e);return n}function ei(t){var e="";for(var n in t)t[n]&&(e&&(e+=" "),e+=n);return e}var ni={svg:"http://www.w3.org/2000/svg",math:"http://www.w3.org/1998/Math/MathML"},ri=b("html,body,base,head,link,meta,style,title,address,article,aside,footer,header,h1,h2,h3,h4,h5,h6,hgroup,nav,section,div,dd,dl,dt,figcaption,figure,picture,hr,img,li,main,ol,p,pre,ul,a,b,abbr,bdi,bdo,br,cite,code,data,dfn,em,i,kbd,mark,q,rp,rt,rtc,ruby,s,samp,small,span,strong,sub,sup,time,u,var,wbr,area,audio,map,track,video,embed,object,param,source,canvas,script,noscript,del,ins,caption,col,colgroup,table,thead,tbody,td,th,tr,button,datalist,fieldset,form,input,label,legend,meter,optgroup,option,output,progress,select,textarea,details,dialog,menu,menuitem,summary,content,element,shadow,template,blockquote,iframe,tfoot"),ii=b("svg,animate,circle,clippath,cursor,defs,desc,ellipse,filter,font-face,foreignObject,g,glyph,image,line,marker,mask,missing-glyph,path,pattern,polygon,polyline,rect,switch,symbol,text,textpath,tspan,use,view",!0),oi=function(t){return ri(t)||ii(t)};function ai(t){return ii(t)?"svg":"math"===t?"math":void 0}var si=Object.create(null);function ci(t){if(!Q)return!0;if(oi(t))return!1;if(t=t.toLowerCase(),null!=si[t])return si[t];var e=document.createElement(t);return t.indexOf("-")>-1?si[t]=e.constructor===window.HTMLUnknownElement||e.constructor===window.HTMLElement:si[t]=/HTMLUnknownElement/.test(e.toString())}var li=b("text,number,password,search,email,tel,url");function ui(t){if("string"===typeof t){var e=document.querySelector(t);return e||document.createElement("div")}return t}function di(t,e){var n=document.createElement(t);return"select"!==t||e.data&&e.data.attrs&&void 0!==e.data.attrs.multiple&&n.setAttribute("multiple","multiple"),n}function hi(t,e){return document.createElementNS(ni[t],e)}function fi(t){return document.createTextNode(t)}function pi(t){return document.createComment(t)}function mi(t,e,n){t.insertBefore(e,n)}function bi(t,e){t.removeChild(e)}function gi(t,e){t.appendChild(e)}function vi(t){return t.parentNode}function wi(t){return t.nextSibling}function yi(t){return t.tagName}function ki(t,e){t.textContent=e}function _i(t,e){t.setAttribute(e,"")}var Oi=Object.freeze({createElement:di,createElementNS:hi,createTextNode:fi,createComment:pi,insertBefore:mi,removeChild:bi,appendChild:gi,parentNode:vi,nextSibling:wi,tagName:yi,setTextContent:ki,setStyleScope:_i}),zi={create:function(t,e){Ai(e)},update:function(t,e){t.data.ref!==e.data.ref&&(Ai(t,!0),Ai(e))},destroy:function(t){Ai(t,!0)}};function Ai(t,e){var n=t.data.ref;if(i(n)){var r=t.context,o=t.componentInstance||t.elm,a=r.$refs;e?Array.isArray(a[n])?v(a[n],o):a[n]===o&&(a[n]=void 0):t.data.refInFor?Array.isArray(a[n])?a[n].indexOf(o)<0&&a[n].push(o):a[n]=[o]:a[n]=o}}var ji=new wt("",{},[]),Mi=["create","activate","update","remove","destroy"];function Ci(t,e){return t.key===e.key&&(t.tag===e.tag&&t.isComment===e.isComment&&i(t.data)===i(e.data)&&Vi(t,e)||o(t.isAsyncPlaceholder)&&t.asyncFactory===e.asyncFactory&&r(e.asyncFactory.error))}function Vi(t,e){if("input"!==t.tag)return!0;var n,r=i(n=t.data)&&i(n=n.attrs)&&n.type,o=i(n=e.data)&&i(n=n.attrs)&&n.type;return r===o||li(r)&&li(o)}function Si(t,e,n){var r,o,a={};for(r=e;r<=n;++r)o=t[r].key,i(o)&&(a[o]=r);return a}function xi(t){var e,n,a={},c=t.modules,l=t.nodeOps;for(e=0;e<Mi.length;++e)for(a[Mi[e]]=[],n=0;n<c.length;++n)i(c[n][Mi[e]])&&a[Mi[e]].push(c[n][Mi[e]]);function u(t){return new wt(l.tagName(t).toLowerCase(),{},[],void 0,t)}function d(t,e){function n(){0===--n.listeners&&h(t)}return n.listeners=e,n}function h(t){var e=l.parentNode(t);i(e)&&l.removeChild(e,t)}function f(t,e,n,r,a,s,c){if(i(t.elm)&&i(s)&&(t=s[c]=Ot(t)),t.isRootInsert=!a,!p(t,e,n,r)){var u=t.data,d=t.children,h=t.tag;i(h)?(t.elm=t.ns?l.createElementNS(t.ns,h):l.createElement(h,t),_(t),w(t,d,e),i(u)&&k(t,e),v(n,t.elm,r)):o(t.isComment)?(t.elm=l.createComment(t.text),v(n,t.elm,r)):(t.elm=l.createTextNode(t.text),v(n,t.elm,r))}}function p(t,e,n,r){var a=t.data;if(i(a)){var s=i(t.componentInstance)&&a.keepAlive;if(i(a=a.hook)&&i(a=a.init)&&a(t,!1),i(t.componentInstance))return m(t,e),v(n,t.elm,r),o(s)&&g(t,e,n,r),!0}}function m(t,e){i(t.data.pendingInsert)&&(e.push.apply(e,t.data.pendingInsert),t.data.pendingInsert=null),t.elm=t.componentInstance.$el,y(t)?(k(t,e),_(t)):(Ai(t),e.push(t))}function g(t,e,n,r){var o,s=t;while(s.componentInstance)if(s=s.componentInstance._vnode,i(o=s.data)&&i(o=o.transition)){for(o=0;o<a.activate.length;++o)a.activate[o](ji,s);e.push(s);break}v(n,t.elm,r)}function v(t,e,n){i(t)&&(i(n)?l.parentNode(n)===t&&l.insertBefore(t,e,n):l.appendChild(t,e))}function w(t,e,n){if(Array.isArray(e)){0;for(var r=0;r<e.length;++r)f(e[r],n,t.elm,null,!0,e,r)}else s(t.text)&&l.appendChild(t.elm,l.createTextNode(String(t.text)))}function y(t){while(t.componentInstance)t=t.componentInstance._vnode;return i(t.tag)}function k(t,n){for(var r=0;r<a.create.length;++r)a.create[r](ji,t);e=t.data.hook,i(e)&&(i(e.create)&&e.create(ji,t),i(e.insert)&&n.push(t))}function _(t){var e;if(i(e=t.fnScopeId))l.setStyleScope(t.elm,e);else{var n=t;while(n)i(e=n.context)&&i(e=e.$options._scopeId)&&l.setStyleScope(t.elm,e),n=n.parent}i(e=Sn)&&e!==t.context&&e!==t.fnContext&&i(e=e.$options._scopeId)&&l.setStyleScope(t.elm,e)}function O(t,e,n,r,i,o){for(;r<=i;++r)f(n[r],o,t,e,!1,n,r)}function z(t){var e,n,r=t.data;if(i(r))for(i(e=r.hook)&&i(e=e.destroy)&&e(t),e=0;e<a.destroy.length;++e)a.destroy[e](t);if(i(e=t.children))for(n=0;n<t.children.length;++n)z(t.children[n])}function A(t,e,n){for(;e<=n;++e){var r=t[e];i(r)&&(i(r.tag)?(j(r),z(r)):h(r.elm))}}function j(t,e){if(i(e)||i(t.data)){var n,r=a.remove.length+1;for(i(e)?e.listeners+=r:e=d(t.elm,r),i(n=t.componentInstance)&&i(n=n._vnode)&&i(n.data)&&j(n,e),n=0;n<a.remove.length;++n)a.remove[n](t,e);i(n=t.data.hook)&&i(n=n.remove)?n(t,e):e()}else h(t.elm)}function M(t,e,n,o,a){var s,c,u,d,h=0,p=0,m=e.length-1,b=e[0],g=e[m],v=n.length-1,w=n[0],y=n[v],k=!a;while(h<=m&&p<=v)r(b)?b=e[++h]:r(g)?g=e[--m]:Ci(b,w)?(V(b,w,o,n,p),b=e[++h],w=n[++p]):Ci(g,y)?(V(g,y,o,n,v),g=e[--m],y=n[--v]):Ci(b,y)?(V(b,y,o,n,v),k&&l.insertBefore(t,b.elm,l.nextSibling(g.elm)),b=e[++h],y=n[--v]):Ci(g,w)?(V(g,w,o,n,p),k&&l.insertBefore(t,g.elm,b.elm),g=e[--m],w=n[++p]):(r(s)&&(s=Si(e,h,m)),c=i(w.key)?s[w.key]:C(w,e,h,m),r(c)?f(w,o,t,b.elm,!1,n,p):(u=e[c],Ci(u,w)?(V(u,w,o,n,p),e[c]=void 0,k&&l.insertBefore(t,u.elm,b.elm)):f(w,o,t,b.elm,!1,n,p)),w=n[++p]);h>m?(d=r(n[v+1])?null:n[v+1].elm,O(t,d,n,p,v,o)):p>v&&A(e,h,m)}function C(t,e,n,r){for(var o=n;o<r;o++){var a=e[o];if(i(a)&&Ci(t,a))return o}}function V(t,e,n,s,c,u){if(t!==e){i(e.elm)&&i(s)&&(e=s[c]=Ot(e));var d=e.elm=t.elm;if(o(t.isAsyncPlaceholder))i(e.asyncFactory.resolved)?T(t.elm,e,n):e.isAsyncPlaceholder=!0;else if(o(e.isStatic)&&o(t.isStatic)&&e.key===t.key&&(o(e.isCloned)||o(e.isOnce)))e.componentInstance=t.componentInstance;else{var h,f=e.data;i(f)&&i(h=f.hook)&&i(h=h.prepatch)&&h(t,e);var p=t.children,m=e.children;if(i(f)&&y(e)){for(h=0;h<a.update.length;++h)a.update[h](t,e);i(h=f.hook)&&i(h=h.update)&&h(t,e)}r(e.text)?i(p)&&i(m)?p!==m&&M(d,p,m,n,u):i(m)?(i(t.text)&&l.setTextContent(d,""),O(d,null,m,0,m.length-1,n)):i(p)?A(p,0,p.length-1):i(t.text)&&l.setTextContent(d,""):t.text!==e.text&&l.setTextContent(d,e.text),i(f)&&i(h=f.hook)&&i(h=h.postpatch)&&h(t,e)}}}function S(t,e,n){if(o(n)&&i(t.parent))t.parent.data.pendingInsert=e;else for(var r=0;r<e.length;++r)e[r].data.hook.insert(e[r])}var x=b("attrs,class,staticClass,staticStyle,key");function T(t,e,n,r){var a,s=e.tag,c=e.data,l=e.children;if(r=r||c&&c.pre,e.elm=t,o(e.isComment)&&i(e.asyncFactory))return e.isAsyncPlaceholder=!0,!0;if(i(c)&&(i(a=c.hook)&&i(a=a.init)&&a(e,!0),i(a=e.componentInstance)))return m(e,n),!0;if(i(s)){if(i(l))if(t.hasChildNodes())if(i(a=c)&&i(a=a.domProps)&&i(a=a.innerHTML)){if(a!==t.innerHTML)return!1}else{for(var u=!0,d=t.firstChild,h=0;h<l.length;h++){if(!d||!T(d,l[h],n,r)){u=!1;break}d=d.nextSibling}if(!u||d)return!1}else w(e,l,n);if(i(c)){var f=!1;for(var p in c)if(!x(p)){f=!0,k(e,n);break}!f&&c["class"]&&be(c["class"])}}else t.data!==e.text&&(t.data=e.text);return!0}return function(t,e,n,s){if(!r(e)){var c=!1,d=[];if(r(t))c=!0,f(e,d);else{var h=i(t.nodeType);if(!h&&Ci(t,e))V(t,e,d,null,null,s);else{if(h){if(1===t.nodeType&&t.hasAttribute(F)&&(t.removeAttribute(F),n=!0),o(n)&&T(t,e,d))return S(e,d,!0),t;t=u(t)}var p=t.elm,m=l.parentNode(p);if(f(e,d,p._leaveCb?null:m,l.nextSibling(p)),i(e.parent)){var b=e.parent,g=y(e);while(b){for(var v=0;v<a.destroy.length;++v)a.destroy[v](b);if(b.elm=e.elm,g){for(var w=0;w<a.create.length;++w)a.create[w](ji,b);var k=b.data.hook.insert;if(k.merged)for(var _=1;_<k.fns.length;_++)k.fns[_]()}else Ai(b);b=b.parent}}i(m)?A([t],0,0):i(t.tag)&&z(t)}}return S(e,d,c),e.elm}i(t)&&z(t)}}var Ti={create:Pi,update:Pi,destroy:function(t){Pi(t,ji)}};function Pi(t,e){(t.data.directives||e.data.directives)&&Ii(t,e)}function Ii(t,e){var n,r,i,o=t===ji,a=e===ji,s=Li(t.data.directives,t.context),c=Li(e.data.directives,e.context),l=[],u=[];for(n in c)r=s[n],i=c[n],r?(i.oldValue=r.value,i.oldArg=r.arg,Hi(i,"update",e,t),i.def&&i.def.componentUpdated&&u.push(i)):(Hi(i,"bind",e,t),i.def&&i.def.inserted&&l.push(i));if(l.length){var d=function(){for(var n=0;n<l.length;n++)Hi(l[n],"inserted",e,t)};o?ke(e,"insert",d):d()}if(u.length&&ke(e,"postpatch",(function(){for(var n=0;n<u.length;n++)Hi(u[n],"componentUpdated",e,t)})),!o)for(n in s)c[n]||Hi(s[n],"unbind",t,t,a)}var Ei=Object.create(null);function Li(t,e){var n,r,i=Object.create(null);if(!t)return i;for(n=0;n<t.length;n++)r=t[n],r.modifiers||(r.modifiers=Ei),i[Bi(r)]=r,r.def=Kt(e.$options,"directives",r.name,!0);return i}function Bi(t){return t.rawName||t.name+"."+Object.keys(t.modifiers||{}).join(".")}function Hi(t,e,n,r,i){var o=t.def&&t.def[e];if(o)try{o(n.elm,t,n,r,i)}catch(Oa){ee(Oa,n.context,"directive "+t.name+" "+e+" hook")}}var Fi=[zi,Ti];function Di(t,e){var n=e.componentOptions;if((!i(n)||!1!==n.Ctor.options.inheritAttrs)&&(!r(t.data.attrs)||!r(e.data.attrs))){var o,a,s,c=e.elm,l=t.data.attrs||{},u=e.data.attrs||{};for(o in i(u.__ob__)&&(u=e.data.attrs=x({},u)),u)a=u[o],s=l[o],s!==a&&Ri(c,o,a);for(o in(tt||nt)&&u.value!==l.value&&Ri(c,"value",u.value),l)r(u[o])&&(Wr(o)?c.removeAttributeNS(qr,Gr(o)):Rr(o)||c.removeAttribute(o))}}function Ri(t,e,n){t.tagName.indexOf("-")>-1?Ni(t,e,n):Ur(e)?Yr(n)?t.removeAttribute(e):(n="allowfullscreen"===e&&"EMBED"===t.tagName?"true":e,t.setAttribute(e,n)):Rr(e)?t.setAttribute(e,$r(e,n)):Wr(e)?Yr(n)?t.removeAttributeNS(qr,Gr(e)):t.setAttributeNS(qr,e,n):Ni(t,e,n)}function Ni(t,e,n){if(Yr(n))t.removeAttribute(e);else{if(tt&&!et&&"TEXTAREA"===t.tagName&&"placeholder"===e&&""!==n&&!t.__ieph){var r=function(e){e.stopImmediatePropagation(),t.removeEventListener("input",r)};t.addEventListener("input",r),t.__ieph=!0}t.setAttribute(e,n)}}var $i={create:Di,update:Di};function Ui(t,e){var n=e.elm,o=e.data,a=t.data;if(!(r(o.staticClass)&&r(o.class)&&(r(a)||r(a.staticClass)&&r(a.class)))){var s=Kr(e),c=n._transitionClasses;i(c)&&(s=Jr(s,Zr(c))),s!==n._prevClass&&(n.setAttribute("class",s),n._prevClass=s)}}var qi,Wi={create:Ui,update:Ui},Gi="__r",Yi="__c";function Ki(t){if(i(t[Gi])){var e=tt?"change":"input";t[e]=[].concat(t[Gi],t[e]||[]),delete t[Gi]}i(t[Yi])&&(t.change=[].concat(t[Yi],t.change||[]),delete t[Yi])}function Qi(t,e,n){var r=qi;return function i(){var o=e.apply(null,arguments);null!==o&&Zi(t,i,n,r)}}var Xi=ae&&!(it&&Number(it[1])<=53);function Ji(t,e,n,r){if(Xi){var i=Gn,o=e;e=o._wrapper=function(t){if(t.target===t.currentTarget||t.timeStamp>=i||t.timeStamp<=0||t.target.ownerDocument!==document)return o.apply(this,arguments)}}qi.addEventListener(t,e,at?{capture:n,passive:r}:n)}function Zi(t,e,n,r){(r||qi).removeEventListener(t,e._wrapper||e,n)}function to(t,e){if(!r(t.data.on)||!r(e.data.on)){var n=e.data.on||{},i=t.data.on||{};qi=e.elm,Ki(n),ye(n,i,Ji,Zi,Qi,e.context),qi=void 0}}var eo,no={create:to,update:to};function ro(t,e){if(!r(t.data.domProps)||!r(e.data.domProps)){var n,o,a=e.elm,s=t.data.domProps||{},c=e.data.domProps||{};for(n in i(c.__ob__)&&(c=e.data.domProps=x({},c)),s)n in c||(a[n]="");for(n in c){if(o=c[n],"textContent"===n||"innerHTML"===n){if(e.children&&(e.children.length=0),o===s[n])continue;1===a.childNodes.length&&a.removeChild(a.childNodes[0])}if("value"===n&&"PROGRESS"!==a.tagName){a._value=o;var l=r(o)?"":String(o);io(a,l)&&(a.value=l)}else if("innerHTML"===n&&ii(a.tagName)&&r(a.innerHTML)){eo=eo||document.createElement("div"),eo.innerHTML="<svg>"+o+"</svg>";var u=eo.firstChild;while(a.firstChild)a.removeChild(a.firstChild);while(u.firstChild)a.appendChild(u.firstChild)}else if(o!==s[n])try{a[n]=o}catch(Oa){}}}}function io(t,e){return!t.composing&&("OPTION"===t.tagName||oo(t,e)||ao(t,e))}function oo(t,e){var n=!0;try{n=document.activeElement!==t}catch(Oa){}return n&&t.value!==e}function ao(t,e){var n=t.value,r=t._vModifiers;if(i(r)){if(r.number)return m(n)!==m(e);if(r.trim)return n.trim()!==e.trim()}return n!==e}var so={create:ro,update:ro},co=k((function(t){var e={},n=/;(?![^(]*\))/g,r=/:(.+)/;return t.split(n).forEach((function(t){if(t){var n=t.split(r);n.length>1&&(e[n[0].trim()]=n[1].trim())}})),e}));function lo(t){var e=uo(t.style);return t.staticStyle?x(t.staticStyle,e):e}function uo(t){return Array.isArray(t)?T(t):"string"===typeof t?co(t):t}function ho(t,e){var n,r={};if(e){var i=t;while(i.componentInstance)i=i.componentInstance._vnode,i&&i.data&&(n=lo(i.data))&&x(r,n)}(n=lo(t.data))&&x(r,n);var o=t;while(o=o.parent)o.data&&(n=lo(o.data))&&x(r,n);return r}var fo,po=/^--/,mo=/\s*!important$/,bo=function(t,e,n){if(po.test(e))t.style.setProperty(e,n);else if(mo.test(n))t.style.setProperty(j(e),n.replace(mo,""),"important");else{var r=vo(e);if(Array.isArray(n))for(var i=0,o=n.length;i<o;i++)t.style[r]=n[i];else t.style[r]=n}},go=["Webkit","Moz","ms"],vo=k((function(t){if(fo=fo||document.createElement("div").style,t=O(t),"filter"!==t&&t in fo)return t;for(var e=t.charAt(0).toUpperCase()+t.slice(1),n=0;n<go.length;n++){var r=go[n]+e;if(r in fo)return r}}));function wo(t,e){var n=e.data,o=t.data;if(!(r(n.staticStyle)&&r(n.style)&&r(o.staticStyle)&&r(o.style))){var a,s,c=e.elm,l=o.staticStyle,u=o.normalizedStyle||o.style||{},d=l||u,h=uo(e.data.style)||{};e.data.normalizedStyle=i(h.__ob__)?x({},h):h;var f=ho(e,!0);for(s in d)r(f[s])&&bo(c,s,"");for(s in f)a=f[s],a!==d[s]&&bo(c,s,null==a?"":a)}}var yo={create:wo,update:wo},ko=/\s+/;function _o(t,e){if(e&&(e=e.trim()))if(t.classList)e.indexOf(" ")>-1?e.split(ko).forEach((function(e){return t.classList.add(e)})):t.classList.add(e);else{var n=" "+(t.getAttribute("class")||"")+" ";n.indexOf(" "+e+" ")<0&&t.setAttribute("class",(n+e).trim())}}function Oo(t,e){if(e&&(e=e.trim()))if(t.classList)e.indexOf(" ")>-1?e.split(ko).forEach((function(e){return t.classList.remove(e)})):t.classList.remove(e),t.classList.length||t.removeAttribute("class");else{var n=" "+(t.getAttribute("class")||"")+" ",r=" "+e+" ";while(n.indexOf(r)>=0)n=n.replace(r," ");n=n.trim(),n?t.setAttribute("class",n):t.removeAttribute("class")}}function zo(t){if(t){if("object"===typeof t){var e={};return!1!==t.css&&x(e,Ao(t.name||"v")),x(e,t),e}return"string"===typeof t?Ao(t):void 0}}var Ao=k((function(t){return{enterClass:t+"-enter",enterToClass:t+"-enter-to",enterActiveClass:t+"-enter-active",leaveClass:t+"-leave",leaveToClass:t+"-leave-to",leaveActiveClass:t+"-leave-active"}})),jo=Q&&!et,Mo="transition",Co="animation",Vo="transition",So="transitionend",xo="animation",To="animationend";jo&&(void 0===window.ontransitionend&&void 0!==window.onwebkittransitionend&&(Vo="WebkitTransition",So="webkitTransitionEnd"),void 0===window.onanimationend&&void 0!==window.onwebkitanimationend&&(xo="WebkitAnimation",To="webkitAnimationEnd"));var Po=Q?window.requestAnimationFrame?window.requestAnimationFrame.bind(window):setTimeout:function(t){return t()};function Io(t){Po((function(){Po(t)}))}function Eo(t,e){var n=t._transitionClasses||(t._transitionClasses=[]);n.indexOf(e)<0&&(n.push(e),_o(t,e))}function Lo(t,e){t._transitionClasses&&v(t._transitionClasses,e),Oo(t,e)}function Bo(t,e,n){var r=Fo(t,e),i=r.type,o=r.timeout,a=r.propCount;if(!i)return n();var s=i===Mo?So:To,c=0,l=function(){t.removeEventListener(s,u),n()},u=function(e){e.target===t&&++c>=a&&l()};setTimeout((function(){c<a&&l()}),o+1),t.addEventListener(s,u)}var Ho=/\b(transform|all)(,|$)/;function Fo(t,e){var n,r=window.getComputedStyle(t),i=(r[Vo+"Delay"]||"").split(", "),o=(r[Vo+"Duration"]||"").split(", "),a=Do(i,o),s=(r[xo+"Delay"]||"").split(", "),c=(r[xo+"Duration"]||"").split(", "),l=Do(s,c),u=0,d=0;e===Mo?a>0&&(n=Mo,u=a,d=o.length):e===Co?l>0&&(n=Co,u=l,d=c.length):(u=Math.max(a,l),n=u>0?a>l?Mo:Co:null,d=n?n===Mo?o.length:c.length:0);var h=n===Mo&&Ho.test(r[Vo+"Property"]);return{type:n,timeout:u,propCount:d,hasTransform:h}}function Do(t,e){while(t.length<e.length)t=t.concat(t);return Math.max.apply(null,e.map((function(e,n){return Ro(e)+Ro(t[n])})))}function Ro(t){return 1e3*Number(t.slice(0,-1).replace(",","."))}function No(t,e){var n=t.elm;i(n._leaveCb)&&(n._leaveCb.cancelled=!0,n._leaveCb());var o=zo(t.data.transition);if(!r(o)&&!i(n._enterCb)&&1===n.nodeType){var a=o.css,s=o.type,l=o.enterClass,u=o.enterToClass,d=o.enterActiveClass,h=o.appearClass,f=o.appearToClass,p=o.appearActiveClass,b=o.beforeEnter,g=o.enter,v=o.afterEnter,w=o.enterCancelled,y=o.beforeAppear,k=o.appear,_=o.afterAppear,O=o.appearCancelled,z=o.duration,A=Sn,j=Sn.$vnode;while(j&&j.parent)A=j.context,j=j.parent;var M=!A._isMounted||!t.isRootInsert;if(!M||k||""===k){var C=M&&h?h:l,V=M&&p?p:d,S=M&&f?f:u,x=M&&y||b,T=M&&"function"===typeof k?k:g,P=M&&_||v,I=M&&O||w,E=m(c(z)?z.enter:z);0;var L=!1!==a&&!et,B=qo(T),F=n._enterCb=H((function(){L&&(Lo(n,S),Lo(n,V)),F.cancelled?(L&&Lo(n,C),I&&I(n)):P&&P(n),n._enterCb=null}));t.data.show||ke(t,"insert",(function(){var e=n.parentNode,r=e&&e._pending&&e._pending[t.key];r&&r.tag===t.tag&&r.elm._leaveCb&&r.elm._leaveCb(),T&&T(n,F)})),x&&x(n),L&&(Eo(n,C),Eo(n,V),Io((function(){Lo(n,C),F.cancelled||(Eo(n,S),B||(Uo(E)?setTimeout(F,E):Bo(n,s,F)))}))),t.data.show&&(e&&e(),T&&T(n,F)),L||B||F()}}}function $o(t,e){var n=t.elm;i(n._enterCb)&&(n._enterCb.cancelled=!0,n._enterCb());var o=zo(t.data.transition);if(r(o)||1!==n.nodeType)return e();if(!i(n._leaveCb)){var a=o.css,s=o.type,l=o.leaveClass,u=o.leaveToClass,d=o.leaveActiveClass,h=o.beforeLeave,f=o.leave,p=o.afterLeave,b=o.leaveCancelled,g=o.delayLeave,v=o.duration,w=!1!==a&&!et,y=qo(f),k=m(c(v)?v.leave:v);0;var _=n._leaveCb=H((function(){n.parentNode&&n.parentNode._pending&&(n.parentNode._pending[t.key]=null),w&&(Lo(n,u),Lo(n,d)),_.cancelled?(w&&Lo(n,l),b&&b(n)):(e(),p&&p(n)),n._leaveCb=null}));g?g(O):O()}function O(){_.cancelled||(!t.data.show&&n.parentNode&&((n.parentNode._pending||(n.parentNode._pending={}))[t.key]=t),h&&h(n),w&&(Eo(n,l),Eo(n,d),Io((function(){Lo(n,l),_.cancelled||(Eo(n,u),y||(Uo(k)?setTimeout(_,k):Bo(n,s,_)))}))),f&&f(n,_),w||y||_())}}function Uo(t){return"number"===typeof t&&!isNaN(t)}function qo(t){if(r(t))return!1;var e=t.fns;return i(e)?qo(Array.isArray(e)?e[0]:e):(t._length||t.length)>1}function Wo(t,e){!0!==e.data.show&&No(e)}var Go=Q?{create:Wo,activate:Wo,remove:function(t,e){!0!==t.data.show?$o(t,e):e()}}:{},Yo=[$i,Wi,no,so,yo,Go],Ko=Yo.concat(Fi),Qo=xi({nodeOps:Oi,modules:Ko});et&&document.addEventListener("selectionchange",(function(){var t=document.activeElement;t&&t.vmodel&&ia(t,"input")}));var Xo={inserted:function(t,e,n,r){"select"===n.tag?(r.elm&&!r.elm._vOptions?ke(n,"postpatch",(function(){Xo.componentUpdated(t,e,n)})):Jo(t,e,n.context),t._vOptions=[].map.call(t.options,ea)):("textarea"===n.tag||li(t.type))&&(t._vModifiers=e.modifiers,e.modifiers.lazy||(t.addEventListener("compositionstart",na),t.addEventListener("compositionend",ra),t.addEventListener("change",ra),et&&(t.vmodel=!0)))},componentUpdated:function(t,e,n){if("select"===n.tag){Jo(t,e,n.context);var r=t._vOptions,i=t._vOptions=[].map.call(t.options,ea);if(i.some((function(t,e){return!L(t,r[e])}))){var o=t.multiple?e.value.some((function(t){return ta(t,i)})):e.value!==e.oldValue&&ta(e.value,i);o&&ia(t,"change")}}}};function Jo(t,e,n){Zo(t,e,n),(tt||nt)&&setTimeout((function(){Zo(t,e,n)}),0)}function Zo(t,e,n){var r=e.value,i=t.multiple;if(!i||Array.isArray(r)){for(var o,a,s=0,c=t.options.length;s<c;s++)if(a=t.options[s],i)o=B(r,ea(a))>-1,a.selected!==o&&(a.selected=o);else if(L(ea(a),r))return void(t.selectedIndex!==s&&(t.selectedIndex=s));i||(t.selectedIndex=-1)}}function ta(t,e){return e.every((function(e){return!L(e,t)}))}function ea(t){return"_value"in t?t._value:t.value}function na(t){t.target.composing=!0}function ra(t){t.target.composing&&(t.target.composing=!1,ia(t.target,"input"))}function ia(t,e){var n=document.createEvent("HTMLEvents");n.initEvent(e,!0,!0),t.dispatchEvent(n)}function oa(t){return!t.componentInstance||t.data&&t.data.transition?t:oa(t.componentInstance._vnode)}var aa={bind:function(t,e,n){var r=e.value;n=oa(n);var i=n.data&&n.data.transition,o=t.__vOriginalDisplay="none"===t.style.display?"":t.style.display;r&&i?(n.data.show=!0,No(n,(function(){t.style.display=o}))):t.style.display=r?o:"none"},update:function(t,e,n){var r=e.value,i=e.oldValue;if(!r!==!i){n=oa(n);var o=n.data&&n.data.transition;o?(n.data.show=!0,r?No(n,(function(){t.style.display=t.__vOriginalDisplay})):$o(n,(function(){t.style.display="none"}))):t.style.display=r?t.__vOriginalDisplay:"none"}},unbind:function(t,e,n,r,i){i||(t.style.display=t.__vOriginalDisplay)}},sa={model:Xo,show:aa},ca={name:String,appear:Boolean,css:Boolean,mode:String,type:String,enterClass:String,leaveClass:String,enterToClass:String,leaveToClass:String,enterActiveClass:String,leaveActiveClass:String,appearClass:String,appearActiveClass:String,appearToClass:String,duration:[Number,String,Object]};function la(t){var e=t&&t.componentOptions;return e&&e.Ctor.options.abstract?la(On(e.children)):t}function ua(t){var e={},n=t.$options;for(var r in n.propsData)e[r]=t[r];var i=n._parentListeners;for(var o in i)e[O(o)]=i[o];return e}function da(t,e){if(/\d-keep-alive$/.test(e.tag))return t("keep-alive",{props:e.componentOptions.propsData})}function ha(t){while(t=t.parent)if(t.data.transition)return!0}function fa(t,e){return e.key===t.key&&e.tag===t.tag}var pa=function(t){return t.tag||_n(t)},ma=function(t){return"show"===t.name},ba={name:"transition",props:ca,abstract:!0,render:function(t){var e=this,n=this.$slots.default;if(n&&(n=n.filter(pa),n.length)){0;var r=this.mode;0;var i=n[0];if(ha(this.$vnode))return i;var o=la(i);if(!o)return i;if(this._leaving)return da(t,i);var a="__transition-"+this._uid+"-";o.key=null==o.key?o.isComment?a+"comment":a+o.tag:s(o.key)?0===String(o.key).indexOf(a)?o.key:a+o.key:o.key;var c=(o.data||(o.data={})).transition=ua(this),l=this._vnode,u=la(l);if(o.data.directives&&o.data.directives.some(ma)&&(o.data.show=!0),u&&u.data&&!fa(o,u)&&!_n(u)&&(!u.componentInstance||!u.componentInstance._vnode.isComment)){var d=u.data.transition=x({},c);if("out-in"===r)return this._leaving=!0,ke(d,"afterLeave",(function(){e._leaving=!1,e.$forceUpdate()})),da(t,i);if("in-out"===r){if(_n(o))return l;var h,f=function(){h()};ke(c,"afterEnter",f),ke(c,"enterCancelled",f),ke(d,"delayLeave",(function(t){h=t}))}}return i}}},ga=x({tag:String,moveClass:String},ca);delete ga.mode;var va={props:ga,beforeMount:function(){var t=this,e=this._update;this._update=function(n,r){var i=xn(t);t.__patch__(t._vnode,t.kept,!1,!0),t._vnode=t.kept,i(),e.call(t,n,r)}},render:function(t){for(var e=this.tag||this.$vnode.data.tag||"span",n=Object.create(null),r=this.prevChildren=this.children,i=this.$slots.default||[],o=this.children=[],a=ua(this),s=0;s<i.length;s++){var c=i[s];if(c.tag)if(null!=c.key&&0!==String(c.key).indexOf("__vlist"))o.push(c),n[c.key]=c,(c.data||(c.data={})).transition=a;else;}if(r){for(var l=[],u=[],d=0;d<r.length;d++){var h=r[d];h.data.transition=a,h.data.pos=h.elm.getBoundingClientRect(),n[h.key]?l.push(h):u.push(h)}this.kept=t(e,null,l),this.removed=u}return t(e,null,o)},updated:function(){var t=this.prevChildren,e=this.moveClass||(this.name||"v")+"-move";t.length&&this.hasMove(t[0].elm,e)&&(t.forEach(wa),t.forEach(ya),t.forEach(ka),this._reflow=document.body.offsetHeight,t.forEach((function(t){if(t.data.moved){var n=t.elm,r=n.style;Eo(n,e),r.transform=r.WebkitTransform=r.transitionDuration="",n.addEventListener(So,n._moveCb=function t(r){r&&r.target!==n||r&&!/transform$/.test(r.propertyName)||(n.removeEventListener(So,t),n._moveCb=null,Lo(n,e))})}})))},methods:{hasMove:function(t,e){if(!jo)return!1;if(this._hasMove)return this._hasMove;var n=t.cloneNode();t._transitionClasses&&t._transitionClasses.forEach((function(t){Oo(n,t)})),_o(n,e),n.style.display="none",this.$el.appendChild(n);var r=Fo(n);return this.$el.removeChild(n),this._hasMove=r.hasTransform}}};function wa(t){t.elm._moveCb&&t.elm._moveCb(),t.elm._enterCb&&t.elm._enterCb()}function ya(t){t.data.newPos=t.elm.getBoundingClientRect()}function ka(t){var e=t.data.pos,n=t.data.newPos,r=e.left-n.left,i=e.top-n.top;if(r||i){t.data.moved=!0;var o=t.elm.style;o.transform=o.WebkitTransform="translate("+r+"px,"+i+"px)",o.transitionDuration="0s"}}var _a={Transition:ba,TransitionGroup:va};Or.config.mustUseProp=Dr,Or.config.isReservedTag=oi,Or.config.isReservedAttr=Hr,Or.config.getTagNamespace=ai,Or.config.isUnknownElement=ci,x(Or.options.directives,sa),x(Or.options.components,_a),Or.prototype.__patch__=Q?Qo:P,Or.prototype.$mount=function(t,e){return t=t&&Q?ui(t):void 0,In(this,t,e)},Q&&setTimeout((function(){N.devtools&&lt&&lt.emit("init",Or)}),0),e["default"]=Or}.call(this,n("c8ba"))},"2b88":function(t,e,n){"use strict";
/*! 
  * portal-vue © Thorsten Lünborg, 2019 
  * 
  * Version: 2.1.7
  * 
  * LICENCE: MIT 
  * 
  * https://github.com/linusborg/portal-vue
  * 
 */function r(t){return t&&"object"===typeof t&&"default"in t?t["default"]:t}Object.defineProperty(e,"__esModule",{value:!0});var i=r(n("2b0e"));function o(t){return o="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"===typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},o(t)}function a(t){return s(t)||c(t)||l()}function s(t){if(Array.isArray(t)){for(var e=0,n=new Array(t.length);e<t.length;e++)n[e]=t[e];return n}}function c(t){if(Symbol.iterator in Object(t)||"[object Arguments]"===Object.prototype.toString.call(t))return Array.from(t)}function l(){throw new TypeError("Invalid attempt to spread non-iterable instance")}var u="undefined"!==typeof window;function d(t){return Array.isArray(t)||"object"===o(t)?Object.freeze(t):t}function h(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return t.reduce((function(t,n){var r=n.passengers[0],i="function"===typeof r?r(e):n.passengers;return t.concat(i)}),[])}function f(t,e){return t.map((function(t,e){return[e,t]})).sort((function(t,n){return e(t[1],n[1])||t[0]-n[0]})).map((function(t){return t[1]}))}function p(t,e){return e.reduce((function(e,n){return t.hasOwnProperty(n)&&(e[n]=t[n]),e}),{})}var m={},b={},g={},v=i.extend({data:function(){return{transports:m,targets:b,sources:g,trackInstances:u}},methods:{open:function(t){if(u){var e=t.to,n=t.from,r=t.passengers,o=t.order,a=void 0===o?1/0:o;if(e&&n&&r){var s={to:e,from:n,passengers:d(r),order:a},c=Object.keys(this.transports);-1===c.indexOf(e)&&i.set(this.transports,e,[]);var l=this.$_getTransportIndex(s),h=this.transports[e].slice(0);-1===l?h.push(s):h[l]=s,this.transports[e]=f(h,(function(t,e){return t.order-e.order}))}}},close:function(t){var e=arguments.length>1&&void 0!==arguments[1]&&arguments[1],n=t.to,r=t.from;if(n&&(r||!1!==e)&&this.transports[n])if(e)this.transports[n]=[];else{var i=this.$_getTransportIndex(t);if(i>=0){var o=this.transports[n].slice(0);o.splice(i,1),this.transports[n]=o}}},registerTarget:function(t,e,n){u&&(this.trackInstances&&!n&&this.targets[t]&&console.warn("[portal-vue]: Target ".concat(t," already exists")),this.$set(this.targets,t,Object.freeze([e])))},unregisterTarget:function(t){this.$delete(this.targets,t)},registerSource:function(t,e,n){u&&(this.trackInstances&&!n&&this.sources[t]&&console.warn("[portal-vue]: source ".concat(t," already exists")),this.$set(this.sources,t,Object.freeze([e])))},unregisterSource:function(t){this.$delete(this.sources,t)},hasTarget:function(t){return!(!this.targets[t]||!this.targets[t][0])},hasSource:function(t){return!(!this.sources[t]||!this.sources[t][0])},hasContentFor:function(t){return!!this.transports[t]&&!!this.transports[t].length},$_getTransportIndex:function(t){var e=t.to,n=t.from;for(var r in this.transports[e])if(this.transports[e][r].from===n)return+r;return-1}}}),w=new v(m),y=1,k=i.extend({name:"portal",props:{disabled:{type:Boolean},name:{type:String,default:function(){return String(y++)}},order:{type:Number,default:0},slim:{type:Boolean},slotProps:{type:Object,default:function(){return{}}},tag:{type:String,default:"DIV"},to:{type:String,default:function(){return String(Math.round(1e7*Math.random()))}}},created:function(){var t=this;this.$nextTick((function(){w.registerSource(t.name,t)}))},mounted:function(){this.disabled||this.sendUpdate()},updated:function(){this.disabled?this.clear():this.sendUpdate()},beforeDestroy:function(){w.unregisterSource(this.name),this.clear()},watch:{to:function(t,e){e&&e!==t&&this.clear(e),this.sendUpdate()}},methods:{clear:function(t){var e={from:this.name,to:t||this.to};w.close(e)},normalizeSlots:function(){return this.$scopedSlots.default?[this.$scopedSlots.default]:this.$slots.default},normalizeOwnChildren:function(t){return"function"===typeof t?t(this.slotProps):t},sendUpdate:function(){var t=this.normalizeSlots();if(t){var e={from:this.name,to:this.to,passengers:a(t),order:this.order};w.open(e)}else this.clear()}},render:function(t){var e=this.$slots.default||this.$scopedSlots.default||[],n=this.tag;return e&&this.disabled?e.length<=1&&this.slim?this.normalizeOwnChildren(e)[0]:t(n,[this.normalizeOwnChildren(e)]):this.slim?t():t(n,{class:{"v-portal":!0},style:{display:"none"},key:"v-portal-placeholder"})}}),_=i.extend({name:"portalTarget",props:{multiple:{type:Boolean,default:!1},name:{type:String,required:!0},slim:{type:Boolean,default:!1},slotProps:{type:Object,default:function(){return{}}},tag:{type:String,default:"div"},transition:{type:[String,Object,Function]}},data:function(){return{transports:w.transports,firstRender:!0}},created:function(){var t=this;this.$nextTick((function(){w.registerTarget(t.name,t)}))},watch:{ownTransports:function(){this.$emit("change",this.children().length>0)},name:function(t,e){w.unregisterTarget(e),w.registerTarget(t,this)}},mounted:function(){var t=this;this.transition&&this.$nextTick((function(){t.firstRender=!1}))},beforeDestroy:function(){w.unregisterTarget(this.name)},computed:{ownTransports:function(){var t=this.transports[this.name]||[];return this.multiple?t:0===t.length?[]:[t[t.length-1]]},passengers:function(){return h(this.ownTransports,this.slotProps)}},methods:{children:function(){return 0!==this.passengers.length?this.passengers:this.$scopedSlots.default?this.$scopedSlots.default(this.slotProps):this.$slots.default||[]},noWrapper:function(){var t=this.slim&&!this.transition;return t&&this.children().length>1&&console.warn("[portal-vue]: PortalTarget with `slim` option received more than one child element."),t}},render:function(t){var e=this.noWrapper(),n=this.children(),r=this.transition||this.tag;return e?n[0]:this.slim&&!r?t():t(r,{props:{tag:this.transition&&this.tag?this.tag:void 0},class:{"vue-portal-target":!0}},n)}}),O=0,z=["disabled","name","order","slim","slotProps","tag","to"],A=["multiple","transition"],j=i.extend({name:"MountingPortal",inheritAttrs:!1,props:{append:{type:[Boolean,String]},bail:{type:Boolean},mountTo:{type:String,required:!0},disabled:{type:Boolean},name:{type:String,default:function(){return"mounted_"+String(O++)}},order:{type:Number,default:0},slim:{type:Boolean},slotProps:{type:Object,default:function(){return{}}},tag:{type:String,default:"DIV"},to:{type:String,default:function(){return String(Math.round(1e7*Math.random()))}},multiple:{type:Boolean,default:!1},targetSlim:{type:Boolean},targetSlotProps:{type:Object,default:function(){return{}}},targetTag:{type:String,default:"div"},transition:{type:[String,Object,Function]}},created:function(){if("undefined"!==typeof document){var t=document.querySelector(this.mountTo);if(t){var e=this.$props;if(w.targets[e.name])e.bail?console.warn("[portal-vue]: Target ".concat(e.name," is already mounted.\n        Aborting because 'bail: true' is set")):this.portalTarget=w.targets[e.name];else{var n=e.append;if(n){var r="string"===typeof n?n:"DIV",i=document.createElement(r);t.appendChild(i),t=i}var o=p(this.$props,A);o.slim=this.targetSlim,o.tag=this.targetTag,o.slotProps=this.targetSlotProps,o.name=this.to,this.portalTarget=new _({el:t,parent:this.$parent||this,propsData:o})}}else console.error("[portal-vue]: Mount Point '".concat(this.mountTo,"' not found in document"))}},beforeDestroy:function(){var t=this.portalTarget;if(this.append){var e=t.$el;e.parentNode.removeChild(e)}t.$destroy()},render:function(t){if(!this.portalTarget)return console.warn("[portal-vue] Target wasn't mounted"),t();if(!this.$scopedSlots.manual){var e=p(this.$props,z);return t(k,{props:e,attrs:this.$attrs,on:this.$listeners,scopedSlots:this.$scopedSlots},this.$slots.default)}var n=this.$scopedSlots.manual({to:this.to});return Array.isArray(n)&&(n=n[0]),n||t()}});function M(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};t.component(e.portalName||"Portal",k),t.component(e.portalTargetName||"PortalTarget",_),t.component(e.MountingPortalName||"MountingPortal",j)}var C={install:M};e.default=C,e.Portal=k,e.PortalTarget=_,e.MountingPortal=j,e.Wormhole=w},"2d83":function(t,e,n){"use strict";var r=n("387f");t.exports=function(t,e,n,i,o){var a=new Error(t);return r(a,e,n,i,o)}},"2dd8":function(t,e,n){},"2e67":function(t,e,n){"use strict";t.exports=function(t){return!(!t||!t.__CANCEL__)}},"2f79":function(t,e,n){"use strict";n.d(e,"a",(function(){return r}));n("b42e");var r="_uid"},"30b5":function(t,e,n){"use strict";var r=n("c532");function i(t){return encodeURIComponent(t).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}t.exports=function(t,e,n){if(!e)return t;var o;if(n)o=n(e);else if(r.isURLSearchParams(e))o=e.toString();else{var a=[];r.forEach(e,(function(t,e){null!==t&&"undefined"!==typeof t&&(r.isArray(t)?e+="[]":t=[t],r.forEach(t,(function(t){r.isDate(t)?t=t.toISOString():r.isObject(t)&&(t=JSON.stringify(t)),a.push(i(e)+"="+i(t))})))})),o=a.join("&")}if(o){var s=t.indexOf("#");-1!==s&&(t=t.slice(0,s)),t+=(-1===t.indexOf("?")?"?":"&")+o}return t}},3790:function(t,e,n){"use strict";n.d(e,"a",(function(){return y})),n.d(e,"b",(function(){return _})),n.d(e,"c",(function(){return O}));var r=n("2b0e"),i=n("e863"),o=n("50d3"),a=n("c9a9"),s=n("a874"),c=n("7b1e"),l=n("d82f"),u=n("686b");function d(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function h(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function f(t,e,n){return e&&h(t.prototype,e),n&&h(t,n),t}var p=function(){function t(){d(this,t),this.$_config={}}return f(t,[{key:"setConfig",value:function(){var t=this,e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};if(Object(c["k"])(e)){var n=Object(l["f"])(e);n.forEach((function(n){var r=e[n];"breakpoints"===n?!Object(c["a"])(r)||r.length<2||r.some((function(t){return!Object(c["n"])(t)||0===t.length}))?Object(u["a"])('"breakpoints" must be an array of at least 2 breakpoint names',o["b"]):t.$_config[n]=Object(a["a"])(r):Object(c["k"])(r)&&(t.$_config[n]=Object(l["f"])(r).reduce((function(t,e){return Object(c["o"])(r[e])||(t[e]=Object(a["a"])(r[e])),t}),t.$_config[n]||{}))}))}}},{key:"resetConfig",value:function(){this.$_config={}}},{key:"getConfig",value:function(){return Object(a["a"])(this.$_config)}},{key:"getConfigValue",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:void 0;return Object(a["a"])(Object(s["b"])(this.$_config,t,e))}}]),t}(),m=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:r["default"];e.prototype[o["c"]]=r["default"].prototype[o["c"]]=e.prototype[o["c"]]||r["default"].prototype[o["c"]]||new p,e.prototype[o["c"]].setConfig(t)};function b(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function g(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?b(Object(n),!0).forEach((function(e){v(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):b(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function v(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var w=function(){var t=!1,e=["Multiple instances of Vue detected!","You may need to set up an alias for Vue in your bundler config.","See: https://bootstrap-vue.org/docs#using-module-bundlers"].join("\n");return function(n){t||r["default"]===n||i["j"]||Object(u["a"])(e),t=!0}}(),y=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=t.components,n=t.directives,r=t.plugins,i=function t(i){var o=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};t.installed||(t.installed=!0,w(i),m(o,i),j(i,e),C(i,n),z(i,r))};return i.installed=!1,i},k=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=t.components,n=t.directives,r=t.plugins,i=function t(i){t.installed||(t.installed=!0,w(i),j(i,e),C(i,n),z(i,r))};return i.installed=!1,i},_=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return g(g({},e),{},{install:y(t)})},O=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return g(g({},e),{},{install:k(t)})},z=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};for(var n in e)n&&e[n]&&t.use(e[n])},A=function(t,e,n){t&&e&&n&&t.component(e,n)},j=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};for(var n in e)A(t,n,e[n])},M=function(t,e,n){t&&e&&n&&t.directive(e.replace(/^VB/,"B"),n)},C=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};for(var n in e)M(t,n,e[n])}},"387f":function(t,e,n){"use strict";t.exports=function(t,e,n,r,i){return t.config=e,n&&(t.code=n),t.request=r,t.response=i,t.isAxiosError=!0,t.toJSON=function(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:this.config,code:this.code}},t}},3934:function(t,e,n){"use strict";var r=n("c532");t.exports=r.isStandardBrowserEnv()?function(){var t,e=/(msie|trident)/i.test(navigator.userAgent),n=document.createElement("a");function i(t){var r=t;return e&&(n.setAttribute("href",r),r=n.href),n.setAttribute("href",r),{href:n.href,protocol:n.protocol?n.protocol.replace(/:$/,""):"",host:n.host,search:n.search?n.search.replace(/^\?/,""):"",hash:n.hash?n.hash.replace(/^#/,""):"",hostname:n.hostname,port:n.port,pathname:"/"===n.pathname.charAt(0)?n.pathname:"/"+n.pathname}}return t=i(window.location.href),function(e){var n=r.isString(e)?i(e):e;return n.protocol===t.protocol&&n.host===t.host}}():function(){return function(){return!0}}()},"3a58":function(t,e,n){"use strict";n.d(e,"c",(function(){return r})),n.d(e,"b",(function(){return i})),n.d(e,"a",(function(){return o}));var r=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:NaN,n=parseInt(t,10);return isNaN(n)?e:n},i=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:NaN,n=parseFloat(t);return isNaN(n)?e:n},o=function(t,e){return i(t).toFixed(r(e,0))}},4362:function(t,e,n){e.nextTick=function(t){var e=Array.prototype.slice.call(arguments);e.shift(),setTimeout((function(){t.apply(null,e)}),0)},e.platform=e.arch=e.execPath=e.title="browser",e.pid=1,e.browser=!0,e.env={},e.argv=[],e.binding=function(t){throw new Error("No such module. (Possibly not yet loaded)")},function(){var t,r="/";e.cwd=function(){return r},e.chdir=function(e){t||(t=n("df7c")),r=t.resolve(e,r)}}(),e.exit=e.kill=e.umask=e.dlopen=e.uptime=e.memoryUsage=e.uvCounters=function(){},e.features={}},"467f":function(t,e,n){"use strict";var r=n("2d83");t.exports=function(t,e,n){var i=n.config.validateStatus;n.status&&i&&!i(n.status)?e(r("Request failed with status code "+n.status,n.config,null,n.request,n)):t(n)}},"4a7a":function(t,e,n){!function(e,n){t.exports=n()}("undefined"!=typeof self&&self,(function(){return function(t){var e={};function n(r){if(e[r])return e[r].exports;var i=e[r]={i:r,l:!1,exports:{}};return t[r].call(i.exports,i,i.exports,n),i.l=!0,i.exports}return n.m=t,n.c=e,n.d=function(t,e,r){n.o(t,e)||Object.defineProperty(t,e,{enumerable:!0,get:r})},n.r=function(t){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},n.t=function(t,e){if(1&e&&(t=n(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var i in t)n.d(r,i,function(e){return t[e]}.bind(null,i));return r},n.n=function(t){var e=t&&t.__esModule?function(){return t.default}:function(){return t};return n.d(e,"a",e),e},n.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},n.p="/",n(n.s=8)}([function(t,e,n){var r=n(4),i=n(5),o=n(6);t.exports=function(t){return r(t)||i(t)||o()}},function(t,e){function n(e){return"function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?t.exports=n=function(t){return typeof t}:t.exports=n=function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},n(e)}t.exports=n},function(t,e,n){},function(t,e){t.exports=function(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}},function(t,e){t.exports=function(t){if(Array.isArray(t)){for(var e=0,n=new Array(t.length);e<t.length;e++)n[e]=t[e];return n}}},function(t,e){t.exports=function(t){if(Symbol.iterator in Object(t)||"[object Arguments]"===Object.prototype.toString.call(t))return Array.from(t)}},function(t,e){t.exports=function(){throw new TypeError("Invalid attempt to spread non-iterable instance")}},function(t,e,n){"use strict";var r=n(2);n.n(r).a},function(t,e,n){"use strict";n.r(e);var r=n(0),i=n.n(r),o=n(1),a=n.n(o),s=n(3),c=n.n(s),l={props:{autoscroll:{type:Boolean,default:!0}},watch:{typeAheadPointer:function(){this.autoscroll&&this.maybeAdjustScroll()}},methods:{maybeAdjustScroll:function(){var t,e=(null===(t=this.$refs.dropdownMenu)||void 0===t?void 0:t.children[this.typeAheadPointer])||!1;if(e){var n=this.getDropdownViewport(),r=e.getBoundingClientRect(),i=r.top,o=r.bottom,a=r.height;if(i<n.top)return this.$refs.dropdownMenu.scrollTop=e.offsetTop;if(o>n.bottom)return this.$refs.dropdownMenu.scrollTop=e.offsetTop-(n.height-a)}},getDropdownViewport:function(){return this.$refs.dropdownMenu?this.$refs.dropdownMenu.getBoundingClientRect():{height:0,top:0,bottom:0}}}},u={data:function(){return{typeAheadPointer:-1}},watch:{filteredOptions:function(){for(var t=0;t<this.filteredOptions.length;t++)if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break}}},methods:{typeAheadUp:function(){for(var t=this.typeAheadPointer-1;t>=0;t--)if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break}},typeAheadDown:function(){for(var t=this.typeAheadPointer+1;t<this.filteredOptions.length;t++)if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break}},typeAheadSelect:function(){var t=this.filteredOptions[this.typeAheadPointer];t&&this.select(t)}}},d={props:{loading:{type:Boolean,default:!1}},data:function(){return{mutableLoading:!1}},watch:{search:function(){this.$emit("search",this.search,this.toggleLoading)},loading:function(t){this.mutableLoading=t}},methods:{toggleLoading:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null;return this.mutableLoading=null==t?!this.mutableLoading:t}}};function h(t,e,n,r,i,o,a,s){var c,l="function"==typeof t?t.options:t;if(e&&(l.render=e,l.staticRenderFns=n,l._compiled=!0),r&&(l.functional=!0),o&&(l._scopeId="data-v-"+o),a?(c=function(t){(t=t||this.$vnode&&this.$vnode.ssrContext||this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext)||"undefined"==typeof __VUE_SSR_CONTEXT__||(t=__VUE_SSR_CONTEXT__),i&&i.call(this,t),t&&t._registeredComponents&&t._registeredComponents.add(a)},l._ssrRegister=c):i&&(c=s?function(){i.call(this,this.$root.$options.shadowRoot)}:i),c)if(l.functional){l._injectStyles=c;var u=l.render;l.render=function(t,e){return c.call(e),u(t,e)}}else{var d=l.beforeCreate;l.beforeCreate=d?[].concat(d,c):[c]}return{exports:t,options:l}}var f={Deselect:h({},(function(){var t=this.$createElement,e=this._self._c||t;return e("svg",{attrs:{xmlns:"http://www.w3.org/2000/svg",width:"10",height:"10"}},[e("path",{attrs:{d:"M6.895455 5l2.842897-2.842898c.348864-.348863.348864-.914488 0-1.263636L9.106534.261648c-.348864-.348864-.914489-.348864-1.263636 0L5 3.104545 2.157102.261648c-.348863-.348864-.914488-.348864-1.263636 0L.261648.893466c-.348864.348864-.348864.914489 0 1.263636L3.104545 5 .261648 7.842898c-.348864.348863-.348864.914488 0 1.263636l.631818.631818c.348864.348864.914773.348864 1.263636 0L5 6.895455l2.842898 2.842897c.348863.348864.914772.348864 1.263636 0l.631818-.631818c.348864-.348864.348864-.914489 0-1.263636L6.895455 5z"}})])}),[],!1,null,null,null).exports,OpenIndicator:h({},(function(){var t=this.$createElement,e=this._self._c||t;return e("svg",{attrs:{xmlns:"http://www.w3.org/2000/svg",width:"14",height:"10"}},[e("path",{attrs:{d:"M9.211364 7.59931l4.48338-4.867229c.407008-.441854.407008-1.158247 0-1.60046l-.73712-.80023c-.407008-.441854-1.066904-.441854-1.474243 0L7 5.198617 2.51662.33139c-.407008-.441853-1.066904-.441853-1.474243 0l-.737121.80023c-.407008.441854-.407008 1.158248 0 1.600461l4.48338 4.867228L7 10l2.211364-2.40069z"}})])}),[],!1,null,null,null).exports},p={inserted:function(t,e,n){var r=n.context;if(r.appendToBody){var i=r.$refs.toggle.getBoundingClientRect(),o=i.height,a=i.top,s=i.left,c=i.width,l=window.scrollX||window.pageXOffset,u=window.scrollY||window.pageYOffset;t.unbindPosition=r.calculatePosition(t,r,{width:c+"px",left:l+s+"px",top:u+a+o+"px"}),document.body.appendChild(t)}},unbind:function(t,e,n){n.context.appendToBody&&(t.unbindPosition&&"function"==typeof t.unbindPosition&&t.unbindPosition(),t.parentNode&&t.parentNode.removeChild(t))}},m=function(t){var e={};return Object.keys(t).sort().forEach((function(n){e[n]=t[n]})),JSON.stringify(e)},b=0,g=function(){return++b};function v(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function w(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?v(Object(n),!0).forEach((function(e){c()(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):v(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}var y={components:w({},f),mixins:[l,u,d],directives:{appendToBody:p},props:{value:{},components:{type:Object,default:function(){return{}}},options:{type:Array,default:function(){return[]}},disabled:{type:Boolean,default:!1},clearable:{type:Boolean,default:!0},searchable:{type:Boolean,default:!0},multiple:{type:Boolean,default:!1},placeholder:{type:String,default:""},transition:{type:String,default:"vs__fade"},clearSearchOnSelect:{type:Boolean,default:!0},closeOnSelect:{type:Boolean,default:!0},label:{type:String,default:"label"},autocomplete:{type:String,default:"off"},reduce:{type:Function,default:function(t){return t}},selectable:{type:Function,default:function(t){return!0}},getOptionLabel:{type:Function,default:function(t){return"object"===a()(t)?t.hasOwnProperty(this.label)?t[this.label]:console.warn('[vue-select warn]: Label key "option.'.concat(this.label,'" does not')+" exist in options object ".concat(JSON.stringify(t),".\n")+"https://vue-select.org/api/props.html#getoptionlabel"):t}},getOptionKey:{type:Function,default:function(t){if("object"!==a()(t))return t;try{return t.hasOwnProperty("id")?t.id:m(t)}catch(e){return console.warn("[vue-select warn]: Could not stringify this option to generate unique key. Please provide'getOptionKey' prop to return a unique key for each option.\nhttps://vue-select.org/api/props.html#getoptionkey",t,e)}}},onTab:{type:Function,default:function(){this.selectOnTab&&!this.isComposing&&this.typeAheadSelect()}},taggable:{type:Boolean,default:!1},tabindex:{type:Number,default:null},pushTags:{type:Boolean,default:!1},filterable:{type:Boolean,default:!0},filterBy:{type:Function,default:function(t,e,n){return(e||"").toLowerCase().indexOf(n.toLowerCase())>-1}},filter:{type:Function,default:function(t,e){var n=this;return t.filter((function(t){var r=n.getOptionLabel(t);return"number"==typeof r&&(r=r.toString()),n.filterBy(t,r,e)}))}},createOption:{type:Function,default:function(t){return"object"===a()(this.optionList[0])?c()({},this.label,t):t}},resetOnOptionsChange:{default:!1,validator:function(t){return["function","boolean"].includes(a()(t))}},clearSearchOnBlur:{type:Function,default:function(t){var e=t.clearSearchOnSelect,n=t.multiple;return e&&!n}},noDrop:{type:Boolean,default:!1},inputId:{type:String},dir:{type:String,default:"auto"},selectOnTab:{type:Boolean,default:!1},selectOnKeyCodes:{type:Array,default:function(){return[13]}},searchInputQuerySelector:{type:String,default:"[type=search]"},mapKeydown:{type:Function,default:function(t,e){return t}},appendToBody:{type:Boolean,default:!1},calculatePosition:{type:Function,default:function(t,e,n){var r=n.width,i=n.top,o=n.left;t.style.top=i,t.style.left=o,t.style.width=r}}},data:function(){return{uid:g(),search:"",open:!1,isComposing:!1,pushedTags:[],_value:[]}},watch:{options:function(t,e){var n=this;!this.taggable&&("function"==typeof n.resetOnOptionsChange?n.resetOnOptionsChange(t,e,n.selectedValue):n.resetOnOptionsChange)&&this.clearSelection(),this.value&&this.isTrackingValues&&this.setInternalValueFromOptions(this.value)},value:function(t){this.isTrackingValues&&this.setInternalValueFromOptions(t)},multiple:function(){this.clearSelection()},open:function(t){this.$emit(t?"open":"close")}},created:function(){this.mutableLoading=this.loading,void 0!==this.value&&this.isTrackingValues&&this.setInternalValueFromOptions(this.value),this.$on("option:created",this.pushTag)},methods:{setInternalValueFromOptions:function(t){var e=this;Array.isArray(t)?this.$data._value=t.map((function(t){return e.findOptionFromReducedValue(t)})):this.$data._value=this.findOptionFromReducedValue(t)},select:function(t){this.$emit("option:selecting",t),this.isOptionSelected(t)||(this.taggable&&!this.optionExists(t)&&this.$emit("option:created",t),this.multiple&&(t=this.selectedValue.concat(t)),this.updateValue(t),this.$emit("option:selected",t)),this.onAfterSelect(t)},deselect:function(t){var e=this;this.$emit("option:deselecting",t),this.updateValue(this.selectedValue.filter((function(n){return!e.optionComparator(n,t)}))),this.$emit("option:deselected",t)},clearSelection:function(){this.updateValue(this.multiple?[]:null)},onAfterSelect:function(t){this.closeOnSelect&&(this.open=!this.open,this.searchEl.blur()),this.clearSearchOnSelect&&(this.search="")},updateValue:function(t){var e=this;void 0===this.value&&(this.$data._value=t),null!==t&&(t=Array.isArray(t)?t.map((function(t){return e.reduce(t)})):this.reduce(t)),this.$emit("input",t)},toggleDropdown:function(t){var e=t.target!==this.searchEl;e&&t.preventDefault();var n=[].concat(i()(this.$refs.deselectButtons||[]),i()([this.$refs.clearButton]||!1));void 0===this.searchEl||n.filter(Boolean).some((function(e){return e.contains(t.target)||e===t.target}))?t.preventDefault():this.open&&e?this.searchEl.blur():this.disabled||(this.open=!0,this.searchEl.focus())},isOptionSelected:function(t){var e=this;return this.selectedValue.some((function(n){return e.optionComparator(n,t)}))},optionComparator:function(t,e){return this.getOptionKey(t)===this.getOptionKey(e)},findOptionFromReducedValue:function(t){var e=this,n=[].concat(i()(this.options),i()(this.pushedTags)).filter((function(n){return JSON.stringify(e.reduce(n))===JSON.stringify(t)}));return 1===n.length?n[0]:n.find((function(t){return e.optionComparator(t,e.$data._value)}))||t},closeSearchOptions:function(){this.open=!1,this.$emit("search:blur")},maybeDeleteValue:function(){if(!this.searchEl.value.length&&this.selectedValue&&this.selectedValue.length&&this.clearable){var t=null;this.multiple&&(t=i()(this.selectedValue.slice(0,this.selectedValue.length-1))),this.updateValue(t)}},optionExists:function(t){var e=this;return this.optionList.some((function(n){return e.optionComparator(n,t)}))},normalizeOptionForSlot:function(t){return"object"===a()(t)?t:c()({},this.label,t)},pushTag:function(t){this.pushedTags.push(t)},onEscape:function(){this.search.length?this.search="":this.searchEl.blur()},onSearchBlur:function(){if(!this.mousedown||this.searching){var t=this.clearSearchOnSelect,e=this.multiple;return this.clearSearchOnBlur({clearSearchOnSelect:t,multiple:e})&&(this.search=""),void this.closeSearchOptions()}this.mousedown=!1,0!==this.search.length||0!==this.options.length||this.closeSearchOptions()},onSearchFocus:function(){this.open=!0,this.$emit("search:focus")},onMousedown:function(){this.mousedown=!0},onMouseUp:function(){this.mousedown=!1},onSearchKeyDown:function(t){var e=this,n=function(t){return t.preventDefault(),!e.isComposing&&e.typeAheadSelect()},r={8:function(t){return e.maybeDeleteValue()},9:function(t){return e.onTab()},27:function(t){return e.onEscape()},38:function(t){return t.preventDefault(),e.typeAheadUp()},40:function(t){return t.preventDefault(),e.typeAheadDown()}};this.selectOnKeyCodes.forEach((function(t){return r[t]=n}));var i=this.mapKeydown(r,this);if("function"==typeof i[t.keyCode])return i[t.keyCode](t)}},computed:{isTrackingValues:function(){return void 0===this.value||this.$options.propsData.hasOwnProperty("reduce")},selectedValue:function(){var t=this.value;return this.isTrackingValues&&(t=this.$data._value),t?[].concat(t):[]},optionList:function(){return this.options.concat(this.pushTags?this.pushedTags:[])},searchEl:function(){return this.$scopedSlots.search?this.$refs.selectedOptions.querySelector(this.searchInputQuerySelector):this.$refs.search},scope:function(){var t=this,e={search:this.search,loading:this.loading,searching:this.searching,filteredOptions:this.filteredOptions};return{search:{attributes:w({disabled:this.disabled,placeholder:this.searchPlaceholder,tabindex:this.tabindex,readonly:!this.searchable,id:this.inputId,"aria-autocomplete":"list","aria-labelledby":"vs".concat(this.uid,"__combobox"),"aria-controls":"vs".concat(this.uid,"__listbox"),ref:"search",type:"search",autocomplete:this.autocomplete,value:this.search},this.dropdownOpen&&this.filteredOptions[this.typeAheadPointer]?{"aria-activedescendant":"vs".concat(this.uid,"__option-").concat(this.typeAheadPointer)}:{}),events:{compositionstart:function(){return t.isComposing=!0},compositionend:function(){return t.isComposing=!1},keydown:this.onSearchKeyDown,blur:this.onSearchBlur,focus:this.onSearchFocus,input:function(e){return t.search=e.target.value}}},spinner:{loading:this.mutableLoading},noOptions:{search:this.search,loading:this.loading,searching:this.searching},openIndicator:{attributes:{ref:"openIndicator",role:"presentation",class:"vs__open-indicator"}},listHeader:e,listFooter:e,header:w({},e,{deselect:this.deselect}),footer:w({},e,{deselect:this.deselect})}},childComponents:function(){return w({},f,{},this.components)},stateClasses:function(){return{"vs--open":this.dropdownOpen,"vs--single":!this.multiple,"vs--searching":this.searching&&!this.noDrop,"vs--searchable":this.searchable&&!this.noDrop,"vs--unsearchable":!this.searchable,"vs--loading":this.mutableLoading,"vs--disabled":this.disabled}},searching:function(){return!!this.search},dropdownOpen:function(){return!this.noDrop&&this.open&&!this.mutableLoading},searchPlaceholder:function(){if(this.isValueEmpty&&this.placeholder)return this.placeholder},filteredOptions:function(){var t=[].concat(this.optionList);if(!this.filterable&&!this.taggable)return t;var e=this.search.length?this.filter(t,this.search,this):t;if(this.taggable&&this.search.length){var n=this.createOption(this.search);this.optionExists(n)||e.unshift(n)}return e},isValueEmpty:function(){return 0===this.selectedValue.length},showClearButton:function(){return!this.multiple&&this.clearable&&!this.open&&!this.isValueEmpty}}},k=(n(7),h(y,(function(){var t=this,e=t.$createElement,n=t._self._c||e;return n("div",{staticClass:"v-select",class:t.stateClasses,attrs:{dir:t.dir}},[t._t("header",null,null,t.scope.header),t._v(" "),n("div",{ref:"toggle",staticClass:"vs__dropdown-toggle",attrs:{id:"vs"+t.uid+"__combobox",role:"combobox","aria-expanded":t.dropdownOpen.toString(),"aria-owns":"vs"+t.uid+"__listbox","aria-label":"Search for option"},on:{mousedown:function(e){return t.toggleDropdown(e)}}},[n("div",{ref:"selectedOptions",staticClass:"vs__selected-options"},[t._l(t.selectedValue,(function(e){return t._t("selected-option-container",[n("span",{key:t.getOptionKey(e),staticClass:"vs__selected"},[t._t("selected-option",[t._v("\n            "+t._s(t.getOptionLabel(e))+"\n          ")],null,t.normalizeOptionForSlot(e)),t._v(" "),t.multiple?n("button",{ref:"deselectButtons",refInFor:!0,staticClass:"vs__deselect",attrs:{disabled:t.disabled,type:"button",title:"Deselect "+t.getOptionLabel(e),"aria-label":"Deselect "+t.getOptionLabel(e)},on:{click:function(n){return t.deselect(e)}}},[n(t.childComponents.Deselect,{tag:"component"})],1):t._e()],2)],{option:t.normalizeOptionForSlot(e),deselect:t.deselect,multiple:t.multiple,disabled:t.disabled})})),t._v(" "),t._t("search",[n("input",t._g(t._b({staticClass:"vs__search"},"input",t.scope.search.attributes,!1),t.scope.search.events))],null,t.scope.search)],2),t._v(" "),n("div",{ref:"actions",staticClass:"vs__actions"},[n("button",{directives:[{name:"show",rawName:"v-show",value:t.showClearButton,expression:"showClearButton"}],ref:"clearButton",staticClass:"vs__clear",attrs:{disabled:t.disabled,type:"button",title:"Clear Selected","aria-label":"Clear Selected"},on:{click:t.clearSelection}},[n(t.childComponents.Deselect,{tag:"component"})],1),t._v(" "),t._t("open-indicator",[t.noDrop?t._e():n(t.childComponents.OpenIndicator,t._b({tag:"component"},"component",t.scope.openIndicator.attributes,!1))],null,t.scope.openIndicator),t._v(" "),t._t("spinner",[n("div",{directives:[{name:"show",rawName:"v-show",value:t.mutableLoading,expression:"mutableLoading"}],staticClass:"vs__spinner"},[t._v("Loading...")])],null,t.scope.spinner)],2)]),t._v(" "),n("transition",{attrs:{name:t.transition}},[t.dropdownOpen?n("ul",{directives:[{name:"append-to-body",rawName:"v-append-to-body"}],key:"vs"+t.uid+"__listbox",ref:"dropdownMenu",staticClass:"vs__dropdown-menu",attrs:{id:"vs"+t.uid+"__listbox",role:"listbox",tabindex:"-1"},on:{mousedown:function(e){return e.preventDefault(),t.onMousedown(e)},mouseup:t.onMouseUp}},[t._t("list-header",null,null,t.scope.listHeader),t._v(" "),t._l(t.filteredOptions,(function(e,r){return n("li",{key:t.getOptionKey(e),staticClass:"vs__dropdown-option",class:{"vs__dropdown-option--selected":t.isOptionSelected(e),"vs__dropdown-option--highlight":r===t.typeAheadPointer,"vs__dropdown-option--disabled":!t.selectable(e)},attrs:{role:"option",id:"vs"+t.uid+"__option-"+r,"aria-selected":r===t.typeAheadPointer||null},on:{mouseover:function(n){t.selectable(e)&&(t.typeAheadPointer=r)},mousedown:function(n){n.preventDefault(),n.stopPropagation(),t.selectable(e)&&t.select(e)}}},[t._t("option",[t._v("\n          "+t._s(t.getOptionLabel(e))+"\n        ")],null,t.normalizeOptionForSlot(e))],2)})),t._v(" "),0===t.filteredOptions.length?n("li",{staticClass:"vs__no-options"},[t._t("no-options",[t._v("Sorry, no matching options.")],null,t.scope.noOptions)],2):t._e(),t._v(" "),t._t("list-footer",null,null,t.scope.listFooter)],2):n("ul",{staticStyle:{display:"none",visibility:"hidden"},attrs:{id:"vs"+t.uid+"__listbox",role:"listbox"}})]),t._v(" "),t._t("footer",null,null,t.scope.footer)],2)}),[],!1,null,null,null).exports),_={ajax:d,pointer:u,pointerScroll:l};n.d(e,"VueSelect",(function(){return k})),n.d(e,"mixins",(function(){return _})),e.default=k}])}))},"4a7b":function(t,e,n){"use strict";var r=n("c532");t.exports=function(t,e){e=e||{};var n={},i=["url","method","data"],o=["headers","auth","proxy","params"],a=["baseURL","transformRequest","transformResponse","paramsSerializer","timeout","timeoutMessage","withCredentials","adapter","responseType","xsrfCookieName","xsrfHeaderName","onUploadProgress","onDownloadProgress","decompress","maxContentLength","maxBodyLength","maxRedirects","transport","httpAgent","httpsAgent","cancelToken","socketPath","responseEncoding"],s=["validateStatus"];function c(t,e){return r.isPlainObject(t)&&r.isPlainObject(e)?r.merge(t,e):r.isPlainObject(e)?r.merge({},e):r.isArray(e)?e.slice():e}function l(i){r.isUndefined(e[i])?r.isUndefined(t[i])||(n[i]=c(void 0,t[i])):n[i]=c(t[i],e[i])}r.forEach(i,(function(t){r.isUndefined(e[t])||(n[t]=c(void 0,e[t]))})),r.forEach(o,l),r.forEach(a,(function(i){r.isUndefined(e[i])?r.isUndefined(t[i])||(n[i]=c(void 0,t[i])):n[i]=c(void 0,e[i])})),r.forEach(s,(function(r){r in e?n[r]=c(t[r],e[r]):r in t&&(n[r]=c(void 0,t[r]))}));var u=i.concat(o).concat(a).concat(s),d=Object.keys(t).concat(Object.keys(e)).filter((function(t){return-1===u.indexOf(t)}));return r.forEach(d,l),n}},"50d3":function(t,e,n){"use strict";n.d(e,"b",(function(){return r})),n.d(e,"c",(function(){return i})),n.d(e,"a",(function(){return o}));var r="BvConfig",i="$bvConfig",o=["xs","sm","md","lg","xl"]},5270:function(t,e,n){"use strict";var r=n("c532"),i=n("c401"),o=n("2e67"),a=n("2444");function s(t){t.cancelToken&&t.cancelToken.throwIfRequested()}t.exports=function(t){s(t),t.headers=t.headers||{},t.data=i(t.data,t.headers,t.transformRequest),t.headers=r.merge(t.headers.common||{},t.headers[t.method]||{},t.headers),r.forEach(["delete","get","head","post","put","patch","common"],(function(e){delete t.headers[e]}));var e=t.adapter||a.adapter;return e(t).then((function(e){return s(t),e.data=i(e.data,e.headers,t.transformResponse),e}),(function(e){return o(e)||(s(t),e&&e.response&&(e.response.data=i(e.response.data,e.response.headers,t.transformResponse))),Promise.reject(e)}))}},"5d4e":function(t,e,n){"use strict";n.d(e,"a",(function(){return u}));var r=n("2b0e"),i=n("b42e"),o=n("c637"),a=n("d82f"),s=n("cf75"),c=n("aa0d"),l=Object(s["d"])(Object(a["j"])(c["b"],["content","stacked"]),o["mb"]),u=r["default"].extend({name:o["mb"],functional:!0,props:l,render:function(t,e){var n=e.data,r=e.props,o=e.children;return t(c["a"],Object(i["a"])(n,{staticClass:"b-iconstack",props:r}),o)}})},"5f02":function(t,e,n){"use strict";t.exports=function(t){return"object"===typeof t&&!0===t.isAxiosError}},"5f5b":function(t,e,n){"use strict";n.d(e,"a",(function(){return BM}));var r=n("3790"),i=n("2b0e"),o=n("2f79"),a=n("c637"),s="activate-tab",c="blur",l="cancel",u="change",d="changed",h="click",f="close",p="context",m="context-changed",b="destroyed",g="disable",v="disabled",w="dismissed",y="dismiss-count-down",k="enable",_="enabled",O="filtered",z="first",A="focusin",j="focusout",M="head-clicked",C="hidden",V="hide",S="img-error",x="input",T="last",P="mouseenter",I="mouseleave",E="next",L="ok",B="open",H="page-click",F="paused",D="prev",R="refresh",N="refreshed",$="remove",U="row-clicked",q="row-contextmenu",W="row-dblclicked",G="row-hovered",Y="row-middle-clicked",K="row-selected",Q="row-unhovered",X="selected",J="show",Z="shown",tt="sliding-end",et="sliding-start",nt="sort-changed",rt="tag-state",it="toggle",ot="unpaused",at="update",st="hook:beforeDestroy",ct="hook:destroyed",lt="update:",ut="bv",dt="::",ht={passive:!0},ft={passive:!0,capture:!1},pt=n("a723"),mt="add-button-text",bt="append",gt="aside",vt="badge",wt="bottom-row",yt="button-content",kt="custom-foot",_t="decrement",Ot="default",zt="description",At="dismiss",jt="drop-placeholder",Mt="ellipsis-text",Ct="empty",Vt="emptyfiltered",St="file-name",xt="first",Tt="first-text",Pt="footer",It="header",Et="header-close",Lt="icon-clear",Bt="icon-empty",Ht="icon-full",Ft="icon-half",Dt="img",Rt="increment",Nt="invalid-feedback",$t="label",Ut="last-text",qt="lead",Wt="loading",Gt="modal-backdrop",Yt="modal-cancel",Kt="modal-footer",Qt="modal-header",Xt="modal-header-close",Jt="modal-ok",Zt="modal-title",te="nav-next-decade",ee="nav-next-month",ne="nav-next-year",re="nav-prev-decade",ie="nav-prev-month",oe="nav-prev-year",ae="nav-this-month",se="next-text",ce="overlay",le="page",ue="placeholder",de="prepend",he="prev-text",fe="row-details",pe="table-busy",me="table-caption",be="table-colgroup",ge="tabs-end",ve="tabs-start",we="text",ye="thead-top",ke="title",_e="toast-title",Oe="top-row",ze="valid-feedback",Ae=n("e863"),je=n("ca88"),Me=n("7b1e"),Ce=function(){return Array.from.apply(Array,arguments)},Ve=function(t,e){return-1!==t.indexOf(e)},Se=function(){for(var t=arguments.length,e=new Array(t),n=0;n<t;n++)e[n]=arguments[n];return Array.prototype.concat.apply([],e)},xe=function(t,e){var n=Object(Me["f"])(e)?e:function(){return e};return Array.apply(null,{length:t}).map(n)},Te=function(t){return t.reduce((function(t,e){return Se(t,e)}),[])},Pe=function t(e){return e.reduce((function(e,n){return Se(e,Array.isArray(n)?t(n):n)}),[])},Ie=n("3a58"),Ee=n("fa73"),Le=je["a"].prototype,Be=["button","[href]:not(.disabled)","input","select","textarea","[tabindex]","[contenteditable]"].map((function(t){return"".concat(t,":not(:disabled):not([disabled])")})).join(", "),He=Le.matches||Le.msMatchesSelector||Le.webkitMatchesSelector,Fe=Le.closest||function(t){var e=this;do{if(Je(e,t))return e;e=e.parentElement||e.parentNode}while(!Object(Me["g"])(e)&&e.nodeType===Node.ELEMENT_NODE);return null},De=Ae["k"].requestAnimationFrame||Ae["k"].webkitRequestAnimationFrame||Ae["k"].mozRequestAnimationFrame||Ae["k"].msRequestAnimationFrame||Ae["k"].oRequestAnimationFrame||function(t){return setTimeout(t,16)},Re=Ae["k"].MutationObserver||Ae["k"].WebKitMutationObserver||Ae["k"].MozMutationObserver||null,Ne=function(t){return t&&t.parentNode&&t.parentNode.removeChild(t)},$e=function(t){return!(!t||t.nodeType!==Node.ELEMENT_NODE)},Ue=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:[],e=Ae["a"].activeElement;return e&&!t.some((function(t){return t===e}))?e:null},qe=function(t,e){return Object(Ee["g"])(t).toLowerCase()===Object(Ee["g"])(e).toLowerCase()},We=function(t){return $e(t)&&t===Ue()},Ge=function(t){if(!$e(t)||!t.parentNode||!tn(Ae["a"].body,t))return!1;if("none"===hn(t,"display"))return!1;var e=fn(t);return!!(e&&e.height>0&&e.width>0)},Ye=function(t){return!$e(t)||t.disabled||ln(t,"disabled")||on(t,"disabled")},Ke=function(t){return $e(t)&&t.offsetHeight},Qe=function(t,e){return Ce(($e(e)?e:Ae["a"]).querySelectorAll(t))},Xe=function(t,e){return($e(e)?e:Ae["a"]).querySelector(t)||null},Je=function(t,e){return!!$e(t)&&He.call(t,e)},Ze=function(t,e){var n=arguments.length>2&&void 0!==arguments[2]&&arguments[2];if(!$e(e))return null;var r=Fe.call(e,t);return n?r:r===e?null:r},tn=function(t,e){return!(!t||!Object(Me["f"])(t.contains))&&t.contains(e)},en=function(t){return Ae["a"].getElementById(/^#/.test(t)?t.slice(1):t)||null},nn=function(t,e){e&&$e(t)&&t.classList&&t.classList.add(e)},rn=function(t,e){e&&$e(t)&&t.classList&&t.classList.remove(e)},on=function(t,e){return!!(e&&$e(t)&&t.classList)&&t.classList.contains(e)},an=function(t,e,n){e&&$e(t)&&t.setAttribute(e,n)},sn=function(t,e){e&&$e(t)&&t.removeAttribute(e)},cn=function(t,e){return e&&$e(t)?t.getAttribute(e):null},ln=function(t,e){return e&&$e(t)?t.hasAttribute(e):null},un=function(t,e,n){e&&$e(t)&&(t.style[e]=n)},dn=function(t,e){e&&$e(t)&&(t.style[e]="")},hn=function(t,e){return e&&$e(t)&&t.style[e]||null},fn=function(t){return $e(t)?t.getBoundingClientRect():null},pn=function(t){var e=Ae["k"].getComputedStyle;return e&&$e(t)?e(t):{}},mn=function(){var t=Ae["k"].getSelection;return t?Ae["k"].getSelection():null},bn=function(t){var e={top:0,left:0};if(!$e(t)||0===t.getClientRects().length)return e;var n=fn(t);if(n){var r=t.ownerDocument.defaultView;e.top=n.top+r.pageYOffset,e.left=n.left+r.pageXOffset}return e},gn=function(t){var e={top:0,left:0};if(!$e(t))return e;var n={top:0,left:0},r=pn(t);if("fixed"===r.position)e=fn(t)||e;else{e=bn(t);var i=t.ownerDocument,o=t.offsetParent||i.documentElement;while(o&&(o===i.body||o===i.documentElement)&&"static"===pn(o).position)o=o.parentNode;if(o&&o!==t&&o.nodeType===Node.ELEMENT_NODE){n=bn(o);var a=pn(o);n.top+=Object(Ie["b"])(a.borderTopWidth,0),n.left+=Object(Ie["b"])(a.borderLeftWidth,0)}}return{top:e.top-n.top-Object(Ie["b"])(r.marginTop,0),left:e.left-n.left-Object(Ie["b"])(r.marginLeft,0)}},vn=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:document;return Qe(Be,t).filter(Ge).filter((function(t){return t.tabIndex>-1&&!t.disabled}))},wn=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};try{t.focus(e)}catch(n){}return We(t)},yn=function(t){try{t.blur()}catch(e){}return!We(t)},kn=n("cf75");function _n(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var On=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=e.type,r=void 0===n?pt["a"]:n,o=e.defaultValue,a=void 0===o?void 0:o,s=e.validator,c=void 0===s?void 0:s,l=e.event,u=void 0===l?x:l,d=_n({},t,Object(kn["c"])(r,a,c)),h=i["default"].extend({model:{prop:t,event:u},props:d});return{mixin:h,props:d,prop:t,event:u}},zn=n("d82f"),An=n("6c06"),jn=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return t=Se(t).filter(An["a"]),t.some((function(t){return e[t]||n[t]}))},Mn=function(t){var e,n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},i=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{};t=Se(t).filter(An["a"]);for(var o=0;o<t.length&&!e;o++){var a=t[o];e=r[a]||i[a]}return Object(Me["f"])(e)?e(n):e},Cn=i["default"].extend({methods:{hasNormalizedSlot:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:Ot,e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:this.$scopedSlots,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:this.$slots;return jn(t,e,n)},normalizeSlot:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:Ot,e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:this.$scopedSlots,r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:this.$slots,i=Mn(t,e,n,r);return i?Se(i):i}}}),Vn=n("b42e"),Sn=n("992e"),xn=function(t){return Ae["d"]?Object(Me["j"])(t)?t:{capture:!!t||!1}:!!(Object(Me["j"])(t)?t.capture:t)},Tn=function(t,e,n,r){t&&t.addEventListener&&t.addEventListener(e,n,xn(r))},Pn=function(t,e,n,r){t&&t.removeEventListener&&t.removeEventListener(e,n,xn(r))},In=function(t){for(var e=t?Tn:Pn,n=arguments.length,r=new Array(n>1?n-1:0),i=1;i<n;i++)r[i-1]=arguments[i];e.apply(void 0,r)},En=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=e.preventDefault,r=void 0===n||n,i=e.propagation,o=void 0===i||i,a=e.immediatePropagation,s=void 0!==a&&a;r&&t.preventDefault(),o&&t.stopPropagation(),s&&t.stopImmediatePropagation()},Ln=function(t){return Object(Ee["b"])(t.replace(Sn["d"],""))},Bn=function(t,e){return[ut,Ln(t),e].join(dt)},Hn=function(t,e){return[ut,e,Ln(t)].join(dt)};function Fn(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Dn=Object(kn["d"])({ariaLabel:Object(kn["c"])(pt["u"],"Close"),content:Object(kn["c"])(pt["u"],"&times;"),disabled:Object(kn["c"])(pt["g"],!1),textVariant:Object(kn["c"])(pt["u"])},a["j"]),Rn=i["default"].extend({name:a["j"],functional:!0,props:Dn,render:function(t,e){var n=e.props,r=e.data,i=e.slots,o=e.scopedSlots,a=i(),s=o||{},c={staticClass:"close",class:Fn({},"text-".concat(n.textVariant),n.textVariant),attrs:{type:"button",disabled:n.disabled,"aria-label":n.ariaLabel?String(n.ariaLabel):null},on:{click:function(t){n.disabled&&Object(Me["d"])(t)&&En(t)}}};return jn(Ot,s,a)||(c.domProps={innerHTML:n.content}),t("button",Object(Vn["a"])(r,c),Mn(Ot,{},s,a))}});function Nn(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function $n(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Nn(Object(n),!0).forEach((function(e){Un(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Nn(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Un(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var qn,Wn={name:"",enterClass:"",enterActiveClass:"",enterToClass:"show",leaveClass:"show",leaveActiveClass:"",leaveToClass:""},Gn=$n($n({},Wn),{},{enterActiveClass:"fade",leaveActiveClass:"fade"}),Yn={appear:Object(kn["c"])(pt["g"],!1),mode:Object(kn["c"])(pt["u"]),noFade:Object(kn["c"])(pt["g"],!1),transProps:Object(kn["c"])(pt["q"])},Kn=i["default"].extend({name:a["xc"],functional:!0,props:Yn,render:function(t,e){var n=e.children,r=e.data,i=e.props,o=i.transProps;return Object(Me["k"])(o)||(o=i.noFade?Wn:Gn,i.appear&&(o=$n($n({},o),{},{appear:!0,appearClass:o.enterClass,appearActiveClass:o.enterActiveClass,appearToClass:o.enterToClass}))),o=$n($n({mode:i.mode},o),{},{css:!0}),t("transition",Object(Vn["a"])(r,{props:o}),n)}});function Qn(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Xn(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Qn(Object(n),!0).forEach((function(e){Jn(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Qn(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Jn(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Zn=On("show",{type:pt["i"],defaultValue:!1}),tr=Zn.mixin,er=Zn.props,nr=Zn.prop,rr=Zn.event,ir=function(t){return""===t||Object(Me["b"])(t)?0:(t=Object(Ie["c"])(t,0),t>0?t:0)},or=function(t){return""===t||!0===t||!(Object(Ie["c"])(t,0)<1)&&!!t},ar=Object(kn["d"])(Object(zn["m"])(Xn(Xn({},er),{},{dismissLabel:Object(kn["c"])(pt["u"],"Close"),dismissible:Object(kn["c"])(pt["g"],!1),fade:Object(kn["c"])(pt["g"],!1),variant:Object(kn["c"])(pt["u"],"info")})),a["a"]),sr=i["default"].extend({name:a["a"],mixins:[tr,Cn],props:ar,data:function(){return{countDown:0,localShow:or(this[nr])}},watch:(qn={},Jn(qn,nr,(function(t){this.countDown=ir(t),this.localShow=or(t)})),Jn(qn,"countDown",(function(t){var e=this;this.clearCountDownInterval();var n=this[nr];Object(Me["i"])(n)&&(this.$emit(y,t),n!==t&&this.$emit(rr,t),t>0?(this.localShow=!0,this.$_countDownTimeout=setTimeout((function(){e.countDown--}),1e3)):this.$nextTick((function(){De((function(){e.localShow=!1}))})))})),Jn(qn,"localShow",(function(t){var e=this[nr];t||!this.dismissible&&!Object(Me["i"])(e)||this.$emit(w),Object(Me["i"])(e)||e===t||this.$emit(rr,t)})),qn),created:function(){this.$_filterTimer=null;var t=this[nr];this.countDown=ir(t),this.localShow=or(t)},beforeDestroy:function(){this.clearCountDownInterval()},methods:{dismiss:function(){this.clearCountDownInterval(),this.countDown=0,this.localShow=!1},clearCountDownInterval:function(){clearTimeout(this.$_countDownTimeout),this.$_countDownTimeout=null}},render:function(t){var e=t();if(this.localShow){var n=this.dismissible,r=this.variant,i=t();n&&(i=t(Rn,{attrs:{"aria-label":this.dismissLabel},on:{click:this.dismiss}},[this.normalizeSlot(At)])),e=t("div",{staticClass:"alert",class:Jn({"alert-dismissible":n},"alert-".concat(r),r),attrs:{role:"alert","aria-live":"polite","aria-atomic":!0},key:this[o["a"]]},[i,this.normalizeSlot()])}return t(Kn,{props:{noFade:!this.fade}},[e])}}),cr=Object(r["b"])({components:{BAlert:sr}}),lr=n("a8c8");function ur(t,e){return mr(t)||pr(t,e)||hr(t,e)||dr()}function dr(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function hr(t,e){if(t){if("string"===typeof t)return fr(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?fr(t,e):void 0}}function fr(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function pr(t,e){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t)){var n=[],r=!0,i=!1,o=void 0;try{for(var a,s=t[Symbol.iterator]();!(r=(a=s.next()).done);r=!0)if(n.push(a.value),e&&n.length===e)break}catch(c){i=!0,o=c}finally{try{r||null==s["return"]||s["return"]()}finally{if(i)throw o}}return n}}function mr(t){if(Array.isArray(t))return t}var br="b-aspect",gr=Object(kn["d"])({aspect:Object(kn["c"])(pt["p"],"1:1"),tag:Object(kn["c"])(pt["u"],"div")},a["b"]),vr=i["default"].extend({name:a["b"],mixins:[Cn],props:gr,computed:{padding:function(){var t=this.aspect,e=1;if(Sn["b"].test(t)){var n=t.split(Sn["c"]).map((function(t){return Object(Ie["b"])(t)||1})),r=ur(n,2),i=r[0],o=r[1];e=i/o}else e=Object(Ie["b"])(t)||1;return"".concat(100/Object(lr["a"])(e),"%")}},render:function(t){var e=t("div",{staticClass:"".concat(br,"-sizer flex-grow-1"),style:{paddingBottom:this.padding,height:0}}),n=t("div",{staticClass:"".concat(br,"-content flex-grow-1 w-100 mw-100"),style:{marginLeft:"-100%"}},this.normalizeSlot());return t(this.tag,{staticClass:"".concat(br," d-flex")},[e,n])}}),wr=Object(r["b"])({components:{BAspect:vr}}),yr="a",kr=function(t){return"%"+t.charCodeAt(0).toString(16)},_r=function(t){return encodeURIComponent(Object(Ee["g"])(t)).replace(Sn["j"],kr).replace(Sn["i"],",")},Or=decodeURIComponent,zr=function(t){if(!Object(Me["k"])(t))return"";var e=Object(zn["h"])(t).map((function(e){var n=t[e];return Object(Me["o"])(n)?"":Object(Me["g"])(n)?_r(e):Object(Me["a"])(n)?n.reduce((function(t,n){return Object(Me["g"])(n)?t.push(_r(e)):Object(Me["o"])(n)||t.push(_r(e)+"="+_r(n)),t}),[]).join("&"):_r(e)+"="+_r(n)})).filter((function(t){return t.length>0})).join("&");return e?"?".concat(e):""},Ar=function(t){var e={};return t=Object(Ee["g"])(t).trim().replace(Sn["u"],""),t?(t.split("&").forEach((function(t){var n=t.replace(Sn["t"]," ").split("="),r=Or(n.shift()),i=n.length>0?Or(n.join("=")):null;Object(Me["o"])(e[r])?e[r]=i:Object(Me["a"])(e[r])?e[r].push(i):e[r]=[e[r],i]})),e):e},jr=function(t){return!(!t.href&&!t.to)},Mr=function(t){return!(!t||qe(t,"a"))},Cr=function(t,e){var n=t.to,r=t.disabled,i=t.routerComponentName,o=!!e.$router;return!o||o&&(r||!n)?yr:i||(e.$nuxt?"nuxt-link":"router-link")},Vr=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=t.target,n=t.rel;return"_blank"===e&&Object(Me["g"])(n)?"noopener":n||null},Sr=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=t.href,n=t.to,r=arguments.length>1&&void 0!==arguments[1]?arguments[1]:yr,i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"#",o=arguments.length>3&&void 0!==arguments[3]?arguments[3]:"/";if(e)return e;if(Mr(r))return null;if(Object(Me["n"])(n))return n||o;if(Object(Me["k"])(n)&&(n.path||n.query||n.hash)){var a=Object(Ee["g"])(n.path),s=zr(n.query),c=Object(Ee["g"])(n.hash);return c=c&&"#"!==c.charAt(0)?"#".concat(c):c,"".concat(a).concat(s).concat(c)||o}return i},xr=n("0759"),Tr=n("7386"),Pr=8,Ir=46,Er=40,Lr=35,Br=13,Hr=27,Fr=36,Dr=37,Rr=34,Nr=33,$r=39,Ur=32,qr=38,Wr=n("c9a9"),Gr=function(t,e){if(t.length!==e.length)return!1;for(var n=!0,r=0;n&&r<t.length;r++)n=Yr(t[r],e[r]);return n},Yr=function t(e,n){if(e===n)return!0;var r=Object(Me["c"])(e),i=Object(Me["c"])(n);if(r||i)return!(!r||!i)&&e.getTime()===n.getTime();if(r=Object(Me["a"])(e),i=Object(Me["a"])(n),r||i)return!(!r||!i)&&Gr(e,n);if(r=Object(Me["j"])(e),i=Object(Me["j"])(n),r||i){if(!r||!i)return!1;var o=Object(zn["h"])(e).length,a=Object(zn["h"])(n).length;if(o!==a)return!1;for(var s in e){var c=Object(zn["g"])(e,s),l=Object(zn["g"])(n,s);if(c&&!l||!c&&l||!t(e[s],n[s]))return!1}}return String(e)===String(n)};function Kr(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Qr=function(t){return!t||0===Object(zn["h"])(t).length},Xr=function(t){return{handler:function(e,n){if(!Yr(e,n))if(Qr(e)||Qr(n))this[t]=Object(Wr["a"])(e);else{for(var r in n)Object(zn["g"])(e,r)||this.$delete(this.$data[t],r);for(var i in e)this.$set(this.$data[t],i,e[i])}}}},Jr=function(t,e){return i["default"].extend({data:function(){return Kr({},e,Object(Wr["a"])(this[t]))},watch:Kr({},t,Xr(e))})},Zr=Jr("$attrs","bvAttrs"),ti=i["default"].extend({methods:{listenOnRoot:function(t,e){var n=this;this.$root.$on(t,e),this.$on(st,(function(){n.$root.$off(t,e)}))},listenOnRootOnce:function(t,e){var n=this;this.$root.$once(t,e),this.$on(st,(function(){n.$root.$off(t,e)}))},emitOnRoot:function(t){for(var e,n=arguments.length,r=new Array(n>1?n-1:0),i=1;i<n;i++)r[i-1]=arguments[i];(e=this.$root).$emit.apply(e,[t].concat(r))}}}),ei=Jr("$listeners","bvListeners");function ni(t){return ai(t)||oi(t)||ii(t)||ri()}function ri(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function ii(t,e){if(t){if("string"===typeof t)return si(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?si(t,e):void 0}}function oi(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function ai(t){if(Array.isArray(t))return si(t)}function si(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function ci(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function li(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?ci(Object(n),!0).forEach((function(e){ui(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):ci(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function ui(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var di=Bn(a["wb"],"clicked"),hi={activeClass:Object(kn["c"])(pt["u"]),append:Object(kn["c"])(pt["g"],!1),event:Object(kn["c"])(pt["f"],h),exact:Object(kn["c"])(pt["g"],!1),exactActiveClass:Object(kn["c"])(pt["u"]),replace:Object(kn["c"])(pt["g"],!1),routerTag:Object(kn["c"])(pt["u"],"a"),to:Object(kn["c"])(pt["s"])},fi={noPrefetch:Object(kn["c"])(pt["g"],!1),prefetch:Object(kn["c"])(pt["g"],null)},pi=Object(kn["d"])(Object(zn["m"])(li(li(li({},fi),hi),{},{active:Object(kn["c"])(pt["g"],!1),disabled:Object(kn["c"])(pt["g"],!1),href:Object(kn["c"])(pt["u"]),rel:Object(kn["c"])(pt["u"],null),routerComponentName:Object(kn["c"])(pt["u"]),target:Object(kn["c"])(pt["u"],"_self")})),a["wb"]),mi=i["default"].extend({name:a["wb"],mixins:[Zr,ei,ti,Cn],inheritAttrs:!1,props:pi,computed:{computedTag:function(){var t=this.to,e=this.disabled,n=this.routerComponentName;return Cr({to:t,disabled:e,routerComponentName:n},this)},isRouterLink:function(){return Mr(this.computedTag)},computedRel:function(){var t=this.target,e=this.rel;return Vr({target:t,rel:e})},computedHref:function(){var t=this.to,e=this.href;return Sr({to:t,href:e},this.computedTag)},computedProps:function(){var t=this.prefetch;return this.isRouterLink?li(li({},Object(kn["e"])(li(li({},hi),fi),this)),{},{prefetch:Object(Me["b"])(t)?t:void 0,tag:this.routerTag}):{}},computedAttrs:function(){var t=this.bvAttrs,e=this.computedHref,n=this.computedRel,r=this.disabled,i=this.target,o=this.routerTag,a=this.isRouterLink;return li(li(li(li({},t),e?{href:e}:{}),a&&!qe(o,"a")?{}:{rel:n,target:i}),{},{tabindex:r?"-1":Object(Me["o"])(t.tabindex)?null:t.tabindex,"aria-disabled":r?"true":null})},computedListeners:function(){return li(li({},this.bvListeners),{},{click:this.onClick})}},methods:{onClick:function(t){var e=arguments,n=Object(Me["d"])(t),r=this.isRouterLink,i=this.bvListeners.click;n&&this.disabled?En(t,{immediatePropagation:!0}):(r&&t.currentTarget.__vue__&&t.currentTarget.__vue__.$emit(h,t),Se(i).filter((function(t){return Object(Me["f"])(t)})).forEach((function(t){t.apply(void 0,ni(e))})),this.emitOnRoot(di,t),this.emitOnRoot("clicked::link",t)),n&&!r&&"#"===this.computedHref&&En(t,{propagation:!1})},focus:function(){wn(this.$el)},blur:function(){yn(this.$el)}},render:function(t){var e=this.active,n=this.disabled;return t(this.computedTag,ui({class:{active:e,disabled:n},attrs:this.computedAttrs,props:this.computedProps},this.isRouterLink?"nativeOn":"on",this.computedListeners),this.normalizeSlot())}});function bi(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function gi(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?bi(Object(n),!0).forEach((function(e){vi(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):bi(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function vi(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var wi=Object(zn["j"])(pi,["event","routerTag"]);delete wi.href.default,delete wi.to.default;var yi=Object(kn["d"])(Object(zn["m"])(gi(gi({},wi),{},{block:Object(kn["c"])(pt["g"],!1),disabled:Object(kn["c"])(pt["g"],!1),pill:Object(kn["c"])(pt["g"],!1),pressed:Object(kn["c"])(pt["g"],null),size:Object(kn["c"])(pt["u"]),squared:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"button"),type:Object(kn["c"])(pt["u"],"button"),variant:Object(kn["c"])(pt["u"],"secondary")})),a["i"]),ki=function(t){"focusin"===t.type?nn(t.target,"focus"):"focusout"===t.type&&rn(t.target,"focus")},_i=function(t){return jr(t)||qe(t.tag,"a")},Oi=function(t){return Object(Me["b"])(t.pressed)},zi=function(t){return!(_i(t)||t.tag&&!qe(t.tag,"button"))},Ai=function(t){return!_i(t)&&!zi(t)},ji=function(t){var e;return["btn-".concat(t.variant||"secondary"),(e={},vi(e,"btn-".concat(t.size),t.size),vi(e,"btn-block",t.block),vi(e,"rounded-pill",t.pill),vi(e,"rounded-0",t.squared&&!t.pill),vi(e,"disabled",t.disabled),vi(e,"active",t.pressed),e)]},Mi=function(t){return _i(t)?Object(kn["e"])(wi,t):{}},Ci=function(t,e){var n=zi(t),r=_i(t),i=Oi(t),o=Ai(t),a=r&&"#"===t.href,s=e.attrs&&e.attrs.role?e.attrs.role:null,c=e.attrs?e.attrs.tabindex:null;return(o||a)&&(c="0"),{type:n&&!r?t.type:null,disabled:n?t.disabled:null,role:o||a?"button":s,"aria-disabled":o?String(t.disabled):null,"aria-pressed":i?String(t.pressed):null,autocomplete:i?"off":null,tabindex:t.disabled&&!n?"-1":c}},Vi=i["default"].extend({name:a["i"],functional:!0,props:yi,render:function(t,e){var n=e.props,r=e.data,i=e.listeners,o=e.children,a=Oi(n),s=_i(n),c=Ai(n),l=s&&"#"===n.href,u={keydown:function(t){if(!n.disabled&&(c||l)){var e=t.keyCode;if(e===Ur||e===Br&&c){var r=t.currentTarget||t.target;En(t,{propagation:!1}),r.click()}}},click:function(t){n.disabled&&Object(Me["d"])(t)?En(t):a&&i&&i["update:pressed"]&&Se(i["update:pressed"]).forEach((function(t){Object(Me["f"])(t)&&t(!n.pressed)}))}};a&&(u.focusin=ki,u.focusout=ki);var d={staticClass:"btn",class:ji(n),props:Mi(n),attrs:Ci(n,r),on:u};return t(s?mi:n.tag,Object(Vn["a"])(r,d),o)}});function Si(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function xi(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Si(Object(n),!0).forEach((function(e){Ti(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Si(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Ti(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Pi="b-avatar",Ii=["sm",null,"lg"],Ei=.4,Li=.7*Ei,Bi=function(t){return t=Object(Me["n"])(t)&&Object(Me["i"])(t)?Object(Ie["b"])(t,0):t,Object(Me["h"])(t)?"".concat(t,"px"):t||null},Hi=Object(zn["j"])(pi,["active","event","routerTag"]),Fi=Object(kn["d"])(Object(zn["m"])(xi(xi({},Hi),{},{alt:Object(kn["c"])(pt["u"],"avatar"),ariaLabel:Object(kn["c"])(pt["u"]),badge:Object(kn["c"])(pt["j"],!1),badgeLeft:Object(kn["c"])(pt["g"],!1),badgeOffset:Object(kn["c"])(pt["u"]),badgeTop:Object(kn["c"])(pt["g"],!1),badgeVariant:Object(kn["c"])(pt["u"],"primary"),button:Object(kn["c"])(pt["g"],!1),buttonType:Object(kn["c"])(pt["u"],"button"),icon:Object(kn["c"])(pt["u"]),rounded:Object(kn["c"])(pt["j"],!1),size:Object(kn["c"])(pt["p"]),square:Object(kn["c"])(pt["g"],!1),src:Object(kn["c"])(pt["u"]),text:Object(kn["c"])(pt["u"]),variant:Object(kn["c"])(pt["u"],"secondary")})),a["c"]),Di=i["default"].extend({name:a["c"],mixins:[Cn],inject:{bvAvatarGroup:{default:null}},props:Fi,data:function(){return{localSrc:this.src||null}},computed:{computedSize:function(){var t=this.bvAvatarGroup;return Bi(t?t.size:this.size)},computedVariant:function(){var t=this.bvAvatarGroup;return t&&t.variant?t.variant:this.variant},computedRounded:function(){var t=this.bvAvatarGroup,e=!(!t||!t.square)||this.square,n=t&&t.rounded?t.rounded:this.rounded;return e?"0":""===n||(n||"circle")},fontStyle:function(){var t=this.computedSize,e=-1===Ii.indexOf(t)?"calc(".concat(t," * ").concat(Ei,")"):null;return e?{fontSize:e}:{}},marginStyle:function(){var t=this.computedSize,e=this.bvAvatarGroup,n=e?e.overlapScale:0,r=t&&n?"calc(".concat(t," * -").concat(n,")"):null;return r?{marginLeft:r,marginRight:r}:{}},badgeStyle:function(){var t=this.computedSize,e=this.badgeTop,n=this.badgeLeft,r=this.badgeOffset,i=r||"0px";return{fontSize:-1===Ii.indexOf(t)?"calc(".concat(t," * ").concat(Li," )"):null,top:e?i:null,bottom:e?null:i,left:n?i:null,right:n?null:i}}},watch:{src:function(t,e){t!==e&&(this.localSrc=t||null)}},methods:{onImgError:function(t){this.localSrc=null,this.$emit(S,t)},onClick:function(t){this.$emit(h,t)}},render:function(t){var e,n=this.computedVariant,r=this.disabled,i=this.computedRounded,o=this.icon,a=this.localSrc,s=this.text,c=this.fontStyle,l=this.marginStyle,u=this.computedSize,d=this.button,h=this.buttonType,f=this.badge,p=this.badgeVariant,m=this.badgeStyle,b=!d&&jr(this),g=d?Vi:b?mi:"span",v=this.alt,w=this.ariaLabel||null,y=null;this.hasNormalizedSlot()?y=t("span",{staticClass:"b-avatar-custom"},[this.normalizeSlot()]):a?(y=t("img",{style:n?{}:{width:"100%",height:"100%"},attrs:{src:a,alt:v},on:{error:this.onImgError}}),y=t("span",{staticClass:"b-avatar-img"},[y])):y=o?t(xr["a"],{props:{icon:o},attrs:{"aria-hidden":"true",alt:v}}):s?t("span",{staticClass:"b-avatar-text",style:c},[t("span",s)]):t(Tr["vr"],{attrs:{"aria-hidden":"true",alt:v}});var k=t(),_=this.hasNormalizedSlot(vt);if(f||""===f||_){var O=!0===f?"":f;k=t("span",{staticClass:"b-avatar-badge",class:Ti({},"badge-".concat(p),p),style:m},[_?this.normalizeSlot(vt):O])}var z={staticClass:Pi,class:(e={},Ti(e,"".concat(Pi,"-").concat(u),u&&-1!==Ii.indexOf(u)),Ti(e,"badge-".concat(n),!d&&n),Ti(e,"rounded",!0===i),Ti(e,"rounded-".concat(i),i&&!0!==i),Ti(e,"disabled",r),e),style:xi(xi({},l),{},{width:u,height:u}),attrs:{"aria-label":w||null},props:d?{variant:n,disabled:r,type:h}:b?Object(kn["e"])(Hi,this):{},on:d||b?{click:this.onClick}:{}};return t(g,z,[y,k])}}),Ri=Object(kn["d"])({overlap:Object(kn["c"])(pt["p"],.3),rounded:Object(kn["c"])(pt["j"],!1),size:Object(kn["c"])(pt["u"]),square:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div"),variant:Object(kn["c"])(pt["u"])},a["d"]),Ni=i["default"].extend({name:a["d"],mixins:[Cn],provide:function(){return{bvAvatarGroup:this}},props:Ri,computed:{computedSize:function(){return Bi(this.size)},overlapScale:function(){return Object(lr["e"])(Object(lr["d"])(Object(Ie["b"])(this.overlap,0),0),1)/2},paddingStyle:function(){var t=this.computedSize;return t=t?"calc(".concat(t," * ").concat(this.overlapScale,")"):null,t?{paddingLeft:t,paddingRight:t}:{}}},render:function(t){var e=t("div",{staticClass:"b-avatar-group-inner",style:this.paddingStyle},this.normalizeSlot());return t(this.tag,{staticClass:"b-avatar-group",attrs:{role:"group"}},[e])}}),$i=Object(r["b"])({components:{BAvatar:Di,BAvatarGroup:Ni}});function Ui(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function qi(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ui(Object(n),!0).forEach((function(e){Wi(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ui(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Wi(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Gi=Object(zn["j"])(pi,["event","routerTag"]);delete Gi.href.default,delete Gi.to.default;var Yi=Object(kn["d"])(Object(zn["m"])(qi(qi({},Gi),{},{pill:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"span"),variant:Object(kn["c"])(pt["u"],"secondary")})),a["e"]),Ki=i["default"].extend({name:a["e"],functional:!0,props:Yi,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.active,a=n.disabled,s=jr(n),c=s?mi:n.tag,l=n.variant||"secondary";return t(c,Object(Vn["a"])(r,{staticClass:"badge",class:["badge-".concat(l),{"badge-pill":n.pill,active:o,disabled:a}],props:s?Object(kn["e"])(Gi,n):{}}),i)}}),Qi=Object(r["b"])({components:{BBadge:Ki}}),Xi=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"";return String(t).replace(Sn["o"],"")},Ji=function(t,e){return t?{innerHTML:t}:e?{textContent:e}:{}};function Zi(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function to(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Zi(Object(n),!0).forEach((function(e){eo(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Zi(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function eo(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var no=Object(kn["d"])(Object(zn["m"])(to(to({},Object(zn["j"])(pi,["event","routerTag"])),{},{ariaCurrent:Object(kn["c"])(pt["u"],"location"),html:Object(kn["c"])(pt["u"]),text:Object(kn["c"])(pt["u"])})),a["h"]),ro=i["default"].extend({name:a["h"],functional:!0,props:no,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.active,a=o?"span":mi,s={attrs:{"aria-current":o?n.ariaCurrent:null},props:Object(kn["e"])(no,n)};return i||(s.domProps=Ji(n.html,n.text)),t(a,Object(Vn["a"])(r,s),i)}}),io=Object(kn["d"])(no,a["g"]),oo=i["default"].extend({name:a["g"],functional:!0,props:io,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t("li",Object(Vn["a"])(r,{staticClass:"breadcrumb-item",class:{active:n.active}}),[t(ro,{props:n},i)])}});function ao(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function so(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?ao(Object(n),!0).forEach((function(e){co(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):ao(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function co(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var lo=Object(kn["d"])({items:Object(kn["c"])(pt["b"])},a["f"]),uo=i["default"].extend({name:a["f"],functional:!0,props:lo,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.items,a=i;if(Object(Me["a"])(o)){var s=!1;a=o.map((function(e,n){Object(Me["j"])(e)||(e={text:Object(Ee["g"])(e)});var r=e,i=r.active;return i&&(s=!0),i||s||(i=n+1===o.length),t(oo,{props:so(so({},e),{},{active:i})})}))}return t("ol",Object(Vn["a"])(r,{staticClass:"breadcrumb"}),a)}}),ho=Object(r["b"])({components:{BBreadcrumb:uo,BBreadcrumbItem:oo,BBreadcrumbLink:ro}}),fo=Object(r["b"])({components:{BButton:Vi,BBtn:Vi,BButtonClose:Rn,BBtnClose:Rn}});function po(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function mo(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?po(Object(n),!0).forEach((function(e){bo(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):po(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function bo(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var go=Object(kn["d"])(Object(zn["m"])(mo(mo({},Object(zn["k"])(yi,["size"])),{},{ariaRole:Object(kn["c"])(pt["u"],"group"),size:Object(kn["c"])(pt["u"]),tag:Object(kn["c"])(pt["u"],"div"),vertical:Object(kn["c"])(pt["g"],!1)})),a["k"]),vo=i["default"].extend({name:a["k"],functional:!0,props:go,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.tag,Object(Vn["a"])(r,{class:bo({"btn-group":!n.vertical,"btn-group-vertical":n.vertical},"btn-group-".concat(n.size),n.size),attrs:{role:n.ariaRole}}),i)}}),wo=Object(r["b"])({components:{BButtonGroup:vo,BBtnGroup:vo}}),yo=[".btn:not(.disabled):not([disabled]):not(.dropdown-item)",".form-control:not(.disabled):not([disabled])","select:not(.disabled):not([disabled])",'input[type="checkbox"]:not(.disabled)','input[type="radio"]:not(.disabled)'].join(","),ko=Object(kn["d"])({justify:Object(kn["c"])(pt["g"],!1),keyNav:Object(kn["c"])(pt["g"],!1)},a["l"]),_o=i["default"].extend({name:a["l"],mixins:[Cn],props:ko,mounted:function(){this.keyNav&&this.getItems()},methods:{getItems:function(){var t=Qe(yo,this.$el);return t.forEach((function(t){t.tabIndex=-1})),t.filter((function(t){return Ge(t)}))},focusFirst:function(){var t=this.getItems();wn(t[0])},focusPrev:function(t){var e=this.getItems(),n=e.indexOf(t.target);n>-1&&(e=e.slice(0,n).reverse(),wn(e[0]))},focusNext:function(t){var e=this.getItems(),n=e.indexOf(t.target);n>-1&&(e=e.slice(n+1),wn(e[0]))},focusLast:function(){var t=this.getItems().reverse();wn(t[0])},onFocusin:function(t){var e=this.$el;t.target!==e||tn(e,t.relatedTarget)||(En(t),this.focusFirst(t))},onKeydown:function(t){var e=t.keyCode,n=t.shiftKey;e===qr||e===Dr?(En(t),n?this.focusFirst(t):this.focusPrev(t)):e!==Er&&e!==$r||(En(t),n?this.focusLast(t):this.focusNext(t))}},render:function(t){var e=this.keyNav;return t("div",{staticClass:"btn-toolbar",class:{"justify-content-between":this.justify},attrs:{role:"toolbar",tabindex:e?"0":null},on:e?{focusin:this.onFocusin,keydown:this.onKeydown}:{}},[this.normalizeSlot()])}}),Oo=Object(r["b"])({components:{BButtonToolbar:_o,BBtnToolbar:_o}}),zo="gregory",Ao="long",jo="narrow",Mo="short",Co="2-digit",Vo="numeric";function So(t,e){return Eo(t)||Io(t,e)||To(t,e)||xo()}function xo(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function To(t,e){if(t){if("string"===typeof t)return Po(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Po(t,e):void 0}}function Po(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function Io(t,e){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t)){var n=[],r=!0,i=!1,o=void 0;try{for(var a,s=t[Symbol.iterator]();!(r=(a=s.next()).done);r=!0)if(n.push(a.value),e&&n.length===e)break}catch(c){i=!0,o=c}finally{try{r||null==s["return"]||s["return"]()}finally{if(i)throw o}}return n}}function Eo(t){if(Array.isArray(t))return t}function Lo(t,e,n){return Lo=Bo()?Reflect.construct:function(t,e,n){var r=[null];r.push.apply(r,e);var i=Function.bind.apply(t,r),o=new i;return n&&Ho(o,n.prototype),o},Lo.apply(null,arguments)}function Bo(){if("undefined"===typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],(function(){}))),!0}catch(t){return!1}}function Ho(t,e){return Ho=Object.setPrototypeOf||function(t,e){return t.__proto__=e,t},Ho(t,e)}var Fo,Do=function(){for(var t=arguments.length,e=new Array(t),n=0;n<t;n++)e[n]=arguments[n];return Lo(Date,e)},Ro=function(t){if(Object(Me["n"])(t)&&Sn["f"].test(t.trim())){var e=t.split(Sn["g"]).map((function(t){return Object(Ie["c"])(t,1)})),n=So(e,3),r=n[0],i=n[1],o=n[2];return Do(r,i-1,o)}return Object(Me["c"])(t)?Do(t.getFullYear(),t.getMonth(),t.getDate()):null},No=function(t){if(t=Ro(t),!t)return null;var e=t.getFullYear(),n="0".concat(t.getMonth()+1).slice(-2),r="0".concat(t.getDate()).slice(-2);return"".concat(e,"-").concat(n,"-").concat(r)},$o=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:zo;t=Se(t).filter(An["a"]);var n=new Intl.DateTimeFormat(t,{calendar:e});return n.resolvedOptions().locale},Uo=function(t,e){var n=new Intl.DateTimeFormat(t,e);return n.format},qo=function(t,e){return No(t)===No(e)},Wo=function(t){return t=Do(t),t.setDate(1),t},Go=function(t){return t=Do(t),t.setMonth(t.getMonth()+1),t.setDate(0),t},Yo=function(t,e){t=Do(t);var n=t.getMonth();return t.setFullYear(t.getFullYear()+e),t.getMonth()!==n&&t.setDate(0),t},Ko=function(t){t=Do(t);var e=t.getMonth();return t.setMonth(e-1),t.getMonth()===e&&t.setDate(0),t},Qo=function(t){t=Do(t);var e=t.getMonth();return t.setMonth(e+1),t.getMonth()===(e+2)%12&&t.setDate(0),t},Xo=function(t){return Yo(t,-1)},Jo=function(t){return Yo(t,1)},Zo=function(t){return Yo(t,-10)},ta=function(t){return Yo(t,10)},ea=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null;return t=Ro(t),e=Ro(e)||t,n=Ro(n)||t,t?t<e?e:t>n?n:t:null},na=["ar","az","ckb","fa","he","ks","lrc","mzn","ps","sd","te","ug","ur","yi"].map((function(t){return t.toLowerCase()})),ra=function(t){var e=Object(Ee["g"])(t).toLowerCase().replace(Sn["A"],"").split("-"),n=e.slice(0,2).join("-"),r=e[0];return Ve(na,n)||Ve(na,r)},ia={id:Object(kn["c"])(pt["u"])},oa=i["default"].extend({props:ia,data:function(){return{localId_:null}},computed:{safeId:function(){var t=this.id||this.localId_,e=function(e){return t?(e=String(e||"").replace(/\s+/g,"_"),e?t+"_"+e:t):null};return e}},mounted:function(){var t=this;this.$nextTick((function(){t.localId_="__BVID__".concat(t[o["a"]])}))}});function aa(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function sa(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?aa(Object(n),!0).forEach((function(e){ca(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):aa(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function ca(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var la=On("value",{type:pt["k"]}),ua=la.mixin,da=la.props,ha=la.prop,fa=la.event,pa=Object(kn["d"])(Object(zn["m"])(sa(sa(sa({},ia),da),{},{ariaControls:Object(kn["c"])(pt["u"]),block:Object(kn["c"])(pt["g"],!1),dateDisabledFn:Object(kn["c"])(pt["l"]),dateFormatOptions:Object(kn["c"])(pt["q"],{year:Vo,month:Ao,day:Vo,weekday:Ao}),dateInfoFn:Object(kn["c"])(pt["l"]),direction:Object(kn["c"])(pt["u"]),disabled:Object(kn["c"])(pt["g"],!1),hidden:Object(kn["c"])(pt["g"],!1),hideHeader:Object(kn["c"])(pt["g"],!1),initialDate:Object(kn["c"])(pt["k"]),labelCalendar:Object(kn["c"])(pt["u"],"Calendar"),labelCurrentMonth:Object(kn["c"])(pt["u"],"Current month"),labelHelp:Object(kn["c"])(pt["u"],"Use cursor keys to navigate calendar dates"),labelNav:Object(kn["c"])(pt["u"],"Calendar navigation"),labelNextDecade:Object(kn["c"])(pt["u"],"Next decade"),labelNextMonth:Object(kn["c"])(pt["u"],"Next month"),labelNextYear:Object(kn["c"])(pt["u"],"Next year"),labelNoDateSelected:Object(kn["c"])(pt["u"],"No date selected"),labelPrevDecade:Object(kn["c"])(pt["u"],"Previous decade"),labelPrevMonth:Object(kn["c"])(pt["u"],"Previous month"),labelPrevYear:Object(kn["c"])(pt["u"],"Previous year"),labelSelected:Object(kn["c"])(pt["u"],"Selected date"),labelToday:Object(kn["c"])(pt["u"],"Today"),locale:Object(kn["c"])(pt["f"]),max:Object(kn["c"])(pt["k"]),min:Object(kn["c"])(pt["k"]),navButtonVariant:Object(kn["c"])(pt["u"],"secondary"),noHighlightToday:Object(kn["c"])(pt["g"],!1),noKeyNav:Object(kn["c"])(pt["g"],!1),readonly:Object(kn["c"])(pt["g"],!1),roleDescription:Object(kn["c"])(pt["u"]),selectedVariant:Object(kn["c"])(pt["u"],"primary"),showDecadeNav:Object(kn["c"])(pt["g"],!1),startWeekday:Object(kn["c"])(pt["p"],0),todayVariant:Object(kn["c"])(pt["u"]),valueAsDate:Object(kn["c"])(pt["g"],!1),weekdayHeaderFormat:Object(kn["c"])(pt["u"],Mo,(function(t){return Ve([Ao,Mo,jo],t)})),width:Object(kn["c"])(pt["u"],"270px")})),a["m"]),ma=i["default"].extend({name:a["m"],mixins:[Zr,oa,ua,Cn],props:pa,data:function(){var t=No(this[ha])||"";return{selectedYMD:t,activeYMD:t||No(ea(this.initialDate||this.getToday()),this.min,this.max),gridHasFocus:!1,isLive:!1}},computed:{valueId:function(){return this.safeId()},widgetId:function(){return this.safeId("_calendar-wrapper_")},navId:function(){return this.safeId("_calendar-nav_")},gridId:function(){return this.safeId("_calendar-grid_")},gridCaptionId:function(){return this.safeId("_calendar-grid-caption_")},gridHelpId:function(){return this.safeId("_calendar-grid-help_")},activeId:function(){return this.activeYMD?this.safeId("_cell-".concat(this.activeYMD,"_")):null},selectedDate:function(){return Ro(this.selectedYMD)},activeDate:function(){return Ro(this.activeYMD)},computedMin:function(){return Ro(this.min)},computedMax:function(){return Ro(this.max)},computedWeekStarts:function(){return Object(lr["d"])(Object(Ie["c"])(this.startWeekday,0),0)%7},computedLocale:function(){return $o(Se(this.locale).filter(An["a"]),zo)},computedDateDisabledFn:function(){var t=this.dateDisabledFn;return Object(kn["b"])(t)?t:function(){return!1}},computedDateInfoFn:function(){var t=this.dateInfoFn;return Object(kn["b"])(t)?t:function(){return{}}},calendarLocale:function(){var t=new Intl.DateTimeFormat(this.computedLocale,{calendar:zo}),e=t.resolvedOptions().calendar,n=t.resolvedOptions().locale;return e!==zo&&(n=n.replace(/-u-.+$/i,"").concat("-u-ca-gregory")),n},calendarYear:function(){return this.activeDate.getFullYear()},calendarMonth:function(){return this.activeDate.getMonth()},calendarFirstDay:function(){return Do(this.calendarYear,this.calendarMonth,1,12)},calendarDaysInMonth:function(){var t=Do(this.calendarFirstDay);return t.setMonth(t.getMonth()+1,0),t.getDate()},computedVariant:function(){return"btn-".concat(this.selectedVariant||"primary")},computedTodayVariant:function(){return"btn-outline-".concat(this.todayVariant||this.selectedVariant||"primary")},computedNavButtonVariant:function(){return"btn-outline-".concat(this.navButtonVariant||"primary")},isRTL:function(){var t=Object(Ee["g"])(this.direction).toLowerCase();return"rtl"===t||"ltr"!==t&&ra(this.computedLocale)},context:function(){var t=this.selectedYMD,e=this.activeYMD,n=Ro(t),r=Ro(e);return{selectedYMD:t,selectedDate:n,selectedFormatted:n?this.formatDateString(n):this.labelNoDateSelected,activeYMD:e,activeDate:r,activeFormatted:r?this.formatDateString(r):"",disabled:this.dateDisabled(r),locale:this.computedLocale,calendarLocale:this.calendarLocale,rtl:this.isRTL}},dateOutOfRange:function(){var t=this.computedMin,e=this.computedMax;return function(n){return n=Ro(n),t&&n<t||e&&n>e}},dateDisabled:function(){var t=this,e=this.dateOutOfRange;return function(n){n=Ro(n);var r=No(n);return!(!e(n)&&!t.computedDateDisabledFn(r,n))}},formatDateString:function(){return Uo(this.calendarLocale,sa(sa({year:Vo,month:Co,day:Co},this.dateFormatOptions),{},{hour:void 0,minute:void 0,second:void 0,calendar:zo}))},formatYearMonth:function(){return Uo(this.calendarLocale,{year:Vo,month:Ao,calendar:zo})},formatWeekdayName:function(){return Uo(this.calendarLocale,{weekday:Ao,calendar:zo})},formatWeekdayNameShort:function(){return Uo(this.calendarLocale,{weekday:this.weekdayHeaderFormat||Mo,calendar:zo})},formatDay:function(){var t=new Intl.NumberFormat([this.computedLocale],{style:"decimal",minimumIntegerDigits:1,minimumFractionDigits:0,maximumFractionDigits:0,notation:"standard"});return function(e){return t.format(e.getDate())}},prevDecadeDisabled:function(){var t=this.computedMin;return this.disabled||t&&Go(Zo(this.activeDate))<t},prevYearDisabled:function(){var t=this.computedMin;return this.disabled||t&&Go(Xo(this.activeDate))<t},prevMonthDisabled:function(){var t=this.computedMin;return this.disabled||t&&Go(Ko(this.activeDate))<t},thisMonthDisabled:function(){return this.disabled},nextMonthDisabled:function(){var t=this.computedMax;return this.disabled||t&&Wo(Qo(this.activeDate))>t},nextYearDisabled:function(){var t=this.computedMax;return this.disabled||t&&Wo(Jo(this.activeDate))>t},nextDecadeDisabled:function(){var t=this.computedMax;return this.disabled||t&&Wo(ta(this.activeDate))>t},calendar:function(){for(var t=[],e=this.calendarFirstDay,n=e.getFullYear(),r=e.getMonth(),i=this.calendarDaysInMonth,o=e.getDay(),a=(this.computedWeekStarts>o?7:0)-this.computedWeekStarts,s=0-a-o,c=0;c<6&&s<i;c++){t[c]=[];for(var l=0;l<7;l++){s++;var u=Do(n,r,s),d=u.getMonth(),h=No(u),f=this.dateDisabled(u),p=this.computedDateInfoFn(h,Ro(h));p=Object(Me["n"])(p)||Object(Me["a"])(p)?{class:p}:Object(Me["k"])(p)?sa({class:""},p):{class:""},t[c].push({ymd:h,day:this.formatDay(u),label:this.formatDateString(u),isThisMonth:d===r,isDisabled:f,info:p})}}return t},calendarHeadings:function(){var t=this;return this.calendar[0].map((function(e){return{text:t.formatWeekdayNameShort(Ro(e.ymd)),label:t.formatWeekdayName(Ro(e.ymd))}}))}},watch:(Fo={},ca(Fo,ha,(function(t,e){var n=No(t)||"",r=No(e)||"";qo(n,r)||(this.activeYMD=n||this.activeYMD,this.selectedYMD=n)})),ca(Fo,"selectedYMD",(function(t,e){t!==e&&this.$emit(fa,this.valueAsDate?Ro(t)||null:t||"")})),ca(Fo,"context",(function(t,e){Yr(t,e)||this.$emit(p,t)})),ca(Fo,"hidden",(function(t){this.activeYMD=this.selectedYMD||No(this[ha]||this.constrainDate(this.initialDate||this.getToday())),this.setLive(!t)})),Fo),created:function(){var t=this;this.$nextTick((function(){t.$emit(p,t.context)}))},mounted:function(){this.setLive(!0)},activated:function(){this.setLive(!0)},deactivated:function(){this.setLive(!1)},beforeDestroy:function(){this.setLive(!1)},methods:{focus:function(){this.disabled||wn(this.$refs.grid)},blur:function(){this.disabled||yn(this.$refs.grid)},setLive:function(t){var e=this;t?this.$nextTick((function(){De((function(){e.isLive=!0}))})):this.isLive=!1},getToday:function(){return Ro(Do())},constrainDate:function(t){return ea(t,this.computedMin,this.computedMax)},emitSelected:function(t){var e=this;this.$nextTick((function(){e.$emit(X,No(t)||"",Ro(t)||null)}))},setGridFocusFlag:function(t){this.gridHasFocus=!this.disabled&&"focus"===t.type},onKeydownWrapper:function(t){if(!this.noKeyNav){var e=t.altKey,n=t.ctrlKey,r=t.keyCode;if(Ve([Nr,Rr,Lr,Fr,Dr,qr,$r,Er],r)){En(t);var i=Do(this.activeDate),o=Do(this.activeDate),a=i.getDate(),s=this.constrainDate(this.getToday()),c=this.isRTL;r===Nr?(i=(e?n?Zo:Xo:Ko)(i),o=Do(i),o.setDate(1)):r===Rr?(i=(e?n?ta:Jo:Qo)(i),o=Do(i),o.setMonth(o.getMonth()+1),o.setDate(0)):r===Dr?(i.setDate(a+(c?1:-1)),i=this.constrainDate(i),o=i):r===$r?(i.setDate(a+(c?-1:1)),i=this.constrainDate(i),o=i):r===qr?(i.setDate(a-7),i=this.constrainDate(i),o=i):r===Er?(i.setDate(a+7),i=this.constrainDate(i),o=i):r===Fr?(i=s,o=i):r===Lr&&(i=Ro(this.selectedDate)||s,o=i),this.dateOutOfRange(o)||qo(i,this.activeDate)||(this.activeYMD=No(i)),this.focus()}}},onKeydownGrid:function(t){var e=t.keyCode,n=this.activeDate;e!==Br&&e!==Ur||(En(t),this.disabled||this.readonly||this.dateDisabled(n)||(this.selectedYMD=No(n),this.emitSelected(n)),this.focus())},onClickDay:function(t){var e=this.selectedDate,n=this.activeDate,r=Ro(t.ymd);this.disabled||t.isDisabled||this.dateDisabled(r)||(this.readonly||(this.selectedYMD=No(qo(r,e)?e:r),this.emitSelected(r)),this.activeYMD=No(qo(r,n)?n:Do(r)),this.focus())},gotoPrevDecade:function(){this.activeYMD=No(this.constrainDate(Zo(this.activeDate)))},gotoPrevYear:function(){this.activeYMD=No(this.constrainDate(Xo(this.activeDate)))},gotoPrevMonth:function(){this.activeYMD=No(this.constrainDate(Ko(this.activeDate)))},gotoCurrentMonth:function(){this.activeYMD=No(this.constrainDate(this.getToday()))},gotoNextMonth:function(){this.activeYMD=No(this.constrainDate(Qo(this.activeDate)))},gotoNextYear:function(){this.activeYMD=No(this.constrainDate(Jo(this.activeDate)))},gotoNextDecade:function(){this.activeYMD=No(this.constrainDate(ta(this.activeDate)))},onHeaderClick:function(){this.disabled||(this.activeYMD=this.selectedYMD||No(this.getToday()),this.focus())}},render:function(t){var e=this;if(this.hidden)return t();var n=this.valueId,r=this.widgetId,i=this.navId,o=this.gridId,a=this.gridCaptionId,s=this.gridHelpId,c=this.activeId,l=this.disabled,u=this.noKeyNav,d=this.isLive,h=this.isRTL,f=this.activeYMD,p=this.selectedYMD,m=this.safeId,b=!this.showDecadeNav,g=No(this.getToday()),v=!this.noHighlightToday,w=t("output",{staticClass:"form-control form-control-sm text-center",class:{"text-muted":l,readonly:this.readonly||l},attrs:{id:n,for:o,role:"status",tabindex:l?null:"-1","data-selected":Object(Ee["g"])(p),"aria-live":d?"polite":"off","aria-atomic":d?"true":null},on:{click:this.onHeaderClick,focus:this.onHeaderClick}},this.selectedDate?[t("bdi",{staticClass:"sr-only"}," (".concat(Object(Ee["g"])(this.labelSelected),") ")),t("bdi",this.formatDateString(this.selectedDate))]:this.labelNoDateSelected||" ");w=t("header",{staticClass:"b-calendar-header",class:{"sr-only":this.hideHeader},attrs:{title:this.selectedDate&&this.labelSelectedDate||null}},[w]);var y={isRTL:h},k={shiftV:.5},_=sa(sa({},k),{},{flipH:h}),O=sa(sa({},k),{},{flipH:!h}),z=this.normalizeSlot(re,y)||t(Tr["Sg"],{props:_}),A=this.normalizeSlot(oe,y)||t(Tr["bh"],{props:_}),j=this.normalizeSlot(ie,y)||t(Tr["gh"],{props:_}),M=this.normalizeSlot(ae,y)||t(Tr["kh"],{props:k}),C=this.normalizeSlot(ee,y)||t(Tr["gh"],{props:O}),V=this.normalizeSlot(ne,y)||t(Tr["bh"],{props:O}),S=this.normalizeSlot(te,y)||t(Tr["Sg"],{props:O}),x=function(n,r,i,o,a){return t("button",{staticClass:"btn btn-sm border-0 flex-fill",class:[e.computedNavButtonVariant,{disabled:o}],attrs:{title:r||null,type:"button",tabindex:u?"-1":null,"aria-label":r||null,"aria-disabled":o?"true":null,"aria-keyshortcuts":a||null},on:o?{}:{click:i}},[t("div",{attrs:{"aria-hidden":"true"}},[n])])},T=t("div",{staticClass:"b-calendar-nav d-flex",attrs:{id:i,role:"group",tabindex:u?"-1":null,"aria-hidden":l?"true":null,"aria-label":this.labelNav||null,"aria-controls":o}},[b?t():x(z,this.labelPrevDecade,this.gotoPrevDecade,this.prevDecadeDisabled,"Ctrl+Alt+PageDown"),x(A,this.labelPrevYear,this.gotoPrevYear,this.prevYearDisabled,"Alt+PageDown"),x(j,this.labelPrevMonth,this.gotoPrevMonth,this.prevMonthDisabled,"PageDown"),x(M,this.labelCurrentMonth,this.gotoCurrentMonth,this.thisMonthDisabled,"Home"),x(C,this.labelNextMonth,this.gotoNextMonth,this.nextMonthDisabled,"PageUp"),x(V,this.labelNextYear,this.gotoNextYear,this.nextYearDisabled,"Alt+PageUp"),b?t():x(S,this.labelNextDecade,this.gotoNextDecade,this.nextDecadeDisabled,"Ctrl+Alt+PageUp")]),P=t("header",{staticClass:"b-calendar-grid-caption text-center font-weight-bold",class:{"text-muted":l},attrs:{id:a,"aria-live":d?"polite":null,"aria-atomic":d?"true":null},key:"grid-caption"},this.formatYearMonth(this.calendarFirstDay)),I=t("div",{staticClass:"b-calendar-grid-weekdays row no-gutters border-bottom",attrs:{"aria-hidden":"true"}},this.calendarHeadings.map((function(e,n){return t("small",{staticClass:"col text-truncate",class:{"text-muted":l},attrs:{title:e.label===e.text?null:e.label,"aria-label":e.label},key:n},e.text)}))),E=this.calendar.map((function(n){var r=n.map((function(n,r){var i,o=n.ymd===p,a=n.ymd===f,s=n.ymd===g,c=m("_cell-".concat(n.ymd,"_")),u=t("span",{staticClass:"btn border-0 rounded-circle text-nowrap",class:(i={focus:a&&e.gridHasFocus,disabled:n.isDisabled||l,active:o},ca(i,e.computedVariant,o),ca(i,e.computedTodayVariant,s&&v&&!o&&n.isThisMonth),ca(i,"btn-outline-light",!(s&&v)&&!o&&!a),ca(i,"btn-light",!(s&&v)&&!o&&a),ca(i,"text-muted",!n.isThisMonth&&!o),ca(i,"text-dark",!(s&&v)&&!o&&!a&&n.isThisMonth),ca(i,"font-weight-bold",(o||n.isThisMonth)&&!n.isDisabled),i),on:{click:function(){return e.onClickDay(n)}}},n.day);return t("div",{staticClass:"col p-0",class:n.isDisabled?"bg-light":n.info.class||"",attrs:{id:c,role:"button","data-date":n.ymd,"aria-hidden":n.isThisMonth?null:"true","aria-disabled":n.isDisabled||l?"true":null,"aria-label":[n.label,o?"(".concat(e.labelSelected,")"):null,s?"(".concat(e.labelToday,")"):null].filter(An["a"]).join(" "),"aria-selected":o?"true":null,"aria-current":o?"date":null},key:r},[u])}));return t("div",{staticClass:"row no-gutters",key:n[0].ymd},r)}));E=t("div",{staticClass:"b-calendar-grid-body",style:l?{pointerEvents:"none"}:{}},E);var L=t("footer",{staticClass:"b-calendar-grid-help border-top small text-muted text-center bg-light",attrs:{id:s}},[t("div",{staticClass:"small"},this.labelHelp)]),B=t("div",{staticClass:"b-calendar-grid form-control h-auto text-center",attrs:{id:o,role:"application",tabindex:u?"-1":l?null:"0","data-month":f.slice(0,-3),"aria-roledescription":this.labelCalendar||null,"aria-labelledby":a,"aria-describedby":s,"aria-disabled":l?"true":null,"aria-activedescendant":c},on:{keydown:this.onKeydownGrid,focus:this.setGridFocusFlag,blur:this.setGridFocusFlag},ref:"grid"},[P,I,E,L]),H=this.normalizeSlot();H=H?t("footer",{staticClass:"b-calendar-footer"},H):t();var F=t("div",{staticClass:"b-calendar-inner",style:this.block?{}:{width:this.width},attrs:{id:r,dir:h?"rtl":"ltr",lang:this.computedLocale||null,role:"group","aria-disabled":l?"true":null,"aria-controls":this.ariaControls||null,"aria-roledescription":this.roleDescription||null,"aria-describedby":[this.bvAttrs["aria-describedby"],n,s].filter(An["a"]).join(" ")},on:{keydown:this.onKeydownWrapper}},[w,T,B,H]);return t("div",{staticClass:"b-calendar",class:{"d-block":this.block}},[F])}}),ba=Object(r["b"])({components:{BCalendar:ma}}),ga=Object(kn["d"])({bgVariant:Object(kn["c"])(pt["u"]),borderVariant:Object(kn["c"])(pt["u"]),tag:Object(kn["c"])(pt["u"],"div"),textVariant:Object(kn["c"])(pt["u"])},a["n"]),va=(i["default"].extend({props:ga}),Object(kn["d"])({title:Object(kn["c"])(pt["u"]),titleTag:Object(kn["c"])(pt["u"],"h4")},a["w"])),wa=i["default"].extend({name:a["w"],functional:!0,props:va,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.titleTag,Object(Vn["a"])(r,{staticClass:"card-title"}),i||Object(Ee["g"])(n.title))}}),ya=Object(kn["d"])({subTitle:Object(kn["c"])(pt["u"]),subTitleTag:Object(kn["c"])(pt["u"],"h6"),subTitleTextVariant:Object(kn["c"])(pt["u"],"muted")},a["u"]),ka=i["default"].extend({name:a["u"],functional:!0,props:ya,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.subTitleTag,Object(Vn["a"])(r,{staticClass:"card-subtitle",class:[n.subTitleTextVariant?"text-".concat(n.subTitleTextVariant):null]}),i||Object(Ee["g"])(n.subTitle))}});function _a(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Oa(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?_a(Object(n),!0).forEach((function(e){za(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):_a(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function za(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Aa=Object(kn["d"])(Object(zn["m"])(Oa(Oa(Oa(Oa({},va),ya),Object(kn["a"])(ga,kn["f"].bind(null,"body"))),{},{bodyClass:Object(kn["c"])(pt["e"]),overlay:Object(kn["c"])(pt["g"],!1)})),a["o"]),ja=i["default"].extend({name:a["o"],functional:!0,props:Aa,render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.bodyBgVariant,s=r.bodyBorderVariant,c=r.bodyTextVariant,l=t();r.title&&(l=t(wa,{props:Object(kn["e"])(va,r)}));var u=t();return r.subTitle&&(u=t(ka,{props:Object(kn["e"])(ya,r),class:["mb-2"]})),t(r.bodyTag,Object(Vn["a"])(i,{staticClass:"card-body",class:[(n={"card-img-overlay":r.overlay},za(n,"bg-".concat(a),a),za(n,"border-".concat(s),s),za(n,"text-".concat(c),c),n),r.bodyClass]}),[l,u,o])}});function Ma(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ca(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ma(Object(n),!0).forEach((function(e){Va(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ma(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Va(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Sa=Object(kn["d"])(Object(zn["m"])(Ca(Ca({},Object(kn["a"])(ga,kn["f"].bind(null,"header"))),{},{header:Object(kn["c"])(pt["u"]),headerClass:Object(kn["c"])(pt["e"]),headerHtml:Object(kn["c"])(pt["u"])})),a["r"]),xa=i["default"].extend({name:a["r"],functional:!0,props:Sa,render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.headerBgVariant,s=r.headerBorderVariant,c=r.headerTextVariant;return t(r.headerTag,Object(Vn["a"])(i,{staticClass:"card-header",class:[r.headerClass,(n={},Va(n,"bg-".concat(a),a),Va(n,"border-".concat(s),s),Va(n,"text-".concat(c),c),n)],domProps:o?{}:Ji(r.headerHtml,r.header)}),o)}});function Ta(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Pa(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ta(Object(n),!0).forEach((function(e){Ia(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ta(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Ia(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Ea=Object(kn["d"])(Object(zn["m"])(Pa(Pa({},Object(kn["a"])(ga,kn["f"].bind(null,"footer"))),{},{footer:Object(kn["c"])(pt["u"]),footerClass:Object(kn["c"])(pt["e"]),footerHtml:Object(kn["c"])(pt["u"])})),a["p"]),La=i["default"].extend({name:a["p"],functional:!0,props:Ea,render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.footerBgVariant,s=r.footerBorderVariant,c=r.footerTextVariant;return t(r.footerTag,Object(Vn["a"])(i,{staticClass:"card-footer",class:[r.footerClass,(n={},Ia(n,"bg-".concat(a),a),Ia(n,"border-".concat(s),s),Ia(n,"text-".concat(c),c),n)],domProps:o?{}:Ji(r.footerHtml,r.footer)}),o)}});function Ba(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Ha='<svg width="%{w}" height="%{h}" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 %{w} %{h}" preserveAspectRatio="none"><rect width="100%" height="100%" style="fill:%{f};"></rect></svg>',Fa=function(t,e,n){var r=encodeURIComponent(Ha.replace("%{w}",Object(Ee["g"])(t)).replace("%{h}",Object(Ee["g"])(e)).replace("%{f}",n));return"data:image/svg+xml;charset=UTF-8,".concat(r)},Da=Object(kn["d"])({alt:Object(kn["c"])(pt["u"]),blank:Object(kn["c"])(pt["g"],!1),blankColor:Object(kn["c"])(pt["u"],"transparent"),block:Object(kn["c"])(pt["g"],!1),center:Object(kn["c"])(pt["g"],!1),fluid:Object(kn["c"])(pt["g"],!1),fluidGrow:Object(kn["c"])(pt["g"],!1),height:Object(kn["c"])(pt["p"]),left:Object(kn["c"])(pt["g"],!1),right:Object(kn["c"])(pt["g"],!1),rounded:Object(kn["c"])(pt["j"],!1),sizes:Object(kn["c"])(pt["f"]),src:Object(kn["c"])(pt["u"]),srcset:Object(kn["c"])(pt["f"]),thumbnail:Object(kn["c"])(pt["g"],!1),width:Object(kn["c"])(pt["p"])},a["ob"]),Ra=i["default"].extend({name:a["ob"],functional:!0,props:Da,render:function(t,e){var n,r=e.props,i=e.data,o=r.alt,a=r.src,s=r.block,c=r.fluidGrow,l=r.rounded,u=Object(Ie["c"])(r.width)||null,d=Object(Ie["c"])(r.height)||null,h=null,f=Se(r.srcset).filter(An["a"]).join(","),p=Se(r.sizes).filter(An["a"]).join(",");return r.blank&&(!d&&u?d=u:!u&&d&&(u=d),u||d||(u=1,d=1),a=Fa(u,d,r.blankColor||"transparent"),f=null,p=null),r.left?h="float-left":r.right?h="float-right":r.center&&(h="mx-auto",s=!0),t("img",Object(Vn["a"])(i,{attrs:{src:a,alt:o,width:u?Object(Ee["g"])(u):null,height:d?Object(Ee["g"])(d):null,srcset:f||null,sizes:p||null},class:(n={"img-thumbnail":r.thumbnail,"img-fluid":r.fluid||c,"w-100":c,rounded:""===l||!0===l},Ba(n,"rounded-".concat(l),Object(Me["n"])(l)&&""!==l),Ba(n,h,h),Ba(n,"d-block",s),n)}))}});function Na(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function $a(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Na(Object(n),!0).forEach((function(e){Ua(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Na(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Ua(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var qa=Object(kn["d"])(Object(zn["m"])($a($a({},Object(zn["k"])(Da,["src","alt","width","height","left","right"])),{},{bottom:Object(kn["c"])(pt["g"],!1),end:Object(kn["c"])(pt["g"],!1),start:Object(kn["c"])(pt["g"],!1),top:Object(kn["c"])(pt["g"],!1)})),a["s"]),Wa=i["default"].extend({name:a["s"],functional:!0,props:qa,render:function(t,e){var n=e.props,r=e.data,i=n.src,o=n.alt,a=n.width,s=n.height,c="card-img";return n.top?c+="-top":n.right||n.end?c+="-right":n.bottom?c+="-bottom":(n.left||n.start)&&(c+="-left"),t("img",Object(Vn["a"])(r,{class:c,attrs:{src:i,alt:o,width:a,height:s}}))}});function Ga(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ya(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ga(Object(n),!0).forEach((function(e){Ka(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ga(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Ka(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Qa=Object(kn["a"])(qa,kn["f"].bind(null,"img"));Qa.imgSrc.required=!1;var Xa=Object(kn["d"])(Object(zn["m"])(Ya(Ya(Ya(Ya(Ya(Ya({},Aa),Sa),Ea),Qa),ga),{},{align:Object(kn["c"])(pt["u"]),noBody:Object(kn["c"])(pt["g"],!1)})),a["n"]),Ja=i["default"].extend({name:a["n"],functional:!0,props:Xa,render:function(t,e){var n,r=e.props,i=e.data,o=e.slots,a=e.scopedSlots,s=r.imgSrc,c=r.imgLeft,l=r.imgRight,u=r.imgStart,d=r.imgEnd,h=r.imgBottom,f=r.header,p=r.headerHtml,m=r.footer,b=r.footerHtml,g=r.align,v=r.textVariant,w=r.bgVariant,y=r.borderVariant,k=a||{},_=o(),O={},z=t(),A=t();if(s){var j=t(Wa,{props:Object(kn["e"])(Qa,r,kn["h"].bind(null,"img"))});h?A=j:z=j}var M=t(),C=jn(It,k,_);(C||f||p)&&(M=t(xa,{props:Object(kn["e"])(Sa,r),domProps:C?{}:Ji(p,f)},Mn(It,O,k,_)));var V=Mn(Ot,O,k,_);r.noBody||(V=t(ja,{props:Object(kn["e"])(Aa,r)},V),r.overlay&&s&&(V=t("div",{staticClass:"position-relative"},[z,V,A]),z=t(),A=t()));var S=t(),x=jn(Pt,k,_);return(x||m||b)&&(S=t(La,{props:Object(kn["e"])(Ea,r),domProps:C?{}:Ji(b,m)},Mn(Pt,O,k,_))),t(r.tag,Object(Vn["a"])(i,{staticClass:"card",class:(n={"flex-row":c||u,"flex-row-reverse":(l||d)&&!(c||u)},Ka(n,"text-".concat(g),g),Ka(n,"bg-".concat(w),w),Ka(n,"border-".concat(y),y),Ka(n,"text-".concat(v),v),n)}),[z,M,V,S,A])}});function Za(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function ts(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function es(t,e,n){return e&&ts(t.prototype,e),n&&ts(t,n),t}var ns,rs="__bv__visibility_observer",is=function(){function t(e,n,r){Za(this,t),this.el=e,this.callback=n.callback,this.margin=n.margin||0,this.once=n.once||!1,this.observer=null,this.visible=void 0,this.doneOnce=!1,this.createObserver(r)}return es(t,[{key:"createObserver",value:function(t){var e=this;if(this.observer&&this.stop(),!this.doneOnce&&Object(Me["f"])(this.callback)){try{this.observer=new IntersectionObserver(this.handler.bind(this),{root:null,rootMargin:this.margin,threshold:0})}catch(n){return this.doneOnce=!0,this.observer=void 0,void this.callback(null)}t.context.$nextTick((function(){De((function(){e.observer&&e.observer.observe(e.el)}))}))}}},{key:"handler",value:function(t){var e=t?t[0]:{},n=Boolean(e.isIntersecting||e.intersectionRatio>0);n!==this.visible&&(this.visible=n,this.callback(n),this.once&&this.visible&&(this.doneOnce=!0,this.stop()))}},{key:"stop",value:function(){this.observer&&this.observer.disconnect(),this.observer=null}}]),t}(),os=function(t){var e=t[rs];e&&e.stop&&e.stop(),delete t[rs]},as=function(t,e,n){var r=e.value,i=e.modifiers,o={margin:"0px",once:!1,callback:r};Object(zn["h"])(i).forEach((function(t){Sn["h"].test(t)?o.margin="".concat(t,"px"):"once"===t.toLowerCase()&&(o.once=!0)})),os(t),t[rs]=new is(t,o,n),t[rs]._prevModifiers=Object(zn["b"])(i)},ss=function(t,e,n){var r=e.value,i=e.oldValue,o=e.modifiers;o=Object(zn["b"])(o),!t||r===i&&t[rs]&&Yr(o,t[rs]._prevModifiers)||as(t,{value:r,modifiers:o},n)},cs=function(t){os(t)},ls={bind:as,componentUpdated:ss,unbind:cs};function us(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ds(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?us(Object(n),!0).forEach((function(e){hs(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):us(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function hs(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var fs="show",ps=lt+fs,ms=Object(zn["j"])(Da,["blank"]),bs=Object(kn["d"])(ds(ds({},ms),{},hs({blankColor:Object(kn["c"])(pt["u"],"transparent"),blankHeight:Object(kn["c"])(pt["p"]),blankSrc:Object(kn["c"])(pt["u"],null),blankWidth:Object(kn["c"])(pt["p"]),offset:Object(kn["c"])(pt["p"],360)},fs,Object(kn["c"])(pt["g"],!1))),a["pb"]),gs=i["default"].extend({name:a["pb"],directives:{"b-visible":ls},props:bs,data:function(){return{isShown:this[fs]}},computed:{computedSrc:function(){var t=this.blankSrc;return!t||this.isShown?this.src:t},computedBlank:function(){return!(this.isShown||this.blankSrc)},computedWidth:function(){var t=this.width;return this.isShown?t:this.blankWidth||t},computedHeight:function(){var t=this.height;return this.isShown?t:this.blankHeight||t},computedSrcset:function(){var t=Se(this.srcset).filter(An["a"]).join(",");return!this.blankSrc||this.isShown?t:null},computedSizes:function(){var t=Se(this.sizes).filter(An["a"]).join(",");return!this.blankSrc||this.isShown?t:null}},watch:(ns={},hs(ns,fs,(function(t,e){if(t!==e){var n=!Ae["b"]||t;this.isShown=n,n!==t&&this.$nextTick(this.updateShowProp)}})),hs(ns,"isShown",(function(t,e){t!==e&&this.updateShowProp()})),ns),mounted:function(){this.isShown=!Ae["b"]||this[fs]},methods:{updateShowProp:function(){this.$emit(ps,this.isShown)},doShow:function(t){!t&&null!==t||this.isShown||(this.isShown=!0)}},render:function(t){var e,n=[];this.isShown||n.push({name:"b-visible",value:this.doShow,modifiers:(e={},hs(e,"".concat(Object(Ie["c"])(this.offset,0)),!0),hs(e,"once",!0),e)});return t(Ra,{directives:n,props:ds({src:this.computedSrc,blank:this.computedBlank,width:this.computedWidth,height:this.computedHeight,srcset:this.computedSrcset||null,sizes:this.computedSizes||null},Object(kn["e"])(ms,this.$props))})}});function vs(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ws(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?vs(Object(n),!0).forEach((function(e){ys(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):vs(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function ys(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ks=Object(kn["d"])(Object(zn["m"])(ws(ws({},Object(zn["j"])(bs,Object(zn["h"])(Da))),Object(zn["j"])(qa,["src","alt","width","height"]))),a["t"]),_s=i["default"].extend({name:a["t"],functional:!0,props:ks,render:function(t,e){var n=e.props,r=e.data,i="card-img";return n.top?i+="-top":n.right||n.end?i+="-right":n.bottom?i+="-bottom":(n.left||n.start)&&(i+="-left"),t(gs,Object(Vn["a"])(r,{class:[i],props:Object(zn["j"])(n,["left","right"])}))}}),Os=Object(kn["d"])({textTag:Object(kn["c"])(pt["u"],"p")},a["v"]),zs=i["default"].extend({name:a["v"],functional:!0,props:Os,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.textTag,Object(Vn["a"])(r,{staticClass:"card-text"}),i)}}),As=Object(kn["d"])({columns:Object(kn["c"])(pt["g"],!1),deck:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div")},a["q"]),js=i["default"].extend({name:a["q"],functional:!0,props:As,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.tag,Object(Vn["a"])(r,{class:n.deck?"card-deck":n.columns?"card-columns":"card-group"}),i)}}),Ms=Object(r["b"])({components:{BCard:Ja,BCardHeader:xa,BCardBody:ja,BCardTitle:wa,BCardSubTitle:ka,BCardFooter:La,BCardImg:Wa,BCardImgLazy:_s,BCardText:zs,BCardGroup:js}}),Cs=function(){},Vs=n("686b");function Ss(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function xs(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ss(Object(n),!0).forEach((function(e){Ts(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ss(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Ts(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Ps,Is=function(t,e,n){if(t=t?t.$el||t:null,!$e(t))return null;if(Object(Vs["b"])("observeDom"))return null;var r=new Re((function(t){for(var n=!1,r=0;r<t.length&&!n;r++){var i=t[r],o=i.type,a=i.target;("characterData"===o&&a.nodeType===Node.TEXT_NODE||"attributes"===o||"childList"===o&&(i.addedNodes.length>0||i.removedNodes.length>0))&&(n=!0)}n&&e()}));return r.observe(t,xs({childList:!0,subtree:!0},n)),r};function Es(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ls(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Es(Object(n),!0).forEach((function(e){Bs(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Es(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Bs(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Hs=On("value",{type:pt["n"],defaultValue:0}),Fs=Hs.mixin,Ds=Hs.props,Rs=Hs.prop,Ns=Hs.event,$s={next:{dirClass:"carousel-item-left",overlayClass:"carousel-item-next"},prev:{dirClass:"carousel-item-right",overlayClass:"carousel-item-prev"}},Us=650,qs=500,Ws=40,Gs={TOUCH:"touch",PEN:"pen"},Ys={WebkitTransition:"webkitTransitionEnd",MozTransition:"transitionend",OTransition:"otransitionend oTransitionEnd",transition:"transitionend"},Ks=function(t){for(var e in Ys)if(!Object(Me["o"])(t.style[e]))return Ys[e];return null},Qs=Object(kn["d"])(Object(zn["m"])(Ls(Ls(Ls({},ia),Ds),{},{background:Object(kn["c"])(pt["u"]),controls:Object(kn["c"])(pt["g"],!1),fade:Object(kn["c"])(pt["g"],!1),imgHeight:Object(kn["c"])(pt["p"]),imgWidth:Object(kn["c"])(pt["p"]),indicators:Object(kn["c"])(pt["g"],!1),interval:Object(kn["c"])(pt["n"],5e3),labelGotoSlide:Object(kn["c"])(pt["u"],"Goto slide"),labelIndicators:Object(kn["c"])(pt["u"],"Select a slide to display"),labelNext:Object(kn["c"])(pt["u"],"Next slide"),labelPrev:Object(kn["c"])(pt["u"],"Previous slide"),noAnimation:Object(kn["c"])(pt["g"],!1),noHoverPause:Object(kn["c"])(pt["g"],!1),noTouch:Object(kn["c"])(pt["g"],!1),noWrap:Object(kn["c"])(pt["g"],!1)})),a["x"]),Xs=i["default"].extend({name:a["x"],mixins:[oa,Fs,Cn],provide:function(){return{bvCarousel:this}},props:Qs,data:function(){return{index:this[Rs]||0,isSliding:!1,transitionEndEvent:null,slides:[],direction:null,isPaused:!(Object(Ie["c"])(this.interval,0)>0),touchStartX:0,touchDeltaX:0}},computed:{numSlides:function(){return this.slides.length}},watch:(Ps={},Bs(Ps,Rs,(function(t,e){t!==e&&this.setSlide(Object(Ie["c"])(t,0))})),Bs(Ps,"interval",(function(t,e){t!==e&&(t?(this.pause(!0),this.start(!1)):this.pause(!1))})),Bs(Ps,"isPaused",(function(t,e){t!==e&&this.$emit(t?F:ot)})),Bs(Ps,"index",(function(t,e){t===e||this.isSliding||this.doSlide(t,e)})),Ps),created:function(){this.$_interval=null,this.$_animationTimeout=null,this.$_touchTimeout=null,this.$_observer=null,this.isPaused=!(Object(Ie["c"])(this.interval,0)>0)},mounted:function(){this.transitionEndEvent=Ks(this.$el)||null,this.updateSlides(),this.setObserver(!0)},beforeDestroy:function(){this.clearInterval(),this.clearAnimationTimeout(),this.clearTouchTimeout(),this.setObserver(!1)},methods:{clearInterval:function(t){function e(){return t.apply(this,arguments)}return e.toString=function(){return t.toString()},e}((function(){clearInterval(this.$_interval),this.$_interval=null})),clearAnimationTimeout:function(){clearTimeout(this.$_animationTimeout),this.$_animationTimeout=null},clearTouchTimeout:function(){clearTimeout(this.$_touchTimeout),this.$_touchTimeout=null},setObserver:function(){var t=arguments.length>0&&void 0!==arguments[0]&&arguments[0];this.$_observer&&this.$_observer.disconnect(),this.$_observer=null,t&&(this.$_observer=Is(this.$refs.inner,this.updateSlides.bind(this),{subtree:!1,childList:!0,attributes:!0,attributeFilter:["id"]}))},setSlide:function(t){var e=this,n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;if(!(Ae["i"]&&document.visibilityState&&document.hidden)){var r=this.noWrap,i=this.numSlides;t=Object(lr["c"])(t),0!==i&&(this.isSliding?this.$once(tt,(function(){De((function(){return e.setSlide(t,n)}))})):(this.direction=n,this.index=t>=i?r?i-1:0:t<0?r?0:i-1:t,r&&this.index!==t&&this.index!==this[Rs]&&this.$emit(Ns,this.index)))}},prev:function(){this.setSlide(this.index-1,"prev")},next:function(){this.setSlide(this.index+1,"next")},pause:function(t){t||(this.isPaused=!0),this.clearInterval()},start:function(t){t||(this.isPaused=!1),this.clearInterval(),this.interval&&this.numSlides>1&&(this.$_interval=setInterval(this.next,Object(lr["d"])(1e3,this.interval)))},restart:function(){this.$el.contains(Ue())||this.start()},doSlide:function(t,e){var n=this,r=Boolean(this.interval),i=this.calcDirection(this.direction,e,t),o=i.overlayClass,a=i.dirClass,s=this.slides[e],c=this.slides[t];if(s&&c){if(this.isSliding=!0,r&&this.pause(!1),this.$emit(et,t),this.$emit(Ns,this.index),this.noAnimation)nn(c,"active"),rn(s,"active"),this.isSliding=!1,this.$nextTick((function(){return n.$emit(tt,t)}));else{nn(c,o),Ke(c),nn(s,a),nn(c,a);var l=!1,u=function e(){if(!l){if(l=!0,n.transitionEndEvent){var r=n.transitionEndEvent.split(/\s+/);r.forEach((function(t){return Pn(c,t,e,ft)}))}n.clearAnimationTimeout(),rn(c,a),rn(c,o),nn(c,"active"),rn(s,"active"),rn(s,a),rn(s,o),an(s,"aria-current","false"),an(c,"aria-current","true"),an(s,"aria-hidden","true"),an(c,"aria-hidden","false"),n.isSliding=!1,n.direction=null,n.$nextTick((function(){return n.$emit(tt,t)}))}};if(this.transitionEndEvent){var d=this.transitionEndEvent.split(/\s+/);d.forEach((function(t){return Tn(c,t,u,ft)}))}this.$_animationTimeout=setTimeout(u,Us)}r&&this.start(!1)}},updateSlides:function(){this.pause(!0),this.slides=Qe(".carousel-item",this.$refs.inner);var t=this.slides.length,e=Object(lr["d"])(0,Object(lr["e"])(Object(lr["c"])(this.index),t-1));this.slides.forEach((function(n,r){var i=r+1;r===e?(nn(n,"active"),an(n,"aria-current","true")):(rn(n,"active"),an(n,"aria-current","false")),an(n,"aria-posinset",String(i)),an(n,"aria-setsize",String(t))})),this.setSlide(e),this.start(this.isPaused)},calcDirection:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null,e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:0;return t?$s[t]:n>e?$s.next:$s.prev},handleClick:function(t,e){var n=t.keyCode;"click"!==t.type&&n!==Ur&&n!==Br||(En(t),e())},handleSwipe:function(){var t=Object(lr["a"])(this.touchDeltaX);if(!(t<=Ws)){var e=t/this.touchDeltaX;this.touchDeltaX=0,e>0?this.prev():e<0&&this.next()}},touchStart:function(t){Ae["e"]&&Gs[t.pointerType.toUpperCase()]?this.touchStartX=t.clientX:Ae["e"]||(this.touchStartX=t.touches[0].clientX)},touchMove:function(t){t.touches&&t.touches.length>1?this.touchDeltaX=0:this.touchDeltaX=t.touches[0].clientX-this.touchStartX},touchEnd:function(t){Ae["e"]&&Gs[t.pointerType.toUpperCase()]&&(this.touchDeltaX=t.clientX-this.touchStartX),this.handleSwipe(),this.pause(!1),this.clearTouchTimeout(),this.$_touchTimeout=setTimeout(this.start,qs+Object(lr["d"])(1e3,this.interval))}},render:function(t){var e=this,n=this.indicators,r=this.background,i=this.noAnimation,o=this.noHoverPause,a=this.noTouch,s=this.index,c=this.isSliding,l=this.pause,u=this.restart,d=this.touchStart,h=this.touchEnd,f=this.safeId("__BV_inner_"),p=t("div",{staticClass:"carousel-inner",attrs:{id:f,role:"list"},ref:"inner"},[this.normalizeSlot()]),m=t();if(this.controls){var b=function(n,r,i){var o=function(t){c?En(t,{propagation:!1}):e.handleClick(t,i)};return t("a",{staticClass:"carousel-control-".concat(n),attrs:{href:"#",role:"button","aria-controls":f,"aria-disabled":c?"true":null},on:{click:o,keydown:o}},[t("span",{staticClass:"carousel-control-".concat(n,"-icon"),attrs:{"aria-hidden":"true"}}),t("span",{class:"sr-only"},[r])])};m=[b("prev",this.labelPrev,this.prev),b("next",this.labelNext,this.next)]}var g=t("ol",{staticClass:"carousel-indicators",directives:[{name:"show",value:n}],attrs:{id:this.safeId("__BV_indicators_"),"aria-hidden":n?"false":"true","aria-label":this.labelIndicators,"aria-owns":f}},this.slides.map((function(r,i){var o=function(t){e.handleClick(t,(function(){e.setSlide(i)}))};return t("li",{class:{active:i===s},attrs:{role:"button",id:e.safeId("__BV_indicator_".concat(i+1,"_")),tabindex:n?"0":"-1","aria-current":i===s?"true":"false","aria-label":"".concat(e.labelGotoSlide," ").concat(i+1),"aria-describedby":r.id||null,"aria-controls":f},on:{click:o,keydown:o},key:"slide_".concat(i)})}))),v={mouseenter:o?Cs:l,mouseleave:o?Cs:u,focusin:l,focusout:u,keydown:function(t){if(!/input|textarea/i.test(t.target.tagName)){var n=t.keyCode;n!==Dr&&n!==$r||(En(t),e[n===Dr?"prev":"next"]())}}};return Ae["g"]&&!a&&(Ae["e"]?(v["&pointerdown"]=d,v["&pointerup"]=h):(v["&touchstart"]=d,v["&touchmove"]=this.touchMove,v["&touchend"]=h)),t("div",{staticClass:"carousel",class:{slide:!i,"carousel-fade":!i&&this.fade,"pointer-event":Ae["g"]&&Ae["e"]&&!a},style:{background:r},attrs:{role:"region",id:this.safeId(),"aria-busy":c?"true":"false"},on:v},[p,m,g])}});function Js(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Zs(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Js(Object(n),!0).forEach((function(e){tc(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Js(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function tc(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ec,nc={imgAlt:Object(kn["c"])(pt["u"]),imgBlank:Object(kn["c"])(pt["g"],!1),imgBlankColor:Object(kn["c"])(pt["u"],"transparent"),imgHeight:Object(kn["c"])(pt["p"]),imgSrc:Object(kn["c"])(pt["u"]),imgWidth:Object(kn["c"])(pt["p"])},rc=Object(kn["d"])(Object(zn["m"])(Zs(Zs(Zs({},ia),nc),{},{background:Object(kn["c"])(pt["u"]),caption:Object(kn["c"])(pt["u"]),captionHtml:Object(kn["c"])(pt["u"]),captionTag:Object(kn["c"])(pt["u"],"h3"),contentTag:Object(kn["c"])(pt["u"],"div"),contentVisibleUp:Object(kn["c"])(pt["u"]),text:Object(kn["c"])(pt["u"]),textHtml:Object(kn["c"])(pt["u"]),textTag:Object(kn["c"])(pt["u"],"p")})),a["y"]),ic=i["default"].extend({name:a["y"],mixins:[oa,Cn],inject:{bvCarousel:{default:function(){return{noTouch:!0}}}},props:rc,computed:{contentClasses:function(){return[this.contentVisibleUp?"d-none":"",this.contentVisibleUp?"d-".concat(this.contentVisibleUp,"-block"):""]},computedWidth:function(){return this.imgWidth||this.bvCarousel.imgWidth||null},computedHeight:function(){return this.imgHeight||this.bvCarousel.imgHeight||null}},render:function(t){var e=this.normalizeSlot(Dt);if(!e&&(this.imgSrc||this.imgBlank)){var n={};!this.bvCarousel.noTouch&&Ae["g"]&&(n.dragstart=function(t){return En(t,{propagation:!1})}),e=t(Ra,{props:Zs(Zs({},Object(kn["e"])(nc,this.$props,kn["h"].bind(null,"img"))),{},{width:this.computedWidth,height:this.computedHeight,fluidGrow:!0,block:!0}),on:n})}var r=[!(!this.caption&&!this.captionHtml)&&t(this.captionTag,{domProps:Ji(this.captionHtml,this.caption)}),!(!this.text&&!this.textHtml)&&t(this.textTag,{domProps:Ji(this.textHtml,this.text)}),this.normalizeSlot()||!1],i=t();return r.some(An["a"])&&(i=t(this.contentTag,{staticClass:"carousel-caption",class:this.contentClasses},r.map((function(e){return e||t()})))),t("div",{staticClass:"carousel-item",style:{background:this.background||this.bvCarousel.background||null},attrs:{id:this.safeId(),role:"listitem"}},[e,i])}}),oc=Object(r["b"])({components:{BCarousel:Xs,BCarouselSlide:ic}}),ac="show",sc=function(t){un(t,"height",0),De((function(){Ke(t),un(t,"height","".concat(t.scrollHeight,"px"))}))},cc=function(t){dn(t,"height")},lc=function(t){un(t,"height","auto"),un(t,"display","block"),un(t,"height","".concat(fn(t).height,"px")),Ke(t),un(t,"height",0)},uc=function(t){dn(t,"height")},dc={css:!0,enterClass:"",enterActiveClass:"collapsing",enterToClass:"collapse show",leaveClass:"collapse show",leaveActiveClass:"collapsing",leaveToClass:"collapse"},hc={enter:sc,afterEnter:cc,leave:lc,afterLeave:uc},fc={appear:Object(kn["c"])(pt["g"],!1)},pc=i["default"].extend({name:a["B"],functional:!0,props:fc,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t("transition",Object(Vn["a"])(r,{props:dc,on:hc},{props:n}),i)}});function mc(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function bc(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?mc(Object(n),!0).forEach((function(e){gc(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):mc(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function gc(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var vc=Hn(a["A"],"toggle"),wc=Hn(a["A"],"request-state"),yc=Bn(a["A"],"accordion"),kc=Bn(a["A"],"state"),_c=Bn(a["A"],"sync-state"),Oc=On("visible",{type:pt["g"],defaultValue:!1}),zc=Oc.mixin,Ac=Oc.props,jc=Oc.prop,Mc=Oc.event,Cc=Object(kn["d"])(Object(zn["m"])(bc(bc(bc({},ia),Ac),{},{accordion:Object(kn["c"])(pt["u"]),appear:Object(kn["c"])(pt["g"],!1),isNav:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div")})),a["A"]),Vc=i["default"].extend({name:a["A"],mixins:[oa,zc,Cn,ti],props:Cc,data:function(){return{show:this[jc],transitioning:!1}},computed:{classObject:function(){var t=this.transitioning;return{"navbar-collapse":this.isNav,collapse:!t,show:this.show&&!t}},slotScope:function(){var t=this;return{visible:this.show,close:function(){t.show=!1}}}},watch:(ec={},gc(ec,jc,(function(t){t!==this.show&&(this.show=t)})),gc(ec,"show",(function(t,e){t!==e&&this.emitState()})),ec),created:function(){this.show=this[jc]},mounted:function(){var t=this;this.show=this[jc],this.listenOnRoot(vc,this.handleToggleEvt),this.listenOnRoot(yc,this.handleAccordionEvt),this.isNav&&(this.setWindowEvents(!0),this.handleResize()),this.$nextTick((function(){t.emitState()})),this.listenOnRoot(wc,(function(e){e===t.safeId()&&t.$nextTick(t.emitSync)}))},updated:function(){this.emitSync()},deactivated:function(){this.isNav&&this.setWindowEvents(!1)},activated:function(){this.isNav&&this.setWindowEvents(!0),this.emitSync()},beforeDestroy:function(){this.show=!1,this.isNav&&Ae["i"]&&this.setWindowEvents(!1)},methods:{setWindowEvents:function(t){In(t,window,"resize",this.handleResize,ft),In(t,window,"orientationchange",this.handleResize,ft)},toggle:function(){this.show=!this.show},onEnter:function(){this.transitioning=!0,this.$emit(J)},onAfterEnter:function(){this.transitioning=!1,this.$emit(Z)},onLeave:function(){this.transitioning=!0,this.$emit(V)},onAfterLeave:function(){this.transitioning=!1,this.$emit(C)},emitState:function(){var t=this.show,e=this.accordion,n=this.safeId();this.$emit(Mc,t),this.emitOnRoot(kc,n,t),e&&t&&this.emitOnRoot(yc,n,e)},emitSync:function(){this.emitOnRoot(_c,this.safeId(),this.show)},checkDisplayBlock:function(){var t=this.$el,e=on(t,ac);rn(t,ac);var n="block"===pn(t).display;return e&&nn(t,ac),n},clickHandler:function(t){var e=t.target;this.isNav&&e&&"block"===pn(this.$el).display&&(!Je(e,".nav-link,.dropdown-item")&&!Ze(".nav-link,.dropdown-item",e)||this.checkDisplayBlock()||(this.show=!1))},handleToggleEvt:function(t){t===this.safeId()&&this.toggle()},handleAccordionEvt:function(t,e){var n=this.accordion,r=this.show;if(n&&n===e){var i=t===this.safeId();(i&&!r||!i&&r)&&this.toggle()}},handleResize:function(){this.show="block"===pn(this.$el).display}},render:function(t){var e=this.appear,n=t(this.tag,{class:this.classObject,directives:[{name:"show",value:this.show}],attrs:{id:this.safeId()},on:{click:this.clickHandler}},this.normalizeSlot(Ot,this.slotScope));return t(pc,{props:{appear:e},on:{enter:this.onEnter,afterEnter:this.onAfterEnter,leave:this.onLeave,afterLeave:this.onAfterLeave}},[n])}}),Sc="collapsed",xc="not-collapsed",Tc="__BV_toggle",Pc="".concat(Tc,"_HANDLER__"),Ic="".concat(Tc,"_CLICK__"),Ec="".concat(Tc,"_STATE__"),Lc="".concat(Tc,"_TARGETS__"),Bc="false",Hc="true",Fc="aria-controls",Dc="aria-expanded",Rc="role",Nc="tabindex",$c="overflow-anchor",Uc=Hn(a["A"],"toggle"),qc=Bn(a["A"],"state"),Wc=Bn(a["A"],"sync-state"),Gc=Hn(a["A"],"request-state"),Yc=[Br,Ur],Kc=function(t){return!Ve(["button","a"],t.tagName.toLowerCase())},Qc=function(t,e){var n=t.modifiers,r=t.arg,i=t.value,o=Object(zn["h"])(n||{});if(i=Object(Me["n"])(i)?i.split(Sn["x"]):i,qe(e.tagName,"a")){var a=cn(e,"href")||"";Sn["m"].test(a)&&o.push(a.replace(Sn["l"],""))}return Se(r,i).forEach((function(t){return Object(Me["n"])(t)&&o.push(t)})),o.filter((function(t,e,n){return t&&n.indexOf(t)===e}))},Xc=function(t){var e=t[Ic];e&&(Pn(t,"click",e,ht),Pn(t,"keydown",e,ht)),t[Ic]=null},Jc=function(t,e){if(Xc(t),e.context){var n=function(n){if(("keydown"!==n.type||Ve(Yc,n.keyCode))&&!Ye(t)){var r=t[Lc]||[];r.forEach((function(t){e.context.$root.$emit(Uc,t)}))}};t[Ic]=n,Tn(t,"click",n,ht),Kc(t)&&Tn(t,"keydown",n,ht)}},Zc=function(t,e){t[Pc]&&e.context&&e.context.$root.$off([qc,Wc],t[Pc]),t[Pc]=null},tl=function(t,e){if(Zc(t,e),e.context){var n=function(e,n){Ve(t[Lc]||[],e)&&(t[Ec]=n,el(t,n))};t[Pc]=n,e.context.$root.$on([qc,Wc],n)}},el=function(t,e){e?(rn(t,Sc),nn(t,xc),an(t,Dc,Hc)):(rn(t,xc),nn(t,Sc),an(t,Dc,Bc))},nl=function(t,e){t[e]=null,delete t[e]},rl=function(t,e,n){if(Ae["i"]&&n.context){Kc(t)&&(ln(t,Rc)||an(t,Rc,"button"),ln(t,Nc)||an(t,Nc,"0")),el(t,t[Ec]);var r=Qc(e,t);r.length>0?(an(t,Fc,r.join(" ")),un(t,$c,"none")):(sn(t,Fc),dn(t,$c)),De((function(){Jc(t,n)})),Yr(r,t[Lc])||(t[Lc]=r,r.forEach((function(t){n.context.$root.$emit(Gc,t)})))}},il={bind:function(t,e,n){t[Ec]=!1,t[Lc]=[],tl(t,n),rl(t,e,n)},componentUpdated:rl,updated:rl,unbind:function(t,e,n){Xc(t),Zc(t,n),nl(t,Pc),nl(t,Ic),nl(t,Ec),nl(t,Lc),rn(t,Sc),rn(t,xc),sn(t,Dc),sn(t,Fc),sn(t,Rc),dn(t,$c)}},ol=Object(r["b"])({directives:{VBToggle:il}}),al=Object(r["b"])({components:{BCollapse:Vc},plugins:{VBTogglePlugin:ol}}),sl=n("f0bd"),cl="top-start",ll="top-end",ul="bottom-start",dl="bottom-end",hl="right-start",fl="left-start";function pl(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function ml(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function bl(t,e,n){return e&&ml(t.prototype,e),n&&ml(t,n),t}var gl=function(){function t(e){var n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};if(pl(this,t),!e)throw new TypeError("Failed to construct '".concat(this.constructor.name,"'. 1 argument required, ").concat(arguments.length," given."));Object(zn["a"])(this,t.Defaults,this.constructor.Defaults,n,{type:e}),Object(zn["d"])(this,{type:Object(zn["l"])(),cancelable:Object(zn["l"])(),nativeEvent:Object(zn["l"])(),target:Object(zn["l"])(),relatedTarget:Object(zn["l"])(),vueTarget:Object(zn["l"])(),componentId:Object(zn["l"])()});var r=!1;this.preventDefault=function(){this.cancelable&&(r=!0)},Object(zn["e"])(this,"defaultPrevented",{enumerable:!0,get:function(){return r}})}return bl(t,null,[{key:"Defaults",get:function(){return{type:"",cancelable:!0,nativeEvent:null,target:null,relatedTarget:null,vueTarget:null,componentId:null}}}]),t}(),vl=i["default"].extend({data:function(){return{listenForClickOut:!1}},watch:{listenForClickOut:function(t,e){t!==e&&(Pn(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,ft),t&&Tn(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,ft))}},beforeCreate:function(){this.clickOutElement=null,this.clickOutEventName=null},mounted:function(){this.clickOutElement||(this.clickOutElement=document),this.clickOutEventName||(this.clickOutEventName="click"),this.listenForClickOut&&Tn(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,ft)},beforeDestroy:function(){Pn(this.clickOutElement,this.clickOutEventName,this._clickOutHandler,ft)},methods:{isClickOut:function(t){return!tn(this.$el,t.target)},_clickOutHandler:function(t){this.clickOutHandler&&this.isClickOut(t)&&this.clickOutHandler(t)}}}),wl=i["default"].extend({data:function(){return{listenForFocusIn:!1}},watch:{listenForFocusIn:function(t,e){t!==e&&(Pn(this.focusInElement,"focusin",this._focusInHandler,ft),t&&Tn(this.focusInElement,"focusin",this._focusInHandler,ft))}},beforeCreate:function(){this.focusInElement=null},mounted:function(){this.focusInElement||(this.focusInElement=document),this.listenForFocusIn&&Tn(this.focusInElement,"focusin",this._focusInHandler,ft)},beforeDestroy:function(){Pn(this.focusInElement,"focusin",this._focusInHandler,ft)},methods:{_focusInHandler:function(t){this.focusInHandler&&this.focusInHandler(t)}}});function yl(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function kl(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?yl(Object(n),!0).forEach((function(e){_l(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):yl(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function _l(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Ol=Bn(a["D"],Z),zl=Bn(a["D"],C),Al=".dropdown form",jl=[".dropdown-item",".b-dropdown-form"].map((function(t){return"".concat(t,":not(.disabled):not([disabled])")})).join(", "),Ml=function(t){return(t||[]).filter(Ge)},Cl=Object(kn["d"])(Object(zn["m"])(kl(kl({},ia),{},{boundary:Object(kn["c"])([je["c"],pt["u"]],"scrollParent"),disabled:Object(kn["c"])(pt["g"],!1),dropleft:Object(kn["c"])(pt["g"],!1),dropright:Object(kn["c"])(pt["g"],!1),dropup:Object(kn["c"])(pt["g"],!1),noFlip:Object(kn["c"])(pt["g"],!1),offset:Object(kn["c"])(pt["p"],0),popperOpts:Object(kn["c"])(pt["q"],{}),right:Object(kn["c"])(pt["g"],!1)})),a["D"]),Vl=i["default"].extend({mixins:[oa,ti,vl,wl],provide:function(){return{bvDropdown:this}},inject:{bvNavbar:{default:null}},props:Cl,data:function(){return{visible:!1,visibleChangePrevented:!1}},computed:{inNavbar:function(){return!Object(Me["g"])(this.bvNavbar)},toggler:function(){var t=this.$refs.toggle;return t?t.$el||t:null},directionClass:function(){return this.dropup?"dropup":this.dropright?"dropright":this.dropleft?"dropleft":""},boundaryClass:function(){return"scrollParent"===this.boundary||this.inNavbar?"":"position-static"}},watch:{visible:function(t,e){if(this.visibleChangePrevented)this.visibleChangePrevented=!1;else if(t!==e){var n=t?J:V,r=new gl(n,{cancelable:!0,vueTarget:this,target:this.$refs.menu,relatedTarget:null,componentId:this.safeId?this.safeId():this.id||null});if(this.emitEvent(r),r.defaultPrevented)return this.visibleChangePrevented=!0,this.visible=e,void this.$off(C,this.focusToggler);t?this.showMenu():this.hideMenu()}},disabled:function(t,e){t!==e&&t&&this.visible&&(this.visible=!1)}},created:function(){this.$_popper=null,this.$_hideTimeout=null},deactivated:function(){this.visible=!1,this.whileOpenListen(!1),this.destroyPopper()},beforeDestroy:function(){this.visible=!1,this.whileOpenListen(!1),this.destroyPopper(),this.clearHideTimeout()},methods:{emitEvent:function(t){var e=t.type;this.emitOnRoot(Bn(a["D"],e),t),this.$emit(e,t)},showMenu:function(){var t=this;if(!this.disabled){if(!this.inNavbar)if("undefined"===typeof sl["a"])Object(Vs["a"])("Popper.js not found. Falling back to CSS positioning",a["D"]);else{var e=this.dropup&&this.right||this.split?this.$el:this.$refs.toggle;e=e.$el||e,this.createPopper(e)}this.emitOnRoot(Ol,this),this.whileOpenListen(!0),this.$nextTick((function(){t.focusMenu(),t.$emit(Z)}))}},hideMenu:function(){this.whileOpenListen(!1),this.emitOnRoot(zl,this),this.$emit(C),this.destroyPopper()},createPopper:function(t){this.destroyPopper(),this.$_popper=new sl["a"](t,this.$refs.menu,this.getPopperConfig())},destroyPopper:function(){this.$_popper&&this.$_popper.destroy(),this.$_popper=null},updatePopper:function(){try{this.$_popper.scheduleUpdate()}catch(t){}},clearHideTimeout:function(){clearTimeout(this.$_hideTimeout),this.$_hideTimeout=null},getPopperConfig:function(){var t=ul;this.dropup?t=this.right?ll:cl:this.dropright?t=hl:this.dropleft?t=fl:this.right&&(t=dl);var e={placement:t,modifiers:{offset:{offset:this.offset||0},flip:{enabled:!this.noFlip}}},n=this.boundary;return n&&(e.modifiers.preventOverflow={boundariesElement:n}),Object(zn["i"])(e,this.popperOpts||{})},whileOpenListen:function(t){this.listenForClickOut=t,this.listenForFocusIn=t;var e=t?"$on":"$off";this.$root[e](Ol,this.rootCloseListener)},rootCloseListener:function(t){t!==this&&(this.visible=!1)},show:function(){var t=this;this.disabled||De((function(){t.visible=!0}))},hide:function(){var t=arguments.length>0&&void 0!==arguments[0]&&arguments[0];this.disabled||(this.visible=!1,t&&this.$once(C,this.focusToggler))},toggle:function(t){t=t||{};var e=t,n=e.type,r=e.keyCode;("click"===n||"keydown"===n&&-1!==[Br,Ur,Er].indexOf(r))&&(this.disabled?this.visible=!1:(this.$emit(it,t),En(t),this.visible?this.hide(!0):this.show()))},onMousedown:function(t){En(t,{propagation:!1})},onKeydown:function(t){var e=t.keyCode;e===Hr?this.onEsc(t):e===Er?this.focusNext(t,!1):e===qr&&this.focusNext(t,!0)},onEsc:function(t){this.visible&&(this.visible=!1,En(t),this.$once(C,this.focusToggler))},onSplitClick:function(t){this.disabled?this.visible=!1:this.$emit(h,t)},hideHandler:function(t){var e=this,n=t.target;!this.visible||tn(this.$refs.menu,n)||tn(this.toggler,n)||(this.clearHideTimeout(),this.$_hideTimeout=setTimeout((function(){return e.hide()}),this.inNavbar?300:0))},clickOutHandler:function(t){this.hideHandler(t)},focusInHandler:function(t){this.hideHandler(t)},focusNext:function(t,e){var n=this,r=t.target;!this.visible||t&&Ze(Al,r)||(En(t),this.$nextTick((function(){var t=n.getItems();if(!(t.length<1)){var i=t.indexOf(r);e&&i>0?i--:!e&&i<t.length-1&&i++,i<0&&(i=0),n.focusItem(i,t)}})))},focusItem:function(t,e){var n=e.find((function(e,n){return n===t}));wn(n)},getItems:function(){return Ml(Qe(jl,this.$refs.menu))},focusMenu:function(){wn(this.$refs.menu)},focusToggler:function(){var t=this;this.$nextTick((function(){wn(t.toggler)}))}}});function Sl(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function xl(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Sl(Object(n),!0).forEach((function(e){Tl(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Sl(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Tl(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Pl=Object(kn["d"])(Object(zn["m"])(xl(xl(xl({},ia),Cl),{},{block:Object(kn["c"])(pt["g"],!1),html:Object(kn["c"])(pt["u"]),lazy:Object(kn["c"])(pt["g"],!1),menuClass:Object(kn["c"])(pt["e"]),noCaret:Object(kn["c"])(pt["g"],!1),role:Object(kn["c"])(pt["u"],"menu"),size:Object(kn["c"])(pt["u"]),split:Object(kn["c"])(pt["g"],!1),splitButtonType:Object(kn["c"])(pt["u"],"button",(function(t){return Ve(["button","submit","reset"],t)})),splitClass:Object(kn["c"])(pt["e"]),splitHref:Object(kn["c"])(pt["u"]),splitTo:Object(kn["c"])(pt["s"]),splitVariant:Object(kn["c"])(pt["u"]),text:Object(kn["c"])(pt["u"]),toggleClass:Object(kn["c"])(pt["e"]),toggleTag:Object(kn["c"])(pt["u"],"button"),toggleText:Object(kn["c"])(pt["u"],"Toggle dropdown"),variant:Object(kn["c"])(pt["u"],"secondary")})),a["D"]),Il=i["default"].extend({name:a["D"],mixins:[oa,Vl,Cn],props:Pl,computed:{dropdownClasses:function(){var t=this.block,e=this.split;return[this.directionClass,this.boundaryClass,{show:this.visible,"btn-group":e||!t,"d-flex":t&&e}]},menuClasses:function(){return[this.menuClass,{"dropdown-menu-right":this.right,show:this.visible}]},toggleClasses:function(){var t=this.split;return[this.toggleClass,{"dropdown-toggle-split":t,"dropdown-toggle-no-caret":this.noCaret&&!t}]}},render:function(t){var e=this.visible,n=this.variant,r=this.size,i=this.block,o=this.disabled,a=this.split,s=this.role,c=this.hide,l=this.toggle,u={variant:n,size:r,block:i,disabled:o},d=this.normalizeSlot(yt),h=this.hasNormalizedSlot(yt)?{}:Ji(this.html,this.text),f=t();if(a){var p=this.splitTo,m=this.splitHref,b=this.splitButtonType,g=xl(xl({},u),{},{variant:this.splitVariant||n});p?g.to=p:m?g.href=m:b&&(g.type=b),f=t(Vi,{class:this.splitClass,attrs:{id:this.safeId("_BV_button_")},props:g,domProps:h,on:{click:this.onSplitClick},ref:"button"},d),d=[t("span",{class:["sr-only"]},[this.toggleText])],h={}}var v=t(Vi,{staticClass:"dropdown-toggle",class:this.toggleClasses,attrs:{id:this.safeId("_BV_toggle_"),"aria-haspopup":"true","aria-expanded":Object(Ee["g"])(e)},props:xl(xl({},u),{},{tag:this.toggleTag,block:i&&!a}),domProps:h,on:{mousedown:this.onMousedown,click:l,keydown:l},ref:"toggle"},d),w=t("ul",{staticClass:"dropdown-menu",class:this.menuClasses,attrs:{role:s,tabindex:"-1","aria-labelledby":this.safeId(a?"_BV_button_":"_BV_toggle_")},on:{keydown:this.onKeydown},ref:"menu"},[!this.lazy||e?this.normalizeSlot(Ot,{hide:c}):t()]);return t("div",{staticClass:"dropdown b-dropdown",class:this.dropdownClasses,attrs:{id:this.safeId()}},[f,v,w])}});function El(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ll(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?El(Object(n),!0).forEach((function(e){Bl(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):El(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Bl(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Hl=Object(zn["j"])(pi,["event","routerTag"]),Fl=Object(kn["d"])(Object(zn["m"])(Ll(Ll({},Hl),{},{linkClass:Object(kn["c"])(pt["e"]),variant:Object(kn["c"])(pt["u"])})),a["I"]),Dl=i["default"].extend({name:a["I"],mixins:[Zr,Cn],inject:{bvDropdown:{default:null}},inheritAttrs:!1,props:Fl,computed:{computedAttrs:function(){return Ll(Ll({},this.bvAttrs),{},{role:"menuitem"})}},methods:{closeDropdown:function(){var t=this;De((function(){t.bvDropdown&&t.bvDropdown.hide(!0)}))},onClick:function(t){this.$emit(h,t),this.closeDropdown()}},render:function(t){var e=this.linkClass,n=this.variant,r=this.active,i=this.disabled,o=this.onClick,a=this.bvAttrs;return t("li",{class:a.class,style:a.style,attrs:{role:"presentation"}},[t(mi,{staticClass:"dropdown-item",class:[e,Bl({},"text-".concat(n),n&&!(r||i))],props:Object(kn["e"])(Hl,this.$props),attrs:this.computedAttrs,on:{click:o},ref:"item"},this.normalizeSlot())])}});function Rl(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Nl(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Rl(Object(n),!0).forEach((function(e){$l(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Rl(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function $l(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Ul=Object(kn["d"])({active:Object(kn["c"])(pt["g"],!1),activeClass:Object(kn["c"])(pt["u"],"active"),buttonClass:Object(kn["c"])(pt["e"]),disabled:Object(kn["c"])(pt["g"],!1),variant:Object(kn["c"])(pt["u"])},a["J"]),ql=i["default"].extend({name:a["J"],mixins:[Zr,Cn],inject:{bvDropdown:{default:null}},inheritAttrs:!1,props:Ul,computed:{computedAttrs:function(){return Nl(Nl({},this.bvAttrs),{},{role:"menuitem",type:"button",disabled:this.disabled})}},methods:{closeDropdown:function(){this.bvDropdown&&this.bvDropdown.hide(!0)},onClick:function(t){this.$emit(h,t),this.closeDropdown()}},render:function(t){var e,n=this.active,r=this.variant,i=this.bvAttrs;return t("li",{class:i.class,style:i.style,attrs:{role:"presentation"}},[t("button",{staticClass:"dropdown-item",class:[this.buttonClass,(e={},$l(e,this.activeClass,n),$l(e,"text-".concat(r),r&&!(n||this.disabled)),e)],attrs:this.computedAttrs,on:{click:this.onClick},ref:"button"},this.normalizeSlot())])}});function Wl(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Gl(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Wl(Object(n),!0).forEach((function(e){Yl(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Wl(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Yl(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Kl=Object(kn["d"])({id:Object(kn["c"])(pt["u"]),tag:Object(kn["c"])(pt["u"],"header"),variant:Object(kn["c"])(pt["u"])},a["H"]),Ql=i["default"].extend({name:a["H"],functional:!0,props:Kl,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.tag,a=n.variant;return t("li",Object(Vn["a"])(Object(zn["j"])(r,["attrs"]),{attrs:{role:"presentation"}}),[t(o,{staticClass:"dropdown-header",class:Yl({},"text-".concat(a),a),attrs:Gl(Gl({},r.attrs||{}),{},{id:n.id||null,role:qe(o,"header")?null:"heading"}),ref:"header"},i)])}});function Xl(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Jl(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Xl(Object(n),!0).forEach((function(e){Zl(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Xl(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Zl(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var tu=Object(kn["d"])({tag:Object(kn["c"])(pt["u"],"hr")},a["E"]),eu=i["default"].extend({name:a["E"],functional:!0,props:tu,render:function(t,e){var n=e.props,r=e.data;return t("li",Object(Vn["a"])(Object(zn["j"])(r,["attrs"]),{attrs:{role:"presentation"}}),[t(n.tag,{staticClass:"dropdown-divider",attrs:Jl(Jl({},r.attrs||{}),{},{role:"separator","aria-orientation":"horizontal"}),ref:"divider"})])}}),nu=Object(kn["d"])({id:Object(kn["c"])(pt["u"]),inline:Object(kn["c"])(pt["g"],!1),novalidate:Object(kn["c"])(pt["g"],!1),validated:Object(kn["c"])(pt["g"],!1)},a["M"]),ru=i["default"].extend({name:a["M"],functional:!0,props:nu,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t("form",Object(Vn["a"])(r,{class:{"form-inline":n.inline,"was-validated":n.validated},attrs:{id:n.id,novalidate:n.novalidate}}),i)}});function iu(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ou(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?iu(Object(n),!0).forEach((function(e){au(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):iu(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function au(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var su=Object(kn["d"])(Object(zn["m"])(ou(ou({},nu),{},{disabled:Object(kn["c"])(pt["g"],!1),formClass:Object(kn["c"])(pt["e"])})),a["F"]),cu=i["default"].extend({name:a["F"],functional:!0,props:su,render:function(t,e){var n=e.props,r=e.data,i=e.listeners,o=e.children;return t("li",Object(Vn["a"])(Object(zn["j"])(r,["attrs","on"]),{attrs:{role:"presentation"}}),[t(ru,{staticClass:"b-dropdown-form",class:[n.formClass,{disabled:n.disabled}],props:n,attrs:ou(ou({},r.attrs||{}),{},{disabled:n.disabled,tabindex:n.disabled?null:"-1"}),on:i,ref:"form"},o)])}});function lu(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var uu=Object(kn["d"])({tag:Object(kn["c"])(pt["u"],"p"),textClass:Object(kn["c"])(pt["e"]),variant:Object(kn["c"])(pt["u"])},a["K"]),du=i["default"].extend({name:a["K"],functional:!0,props:uu,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.tag,a=n.textClass,s=n.variant;return t("li",Object(Vn["a"])(Object(zn["j"])(r,["attrs"]),{attrs:{role:"presentation"}}),[t(o,{staticClass:"b-dropdown-text",class:[a,lu({},"text-".concat(s),s)],props:n,attrs:r.attrs||{},ref:"text"},i)])}});function hu(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function fu(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?hu(Object(n),!0).forEach((function(e){pu(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):hu(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function pu(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var mu=Object(kn["d"])({ariaDescribedby:Object(kn["c"])(pt["u"]),header:Object(kn["c"])(pt["u"]),headerClasses:Object(kn["c"])(pt["e"]),headerTag:Object(kn["c"])(pt["u"],"header"),headerVariant:Object(kn["c"])(pt["u"]),id:Object(kn["c"])(pt["u"])},a["G"]),bu=i["default"].extend({name:a["G"],functional:!0,props:mu,render:function(t,e){var n=e.props,r=e.data,i=e.slots,o=e.scopedSlots,a=n.id,s=n.variant,c=n.header,l=n.headerTag,u=i(),d=o||{},h={},f=a?"_bv_".concat(a,"_group_dd_header"):null,p=t();return(jn(It,d,u)||c)&&(p=t(l,{staticClass:"dropdown-header",class:[n.headerClasses,pu({},"text-".concat(s),s)],attrs:{id:f,role:qe(l,"header")?null:"heading"}},Mn(It,h,d,u)||c)),t("li",Object(Vn["a"])(Object(zn["j"])(r,["attrs"]),{attrs:{role:"presentation"}}),[p,t("ul",{staticClass:"list-unstyled",attrs:fu(fu({},r.attrs||{}),{},{id:a,role:"group","aria-describedby":[f,n.ariaDescribedBy].filter(An["a"]).join(" ").trim()||null})},Mn(Ot,h,d,u))])}}),gu=Object(r["b"])({components:{BDropdown:Il,BDd:Il,BDropdownItem:Dl,BDdItem:Dl,BDropdownItemButton:ql,BDropdownItemBtn:ql,BDdItemButton:ql,BDdItemBtn:ql,BDropdownHeader:Ql,BDdHeader:Ql,BDropdownDivider:eu,BDdDivider:eu,BDropdownForm:cu,BDdForm:cu,BDropdownText:du,BDdText:du,BDropdownGroup:bu,BDdGroup:bu}});function vu(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var wu=["iframe","embed","video","object","img","b-img","b-img-lazy"],yu=Object(kn["d"])({aspect:Object(kn["c"])(pt["u"],"16by9"),tag:Object(kn["c"])(pt["u"],"div"),type:Object(kn["c"])(pt["u"],"iframe",(function(t){return Ve(wu,t)}))},a["L"]),ku=i["default"].extend({name:a["L"],functional:!0,props:yu,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.aspect;return t(n.tag,{staticClass:"embed-responsive",class:vu({},"embed-responsive-".concat(o),o),ref:r.ref},[t(n.type,Object(Vn["a"])(Object(zn["j"])(r,["ref"]),{staticClass:"embed-responsive-item"}),i)])}}),_u=Object(r["b"])({components:{BEmbed:ku}}),Ou=n("a874"),zu='Setting prop "options" to an object is deprecated. Use the array format instead.',Au=Object(kn["d"])({disabledField:Object(kn["c"])(pt["u"],"disabled"),htmlField:Object(kn["c"])(pt["u"],"html"),options:Object(kn["c"])(pt["d"],[]),textField:Object(kn["c"])(pt["u"],"text"),valueField:Object(kn["c"])(pt["u"],"value")},"formOptionControls"),ju=i["default"].extend({props:Au,computed:{formOptions:function(){return this.normalizeOptions(this.options)}},methods:{normalizeOption:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;if(Object(Me["k"])(t)){var n=Object(Ou["a"])(t,this.valueField),r=Object(Ou["a"])(t,this.textField);return{value:Object(Me["o"])(n)?e||r:n,text:Xi(String(Object(Me["o"])(r)?e:r)),html:Object(Ou["a"])(t,this.htmlField),disabled:Boolean(Object(Ou["a"])(t,this.disabledField))}}return{value:e||t,text:Xi(String(t)),disabled:!1}},normalizeOptions:function(t){var e=this;return Object(Me["a"])(t)?t.map((function(t){return e.normalizeOption(t)})):Object(Me["k"])(t)?(Object(Vs["a"])(zu,this.$options.name),Object(zn["h"])(t).map((function(n){return e.normalizeOption(t[n]||{},n)}))):[]}}});function Mu(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Cu(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Mu(Object(n),!0).forEach((function(e){Vu(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Mu(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Vu(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Su=Object(kn["d"])(Object(zn["m"])(Cu(Cu({},Au),{},{id:Object(kn["c"])(pt["u"],void 0,!0)})),a["Q"]),xu=i["default"].extend({name:a["Q"],mixins:[ju,Cn],props:Su,render:function(t){var e=this.id,n=this.formOptions.map((function(e,n){var r=e.value,i=e.text,o=e.html,a=e.disabled;return t("option",{attrs:{value:r,disabled:a},domProps:Ji(o,i),key:"option_".concat(n)})}));return t("datalist",{attrs:{id:e}},[n,this.normalizeSlot()])}});function Tu(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Pu,Iu,Eu=Object(kn["d"])({id:Object(kn["c"])(pt["u"]),inline:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"small"),textVariant:Object(kn["c"])(pt["u"],"muted")},a["hb"]),Lu=i["default"].extend({name:a["hb"],functional:!0,props:Eu,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.tag,Object(Vn["a"])(r,{class:Tu({"form-text":!n.inline},"text-".concat(n.textVariant),n.textVariant),attrs:{id:n.id}}),i)}}),Bu=Object(kn["d"])({ariaLive:Object(kn["c"])(pt["u"]),forceShow:Object(kn["c"])(pt["g"],!1),id:Object(kn["c"])(pt["u"]),role:Object(kn["c"])(pt["u"]),state:Object(kn["c"])(pt["g"],null),tag:Object(kn["c"])(pt["u"],"div"),tooltip:Object(kn["c"])(pt["g"],!1)},a["V"]),Hu=i["default"].extend({name:a["V"],functional:!0,props:Bu,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.tooltip,a=n.ariaLive,s=!0===n.forceShow||!1===n.state;return t(n.tag,Object(Vn["a"])(r,{class:{"d-block":s,"invalid-feedback":!o,"invalid-tooltip":o},attrs:{id:n.id||null,role:n.role||null,"aria-live":a||null,"aria-atomic":a?"true":null}}),i)}}),Fu=Object(kn["d"])({ariaLive:Object(kn["c"])(pt["u"]),forceShow:Object(kn["c"])(pt["g"],!1),id:Object(kn["c"])(pt["u"]),role:Object(kn["c"])(pt["u"]),state:Object(kn["c"])(pt["g"],null),tag:Object(kn["c"])(pt["u"],"div"),tooltip:Object(kn["c"])(pt["g"],!1)},a["kb"]),Du=i["default"].extend({name:a["kb"],functional:!0,props:Fu,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.tooltip,a=n.ariaLive,s=!0===n.forceShow||!0===n.state;return t(n.tag,Object(Vn["a"])(r,{class:{"d-block":s,"valid-feedback":!o,"valid-tooltip":o},attrs:{id:n.id||null,role:n.role||null,"aria-live":a||null,"aria-atomic":a?"true":null}}),i)}}),Ru=Object(kn["d"])({tag:Object(kn["c"])(pt["u"],"div")},a["ab"]),Nu=i["default"].extend({name:a["ab"],functional:!0,props:Ru,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.tag,Object(Vn["a"])(r,{staticClass:"form-row"}),i)}}),$u=Object(r["b"])({components:{BForm:ru,BFormDatalist:xu,BDatalist:xu,BFormText:Lu,BFormInvalidFeedback:Hu,BFormFeedback:Hu,BFormValidFeedback:Du,BFormRow:Nu}}),Uu=function(t,e){for(var n=0;n<t.length;n++)if(Yr(t[n],e))return n;return-1},qu="input, textarea, select",Wu=Object(kn["d"])({autofocus:Object(kn["c"])(pt["g"],!1),disabled:Object(kn["c"])(pt["g"],!1),form:Object(kn["c"])(pt["u"]),id:Object(kn["c"])(pt["u"]),name:Object(kn["c"])(pt["u"]),required:Object(kn["c"])(pt["g"],!1)},"formControls"),Gu=i["default"].extend({props:Wu,mounted:function(){this.handleAutofocus()},activated:function(){this.handleAutofocus()},methods:{handleAutofocus:function(){var t=this;this.$nextTick((function(){De((function(){var e=t.$el;t.autofocus&&Ge(e)&&(Je(e,qu)||(e=Xe(qu,e)),wn(e))}))}))}}}),Yu=Object(kn["d"])({plain:Object(kn["c"])(pt["g"],!1)},"formControls"),Ku=i["default"].extend({props:Yu,computed:{custom:function(){return!this.plain}}}),Qu=Object(kn["d"])({size:Object(kn["c"])(pt["u"])},"formControls"),Xu=i["default"].extend({props:Qu,computed:{sizeFormClass:function(){return[this.size?"form-control-".concat(this.size):null]}}}),Ju=Object(kn["d"])({state:Object(kn["c"])(pt["g"],null)},"formState"),Zu=i["default"].extend({props:Ju,computed:{computedState:function(){return Object(Me["b"])(this.state)?this.state:null},stateClass:function(){var t=this.computedState;return!0===t?"is-valid":!1===t?"is-invalid":null},computedAriaInvalid:function(){var t=this.ariaInvalid;return!0===t||"true"===t||""===t||!1===this.computedState?"true":t}}});function td(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ed(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?td(Object(n),!0).forEach((function(e){nd(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):td(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function nd(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var rd,id=On("checked",{defaultValue:null}),od=id.mixin,ad=id.props,sd=id.prop,cd=id.event,ld=Object(kn["d"])(Object(zn["m"])(ed(ed(ed(ed(ed(ed(ed({},ia),ad),Wu),Qu),Ju),Yu),{},{ariaLabel:Object(kn["c"])(pt["u"]),ariaLabelledby:Object(kn["c"])(pt["u"]),button:Object(kn["c"])(pt["g"],!1),buttonVariant:Object(kn["c"])(pt["u"]),inline:Object(kn["c"])(pt["g"],!1),value:Object(kn["c"])(pt["a"])})),"formRadioCheckControls"),ud=i["default"].extend({mixins:[Zr,oa,od,Cn,Gu,Xu,Zu,Ku],inheritAttrs:!1,props:ld,data:function(){return{localChecked:this.isGroup?this.bvGroup[sd]:this[sd],hasFocus:!1}},computed:{computedLocalChecked:{get:function(){return this.isGroup?this.bvGroup.localChecked:this.localChecked},set:function(t){this.isGroup?this.bvGroup.localChecked=t:this.localChecked=t}},isChecked:function(){return Yr(this.value,this.computedLocalChecked)},isRadio:function(){return!0},isGroup:function(){return!!this.bvGroup},isBtnMode:function(){return this.isGroup?this.bvGroup.buttons:this.button},isPlain:function(){return!this.isBtnMode&&(this.isGroup?this.bvGroup.plain:this.plain)},isCustom:function(){return!this.isBtnMode&&!this.isPlain},isSwitch:function(){return!(this.isBtnMode||this.isRadio||this.isPlain)&&(this.isGroup?this.bvGroup.switches:this.switch)},isInline:function(){return this.isGroup?this.bvGroup.inline:this.inline},isDisabled:function(){return this.isGroup&&this.bvGroup.disabled||this.disabled},isRequired:function(){return this.computedName&&(this.isGroup?this.bvGroup.required:this.required)},computedName:function(){return(this.isGroup?this.bvGroup.groupName:this.name)||null},computedForm:function(){return(this.isGroup?this.bvGroup.form:this.form)||null},computedSize:function(){return(this.isGroup?this.bvGroup.size:this.size)||""},computedState:function(){return this.isGroup?this.bvGroup.computedState:Object(Me["b"])(this.state)?this.state:null},computedButtonVariant:function(){var t=this.buttonVariant;return t||(this.isGroup&&this.bvGroup.buttonVariant?this.bvGroup.buttonVariant:"secondary")},buttonClasses:function(){var t,e=this.computedSize;return["btn","btn-".concat(this.computedButtonVariant),(t={},nd(t,"btn-".concat(e),e),nd(t,"disabled",this.isDisabled),nd(t,"active",this.isChecked),nd(t,"focus",this.hasFocus),t)]},computedAttrs:function(){var t=this.isDisabled,e=this.isRequired;return ed(ed({},this.bvAttrs),{},{id:this.safeId(),type:this.isRadio?"radio":"checkbox",name:this.computedName,form:this.computedForm,disabled:t,required:e,"aria-required":e||null,"aria-label":this.ariaLabel||null,"aria-labelledby":this.ariaLabelledby||null})}},watch:(Pu={},nd(Pu,sd,(function(){this["".concat(sd,"Watcher")].apply(this,arguments)})),nd(Pu,"computedLocalChecked",(function(){this.computedLocalCheckedWatcher.apply(this,arguments)})),Pu),methods:(Iu={},nd(Iu,"".concat(sd,"Watcher"),(function(t){Yr(t,this.computedLocalChecked)||(this.computedLocalChecked=t)})),nd(Iu,"computedLocalCheckedWatcher",(function(t,e){Yr(t,e)||this.$emit(cd,t)})),nd(Iu,"handleChange",(function(t){var e=this,n=t.target.checked,r=this.value,i=n?r:null;this.computedLocalChecked=r,this.$nextTick((function(){e.$emit(u,i),e.isGroup&&e.bvGroup.$emit(u,i)}))})),nd(Iu,"handleFocus",(function(t){t.target&&("focus"===t.type?this.hasFocus=!0:"blur"===t.type&&(this.hasFocus=!1))})),nd(Iu,"focus",(function(){this.isDisabled||wn(this.$refs.input)})),nd(Iu,"blur",(function(){this.isDisabled||yn(this.$refs.input)})),Iu),render:function(t){var e=this.isRadio,n=this.isBtnMode,r=this.isPlain,i=this.isCustom,o=this.isInline,a=this.isSwitch,s=this.computedSize,c=this.bvAttrs,l=this.normalizeSlot(),u=t("input",{class:[{"form-check-input":r,"custom-control-input":i,"position-static":r&&!l},n?"":this.stateClass],directives:[{name:"model",value:this.computedLocalChecked}],attrs:this.computedAttrs,domProps:{value:this.value,checked:this.isChecked},on:ed({change:this.handleChange},n?{focus:this.handleFocus,blur:this.handleFocus}:{}),key:"input",ref:"input"});if(n){var d=t("label",{class:this.buttonClasses},[u,l]);return this.isGroup||(d=t("div",{class:["btn-group-toggle","d-inline-block"]},[d])),d}var h=t();return r&&!l||(h=t("label",{class:{"form-check-label":r,"custom-control-label":i},attrs:{for:this.safeId()}},l)),t("div",{class:[nd({"form-check":r,"form-check-inline":r&&o,"custom-control":i,"custom-control-inline":i&&o,"custom-checkbox":i&&!e&&!a,"custom-switch":a,"custom-radio":i&&e},"b-custom-control-".concat(s),s&&!n),c.class],style:c.style},[u,h])}});function dd(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function hd(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?dd(Object(n),!0).forEach((function(e){fd(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):dd(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function fd(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var pd="indeterminate",md=lt+pd,bd=Object(kn["d"])(Object(zn["m"])(hd(hd({},ld),{},(rd={},fd(rd,pd,Object(kn["c"])(pt["g"],!1)),fd(rd,"switch",Object(kn["c"])(pt["g"],!1)),fd(rd,"uncheckedValue",Object(kn["c"])(pt["a"],!1)),fd(rd,"value",Object(kn["c"])(pt["a"],!0)),rd))),a["O"]),gd=i["default"].extend({name:a["O"],mixins:[ud],inject:{bvGroup:{from:"bvCheckGroup",default:null}},props:bd,computed:{isChecked:function(){var t=this.value,e=this.computedLocalChecked;return Object(Me["a"])(e)?Uu(e,t)>-1:Yr(e,t)},isRadio:function(){return!1}},watch:fd({},pd,(function(t,e){Yr(t,e)||this.setIndeterminate(t)})),mounted:function(){this.setIndeterminate(this[pd])},methods:{computedLocalCheckedWatcher:function(t,e){if(!Yr(t,e)){this.$emit(cd,t);var n=this.$refs.input;n&&this.$emit(md,n.indeterminate)}},handleChange:function(t){var e=this,n=t.target,r=n.checked,i=n.indeterminate,o=this.value,a=this.uncheckedValue,s=this.computedLocalChecked;if(Object(Me["a"])(s)){var c=Uu(s,o);r&&c<0?s=s.concat(o):!r&&c>-1&&(s=s.slice(0,c).concat(s.slice(c+1)))}else s=r?o:a;this.computedLocalChecked=s,this.$nextTick((function(){e.$emit(u,s),e.isGroup&&e.bvGroup.$emit(u,s),e.$emit(md,i)}))},setIndeterminate:function(t){Object(Me["a"])(this.computedLocalChecked)&&(t=!1);var e=this.$refs.input;e&&(e.indeterminate=t,this.$emit(md,t))}}});function vd(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function wd(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?vd(Object(n),!0).forEach((function(e){yd(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):vd(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function yd(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var kd,_d=Object(kn["d"])(Object(zn["m"])(wd(wd(wd(wd(wd({},ia),Wu),ld),Qu),Ju)),a["W"]),Od=i["default"].extend({name:a["W"],mixins:[oa,ud,Gu,Xu,Zu],inject:{bvGroup:{from:"bvRadioGroup",default:!1}},props:_d,watch:{computedLocalChecked:function(t,e){Yr(t,e)||this.$emit(cd,t)}}});function zd(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ad(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?zd(Object(n),!0).forEach((function(e){jd(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):zd(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function jd(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Md,Cd=["aria-describedby","aria-labelledby"],Vd=On("checked"),Sd=Vd.mixin,xd=Vd.props,Td=Vd.prop,Pd=Vd.event,Id=Object(kn["d"])(Object(zn["m"])(Ad(Ad(Ad(Ad(Ad(Ad(Ad(Ad({},ia),xd),Wu),Au),Qu),Ju),Yu),{},{ariaInvalid:Object(kn["c"])(pt["j"],!1),buttonVariant:Object(kn["c"])(pt["u"]),buttons:Object(kn["c"])(pt["g"],!1),stacked:Object(kn["c"])(pt["g"],!1),validated:Object(kn["c"])(pt["g"],!1)})),"formRadioCheckGroups"),Ed=i["default"].extend({mixins:[oa,Sd,Cn,Gu,ju,Xu,Zu,Ku],inheritAttrs:!1,props:Id,data:function(){return{localChecked:this[Td]}},computed:{inline:function(){return!this.stacked},groupName:function(){return this.name||this.safeId()},groupClasses:function(){var t=this.inline,e=this.size,n=this.validated,r={"was-validated":n};return this.buttons&&(r=[r,"btn-group-toggle",jd({"btn-group":t,"btn-group-vertical":!t},"btn-group-".concat(e),e)]),r}},watch:(kd={},jd(kd,Td,(function(t){Yr(t,this.localChecked)||(this.localChecked=t)})),jd(kd,"localChecked",(function(t,e){Yr(t,e)||this.$emit(Pd,t)})),kd),render:function(t){var e=this,n=this.isRadioGroup,r=Object(zn["k"])(this.$attrs,Cd),i=n?Od:gd,o=this.formOptions.map((function(n,o){var a="BV_option_".concat(o);return t(i,{props:{disabled:n.disabled||!1,id:e.safeId(a),value:n.value},attrs:r,key:a},[t("span",{domProps:Ji(n.html,n.text)})])}));return t("div",{class:[this.groupClasses,"bv-no-focus-ring"],attrs:Ad(Ad({},Object(zn["j"])(this.$attrs,Cd)),{},{"aria-invalid":this.computedAriaInvalid,"aria-required":this.required?"true":null,id:this.safeId(),role:n?"radiogroup":"group",tabindex:"-1"})},[this.normalizeSlot(xt),o,this.normalizeSlot()])}});function Ld(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Bd(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ld(Object(n),!0).forEach((function(e){Hd(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ld(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Hd(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Fd=Object(kn["d"])(Object(zn["m"])(Bd(Bd({},Id),{},(Md={},Hd(Md,Td,Object(kn["c"])(pt["b"],[])),Hd(Md,"switches",Object(kn["c"])(pt["g"],!1)),Md))),a["P"]),Dd=i["default"].extend({name:a["P"],mixins:[Ed],provide:function(){return{bvCheckGroup:this}},props:Fd,computed:{isRadioGroup:function(){return!1}}}),Rd=Object(r["b"])({components:{BFormCheckbox:gd,BCheckbox:gd,BCheck:gd,BFormCheckboxGroup:Dd,BCheckboxGroup:Dd,BCheckGroup:Dd}}),Nd="__BV_hover_handler__",$d="mouseenter",Ud="mouseleave",qd=function(t){var e=function(e){t(e.type===$d,e)};return e.fn=t,e},Wd=function(t,e,n){In(t,e,$d,n,ft),In(t,e,Ud,n,ft)},Gd=function(t,e){var n=e.value,r=void 0===n?null:n;if(Ae["i"]){var i=t[Nd],o=Object(Me["f"])(i),a=!(o&&i.fn===r);o&&a&&(Wd(!1,t,i),delete t[Nd]),Object(Me["f"])(r)&&a&&(t[Nd]=qd(r),Wd(!0,t,t[Nd]))}},Yd={bind:Gd,componentUpdated:Gd,unbind:function(t){Gd(t,{value:null})}};function Kd(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Qd(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Kd(Object(n),!0).forEach((function(e){Xd(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Kd(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Xd(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Jd,Zd=Object(zn["m"])(Qd(Qd(Qd(Qd(Qd(Qd({},ia),Qu),Ju),Object(zn["j"])(Cl,["disabled"])),Object(zn["j"])(Wu,["autofocus"])),{},{buttonOnly:Object(kn["c"])(pt["g"],!1),buttonVariant:Object(kn["c"])(pt["u"],"secondary"),formattedValue:Object(kn["c"])(pt["u"]),labelSelected:Object(kn["c"])(pt["u"]),lang:Object(kn["c"])(pt["u"]),menuClass:Object(kn["c"])(pt["e"]),placeholder:Object(kn["c"])(pt["u"]),readonly:Object(kn["c"])(pt["g"],!1),rtl:Object(kn["c"])(pt["g"],null),value:Object(kn["c"])(pt["u"],"")})),th=i["default"].extend({name:a["N"],directives:{"b-hover":Yd},mixins:[oa,Xu,Zu,Vl,Cn],props:Zd,data:function(){return{isHovered:!1,hasFocus:!1}},computed:{idButton:function(){return this.safeId()},idLabel:function(){return this.safeId("_value_")},idMenu:function(){return this.safeId("_dialog_")},idWrapper:function(){return this.safeId("_outer_")},computedDir:function(){return!0===this.rtl?"rtl":!1===this.rtl?"ltr":null}},methods:{focus:function(){this.disabled||wn(this.$refs.toggle)},blur:function(){this.disabled||yn(this.$refs.toggle)},setFocus:function(t){this.hasFocus="focus"===t.type},handleHover:function(t){this.isHovered=t}},render:function(t){var e,n=this.idButton,r=this.idLabel,i=this.idMenu,o=this.idWrapper,a=this.disabled,s=this.readonly,c=this.required,l=this.name,u=this.state,d=this.visible,h=this.size,f=this.isHovered,p=this.hasFocus,m=this.labelSelected,b=this.buttonVariant,g=this.buttonOnly,v=Object(Ee["g"])(this.value)||"",w=!1===u||c&&!v,y={isHovered:f,hasFocus:p,state:u,opened:d},k=t("button",{staticClass:"btn",class:(e={},Xd(e,"btn-".concat(b),g),Xd(e,"btn-".concat(h),h),Xd(e,"h-auto",!g),Xd(e,"dropdown-toggle",g),Xd(e,"dropdown-toggle-no-caret",g),e),attrs:{id:n,type:"button",disabled:a,"aria-haspopup":"dialog","aria-expanded":d?"true":"false","aria-invalid":w?"true":null,"aria-required":c?"true":null},directives:[{name:"b-hover",value:this.handleHover}],on:{mousedown:this.onMousedown,click:this.toggle,keydown:this.toggle,"!focus":this.setFocus,"!blur":this.setFocus},ref:"toggle"},[this.hasNormalizedSlot(yt)?this.normalizeSlot(yt,y):t(Tr["eh"],{props:{scale:1.25}})]),_=t();l&&!a&&(_=t("input",{attrs:{type:"hidden",name:l||null,form:this.form||null,value:v}}));var O=t("div",{staticClass:"dropdown-menu",class:[this.menuClass,{show:d,"dropdown-menu-right":this.right}],attrs:{id:i,role:"dialog",tabindex:"-1","aria-modal":"false","aria-labelledby":r},on:{keydown:this.onKeydown},ref:"menu"},[this.normalizeSlot(Ot,{opened:d})]),z=t("label",{class:g?"sr-only":["form-control",{"text-muted":!v},this.stateClass,this.sizeFormClass],attrs:{id:r,for:n,"aria-invalid":w?"true":null,"aria-required":c?"true":null},directives:[{name:"b-hover",value:this.handleHover}],on:{"!click":function(t){En(t,{preventDefault:!1})}}},[v?this.formattedValue||v:this.placeholder||"",v&&m?t("bdi",{staticClass:"sr-only"},m):""]);return t("div",{staticClass:"b-form-btn-label-control dropdown",class:[this.directionClass,this.boundaryClass,[{"btn-group":g,"form-control":!g,focus:p&&!g,show:d,"is-valid":!0===u,"is-invalid":!1===u},g?null:this.sizeFormClass]],attrs:{id:o,role:g?null:"group",lang:this.lang||null,dir:this.computedDir,"aria-disabled":a,"aria-readonly":s&&!a,"aria-labelledby":r,"aria-invalid":!1===u||c&&!v?"true":null,"aria-required":c?"true":null}},[k,_,O,z])}});function eh(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function nh(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?eh(Object(n),!0).forEach((function(e){rh(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):eh(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function rh(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ih,oh=On("value",{type:pt["k"]}),ah=oh.mixin,sh=oh.props,ch=oh.prop,lh=oh.event,uh=Object(zn["j"])(pa,["block","hidden","id","noKeyNav","roleDescription","value","width"]),dh=Object(zn["j"])(Zd,["formattedValue","id","lang","rtl","value"]),hh=Object(kn["d"])(Object(zn["m"])(nh(nh(nh(nh(nh({},ia),sh),uh),dh),{},{calendarWidth:Object(kn["c"])(pt["u"],"270px"),closeButton:Object(kn["c"])(pt["g"],!1),closeButtonVariant:Object(kn["c"])(pt["u"],"outline-secondary"),dark:Object(kn["c"])(pt["g"],!1),labelCloseButton:Object(kn["c"])(pt["u"],"Close"),labelResetButton:Object(kn["c"])(pt["u"],"Reset"),labelTodayButton:Object(kn["c"])(pt["u"],"Select today"),noCloseOnSelect:Object(kn["c"])(pt["g"],!1),resetButton:Object(kn["c"])(pt["g"],!1),resetButtonVariant:Object(kn["c"])(pt["u"],"outline-danger"),resetValue:Object(kn["c"])(pt["k"]),todayButton:Object(kn["c"])(pt["g"],!1),todayButtonVariant:Object(kn["c"])(pt["u"],"outline-primary")})),a["R"]),fh=i["default"].extend({name:a["R"],mixins:[oa,ah],props:hh,data:function(){return{localYMD:No(this[ch])||"",isVisible:!1,localLocale:null,isRTL:!1,formattedValue:"",activeYMD:""}},computed:{calendarYM:function(){return this.activeYMD.slice(0,-3)},computedLang:function(){return(this.localLocale||"").replace(/-u-.*$/i,"")||null},computedResetValue:function(){return No(ea(this.resetValue))||""}},watch:(Jd={},rh(Jd,ch,(function(t){this.localYMD=No(t)||""})),rh(Jd,"localYMD",(function(t){this.isVisible&&this.$emit(lh,this.valueAsDate?Ro(t)||null:t||"")})),rh(Jd,"calendarYM",(function(t,e){if(t!==e&&e)try{this.$refs.control.updatePopper()}catch(n){}})),Jd),methods:{focus:function(){this.disabled||wn(this.$refs.control)},blur:function(){this.disabled||yn(this.$refs.control)},setAndClose:function(t){var e=this;this.localYMD=t,this.noCloseOnSelect||this.$nextTick((function(){e.$refs.control.hide(!0)}))},onSelected:function(t){var e=this;this.$nextTick((function(){e.setAndClose(t)}))},onInput:function(t){this.localYMD!==t&&(this.localYMD=t)},onContext:function(t){var e=t.activeYMD,n=t.isRTL,r=t.locale,i=t.selectedYMD,o=t.selectedFormatted;this.isRTL=n,this.localLocale=r,this.formattedValue=o,this.localYMD=i,this.activeYMD=e,this.$emit(p,t)},onTodayButton:function(){this.setAndClose(No(ea(Do(),this.min,this.max)))},onResetButton:function(){this.setAndClose(this.computedResetValue)},onCloseButton:function(){this.$refs.control.hide(!0)},onShow:function(){this.isVisible=!0},onShown:function(){var t=this;this.$nextTick((function(){wn(t.$refs.calendar),t.$emit(Z)}))},onHidden:function(){this.isVisible=!1,this.$emit(C)},defaultButtonFn:function(t){var e=t.isHovered,n=t.hasFocus;return this.$createElement(e||n?Tr["Qe"]:Tr["Zd"],{attrs:{"aria-hidden":"true"}})}},render:function(t){var e=this.localYMD,n=this.disabled,r=this.readonly,i=this.dark,o=this.$props,a=this.$scopedSlots,s=Object(Me["p"])(this.placeholder)?this.labelNoDateSelected:this.placeholder,c=[];if(this.todayButton){var l=this.labelTodayButton;c.push(t(Vi,{props:{disabled:n||r,size:"sm",variant:this.todayButtonVariant},attrs:{"aria-label":l||null},on:{click:this.onTodayButton}},l))}if(this.resetButton){var u=this.labelResetButton;c.push(t(Vi,{props:{disabled:n||r,size:"sm",variant:this.resetButtonVariant},attrs:{"aria-label":u||null},on:{click:this.onResetButton}},u))}if(this.closeButton){var d=this.labelCloseButton;c.push(t(Vi,{props:{disabled:n,size:"sm",variant:this.closeButtonVariant},attrs:{"aria-label":d||null},on:{click:this.onCloseButton}},d))}c.length>0&&(c=[t("div",{staticClass:"b-form-date-controls d-flex flex-wrap",class:{"justify-content-between":c.length>1,"justify-content-end":c.length<2}},c)]);var h=t(ma,{staticClass:"b-form-date-calendar w-100",props:nh(nh({},Object(kn["e"])(uh,o)),{},{hidden:!this.isVisible,value:e,valueAsDate:!1,width:this.calendarWidth}),on:{selected:this.onSelected,input:this.onInput,context:this.onContext},scopedSlots:Object(zn["k"])(a,["nav-prev-decade","nav-prev-year","nav-prev-month","nav-this-month","nav-next-month","nav-next-year","nav-next-decade"]),key:"calendar",ref:"calendar"},c);return t(th,{staticClass:"b-form-datepicker",props:nh(nh({},Object(kn["e"])(dh,o)),{},{formattedValue:e?this.formattedValue:"",id:this.safeId(),lang:this.computedLang,menuClass:[{"bg-dark":i,"text-light":i},this.menuClass],placeholder:s,rtl:this.isRTL,value:e}),on:{show:this.onShow,shown:this.onShown,hidden:this.onHidden},scopedSlots:rh({},yt,a[yt]||this.defaultButtonFn),ref:"control"},[h])}}),ph=Object(r["b"])({components:{BFormDatepicker:fh,BDatepicker:fh}});function mh(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function bh(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?mh(Object(n),!0).forEach((function(e){gh(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):mh(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function gh(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var vh=On("value",{type:[pt["b"],je["b"]],defaultValue:null,validator:function(t){return""===t?(Object(Vs["a"])(Oh,a["S"]),!0):Object(Me["p"])(t)||zh(t)}}),wh=vh.mixin,yh=vh.props,kh=vh.prop,_h=vh.event,Oh='Setting "value"/"v-model" to an empty string for reset is deprecated. Set to "null" instead.',zh=function t(e){return Object(Me["e"])(e)||Object(Me["a"])(e)&&e.every((function(e){return t(e)}))},Ah=function(t){return Object(Me["f"])(t.getAsEntry)?t.getAsEntry():Object(Me["f"])(t.webkitGetAsEntry)?t.webkitGetAsEntry():null},jh=function(t){var e=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];return Promise.all(Ce(t).filter((function(t){return"file"===t.kind})).map((function(t){var n=Ah(t);if(n){if(n.isDirectory&&e)return Mh(n.createReader(),"".concat(n.name,"/"));if(n.isFile)return new Promise((function(t){n.file((function(e){e.$path="",t(e)}))}))}return null})).filter(An["a"]))},Mh=function t(e){var n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"";return new Promise((function(r){var i=[],o=function o(){e.readEntries((function(e){0===e.length?r(Promise.all(i).then((function(t){return Te(t)}))):(i.push(Promise.all(e.map((function(e){if(e){if(e.isDirectory)return t(e.createReader(),"".concat(n).concat(e.name,"/"));if(e.isFile)return new Promise((function(t){e.file((function(e){e.$path="".concat(n).concat(e.name),t(e)}))}))}return null})).filter(An["a"]))),o())}))};o()}))},Ch=Object(kn["d"])(Object(zn["m"])(bh(bh(bh(bh(bh(bh(bh({},ia),yh),Wu),Yu),Ju),Qu),{},{accept:Object(kn["c"])(pt["u"],""),browseText:Object(kn["c"])(pt["u"],"Browse"),capture:Object(kn["c"])(pt["g"],!1),directory:Object(kn["c"])(pt["g"],!1),dropPlaceholder:Object(kn["c"])(pt["u"],"Drop files here"),fileNameFormatter:Object(kn["c"])(pt["l"]),multiple:Object(kn["c"])(pt["g"],!1),noDrop:Object(kn["c"])(pt["g"],!1),noDropPlaceholder:Object(kn["c"])(pt["u"],"Not allowed"),noTraverse:Object(kn["c"])(pt["g"],!1),placeholder:Object(kn["c"])(pt["u"],"No file chosen")})),a["S"]),Vh=i["default"].extend({name:a["S"],mixins:[Zr,oa,wh,Cn,Gu,Zu,Ku,Cn],inheritAttrs:!1,props:Ch,data:function(){return{files:[],dragging:!1,dropAllowed:!this.noDrop,hasFocus:!1}},computed:{computedAccept:function(){var t=this.accept;return t=(t||"").trim().split(/[,\s]+/).filter(An["a"]),0===t.length?null:t.map((function(t){var e="name",n="^",r="$";Sn["k"].test(t)?n="":(e="type",Sn["y"].test(t)&&(r=".+$",t=t.slice(0,-1))),t=Object(Ee["a"])(t);var i=new RegExp("".concat(n).concat(t).concat(r));return{rx:i,prop:e}}))},computedCapture:function(){var t=this.capture;return!0===t||""===t||(t||null)},computedAttrs:function(){var t=this.name,e=this.disabled,n=this.required,r=this.form,i=this.computedCapture,o=this.accept,a=this.multiple,s=this.directory;return bh(bh({},this.bvAttrs),{},{type:"file",id:this.safeId(),name:t,disabled:e,required:n,form:r||null,capture:i,accept:o||null,multiple:a,directory:s,webkitdirectory:s,"aria-required":n?"true":null})},computedFileNameFormatter:function(){var t=this.fileNameFormatter;return Object(kn["b"])(t)?t:this.defaultFileNameFormatter},clonedFiles:function(){return Object(Wr["a"])(this.files)},flattenedFiles:function(){return Pe(this.files)},fileNames:function(){return this.flattenedFiles.map((function(t){return t.name}))},labelContent:function(){if(this.dragging&&!this.noDrop)return this.normalizeSlot(jt,{allowed:this.dropAllowed})||(this.dropAllowed?this.dropPlaceholder:this.$createElement("span",{staticClass:"text-danger"},this.noDropPlaceholder));if(0===this.files.length)return this.normalizeSlot(ue)||this.placeholder;var t=this.flattenedFiles,e=this.clonedFiles,n=this.fileNames,r=this.computedFileNameFormatter;return this.hasNormalizedSlot(St)?this.normalizeSlot(St,{files:t,filesTraversed:e,names:n}):r(t,e,n)}},watch:(ih={},gh(ih,kh,(function(t){(!t||Object(Me["a"])(t)&&0===t.length)&&this.reset()})),gh(ih,"files",(function(t,e){if(!Yr(t,e)){var n=this.multiple,r=this.noTraverse,i=!n||r?Pe(t):t;this.$emit(_h,n?i:i[0]||null)}})),ih),created:function(){this.$_form=null},mounted:function(){var t=Ze("form",this.$el);t&&(Tn(t,"reset",this.reset,ht),this.$_form=t)},beforeDestroy:function(){var t=this.$_form;t&&Pn(t,"reset",this.reset,ht)},methods:{isFileValid:function(t){if(!t)return!1;var e=this.computedAccept;return!e||e.some((function(e){return e.rx.test(t[e.prop])}))},isFilesArrayValid:function(t){var e=this;return Object(Me["a"])(t)?t.every((function(t){return e.isFileValid(t)})):this.isFileValid(t)},defaultFileNameFormatter:function(t,e,n){return n.join(", ")},setFiles:function(t){this.dropAllowed=!this.noDrop,this.dragging=!1,this.files=this.multiple?this.directory?t:Pe(t):Pe(t).slice(0,1)},setInputFiles:function(t){try{var e=new ClipboardEvent("").clipboardData||new DataTransfer;Pe(Object(Wr["a"])(t)).forEach((function(t){delete t.$path,e.items.add(t)})),this.$refs.input.files=e.files}catch(n){}},reset:function(){try{var t=this.$refs.input;t.value="",t.type="",t.type="file"}catch(e){}this.files=[]},handleFiles:function(t){var e=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(e){var n=t.filter(this.isFilesArrayValid);n.length>0&&(this.setFiles(n),this.setInputFiles(n))}else this.setFiles(t)},focusHandler:function(t){this.plain||"focusout"===t.type?this.hasFocus=!1:this.hasFocus=!0},onChange:function(t){var e=this,n=t.type,r=t.target,i=t.dataTransfer,o=void 0===i?{}:i,a="drop"===n;this.$emit(u,t);var s=Ce(o.items||[]);if(Ae["f"]&&s.length>0&&!Object(Me["g"])(Ah(s[0])))jh(s,this.directory).then((function(t){return e.handleFiles(t,a)}));else{var c=Ce(r.files||o.files||[]).map((function(t){return t.$path=t.webkitRelativePath||"",t}));this.handleFiles(c,a)}},onDragenter:function(t){En(t),this.dragging=!0;var e=t.dataTransfer,n=void 0===e?{}:e;if(this.noDrop||this.disabled||!this.dropAllowed)return n.dropEffect="none",void(this.dropAllowed=!1);n.dropEffect="copy"},onDragover:function(t){En(t),this.dragging=!0;var e=t.dataTransfer,n=void 0===e?{}:e;if(this.noDrop||this.disabled||!this.dropAllowed)return n.dropEffect="none",void(this.dropAllowed=!1);n.dropEffect="copy"},onDragleave:function(t){var e=this;En(t),this.$nextTick((function(){e.dragging=!1,e.dropAllowed=!e.noDrop}))},onDrop:function(t){var e=this;En(t),this.dragging=!1,this.noDrop||this.disabled||!this.dropAllowed?this.$nextTick((function(){e.dropAllowed=!e.noDrop})):this.onChange(t)}},render:function(t){var e=this.custom,n=this.plain,r=this.size,i=this.dragging,o=this.stateClass,a=this.bvAttrs,s=t("input",{class:[{"form-control-file":n,"custom-file-input":e,focus:e&&this.hasFocus},o],style:e?{zIndex:-5}:{},attrs:this.computedAttrs,on:{change:this.onChange,focusin:this.focusHandler,focusout:this.focusHandler,reset:this.reset},ref:"input"});if(n)return s;var c=t("label",{staticClass:"custom-file-label",class:{dragging:i},attrs:{for:this.safeId(),"data-browse":this.browseText||null}},[t("span",{staticClass:"d-block form-file-text",style:{pointerEvents:"none"}},[this.labelContent])]);return t("div",{staticClass:"custom-file b-form-file",class:[gh({},"b-custom-control-".concat(r),r),o,a.class],style:a.style,attrs:{id:this.safeId("_BV_file_outer_")},on:{dragenter:this.onDragenter,dragover:this.onDragover,dragleave:this.onDragleave,drop:this.onDrop}},[s,c])}}),Sh=Object(r["b"])({components:{BFormFile:Vh,BFile:Vh}}),xh=n("228e"),Th=function(t){return"\\"+t},Ph=function(t){t=Object(Ee["g"])(t);var e=t.length,n=t.charCodeAt(0);return t.split("").reduce((function(r,i,o){var a=t.charCodeAt(o);return 0===a?r+"�":127===a||a>=1&&a<=31||0===o&&a>=48&&a<=57||1===o&&a>=48&&a<=57&&45===n?r+Th("".concat(a.toString(16)," ")):0===o&&45===a&&1===e?r+Th(i):a>=128||45===a||95===a||a>=48&&a<=57||a>=65&&a<=90||a>=97&&a<=122?r+i:r+Th(i)}),"")},Ih=n("b508");function Eh(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Lh(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Eh(Object(n),!0).forEach((function(e){Bh(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Eh(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Bh(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Hh=["auto","start","end","center","baseline","stretch"],Fh=function(t,e,n){var r=t;if(!Object(Me["p"])(n)&&!1!==n)return e&&(r+="-".concat(e)),"col"!==t||""!==n&&!0!==n?(r+="-".concat(n),Object(Ee["c"])(r)):Object(Ee["c"])(r)},Dh=Object(Ih["a"])(Fh),Rh=Object(zn["c"])(null),Nh=function(){var t=Object(xh["b"])().filter(An["a"]),e=t.reduce((function(t,e){return t[e]=Object(kn["c"])(pt["i"]),t}),Object(zn["c"])(null)),n=t.reduce((function(t,e){return t[Object(kn["g"])(e,"offset")]=Object(kn["c"])(pt["p"]),t}),Object(zn["c"])(null)),r=t.reduce((function(t,e){return t[Object(kn["g"])(e,"order")]=Object(kn["c"])(pt["p"]),t}),Object(zn["c"])(null));return Rh=Object(zn["a"])(Object(zn["c"])(null),{col:Object(zn["h"])(e),offset:Object(zn["h"])(n),order:Object(zn["h"])(r)}),Object(kn["d"])(Object(zn["m"])(Lh(Lh(Lh(Lh({},e),n),r),{},{alignSelf:Object(kn["c"])(pt["u"],null,(function(t){return Ve(Hh,t)})),col:Object(kn["c"])(pt["g"],!1),cols:Object(kn["c"])(pt["p"]),offset:Object(kn["c"])(pt["p"]),order:Object(kn["c"])(pt["p"]),tag:Object(kn["c"])(pt["u"],"div")})),a["z"])},$h={name:a["z"],functional:!0,get props(){return delete this.props,this.props=Nh()},render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.cols,s=r.offset,c=r.order,l=r.alignSelf,u=[];for(var d in Rh)for(var h=Rh[d],f=0;f<h.length;f++){var p=Dh(d,h[f].replace(d,""),r[h[f]]);p&&u.push(p)}var m=u.some((function(t){return Sn["e"].test(t)}));return u.push((n={col:r.col||!m&&!a},Bh(n,"col-".concat(a),a),Bh(n,"offset-".concat(s),s),Bh(n,"order-".concat(c),c),Bh(n,"align-self-".concat(l),l),n)),t(r.tag,Object(Vn["a"])(i,{class:u}),o)}};function Uh(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function qh(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Uh(Object(n),!0).forEach((function(e){Wh(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Uh(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Wh(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Gh=["input","select","textarea"],Yh=Gh.map((function(t){return"".concat(t,":not([disabled])")})).join(),Kh=[].concat(Gh,["a","button","label"]),Qh=function(){return Object(kn["d"])(Object(zn["m"])(qh(qh(qh(qh({},ia),Ju),Object(xh["b"])().reduce((function(t,e){return t[Object(kn["g"])(e,"contentCols")]=Object(kn["c"])(pt["i"]),t[Object(kn["g"])(e,"labelAlign")]=Object(kn["c"])(pt["u"]),t[Object(kn["g"])(e,"labelCols")]=Object(kn["c"])(pt["i"]),t}),Object(zn["c"])(null))),{},{description:Object(kn["c"])(pt["u"]),disabled:Object(kn["c"])(pt["g"],!1),feedbackAriaLive:Object(kn["c"])(pt["u"],"assertive"),invalidFeedback:Object(kn["c"])(pt["u"]),label:Object(kn["c"])(pt["u"]),labelClass:Object(kn["c"])(pt["e"]),labelFor:Object(kn["c"])(pt["u"]),labelSize:Object(kn["c"])(pt["u"]),labelSrOnly:Object(kn["c"])(pt["g"],!1),tooltip:Object(kn["c"])(pt["g"],!1),validFeedback:Object(kn["c"])(pt["u"]),validated:Object(kn["c"])(pt["g"],!1)})),a["T"])},Xh={name:a["T"],mixins:[oa,Zu,Cn],get props(){return delete this.props,this.props=Qh()},data:function(){return{ariaDescribedby:null}},computed:{contentColProps:function(){return this.getColProps(this.$props,"content")},labelAlignClasses:function(){return this.getAlignClasses(this.$props,"label")},labelColProps:function(){return this.getColProps(this.$props,"label")},isHorizontal:function(){return Object(zn["h"])(this.contentColProps).length>0||Object(zn["h"])(this.labelColProps).length>0}},watch:{ariaDescribedby:function(t,e){t!==e&&this.updateAriaDescribedby(t,e)}},mounted:function(){var t=this;this.$nextTick((function(){t.updateAriaDescribedby(t.ariaDescribedby)}))},methods:{getAlignClasses:function(t,e){return Object(xh["b"])().reduce((function(n,r){var i=t[Object(kn["g"])(r,"".concat(e,"Align"))]||null;return i&&n.push(["text",r,i].filter(An["a"]).join("-")),n}),[])},getColProps:function(t,e){return Object(xh["b"])().reduce((function(n,r){var i=t[Object(kn["g"])(r,"".concat(e,"Cols"))];return i=""===i||(i||!1),Object(Me["b"])(i)||"auto"===i||(i=Object(Ie["c"])(i,0),i=i>0&&i),i&&(n[r||(Object(Me["b"])(i)?"col":"cols")]=i),n}),{})},updateAriaDescribedby:function(t,e){var n=this.labelFor;if(Ae["i"]&&n){var r=Xe("#".concat(Ph(n)),this.$refs.content);if(r){var i="aria-describedby",o=(t||"").split(Sn["x"]),a=(e||"").split(Sn["x"]),s=(cn(r,i)||"").split(Sn["x"]).filter((function(t){return!Ve(a,t)})).concat(o).filter((function(t,e,n){return n.indexOf(t)===e})).filter(An["a"]).join(" ").trim();s?an(r,i,s):sn(r,i)}}},onLegendClick:function(t){if(!this.labelFor){var e=t.target,n=e?e.tagName:"";if(-1===Kh.indexOf(n)){var r=Qe(Yh,this.$refs.content).filter(Ge);1===r.length&&wn(r[0])}}}},render:function(t){var e=this.computedState,n=this.feedbackAriaLive,r=this.isHorizontal,i=this.labelFor,o=this.normalizeSlot,a=this.safeId,s=this.tooltip,c=a(),l=!i,u=t(),d=o($t)||this.label,h=d?a("_BV_label_"):null;if(d||r){var f=this.labelSize,p=this.labelColProps,m=l?"legend":"label";this.labelSrOnly?(d&&(u=t(m,{class:"sr-only",attrs:{id:h,for:i||null}},[d])),u=t(r?$h:"div",{props:r?p:{}},[u])):u=t(r?$h:m,{on:l?{click:this.onLegendClick}:{},props:r?qh(qh({},p),{},{tag:m}):{},attrs:{id:h,for:i||null,tabindex:l?"-1":null},class:[l?"bv-no-focus-ring":"",r||l?"col-form-label":"",!r&&l?"pt-0":"",r||l?"":"d-block",f?"col-form-label-".concat(f):"",this.labelAlignClasses,this.labelClass]},[d])}var b=t(),g=o(Nt)||this.invalidFeedback,v=g?a("_BV_feedback_invalid_"):null;g&&(b=t(Hu,{props:{ariaLive:n,id:v,role:n?"alert":null,state:e,tooltip:s},attrs:{tabindex:g?"-1":null}},[g]));var w=t(),y=o(ze)||this.validFeedback,k=y?a("_BV_feedback_valid_"):null;y&&(w=t(Du,{props:{ariaLive:n,id:k,role:n?"alert":null,state:e,tooltip:s},attrs:{tabindex:y?"-1":null}},[y]));var _=t(),O=o(zt)||this.description,z=O?a("_BV_description_"):null;O&&(_=t(Lu,{attrs:{id:z,tabindex:"-1"}},[O]));var A=this.ariaDescribedby=[z,!1===e?v:null,!0===e?k:null].filter(An["a"]).join(" ")||null,j=t(r?$h:"div",{props:r?this.contentColProps:{},ref:"content"},[o(Ot,{ariaDescribedby:A,descriptionId:z,id:c,labelId:h})||t(),b,w,_]);return t(l?"fieldset":r?Nu:"div",{staticClass:"form-group",class:[{"was-validated":this.validated},this.stateClass],attrs:{id:c,disabled:l?this.disabled:null,role:l?null:"group","aria-invalid":this.computedAriaInvalid,"aria-labelledby":l&&r?h:null}},r&&l?[t(Nu,[u,j])]:[u,j])}},Jh=Object(r["b"])({components:{BFormGroup:Xh,BFormFieldset:Xh}}),Zh=i["default"].extend({computed:{selectionStart:{cache:!1,get:function(){return this.$refs.input.selectionStart},set:function(t){this.$refs.input.selectionStart=t}},selectionEnd:{cache:!1,get:function(){return this.$refs.input.selectionEnd},set:function(t){this.$refs.input.selectionEnd=t}},selectionDirection:{cache:!1,get:function(){return this.$refs.input.selectionDirection},set:function(t){this.$refs.input.selectionDirection=t}}},methods:{select:function(){var t;(t=this.$refs.input).select.apply(t,arguments)},setSelectionRange:function(){var t;(t=this.$refs.input).setSelectionRange.apply(t,arguments)},setRangeText:function(){var t;(t=this.$refs.input).setRangeText.apply(t,arguments)}}});function tf(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ef(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?tf(Object(n),!0).forEach((function(e){nf(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):tf(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function nf(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var rf=On("value",{type:pt["p"],defaultValue:"",event:at}),of=rf.mixin,af=rf.props,sf=rf.prop,cf=rf.event,lf=Object(kn["d"])(Object(zn["m"])(ef(ef({},af),{},{ariaInvalid:Object(kn["c"])(pt["j"],!1),autocomplete:Object(kn["c"])(pt["u"]),debounce:Object(kn["c"])(pt["p"],0),formatter:Object(kn["c"])(pt["l"]),lazy:Object(kn["c"])(pt["g"],!1),lazyFormatter:Object(kn["c"])(pt["g"],!1),number:Object(kn["c"])(pt["g"],!1),placeholder:Object(kn["c"])(pt["u"]),plaintext:Object(kn["c"])(pt["g"],!1),readonly:Object(kn["c"])(pt["g"],!1),trim:Object(kn["c"])(pt["g"],!1)})),"formTextControls"),uf=i["default"].extend({mixins:[of],props:lf,data:function(){var t=this[sf];return{localValue:Object(Ee["g"])(t),vModelValue:this.modifyValue(t)}},computed:{computedClass:function(){var t=this.plaintext,e=this.type,n="range"===e,r="color"===e;return[{"custom-range":n,"form-control-plaintext":t&&!n&&!r,"form-control":r||!t&&!n},this.sizeFormClass,this.stateClass]},computedDebounce:function(){return Object(lr["d"])(Object(Ie["c"])(this.debounce,0),0)},hasFormatter:function(){return Object(kn["b"])(this.formatter)}},watch:nf({},sf,(function(t){var e=Object(Ee["g"])(t),n=this.modifyValue(t);e===this.localValue&&n===this.vModelValue||(this.clearDebounce(),this.localValue=e,this.vModelValue=n)})),created:function(){this.$_inputDebounceTimer=null},mounted:function(){this.$on(st,this.clearDebounce)},beforeDestroy:function(){this.clearDebounce()},methods:{clearDebounce:function(){clearTimeout(this.$_inputDebounceTimer),this.$_inputDebounceTimer=null},formatValue:function(t,e){var n=arguments.length>2&&void 0!==arguments[2]&&arguments[2];return t=Object(Ee["g"])(t),!this.hasFormatter||this.lazyFormatter&&!n||(t=this.formatter(t,e)),t},modifyValue:function(t){return t=Object(Ee["g"])(t),this.trim&&(t=t.trim()),this.number&&(t=Object(Ie["b"])(t,t)),t},updateValue:function(t){var e=this,n=arguments.length>1&&void 0!==arguments[1]&&arguments[1],r=this.lazy;if(!r||n){this.clearDebounce();var i=function(){if(t=e.modifyValue(t),t!==e.vModelValue)e.vModelValue=t,e.$emit(cf,t);else if(e.hasFormatter){var n=e.$refs.input;n&&t!==n.value&&(n.value=t)}},o=this.computedDebounce;o>0&&!r&&!n?this.$_inputDebounceTimer=setTimeout(i,o):i()}},onInput:function(t){if(!t.target.composing){var e=t.target.value,n=this.formatValue(e,t);!1===n||t.defaultPrevented?En(t,{propagation:!1}):(this.localValue=n,this.updateValue(n),this.$emit(x,n))}},onChange:function(t){var e=t.target.value,n=this.formatValue(e,t);!1===n||t.defaultPrevented?En(t,{propagation:!1}):(this.localValue=n,this.updateValue(n,!0),this.$emit(u,n))},onBlur:function(t){var e=t.target.value,n=this.formatValue(e,t,!0);!1!==n&&(this.localValue=Object(Ee["g"])(this.modifyValue(n)),this.updateValue(n,!0)),this.$emit(c,t)},focus:function(){this.disabled||wn(this.$el)},blur:function(){this.disabled||yn(this.$el)}}}),df=i["default"].extend({computed:{validity:{cache:!1,get:function(){return this.$refs.input.validity}},validationMessage:{cache:!1,get:function(){return this.$refs.input.validationMessage}},willValidate:{cache:!1,get:function(){return this.$refs.input.willValidate}}},methods:{setCustomValidity:function(){var t;return(t=this.$refs.input).setCustomValidity.apply(t,arguments)},checkValidity:function(){var t;return(t=this.$refs.input).checkValidity.apply(t,arguments)},reportValidity:function(){var t;return(t=this.$refs.input).reportValidity.apply(t,arguments)}}});function hf(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ff(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?hf(Object(n),!0).forEach((function(e){pf(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):hf(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function pf(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var mf,bf=["text","password","email","number","url","tel","search","range","color","date","time","datetime","datetime-local","month","week"],gf=Object(kn["d"])(Object(zn["m"])(ff(ff(ff(ff(ff(ff({},ia),Wu),Qu),Ju),lf),{},{list:Object(kn["c"])(pt["u"]),max:Object(kn["c"])(pt["p"]),min:Object(kn["c"])(pt["p"]),noWheel:Object(kn["c"])(pt["g"],!1),step:Object(kn["c"])(pt["p"]),type:Object(kn["c"])(pt["u"],"text",(function(t){return Ve(bf,t)}))})),a["U"]),vf=i["default"].extend({name:a["U"],mixins:[ei,oa,Gu,Xu,Zu,uf,Zh,df],props:gf,computed:{localType:function(){var t=this.type;return Ve(bf,t)?t:"text"},computedAttrs:function(){var t=this.localType,e=this.name,n=this.form,r=this.disabled,i=this.placeholder,o=this.required,a=this.min,s=this.max,c=this.step;return{id:this.safeId(),name:e,form:n,type:t,disabled:r,placeholder:i,required:o,autocomplete:this.autocomplete||null,readonly:this.readonly||this.plaintext,min:a,max:s,step:c,list:"password"!==t?this.list:null,"aria-required":o?"true":null,"aria-invalid":this.computedAriaInvalid}},computedListeners:function(){return ff(ff({},this.bvListeners),{},{input:this.onInput,change:this.onChange,blur:this.onBlur})}},watch:{noWheel:function(t){this.setWheelStopper(t)}},mounted:function(){this.setWheelStopper(this.noWheel)},deactivated:function(){this.setWheelStopper(!1)},activated:function(){this.setWheelStopper(this.noWheel)},beforeDestroy:function(){this.setWheelStopper(!1)},methods:{setWheelStopper:function(t){var e=this.$el;In(t,e,"focus",this.onWheelFocus),In(t,e,"blur",this.onWheelBlur),t||Pn(document,"wheel",this.stopWheel)},onWheelFocus:function(){Tn(document,"wheel",this.stopWheel)},onWheelBlur:function(){Pn(document,"wheel",this.stopWheel)},stopWheel:function(t){En(t,{propagation:!1}),yn(this.$el)}},render:function(t){return t("input",{class:this.computedClass,attrs:this.computedAttrs,domProps:{value:this.localValue},on:this.computedListeners,ref:"input"})}}),wf=Object(r["b"])({components:{BFormInput:vf,BInput:vf}}),yf=Object(kn["d"])(Id,a["X"]),kf=i["default"].extend({name:a["X"],mixins:[Ed],provide:function(){return{bvRadioGroup:this}},props:yf,computed:{isRadioGroup:function(){return!0}}}),_f=Object(r["b"])({components:{BFormRadio:Od,BRadio:Od,BFormRadioGroup:kf,BRadioGroup:kf}});function Of(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function zf(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Of(Object(n),!0).forEach((function(e){Af(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Of(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Af(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var jf=On("value",{type:pt["p"],event:u}),Mf=jf.mixin,Cf=jf.props,Vf=jf.prop,Sf=jf.event,xf=3,Tf=5,Pf=function(t){return Object(lr["d"])(xf,Object(Ie["c"])(t,Tf))},If=function(t,e,n){return Object(lr["d"])(Object(lr["e"])(t,n),e)},Ef=i["default"].extend({name:a["Z"],mixins:[Cn],props:{disabled:Object(kn["c"])(pt["g"],!1),focused:Object(kn["c"])(pt["g"],!1),hasClear:Object(kn["c"])(pt["g"],!1),rating:Object(kn["c"])(pt["n"],0),readonly:Object(kn["c"])(pt["g"],!1),star:Object(kn["c"])(pt["n"],0),variant:Object(kn["c"])(pt["u"])},methods:{onClick:function(t){this.disabled||this.readonly||(En(t,{propagation:!1}),this.$emit(X,this.star))}},render:function(t){var e=this.rating,n=this.star,r=this.focused,i=this.hasClear,o=this.variant,a=this.disabled,s=this.readonly,c=i?0:1,l=e>=n?"full":e>=n-.5?"half":"empty",u={variant:o,disabled:a,readonly:s};return t("span",{staticClass:"b-rating-star",class:{focused:r&&e===n||!Object(Ie["c"])(e)&&n===c,"b-rating-star-empty":"empty"===l,"b-rating-star-half":"half"===l,"b-rating-star-full":"full"===l},attrs:{tabindex:a||s?null:"-1"},on:{click:this.onClick}},[t("span",{staticClass:"b-rating-icon"},[this.normalizeSlot(l,u)])])}}),Lf=Object(kn["d"])(Object(zn["m"])(zf(zf(zf(zf(zf({},ia),Cf),Object(zn["j"])(Wu,["required","autofocus"])),Qu),{},{color:Object(kn["c"])(pt["u"]),iconClear:Object(kn["c"])(pt["u"],"x"),iconEmpty:Object(kn["c"])(pt["u"],"star"),iconFull:Object(kn["c"])(pt["u"],"star-fill"),iconHalf:Object(kn["c"])(pt["u"],"star-half"),inline:Object(kn["c"])(pt["g"],!1),locale:Object(kn["c"])(pt["f"]),noBorder:Object(kn["c"])(pt["g"],!1),precision:Object(kn["c"])(pt["p"]),readonly:Object(kn["c"])(pt["g"],!1),showClear:Object(kn["c"])(pt["g"],!1),showValue:Object(kn["c"])(pt["g"],!1),showValueMax:Object(kn["c"])(pt["g"],!1),stars:Object(kn["c"])(pt["p"],Tf,(function(t){return Object(Ie["c"])(t)>=xf})),variant:Object(kn["c"])(pt["u"])})),a["Y"]),Bf=i["default"].extend({name:a["Y"],components:{BIconStar:Tr["ru"],BIconStarHalf:Tr["tu"],BIconStarFill:Tr["su"],BIconX:Tr["Uw"]},mixins:[oa,Mf,Xu],props:Lf,data:function(){var t=Object(Ie["b"])(this[Vf],null),e=Pf(this.stars);return{localValue:Object(Me["g"])(t)?null:If(t,0,e),hasFocus:!1}},computed:{computedStars:function(){return Pf(this.stars)},computedRating:function(){var t=Object(Ie["b"])(this.localValue,0),e=Object(Ie["c"])(this.precision,3);return If(Object(Ie["b"])(t.toFixed(e)),0,this.computedStars)},computedLocale:function(){var t=Se(this.locale).filter(An["a"]),e=new Intl.NumberFormat(t);return e.resolvedOptions().locale},isInteractive:function(){return!this.disabled&&!this.readonly},isRTL:function(){return ra(this.computedLocale)},formattedRating:function(){var t=Object(Ie["c"])(this.precision),e=this.showValueMax,n=this.computedLocale,r={notation:"standard",minimumFractionDigits:isNaN(t)?0:t,maximumFractionDigits:isNaN(t)?3:t},i=this.computedStars.toLocaleString(n),o=this.localValue;return o=Object(Me["g"])(o)?e?"-":"":o.toLocaleString(n,r),e?"".concat(o,"/").concat(i):o}},watch:(mf={},Af(mf,Vf,(function(t,e){if(t!==e){var n=Object(Ie["b"])(t,null);this.localValue=Object(Me["g"])(n)?null:If(n,0,this.computedStars)}})),Af(mf,"localValue",(function(t,e){t!==e&&t!==(this.value||0)&&this.$emit(Sf,t||null)})),Af(mf,"disabled",(function(t){t&&(this.hasFocus=!1,this.blur())})),mf),methods:{focus:function(){this.disabled||wn(this.$el)},blur:function(){this.disabled||yn(this.$el)},onKeydown:function(t){var e=t.keyCode;if(this.isInteractive&&Ve([Dr,Er,$r,qr],e)){En(t,{propagation:!1});var n=Object(Ie["c"])(this.localValue,0),r=this.showClear?0:1,i=this.computedStars,o=this.isRTL?-1:1;e===Dr?this.localValue=If(n-o,r,i)||null:e===$r?this.localValue=If(n+o,r,i):e===Er?this.localValue=If(n-1,r,i)||null:e===qr&&(this.localValue=If(n+1,r,i))}},onSelected:function(t){this.isInteractive&&(this.localValue=t)},onFocus:function(t){this.hasFocus=!!this.isInteractive&&"focus"===t.type},renderIcon:function(t){return this.$createElement(xr["a"],{props:{icon:t,variant:this.disabled||this.color?null:this.variant||null}})},iconEmptyFn:function(){return this.renderIcon(this.iconEmpty)},iconHalfFn:function(){return this.renderIcon(this.iconHalf)},iconFullFn:function(){return this.renderIcon(this.iconFull)},iconClearFn:function(){return this.$createElement(xr["a"],{props:{icon:this.iconClear}})}},render:function(t){var e=this,n=this.disabled,r=this.readonly,i=this.name,o=this.form,a=this.inline,s=this.variant,c=this.color,l=this.noBorder,u=this.hasFocus,d=this.computedRating,h=this.computedStars,f=this.formattedRating,p=this.showClear,m=this.isRTL,b=this.isInteractive,g=this.$scopedSlots,v=[];if(p&&!n&&!r){var w=t("span",{staticClass:"b-rating-icon"},[(g[Lt]||this.iconClearFn)()]);v.push(t("span",{staticClass:"b-rating-star b-rating-star-clear flex-grow-1",class:{focused:u&&0===d},attrs:{tabindex:b?"-1":null},on:{click:function(){return e.onSelected(null)}},key:"clear"},[w]))}for(var y=0;y<h;y++){var k=y+1;v.push(t(Ef,{staticClass:"flex-grow-1",style:c&&!n?{color:c}:{},props:{rating:d,star:k,variant:n?null:s||null,disabled:n,readonly:r,focused:u,hasClear:p},on:{selected:this.onSelected},scopedSlots:{empty:g[Bt]||this.iconEmptyFn,half:g[Ft]||this.iconHalfFn,full:g[Ht]||this.iconFullFn},key:y}))}return i&&v.push(t("input",{attrs:{type:"hidden",value:Object(Me["g"])(this.localValue)?"":d,name:i,form:o||null},key:"hidden"})),this.showValue&&v.push(t("b",{staticClass:"b-rating-value flex-grow-1",attrs:{"aria-hidden":"true"},key:"value"},Object(Ee["g"])(f))),t("output",{staticClass:"b-rating form-control align-items-center",class:[{"d-inline-flex":a,"d-flex":!a,"border-0":l,disabled:n,readonly:!n&&r},this.sizeFormClass],attrs:{id:this.safeId(),dir:m?"rtl":"ltr",tabindex:n?null:"0",disabled:n,role:"slider","aria-disabled":n?"true":null,"aria-readonly":!n&&r?"true":null,"aria-live":"off","aria-valuemin":p?"0":"1","aria-valuemax":Object(Ee["g"])(h),"aria-valuenow":d?Object(Ee["g"])(d):null},on:{keydown:this.onKeydown,focus:this.onFocus,blur:this.onFocus}},v)}}),Hf=Object(r["b"])({components:{BFormRating:Bf,BRating:Bf}}),Ff=On("value"),Df=Ff.mixin,Rf=Ff.props,Nf=Ff.prop,$f=Ff.event;function Uf(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function qf(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Uf(Object(n),!0).forEach((function(e){Wf(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Uf(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Wf(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Gf=Object(kn["d"])(Object(zn["m"])(qf(qf({},Au),{},{labelField:Object(kn["c"])(pt["u"],"label"),optionsField:Object(kn["c"])(pt["u"],"options")})),"formOptions"),Yf=i["default"].extend({mixins:[ju],props:Gf,methods:{normalizeOption:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;if(Object(Me["k"])(t)){var n=Object(Ou["a"])(t,this.valueField),r=Object(Ou["a"])(t,this.textField),i=Object(Ou["a"])(t,this.optionsField,null);return Object(Me["g"])(i)?{value:Object(Me["o"])(n)?e||r:n,text:String(Object(Me["o"])(r)?e:r),html:Object(Ou["a"])(t,this.htmlField),disabled:Boolean(Object(Ou["a"])(t,this.disabledField))}:{label:String(Object(Ou["a"])(t,this.labelField)||r),options:this.normalizeOptions(i)}}return{value:e||t,text:String(t),disabled:!1}}}}),Kf=Object(kn["d"])({disabled:Object(kn["c"])(pt["g"],!1),value:Object(kn["c"])(pt["a"],void 0,!0)},a["cb"]),Qf=i["default"].extend({name:a["cb"],functional:!0,props:Kf,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.value,a=n.disabled;return t("option",Object(Vn["a"])(r,{attrs:{disabled:a},domProps:{value:o}}),i)}});function Xf(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Jf(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Xf(Object(n),!0).forEach((function(e){Zf(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Xf(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Zf(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var tp=Object(kn["d"])(Object(zn["m"])(Jf(Jf({},Au),{},{label:Object(kn["c"])(pt["u"],void 0,!0)})),a["db"]),ep=i["default"].extend({name:a["db"],mixins:[Cn,ju],props:tp,render:function(t){var e=this.label,n=this.formOptions.map((function(e,n){var r=e.value,i=e.text,o=e.html,a=e.disabled;return t(Qf,{attrs:{value:r,disabled:a},domProps:Ji(o,i),key:"option_".concat(n)})}));return t("optgroup",{attrs:{label:e}},[this.normalizeSlot(xt),n,this.normalizeSlot()])}});function np(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function rp(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?np(Object(n),!0).forEach((function(e){ip(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):np(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function ip(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var op,ap=Object(kn["d"])(Object(zn["m"])(rp(rp(rp(rp(rp(rp(rp({},ia),Rf),Wu),Yu),Qu),Ju),{},{ariaInvalid:Object(kn["c"])(pt["j"],!1),multiple:Object(kn["c"])(pt["g"],!1),selectSize:Object(kn["c"])(pt["n"],0)})),a["bb"]),sp=i["default"].extend({name:a["bb"],mixins:[oa,Df,Gu,Xu,Zu,Ku,Yf,Cn],props:ap,data:function(){return{localValue:this[Nf]}},computed:{computedSelectSize:function(){return this.plain||0!==this.selectSize?this.selectSize:null},inputClass:function(){return[this.plain?"form-control":"custom-select",this.size&&this.plain?"form-control-".concat(this.size):null,this.size&&!this.plain?"custom-select-".concat(this.size):null,this.stateClass]}},watch:{value:function(t){this.localValue=t},localValue:function(){this.$emit($f,this.localValue)}},methods:{focus:function(){wn(this.$refs.input)},blur:function(){yn(this.$refs.input)},onChange:function(t){var e=this,n=t.target,r=Ce(n.options).filter((function(t){return t.selected})).map((function(t){return"_value"in t?t._value:t.value}));this.localValue=n.multiple?r:r[0],this.$nextTick((function(){e.$emit(u,e.localValue)}))}},render:function(t){var e=this.name,n=this.disabled,r=this.required,i=this.computedSelectSize,o=this.localValue,a=this.formOptions.map((function(e,n){var r=e.value,i=e.label,o=e.options,a=e.disabled,s="option_".concat(n);return Object(Me["a"])(o)?t(ep,{props:{label:i,options:o},key:s}):t(Qf,{props:{value:r,disabled:a},domProps:Ji(e.html,e.text),key:s})}));return t("select",{class:this.inputClass,attrs:{id:this.safeId(),name:e,form:this.form||null,multiple:this.multiple||null,size:i,disabled:n,required:r,"aria-required":r?"true":null,"aria-invalid":this.computedAriaInvalid},on:{change:this.onChange},directives:[{name:"model",value:o}],ref:"input"},[this.normalizeSlot(xt),a,this.normalizeSlot()])}}),cp=Object(r["b"])({components:{BFormSelect:sp,BFormSelectOption:Qf,BFormSelectOptionGroup:ep,BSelect:sp,BSelectOption:Qf,BSelectOptionGroup:ep}});function lp(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function up(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?lp(Object(n),!0).forEach((function(e){dp(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):lp(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function dp(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var hp=On("value",{type:pt["h"]}),fp=hp.mixin,pp=hp.props,mp=hp.prop,bp=hp.event,gp=1,vp=100,wp=1,yp=500,kp=100,_p=10,Op=4,zp=[qr,Er,Fr,Lr,Nr,Rr],Ap=Object(kn["d"])(Object(zn["m"])(up(up(up(up(up(up({},ia),pp),Object(zn["j"])(Wu,["required","autofocus"])),Qu),Ju),{},{ariaControls:Object(kn["c"])(pt["u"]),ariaLabel:Object(kn["c"])(pt["u"]),formatterFn:Object(kn["c"])(pt["l"]),inline:Object(kn["c"])(pt["g"],!1),labelDecrement:Object(kn["c"])(pt["u"],"Decrement"),labelIncrement:Object(kn["c"])(pt["u"],"Increment"),locale:Object(kn["c"])(pt["f"]),max:Object(kn["c"])(pt["p"],vp),min:Object(kn["c"])(pt["p"],gp),placeholder:Object(kn["c"])(pt["u"]),readonly:Object(kn["c"])(pt["g"],!1),repeatDelay:Object(kn["c"])(pt["p"],yp),repeatInterval:Object(kn["c"])(pt["p"],kp),repeatStepMultiplier:Object(kn["c"])(pt["p"],Op),repeatThreshold:Object(kn["c"])(pt["p"],_p),step:Object(kn["c"])(pt["p"],wp),vertical:Object(kn["c"])(pt["g"],!1),wrap:Object(kn["c"])(pt["g"],!1)})),a["eb"]),jp=i["default"].extend({name:a["eb"],mixins:[Zr,oa,fp,Xu,Zu,Cn],inheritAttrs:!1,props:Ap,data:function(){return{localValue:Object(Ie["b"])(this[mp],null),hasFocus:!1}},computed:{spinId:function(){return this.safeId()},computedInline:function(){return this.inline&&!this.vertical},computedReadonly:function(){return this.readonly&&!this.disabled},computedRequired:function(){return this.required&&!this.computedReadonly&&!this.disabled},computedStep:function(){return Object(Ie["b"])(this.step,wp)},computedMin:function(){return Object(Ie["b"])(this.min,gp)},computedMax:function(){var t=Object(Ie["b"])(this.max,vp),e=this.computedStep,n=this.computedMin;return Object(lr["c"])((t-n)/e)*e+n},computedDelay:function(){var t=Object(Ie["c"])(this.repeatDelay,0);return t>0?t:yp},computedInterval:function(){var t=Object(Ie["c"])(this.repeatInterval,0);return t>0?t:kp},computedThreshold:function(){return Object(lr["d"])(Object(Ie["c"])(this.repeatThreshold,_p),1)},computedStepMultiplier:function(){return Object(lr["d"])(Object(Ie["c"])(this.repeatStepMultiplier,Op),1)},computedPrecision:function(){var t=this.computedStep;return Object(lr["c"])(t)===t?0:(t.toString().split(".")[1]||"").length},computedMultiplier:function(){return Object(lr["f"])(10,this.computedPrecision||0)},valueAsFixed:function(){var t=this.localValue;return Object(Me["g"])(t)?"":t.toFixed(this.computedPrecision)},computedLocale:function(){var t=Se(this.locale).filter(An["a"]),e=new Intl.NumberFormat(t);return e.resolvedOptions().locale},computedRTL:function(){return ra(this.computedLocale)},defaultFormatter:function(){var t=this.computedPrecision,e=new Intl.NumberFormat(this.computedLocale,{style:"decimal",useGrouping:!1,minimumIntegerDigits:1,minimumFractionDigits:t,maximumFractionDigits:t,notation:"standard"});return e.format},computedFormatter:function(){var t=this.formatterFn;return Object(kn["b"])(t)?t:this.defaultFormatter},computedAttrs:function(){return up(up({},this.bvAttrs),{},{role:"group",lang:this.computedLocale,tabindex:this.disabled?null:"-1",title:this.ariaLabel})},computedSpinAttrs:function(){var t=this.spinId,e=this.localValue,n=this.computedRequired,r=this.disabled,i=this.state,o=this.computedFormatter,a=!Object(Me["g"])(e);return up(up({dir:this.computedRTL?"rtl":"ltr"},this.bvAttrs),{},{id:t,role:"spinbutton",tabindex:r?null:"0","aria-live":"off","aria-label":this.ariaLabel||null,"aria-controls":this.ariaControls||null,"aria-invalid":!1===i||!a&&n?"true":null,"aria-required":n?"true":null,"aria-valuemin":Object(Ee["g"])(this.computedMin),"aria-valuemax":Object(Ee["g"])(this.computedMax),"aria-valuenow":a?e:null,"aria-valuetext":a?o(e):null})}},watch:(op={},dp(op,mp,(function(t){this.localValue=Object(Ie["b"])(t,null)})),dp(op,"localValue",(function(t){this.$emit(bp,t)})),dp(op,"disabled",(function(t){t&&this.clearRepeat()})),dp(op,"readonly",(function(t){t&&this.clearRepeat()})),op),created:function(){this.$_autoDelayTimer=null,this.$_autoRepeatTimer=null,this.$_keyIsDown=!1},beforeDestroy:function(){this.clearRepeat()},deactivated:function(){this.clearRepeat()},methods:{focus:function(){this.disabled||wn(this.$refs.spinner)},blur:function(){this.disabled||yn(this.$refs.spinner)},emitChange:function(){this.$emit(u,this.localValue)},stepValue:function(t){var e=this.localValue;if(!this.disabled&&!Object(Me["g"])(e)){var n=this.computedStep*t,r=this.computedMin,i=this.computedMax,o=this.computedMultiplier,a=this.wrap;e=Object(lr["g"])((e-r)/n)*n+r+n,e=Object(lr["g"])(e*o)/o,this.localValue=e>i?a?r:i:e<r?a?i:r:e}},onFocusBlur:function(t){this.disabled?this.hasFocus=!1:this.hasFocus="focus"===t.type},stepUp:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:1,e=this.localValue;Object(Me["g"])(e)?this.localValue=this.computedMin:this.stepValue(1*t)},stepDown:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:1,e=this.localValue;Object(Me["g"])(e)?this.localValue=this.wrap?this.computedMax:this.computedMin:this.stepValue(-1*t)},onKeydown:function(t){var e=t.keyCode,n=t.altKey,r=t.ctrlKey,i=t.metaKey;if(!(this.disabled||this.readonly||n||r||i)&&Ve(zp,e)){if(En(t,{propagation:!1}),this.$_keyIsDown)return;this.resetTimers(),Ve([qr,Er],e)?(this.$_keyIsDown=!0,e===qr?this.handleStepRepeat(t,this.stepUp):e===Er&&this.handleStepRepeat(t,this.stepDown)):e===Nr?this.stepUp(this.computedStepMultiplier):e===Rr?this.stepDown(this.computedStepMultiplier):e===Fr?this.localValue=this.computedMin:e===Lr&&(this.localValue=this.computedMax)}},onKeyup:function(t){var e=t.keyCode,n=t.altKey,r=t.ctrlKey,i=t.metaKey;this.disabled||this.readonly||n||r||i||Ve(zp,e)&&(En(t,{propagation:!1}),this.resetTimers(),this.$_keyIsDown=!1,this.emitChange())},handleStepRepeat:function(t,e){var n=this,r=t||{},i=r.type,o=r.button;if(!this.disabled&&!this.readonly){if("mousedown"===i&&o)return;this.resetTimers(),e(1);var a=this.computedThreshold,s=this.computedStepMultiplier,c=this.computedDelay,l=this.computedInterval;this.$_autoDelayTimer=setTimeout((function(){var t=0;n.$_autoRepeatTimer=setInterval((function(){e(t<a?1:s),t++}),l)}),c)}},onMouseup:function(t){var e=t||{},n=e.type,r=e.button;"mouseup"===n&&r||(En(t,{propagation:!1}),this.resetTimers(),this.setMouseup(!1),this.emitChange())},setMouseup:function(t){try{In(t,document.body,"mouseup",this.onMouseup,!1),In(t,document.body,"touchend",this.onMouseup,!1)}catch(e){}},resetTimers:function(){clearTimeout(this.$_autoDelayTimer),clearInterval(this.$_autoRepeatTimer),this.$_autoDelayTimer=null,this.$_autoRepeatTimer=null},clearRepeat:function(){this.resetTimers(),this.setMouseup(!1),this.$_keyIsDown=!1}},render:function(t){var e=this,n=this.spinId,r=this.localValue,i=this.computedInline,o=this.computedReadonly,a=this.vertical,s=this.disabled,c=this.computedFormatter,l=!Object(Me["g"])(r),u=function(r,i,c,l,u,d,h){var f=t(c,{props:{scale:e.hasFocus?1.5:1.25},attrs:{"aria-hidden":"true"}}),p={hasFocus:e.hasFocus},m=function(t){s||o||(En(t,{propagation:!1}),e.setMouseup(!0),wn(t.currentTarget),e.handleStepRepeat(t,r))};return t("button",{staticClass:"btn btn-sm border-0 rounded-0",class:{"py-0":!a},attrs:{tabindex:"-1",type:"button",disabled:s||o||d,"aria-disabled":s||o||d?"true":null,"aria-controls":n,"aria-label":i||null,"aria-keyshortcuts":u||null},on:{mousedown:m,touchstart:m},key:l||null,ref:l},[e.normalizeSlot(h,p)||f])},d=u(this.stepUp,this.labelIncrement,Tr["Tr"],"inc","ArrowUp",!1,Rt),h=u(this.stepDown,this.labelDecrement,Tr["si"],"dec","ArrowDown",!1,_t),f=t();this.name&&!s&&(f=t("input",{attrs:{type:"hidden",name:this.name,form:this.form||null,value:this.valueAsFixed},key:"hidden"}));var p=t("output",{staticClass:"flex-grow-1",class:{"d-flex":a,"align-self-center":!a,"align-items-center":a,"border-top":a,"border-bottom":a,"border-left":!a,"border-right":!a},attrs:this.computedSpinAttrs,key:"output",ref:"spinner"},[t("bdi",l?c(r):this.placeholder||"")]);return t("div",{staticClass:"b-form-spinbutton form-control",class:[{disabled:s,readonly:o,focus:this.hasFocus,"d-inline-flex":i||a,"d-flex":!i&&!a,"align-items-stretch":!a,"flex-column":a},this.sizeFormClass,this.stateClass],attrs:this.computedAttrs,on:{keydown:this.onKeydown,keyup:this.onKeyup,"!focus":this.onFocusBlur,"!blur":this.onFocusBlur}},a?[d,f,p,h]:[h,f,p,d])}}),Mp=Object(r["b"])({components:{BFormSpinbutton:jp,BSpinbutton:jp}});function Cp(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Vp(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Cp(Object(n),!0).forEach((function(e){Sp(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Cp(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Sp(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var xp,Tp=Object(kn["d"])(Object(zn["m"])(Vp(Vp({},ia),{},{disabled:Object(kn["c"])(pt["g"],!1),noRemove:Object(kn["c"])(pt["g"],!1),pill:Object(kn["c"])(pt["g"],!1),removeLabel:Object(kn["c"])(pt["u"],"Remove tag"),tag:Object(kn["c"])(pt["u"],"span"),title:Object(kn["c"])(pt["u"]),variant:Object(kn["c"])(pt["u"],"secondary")})),a["fb"]),Pp=i["default"].extend({name:a["fb"],mixins:[oa,Cn],props:Tp,methods:{onRemove:function(t){var e=t.type,n=t.keyCode;this.disabled||"click"!==e&&("keydown"!==e||n!==Ir)||this.$emit($)}},render:function(t){var e=this.title,n=this.tag,r=this.variant,i=this.pill,o=this.disabled,a=this.safeId(),s=this.safeId("_taglabel_"),c=t();this.noRemove||o||(c=t(Rn,{staticClass:"b-form-tag-remove",props:{ariaLabel:this.removeLabel},attrs:{"aria-controls":a,"aria-describedby":s,"aria-keyshortcuts":"Delete"},on:{click:this.onRemove,keydown:this.onRemove}}));var l=t("span",{staticClass:"b-form-tag-content flex-grow-1 text-truncate",attrs:{id:s}},this.normalizeSlot()||e);return t(Ki,{staticClass:"b-form-tag d-inline-flex align-items-baseline mw-100",class:{disabled:o},props:{tag:n,variant:r,pill:i},attrs:{id:a,title:e||null,"aria-labelledby":s}},[l,c])}});function Ip(t){return Hp(t)||Bp(t)||Lp(t)||Ep()}function Ep(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function Lp(t,e){if(t){if("string"===typeof t)return Fp(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Fp(t,e):void 0}}function Bp(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function Hp(t){if(Array.isArray(t))return Fp(t)}function Fp(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function Dp(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Rp(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Dp(Object(n),!0).forEach((function(e){Np(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Dp(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Np(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var $p=On("value",{type:pt["b"],defaultValue:[]}),Up=$p.mixin,qp=$p.props,Wp=$p.prop,Gp=$p.event,Yp=["text","email","tel","url","number"],Kp=[".b-form-tag","button","input","select"].join(" "),Qp=function(t){return Object(Ee["a"])(t).replace(Sn["w"],"\\s")},Xp=function(t){return Se(t).map((function(t){return Object(Ee["h"])(Object(Ee["g"])(t))})).filter((function(t,e,n){return t.length>0&&n.indexOf(t)===e}))},Jp=function(t){return Object(Me["n"])(t)?t:Object(Me["d"])(t)&&t.target.value||""},Zp=function(){return{all:[],valid:[],invalid:[],duplicate:[]}},tm=Object(kn["d"])(Object(zn["m"])(Rp(Rp(Rp(Rp(Rp(Rp({},ia),qp),Wu),Qu),Ju),{},{addButtonText:Object(kn["c"])(pt["u"],"Add"),addButtonVariant:Object(kn["c"])(pt["u"],"outline-secondary"),addOnChange:Object(kn["c"])(pt["g"],!1),duplicateTagText:Object(kn["c"])(pt["u"],"Duplicate tag(s)"),ignoreInputFocusSelector:Object(kn["c"])(pt["f"],Kp),inputAttrs:Object(kn["c"])(pt["q"],{}),inputClass:Object(kn["c"])(pt["e"]),inputId:Object(kn["c"])(pt["u"]),inputType:Object(kn["c"])(pt["u"],"text",(function(t){return Ve(Yp,t)})),invalidTagText:Object(kn["c"])(pt["u"],"Invalid tag(s)"),limit:Object(kn["c"])(pt["n"]),limitTagsText:Object(kn["c"])(pt["u"],"Tag limit reached"),noAddOnEnter:Object(kn["c"])(pt["g"],!1),noOuterFocus:Object(kn["c"])(pt["g"],!1),noTagRemove:Object(kn["c"])(pt["g"],!1),placeholder:Object(kn["c"])(pt["u"],"Add tag..."),removeOnDelete:Object(kn["c"])(pt["g"],!1),separator:Object(kn["c"])(pt["f"]),tagClass:Object(kn["c"])(pt["e"]),tagPills:Object(kn["c"])(pt["g"],!1),tagRemoveLabel:Object(kn["c"])(pt["u"],"Remove tag"),tagRemovedLabel:Object(kn["c"])(pt["u"],"Tag removed"),tagValidator:Object(kn["c"])(pt["l"]),tagVariant:Object(kn["c"])(pt["u"],"secondary")})),a["gb"]),em=i["default"].extend({name:a["gb"],mixins:[oa,Up,Gu,Xu,Zu,Cn],props:tm,data:function(){return{hasFocus:!1,newTag:"",tags:[],removedTags:[],tagsState:Zp()}},computed:{computedInputId:function(){return this.inputId||this.safeId("__input__")},computedInputType:function(){return Ve(Yp,this.inputType)?this.inputType:"text"},computedInputAttrs:function(){var t=this.disabled,e=this.form;return Rp(Rp({},this.inputAttrs),{},{id:this.computedInputId,value:this.newTag,disabled:t,form:e})},computedInputHandlers:function(){return{input:this.onInputInput,change:this.onInputChange,keydown:this.onInputKeydown,reset:this.reset}},computedSeparator:function(){return Se(this.separator).filter(Me["n"]).filter(An["a"]).join("")},computedSeparatorRegExp:function(){var t=this.computedSeparator;return t?new RegExp("[".concat(Qp(t),"]+")):null},computedJoiner:function(){var t=this.computedSeparator.charAt(0);return" "!==t?"".concat(t," "):t},computeIgnoreInputFocusSelector:function(){return Se(this.ignoreInputFocusSelector).filter(An["a"]).join(",").trim()},disableAddButton:function(){var t=this,e=Object(Ee["h"])(this.newTag);return""===e||!this.splitTags(e).some((function(e){return!Ve(t.tags,e)&&t.validateTag(e)}))},duplicateTags:function(){return this.tagsState.duplicate},hasDuplicateTags:function(){return this.duplicateTags.length>0},invalidTags:function(){return this.tagsState.invalid},hasInvalidTags:function(){return this.invalidTags.length>0},isLimitReached:function(){var t=this.limit;return Object(Me["h"])(t)&&t>=0&&this.tags.length>=t}},watch:(xp={},Np(xp,Wp,(function(t){this.tags=Xp(t)})),Np(xp,"tags",(function(t,e){Yr(t,this[Wp])||this.$emit(Gp,t),Yr(t,e)||(t=Se(t).filter(An["a"]),e=Se(e).filter(An["a"]),this.removedTags=e.filter((function(e){return!Ve(t,e)})))})),Np(xp,"tagsState",(function(t,e){Yr(t,e)||this.$emit(rt,t.valid,t.invalid,t.duplicate)})),xp),created:function(){this.tags=Xp(this[Wp])},mounted:function(){var t=this,e=Ze("form",this.$el);e&&(Tn(e,"reset",this.reset,ht),this.$on(st,(function(){Pn(e,"reset",t.reset,ht)})))},methods:{addTag:function(t){if(t=Object(Me["n"])(t)?t:this.newTag,!this.disabled&&""!==Object(Ee["h"])(t)&&!this.isLimitReached){var e=this.parseTags(t);if(e.valid.length>0||0===e.all.length)if(Je(this.getInput(),"select"))this.newTag="";else{var n=[].concat(Ip(e.invalid),Ip(e.duplicate));this.newTag=e.all.filter((function(t){return Ve(n,t)})).join(this.computedJoiner).concat(n.length>0?this.computedJoiner.charAt(0):"")}e.valid.length>0&&(this.tags=Se(this.tags,e.valid)),this.tagsState=e,this.focus()}},removeTag:function(t){var e=this;this.disabled||(this.tags=this.tags.filter((function(e){return e!==t})),this.$nextTick((function(){e.focus()})))},reset:function(){var t=this;this.newTag="",this.tags=[],this.$nextTick((function(){t.removedTags=[],t.tagsState=Zp()}))},onInputInput:function(t){if(!(this.disabled||Object(Me["d"])(t)&&t.target.composing)){var e=Jp(t),n=this.computedSeparatorRegExp;this.newTag!==e&&(this.newTag=e),e=Object(Ee["i"])(e),n&&n.test(e.slice(-1))?this.addTag():this.tagsState=""===e?Zp():this.parseTags(e)}},onInputChange:function(t){if(!this.disabled&&this.addOnChange){var e=Jp(t);this.newTag!==e&&(this.newTag=e),this.addTag()}},onInputKeydown:function(t){if(!this.disabled&&Object(Me["d"])(t)){var e=t.keyCode,n=t.target.value||"";this.noAddOnEnter||e!==Br?!this.removeOnDelete||e!==Pr&&e!==Ir||""!==n||(En(t,{propagation:!1}),this.tags=this.tags.slice(0,-1)):(En(t,{propagation:!1}),this.addTag())}},onClick:function(t){var e=this,n=this.computeIgnoreInputFocusSelector,r=t.target;this.disabled||We(r)||n&&Ze(n,r,!0)||this.$nextTick((function(){e.focus()}))},onFocusin:function(){this.hasFocus=!0},onFocusout:function(){this.hasFocus=!1},handleAutofocus:function(){var t=this;this.$nextTick((function(){De((function(){t.autofocus&&!t.disabled&&t.focus()}))}))},focus:function(){this.disabled||wn(this.getInput())},blur:function(){this.disabled||yn(this.getInput())},splitTags:function(t){t=Object(Ee["g"])(t);var e=this.computedSeparatorRegExp;return(e?t.split(e):[t]).map(Ee["h"]).filter(An["a"])},parseTags:function(t){var e=this,n=this.splitTags(t),r={all:n,valid:[],invalid:[],duplicate:[]};return n.forEach((function(t){Ve(e.tags,t)||Ve(r.valid,t)?Ve(r.duplicate,t)||r.duplicate.push(t):e.validateTag(t)?r.valid.push(t):Ve(r.invalid,t)||r.invalid.push(t)})),r},validateTag:function(t){var e=this.tagValidator;return!Object(kn["b"])(e)||e(t)},getInput:function(){return Xe("#".concat(Ph(this.computedInputId)),this.$el)},defaultRender:function(t){var e=t.addButtonText,n=t.addButtonVariant,r=t.addTag,i=t.disableAddButton,o=t.disabled,a=t.duplicateTagText,s=t.inputAttrs,c=t.inputClass,l=t.inputHandlers,u=t.inputType,d=t.invalidTagText,h=t.isDuplicate,f=t.isInvalid,p=t.isLimitReached,m=t.limitTagsText,b=t.noTagRemove,g=t.placeholder,v=t.removeTag,w=t.tagClass,y=t.tagPills,k=t.tagRemoveLabel,_=t.tagVariant,O=t.tags,z=this.$createElement,A=O.map((function(t){return t=Object(Ee["g"])(t),z(Pp,{class:w,props:{disabled:o,noRemove:b,pill:y,removeLabel:k,tag:"li",title:t,variant:_},on:{remove:function(){return v(t)}},key:"tags_".concat(t)},t)})),j=d&&f?this.safeId("__invalid_feedback__"):null,M=a&&h?this.safeId("__duplicate_feedback__"):null,C=m&&p?this.safeId("__limit_feedback__"):null,V=[s["aria-describedby"],j,M,C].filter(An["a"]).join(" "),S=z("input",{staticClass:"b-form-tags-input w-100 flex-grow-1 p-0 m-0 bg-transparent border-0",class:c,style:{outline:0,minWidth:"5rem"},attrs:Rp(Rp({},s),{},{"aria-describedby":V||null,type:u,placeholder:g||null}),domProps:{value:s.value},on:l,directives:[{name:"model",value:s.value}],ref:"input"}),x=z(Vi,{staticClass:"b-form-tags-button py-0",class:{invisible:i},style:{fontSize:"90%"},props:{disabled:i||p,variant:n},on:{click:function(){return r()}},ref:"button"},[this.normalizeSlot(mt)||e]),T=this.safeId("__tag_list__"),P=z("li",{staticClass:"b-from-tags-field flex-grow-1",attrs:{role:"none","aria-live":"off","aria-controls":T},key:"tags_field"},[z("div",{staticClass:"d-flex",attrs:{role:"group"}},[S,x])]),I=z("ul",{staticClass:"b-form-tags-list list-unstyled mb-0 d-flex flex-wrap align-items-center",attrs:{id:T},key:"tags_list"},[A,P]),E=z();if(d||a||m){var L=this.computedJoiner,B=z();j&&(B=z(Hu,{props:{id:j,forceShow:!0},key:"tags_invalid_feedback"},[this.invalidTagText,": ",this.invalidTags.join(L)]));var H=z();M&&(H=z(Lu,{props:{id:M},key:"tags_duplicate_feedback"},[this.duplicateTagText,": ",this.duplicateTags.join(L)]));var F=z();C&&(F=z(Lu,{props:{id:C},key:"tags_limit_feedback"},[m])),E=z("div",{attrs:{"aria-live":"polite","aria-atomic":"true"},key:"tags_feedback"},[B,H,F])}return[I,E]}},render:function(t){var e=this.name,n=this.disabled,r=this.required,i=this.form,o=this.tags,a=this.computedInputId,s=this.hasFocus,c=this.noOuterFocus,l=Rp({tags:o.slice(),inputAttrs:this.computedInputAttrs,inputType:this.computedInputType,inputHandlers:this.computedInputHandlers,removeTag:this.removeTag,addTag:this.addTag,reset:this.reset,inputId:a,isInvalid:this.hasInvalidTags,invalidTags:this.invalidTags.slice(),isDuplicate:this.hasDuplicateTags,duplicateTags:this.duplicateTags.slice(),isLimitReached:this.isLimitReached,disableAddButton:this.disableAddButton},Object(zn["k"])(this.$props,["addButtonText","addButtonVariant","disabled","duplicateTagText","form","inputClass","invalidTagText","limit","limitTagsText","noTagRemove","placeholder","required","separator","size","state","tagClass","tagPills","tagRemoveLabel","tagVariant"])),u=this.normalizeSlot(Ot,l)||this.defaultRender(l),d=t("output",{staticClass:"sr-only",attrs:{id:this.safeId("__selected_tags__"),role:"status",for:a,"aria-live":s?"polite":"off","aria-atomic":"true","aria-relevant":"additions text"}},this.tags.join(", ")),h=t("div",{staticClass:"sr-only",attrs:{id:this.safeId("__removed_tags__"),role:"status","aria-live":s?"assertive":"off","aria-atomic":"true"}},this.removedTags.length>0?"(".concat(this.tagRemovedLabel,") ").concat(this.removedTags.join(", ")):""),f=t();if(e&&!n){var p=o.length>0;f=(p?o:[""]).map((function(n){return t("input",{class:{"sr-only":!p},attrs:{type:p?"hidden":"text",value:n,required:r,name:e,form:i},key:"tag_input_".concat(n)})}))}return t("div",{staticClass:"b-form-tags form-control h-auto",class:[{focus:s&&!c&&!n,disabled:n},this.sizeFormClass,this.stateClass],attrs:{id:this.safeId(),role:"group",tabindex:n||c?null:"-1","aria-describedby":this.safeId("__selected_tags__")},on:{click:this.onClick,focusin:this.onFocusin,focusout:this.onFocusout}},[d,h,u,f])}}),nm=Object(r["b"])({components:{BFormTags:em,BTags:em,BFormTag:Pp,BTag:Pp}});function rm(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function im(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?rm(Object(n),!0).forEach((function(e){om(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):rm(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function om(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var am,sm=Object(kn["d"])(Object(zn["m"])(im(im(im(im(im(im({},ia),Wu),Qu),Ju),lf),{},{maxRows:Object(kn["c"])(pt["p"]),noAutoShrink:Object(kn["c"])(pt["g"],!1),noResize:Object(kn["c"])(pt["g"],!1),rows:Object(kn["c"])(pt["p"],2),wrap:Object(kn["c"])(pt["u"],"soft")})),a["ib"]),cm=i["default"].extend({name:a["ib"],directives:{"b-visible":ls},mixins:[ei,oa,ti,Gu,Xu,Zu,uf,Zh,df],props:sm,data:function(){return{heightInPx:null}},computed:{computedStyle:function(){var t={resize:!this.computedRows||this.noResize?"none":null};return this.computedRows||(t.height=this.heightInPx,t.overflowY="scroll"),t},computedMinRows:function(){return Object(lr["d"])(Object(Ie["c"])(this.rows,2),2)},computedMaxRows:function(){return Object(lr["d"])(this.computedMinRows,Object(Ie["c"])(this.maxRows,0))},computedRows:function(){return this.computedMinRows===this.computedMaxRows?this.computedMinRows:null},computedAttrs:function(){var t=this.disabled,e=this.required;return{id:this.safeId(),name:this.name||null,form:this.form||null,disabled:t,placeholder:this.placeholder||null,required:e,autocomplete:this.autocomplete||null,readonly:this.readonly||this.plaintext,rows:this.computedRows,wrap:this.wrap||null,"aria-required":this.required?"true":null,"aria-invalid":this.computedAriaInvalid}},computedListeners:function(){return im(im({},this.bvListeners),{},{input:this.onInput,change:this.onChange,blur:this.onBlur})}},watch:{localValue:function(){this.setHeight()}},mounted:function(){this.setHeight()},methods:{visibleCallback:function(t){t&&this.$nextTick(this.setHeight)},setHeight:function(){var t=this;this.$nextTick((function(){De((function(){t.heightInPx=t.computeHeight()}))}))},computeHeight:function(){if(this.$isServer||!Object(Me["g"])(this.computedRows))return null;var t=this.$el;if(!Ge(t))return null;var e=pn(t),n=Object(Ie["b"])(e.lineHeight,1),r=Object(Ie["b"])(e.borderTopWidth,0)+Object(Ie["b"])(e.borderBottomWidth,0),i=Object(Ie["b"])(e.paddingTop,0)+Object(Ie["b"])(e.paddingBottom,0),o=r+i,a=n*this.computedMinRows+o,s=hn(t,"height")||e.height;un(t,"height","auto");var c=t.scrollHeight;un(t,"height",s);var l=Object(lr["d"])((c-i)/n,2),u=Object(lr["e"])(Object(lr["d"])(l,this.computedMinRows),this.computedMaxRows),d=Object(lr["d"])(Object(lr["b"])(u*n+o),a);return this.noAutoShrink&&Object(Ie["b"])(s,0)>d?s:"".concat(d,"px")}},render:function(t){return t("textarea",{class:this.computedClass,style:this.computedStyle,directives:[{name:"b-visible",value:this.visibleCallback,modifiers:{640:!0}}],attrs:this.computedAttrs,domProps:{value:this.localValue},on:this.computedListeners,ref:"input"})}}),lm=Object(r["b"])({components:{BFormTextarea:cm,BTextarea:cm}});function um(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function dm(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?um(Object(n),!0).forEach((function(e){hm(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):um(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function hm(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function fm(t,e){return vm(t)||gm(t,e)||mm(t,e)||pm()}function pm(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function mm(t,e){if(t){if("string"===typeof t)return bm(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?bm(t,e):void 0}}function bm(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function gm(t,e){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t)){var n=[],r=!0,i=!1,o=void 0;try{for(var a,s=t[Symbol.iterator]();!(r=(a=s.next()).done);r=!0)if(n.push(a.value),e&&n.length===e)break}catch(c){i=!0,o=c}finally{try{r||null==s["return"]||s["return"]()}finally{if(i)throw o}}return n}}function vm(t){if(Array.isArray(t))return t}var wm,ym=On("value",{type:pt["u"],defaultValue:""}),km=ym.mixin,_m=ym.props,Om=ym.prop,zm=ym.event,Am="numeric",jm=function(t){return"00".concat(t||"").slice(-2)},Mm=function(t){t=Object(Ee["g"])(t);var e=null,n=null,r=null;if(Sn["B"].test(t)){var i=t.split(":").map((function(t){return Object(Ie["c"])(t,null)})),o=fm(i,3);e=o[0],n=o[1],r=o[2]}return{hours:Object(Me["p"])(e)?null:e,minutes:Object(Me["p"])(n)?null:n,seconds:Object(Me["p"])(r)?null:r,ampm:Object(Me["p"])(e)||e<12?0:1}},Cm=function(t){var e=t.hours,n=t.minutes,r=t.seconds,i=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(Object(Me["g"])(e)||Object(Me["g"])(n)||i&&Object(Me["g"])(r))return"";var o=[e,n,i?r:0];return o.map(jm).join(":")},Vm=Object(kn["d"])(Object(zn["m"])(dm(dm(dm(dm({},ia),_m),Object(zn["k"])(Ap,["labelIncrement","labelDecrement"])),{},{ariaLabelledby:Object(kn["c"])(pt["u"]),disabled:Object(kn["c"])(pt["g"],!1),hidden:Object(kn["c"])(pt["g"],!1),hideHeader:Object(kn["c"])(pt["g"],!1),hour12:Object(kn["c"])(pt["g"],null),labelAm:Object(kn["c"])(pt["u"],"AM"),labelAmpm:Object(kn["c"])(pt["u"],"AM/PM"),labelHours:Object(kn["c"])(pt["u"],"Hours"),labelMinutes:Object(kn["c"])(pt["u"],"Minutes"),labelNoTimeSelected:Object(kn["c"])(pt["u"],"No time selected"),labelPm:Object(kn["c"])(pt["u"],"PM"),labelSeconds:Object(kn["c"])(pt["u"],"Seconds"),labelSelected:Object(kn["c"])(pt["u"],"Selected time"),locale:Object(kn["c"])(pt["f"]),minutesStep:Object(kn["c"])(pt["p"],1),readonly:Object(kn["c"])(pt["g"],!1),secondsStep:Object(kn["c"])(pt["p"],1),showSeconds:Object(kn["c"])(pt["g"],!1)})),a["pc"]),Sm=i["default"].extend({name:a["pc"],mixins:[oa,km,Cn],props:Vm,data:function(){var t=Mm(this[Om]||"");return{modelHours:t.hours,modelMinutes:t.minutes,modelSeconds:t.seconds,modelAmpm:t.ampm,isLive:!1}},computed:{computedHMS:function(){var t=this.modelHours,e=this.modelMinutes,n=this.modelSeconds;return Cm({hours:t,minutes:e,seconds:n},this.showSeconds)},resolvedOptions:function(){var t=Se(this.locale).filter(An["a"]),e={hour:Am,minute:Am,second:Am};Object(Me["p"])(this.hour12)||(e.hour12=!!this.hour12);var n=new Intl.DateTimeFormat(t,e),r=n.resolvedOptions(),i=r.hour12||!1,o=r.hourCycle||(i?"h12":"h23");return{locale:r.locale,hour12:i,hourCycle:o}},computedLocale:function(){return this.resolvedOptions.locale},computedLang:function(){return(this.computedLocale||"").replace(/-u-.*$/,"")},computedRTL:function(){return ra(this.computedLang)},computedHourCycle:function(){return this.resolvedOptions.hourCycle},is12Hour:function(){return!!this.resolvedOptions.hour12},context:function(){return{locale:this.computedLocale,isRTL:this.computedRTL,hourCycle:this.computedHourCycle,hour12:this.is12Hour,hours:this.modelHours,minutes:this.modelMinutes,seconds:this.showSeconds?this.modelSeconds:0,value:this.computedHMS,formatted:this.formattedTimeString}},valueId:function(){return this.safeId()||null},computedAriaLabelledby:function(){return[this.ariaLabelledby,this.valueId].filter(An["a"]).join(" ")||null},timeFormatter:function(){var t={hour12:this.is12Hour,hourCycle:this.computedHourCycle,hour:Am,minute:Am,timeZone:"UTC"};return this.showSeconds&&(t.second=Am),Uo(this.computedLocale,t)},numberFormatter:function(){var t=new Intl.NumberFormat(this.computedLocale,{style:"decimal",minimumIntegerDigits:2,minimumFractionDigits:0,maximumFractionDigits:0,notation:"standard"});return t.format},formattedTimeString:function(){var t=this.modelHours,e=this.modelMinutes,n=this.showSeconds&&this.modelSeconds||0;return this.computedHMS?this.timeFormatter(Do(Date.UTC(0,0,1,t,e,n))):this.labelNoTimeSelected||" "},spinScopedSlots:function(){var t=this.$createElement;return{increment:function(e){var n=e.hasFocus;return t(Tr["ih"],{props:{scale:n?1.5:1.25},attrs:{"aria-hidden":"true"}})},decrement:function(e){var n=e.hasFocus;return t(Tr["ih"],{props:{flipV:!0,scale:n?1.5:1.25},attrs:{"aria-hidden":"true"}})}}}},watch:(am={},hm(am,Om,(function(t,e){if(t!==e&&!Yr(Mm(t),Mm(this.computedHMS))){var n=Mm(t),r=n.hours,i=n.minutes,o=n.seconds,a=n.ampm;this.modelHours=r,this.modelMinutes=i,this.modelSeconds=o,this.modelAmpm=a}})),hm(am,"computedHMS",(function(t,e){t!==e&&this.$emit(zm,t)})),hm(am,"context",(function(t,e){Yr(t,e)||this.$emit(p,t)})),hm(am,"modelAmpm",(function(t,e){var n=this;if(t!==e){var r=Object(Me["g"])(this.modelHours)?0:this.modelHours;this.$nextTick((function(){0===t&&r>11?n.modelHours=r-12:1===t&&r<12&&(n.modelHours=r+12)}))}})),hm(am,"modelHours",(function(t,e){t!==e&&(this.modelAmpm=t>11?1:0)})),am),created:function(){var t=this;this.$nextTick((function(){t.$emit(p,t.context)}))},mounted:function(){this.setLive(!0)},activated:function(){this.setLive(!0)},deactivated:function(){this.setLive(!1)},beforeDestroy:function(){this.setLive(!1)},methods:{focus:function(){this.disabled||wn(this.$refs.spinners[0])},blur:function(){if(!this.disabled){var t=Ue();tn(this.$el,t)&&yn(t)}},formatHours:function(t){var e=this.computedHourCycle;return t=this.is12Hour&&t>12?t-12:t,t=0===t&&"h12"===e?12:0===t&&"h24"===e?24:12===t&&"h11"===e?0:t,this.numberFormatter(t)},formatMinutes:function(t){return this.numberFormatter(t)},formatSeconds:function(t){return this.numberFormatter(t)},formatAmpm:function(t){return 0===t?this.labelAm:1===t?this.labelPm:""},setHours:function(t){this.modelHours=t},setMinutes:function(t){this.modelMinutes=t},setSeconds:function(t){this.modelSeconds=t},setAmpm:function(t){this.modelAmpm=t},onSpinLeftRight:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=t.type,n=t.keyCode;if(!this.disabled&&"keydown"===e&&(n===Dr||n===$r)){En(t);var r=this.$refs.spinners||[],i=r.map((function(t){return!!t.hasFocus})).indexOf(!0);i+=n===Dr?-1:1,i=i>=r.length?0:i<0?r.length-1:i,wn(r[i])}},setLive:function(t){var e=this;t?this.$nextTick((function(){De((function(){e.isLive=!0}))})):this.isLive=!1}},render:function(t){var e=this;if(this.hidden)return t();var n=this.valueId,r=this.computedAriaLabelledby,i=[],o=function(r,o,a){var s=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},c=e.safeId("_spinbutton_".concat(o,"_"))||null;return i.push(c),t(jp,{class:a,props:dm({id:c,placeholder:"--",vertical:!0,required:!0,disabled:e.disabled,readonly:e.readonly,locale:e.computedLocale,labelIncrement:e.labelIncrement,labelDecrement:e.labelDecrement,wrap:!0,ariaControls:n,min:0},s),scopedSlots:e.spinScopedSlots,on:{change:r},key:o,ref:"spinners",refInFor:!0})},a=function(){return t("div",{staticClass:"d-flex flex-column",class:{"text-muted":e.disabled||e.readonly},attrs:{"aria-hidden":"true"}},[t(Tr["kh"],{props:{shiftV:4,scale:.5}}),t(Tr["kh"],{props:{shiftV:-4,scale:.5}})])},s=[];s.push(o(this.setHours,"hours","b-time-hours",{value:this.modelHours,max:23,step:1,formatterFn:this.formatHours,ariaLabel:this.labelHours})),s.push(a()),s.push(o(this.setMinutes,"minutes","b-time-minutes",{value:this.modelMinutes,max:59,step:this.minutesStep||1,formatterFn:this.formatMinutes,ariaLabel:this.labelMinutes})),this.showSeconds&&(s.push(a()),s.push(o(this.setSeconds,"seconds","b-time-seconds",{value:this.modelSeconds,max:59,step:this.secondsStep||1,formatterFn:this.formatSeconds,ariaLabel:this.labelSeconds}))),this.is12Hour&&s.push(o(this.setAmpm,"ampm","b-time-ampm",{value:this.modelAmpm,max:1,formatterFn:this.formatAmpm,ariaLabel:this.labelAmpm,required:!1})),s=t("div",{staticClass:"d-flex align-items-center justify-content-center mx-auto",attrs:{role:"group",tabindex:this.disabled||this.readonly?null:"-1","aria-labelledby":r},on:{keydown:this.onSpinLeftRight,click:function(t){t.target===t.currentTarget&&e.focus()}}},s);var c=t("output",{staticClass:"form-control form-control-sm text-center",class:{disabled:this.disabled||this.readonly},attrs:{id:n,role:"status",for:i.filter(An["a"]).join(" ")||null,tabindex:this.disabled?null:"-1","aria-live":this.isLive?"polite":"off","aria-atomic":"true"},on:{click:this.focus,focus:this.focus}},[t("bdi",this.formattedTimeString),this.computedHMS?t("span",{staticClass:"sr-only"}," (".concat(this.labelSelected,") ")):""]),l=t("header",{staticClass:"b-time-header",class:{"sr-only":this.hideHeader}},[c]),u=this.normalizeSlot();return u=u?t("footer",{staticClass:"b-time-footer"},u):t(),t("div",{staticClass:"b-time d-inline-flex flex-column text-center",attrs:{role:"group",lang:this.computedLang||null,"aria-labelledby":r||null,"aria-disabled":this.disabled?"true":null,"aria-readonly":this.readonly&&!this.disabled?"true":null}},[l,s,u])}});function xm(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Tm(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?xm(Object(n),!0).forEach((function(e){Pm(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):xm(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Pm(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Im=On("value",{type:pt["u"],defaultValue:""}),Em=Im.mixin,Lm=Im.props,Bm=Im.prop,Hm=Im.event,Fm=Object(zn["j"])(Vm,["hidden","id","value"]),Dm=Object(zn["j"])(Zd,["formattedValue","id","lang","rtl","value"]),Rm=Object(kn["d"])(Object(zn["m"])(Tm(Tm(Tm(Tm(Tm({},ia),Lm),Fm),Dm),{},{closeButtonVariant:Object(kn["c"])(pt["u"],"outline-secondary"),labelCloseButton:Object(kn["c"])(pt["u"],"Close"),labelNowButton:Object(kn["c"])(pt["u"],"Select now"),labelResetButton:Object(kn["c"])(pt["u"],"Reset"),noCloseButton:Object(kn["c"])(pt["g"],!1),nowButton:Object(kn["c"])(pt["g"],!1),nowButtonVariant:Object(kn["c"])(pt["u"],"outline-primary"),resetButton:Object(kn["c"])(pt["g"],!1),resetButtonVariant:Object(kn["c"])(pt["u"],"outline-danger"),resetValue:Object(kn["c"])(pt["k"])})),a["jb"]),Nm=i["default"].extend({name:a["jb"],mixins:[oa,Em],props:Rm,data:function(){return{localHMS:this[Bm]||"",localLocale:null,isRTL:!1,formattedValue:"",isVisible:!1}},computed:{computedLang:function(){return(this.localLocale||"").replace(/-u-.*$/i,"")||null}},watch:(wm={},Pm(wm,Bm,(function(t){this.localHMS=t||""})),Pm(wm,"localHMS",(function(t){this.isVisible&&this.$emit(Hm,t||"")})),wm),methods:{focus:function(){this.disabled||wn(this.$refs.control)},blur:function(){this.disabled||yn(this.$refs.control)},setAndClose:function(t){var e=this;this.localHMS=t,this.$nextTick((function(){e.$refs.control.hide(!0)}))},onInput:function(t){this.localHMS!==t&&(this.localHMS=t)},onContext:function(t){var e=t.isRTL,n=t.locale,r=t.value,i=t.formatted;this.isRTL=e,this.localLocale=n,this.formattedValue=i,this.localHMS=r||"",this.$emit(p,t)},onNowButton:function(){var t=new Date,e=t.getHours(),n=t.getMinutes(),r=this.showSeconds?t.getSeconds():0,i=[e,n,r].map((function(t){return"00".concat(t||"").slice(-2)})).join(":");this.setAndClose(i)},onResetButton:function(){this.setAndClose(this.resetValue)},onCloseButton:function(){this.$refs.control.hide(!0)},onShow:function(){this.isVisible=!0},onShown:function(){var t=this;this.$nextTick((function(){wn(t.$refs.time),t.$emit(Z)}))},onHidden:function(){this.isVisible=!1,this.$emit(C)},defaultButtonFn:function(t){var e=t.isHovered,n=t.hasFocus;return this.$createElement(e||n?Tr["uh"]:Tr["th"],{attrs:{"aria-hidden":"true"}})}},render:function(t){var e=this.localHMS,n=this.disabled,r=this.readonly,i=this.$props,o=Object(Me["p"])(this.placeholder)?this.labelNoTimeSelected:this.placeholder,a=[];if(this.nowButton){var s=this.labelNowButton;a.push(t(Vi,{props:{size:"sm",disabled:n||r,variant:this.nowButtonVariant},attrs:{"aria-label":s||null},on:{click:this.onNowButton},key:"now-btn"},s))}if(this.resetButton){a.length>0&&a.push(t("span"," "));var c=this.labelResetButton;a.push(t(Vi,{props:{size:"sm",disabled:n||r,variant:this.resetButtonVariant},attrs:{"aria-label":c||null},on:{click:this.onResetButton},key:"reset-btn"},c))}if(!this.noCloseButton){a.length>0&&a.push(t("span"," "));var l=this.labelCloseButton;a.push(t(Vi,{props:{size:"sm",disabled:n,variant:this.closeButtonVariant},attrs:{"aria-label":l||null},on:{click:this.onCloseButton},key:"close-btn"},l))}a.length>0&&(a=[t("div",{staticClass:"b-form-date-controls d-flex flex-wrap",class:{"justify-content-between":a.length>1,"justify-content-end":a.length<2}},a)]);var u=t(Sm,{staticClass:"b-form-time-control",props:Tm(Tm({},Object(kn["e"])(Fm,i)),{},{value:e,hidden:!this.isVisible}),on:{input:this.onInput,context:this.onContext},ref:"time"},a);return t(th,{staticClass:"b-form-timepicker",props:Tm(Tm({},Object(kn["e"])(Dm,i)),{},{id:this.safeId(),value:e,formattedValue:e?this.formattedValue:"",placeholder:o,rtl:this.isRTL,lang:this.computedLang}),on:{show:this.onShow,shown:this.onShown,hidden:this.onHidden},scopedSlots:Pm({},yt,this.$scopedSlots[yt]||this.defaultButtonFn),ref:"control"},[u])}}),$m=Object(r["b"])({components:{BFormTimepicker:Nm,BTimepicker:Nm}}),Um=Object(r["b"])({components:{BImg:Ra,BImgLazy:gs}}),qm=Object(kn["d"])({tag:Object(kn["c"])(pt["u"],"div")},a["ub"]),Wm=i["default"].extend({name:a["ub"],functional:!0,props:qm,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.tag,Object(Vn["a"])(r,{staticClass:"input-group-text"}),i)}}),Gm=Object(kn["d"])({append:Object(kn["c"])(pt["g"],!1),id:Object(kn["c"])(pt["u"]),isText:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div")},a["rb"]),Ym=i["default"].extend({name:a["rb"],functional:!0,props:Gm,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.append;return t(n.tag,Object(Vn["a"])(r,{class:{"input-group-append":o,"input-group-prepend":!o},attrs:{id:n.id}}),n.isText?[t(Wm,i)]:i)}});function Km(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Qm(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Km(Object(n),!0).forEach((function(e){Xm(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Km(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Xm(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Jm=Object(kn["d"])(Object(zn["j"])(Gm,["append"]),a["sb"]),Zm=i["default"].extend({name:a["sb"],functional:!0,props:Jm,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(Ym,Object(Vn["a"])(r,{props:Qm(Qm({},n),{},{append:!0})}),i)}});function tb(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function eb(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?tb(Object(n),!0).forEach((function(e){nb(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):tb(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function nb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var rb=Object(kn["d"])(Object(zn["j"])(Gm,["append"]),a["tb"]),ib=i["default"].extend({name:a["tb"],functional:!0,props:rb,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(Ym,Object(Vn["a"])(r,{props:eb(eb({},n),{},{append:!1})}),i)}});function ob(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ab=Object(kn["d"])({append:Object(kn["c"])(pt["u"]),appendHtml:Object(kn["c"])(pt["u"]),id:Object(kn["c"])(pt["u"]),prepend:Object(kn["c"])(pt["u"]),prependHtml:Object(kn["c"])(pt["u"]),size:Object(kn["c"])(pt["u"]),tag:Object(kn["c"])(pt["u"],"div")},a["qb"]),sb=i["default"].extend({name:a["qb"],functional:!0,props:ab,render:function(t,e){var n=e.props,r=e.data,i=e.slots,o=e.scopedSlots,a=n.prepend,s=n.prependHtml,c=n.append,l=n.appendHtml,u=n.size,d=o||{},h=i(),f={},p=t(),m=jn(de,d,h);(m||a||s)&&(p=t(ib,[m?Mn(de,f,d,h):t(Wm,{domProps:Ji(s,a)})]));var b=t(),g=jn(bt,d,h);return(g||c||l)&&(b=t(Zm,[g?Mn(bt,f,d,h):t(Wm,{domProps:Ji(l,c)})])),t(n.tag,Object(Vn["a"])(r,{staticClass:"input-group",class:ob({},"input-group-".concat(u),u),attrs:{id:n.id||null,role:"group"}}),[p,Mn(Ot,f,d,h),b])}}),cb=Object(r["b"])({components:{BInputGroup:sb,BInputGroupAddon:Ym,BInputGroupPrepend:ib,BInputGroupAppend:Zm,BInputGroupText:Wm}});function lb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ub=Object(kn["d"])({fluid:Object(kn["c"])(pt["j"],!1),tag:Object(kn["c"])(pt["u"],"div")},a["C"]),db=i["default"].extend({name:a["C"],functional:!0,props:ub,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.fluid;return t(n.tag,Object(Vn["a"])(r,{class:lb({container:!(o||""===o),"container-fluid":!0===o||""===o},"container-".concat(o),o&&!0!==o)}),i)}});function hb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var fb=Object(kn["d"])({bgVariant:Object(kn["c"])(pt["u"]),borderVariant:Object(kn["c"])(pt["u"]),containerFluid:Object(kn["c"])(pt["j"],!1),fluid:Object(kn["c"])(pt["g"],!1),header:Object(kn["c"])(pt["u"]),headerHtml:Object(kn["c"])(pt["u"]),headerLevel:Object(kn["c"])(pt["p"],3),headerTag:Object(kn["c"])(pt["u"],"h1"),lead:Object(kn["c"])(pt["u"]),leadHtml:Object(kn["c"])(pt["u"]),leadTag:Object(kn["c"])(pt["u"],"p"),tag:Object(kn["c"])(pt["u"],"div"),textVariant:Object(kn["c"])(pt["u"])},a["vb"]),pb=i["default"].extend({name:a["vb"],functional:!0,props:fb,render:function(t,e){var n,r=e.props,i=e.data,o=e.slots,a=e.scopedSlots,s=r.header,c=r.headerHtml,l=r.lead,u=r.leadHtml,d=r.textVariant,h=r.bgVariant,f=r.borderVariant,p=a||{},m=o(),b={},g=t(),v=jn(It,p,m);if(v||s||c){var w=r.headerLevel;g=t(r.headerTag,{class:hb({},"display-".concat(w),w),domProps:v?{}:Ji(c,s)},Mn(It,b,p,m))}var y=t(),k=jn(qt,p,m);(k||l||u)&&(y=t(r.leadTag,{staticClass:"lead",domProps:k?{}:Ji(u,l)},Mn(qt,b,p,m)));var _=[g,y,Mn(Ot,b,p,m)];return r.fluid&&(_=[t(db,{props:{fluid:r.containerFluid}},_)]),t(r.tag,Object(Vn["a"])(i,{staticClass:"jumbotron",class:(n={"jumbotron-fluid":r.fluid},hb(n,"text-".concat(d),d),hb(n,"bg-".concat(h),h),hb(n,"border-".concat(f),f),hb(n,"border",f),n)}),_)}}),mb=Object(r["b"])({components:{BJumbotron:pb}});function bb(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function gb(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?bb(Object(n),!0).forEach((function(e){vb(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):bb(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function vb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var wb=["start","end","center"],yb=Object(Ih["a"])((function(t,e){return e=Object(Ee["h"])(Object(Ee["g"])(e)),e?Object(Ee["c"])(["row-cols",t,e].filter(An["a"]).join("-")):null})),kb=Object(Ih["a"])((function(t){return Object(Ee["c"])(t.replace("cols",""))})),_b=[],Ob=function(){var t=Object(xh["b"])().reduce((function(t,e){return t[Object(kn["g"])(e,"cols")]=Object(kn["c"])(pt["p"]),t}),Object(zn["c"])(null));return _b=Object(zn["h"])(t),Object(kn["d"])(Object(zn["m"])(gb(gb({},t),{},{alignContent:Object(kn["c"])(pt["u"],null,(function(t){return Ve(Se(wb,"between","around","stretch"),t)})),alignH:Object(kn["c"])(pt["u"],null,(function(t){return Ve(Se(wb,"between","around"),t)})),alignV:Object(kn["c"])(pt["u"],null,(function(t){return Ve(Se(wb,"baseline","stretch"),t)})),noGutters:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div")})),a["Wb"])},zb={name:a["Wb"],functional:!0,get props(){return delete this.props,this.props=Ob(),this.props},render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.alignV,s=r.alignH,c=r.alignContent,l=[];return _b.forEach((function(t){var e=yb(kb(t),r[t]);e&&l.push(e)})),l.push((n={"no-gutters":r.noGutters},vb(n,"align-items-".concat(a),a),vb(n,"justify-content-".concat(s),s),vb(n,"align-content-".concat(c),c),n)),t(r.tag,Object(Vn["a"])(i,{staticClass:"row",class:l}),o)}},Ab=Object(r["b"])({components:{BContainer:db,BRow:zb,BCol:$h,BFormRow:Nu}}),jb=Object(r["b"])({components:{BLink:mi}});function Mb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Cb=Object(kn["d"])({flush:Object(kn["c"])(pt["g"],!1),horizontal:Object(kn["c"])(pt["j"],!1),tag:Object(kn["c"])(pt["u"],"div")},a["xb"]),Vb=i["default"].extend({name:a["xb"],functional:!0,props:Cb,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=""===n.horizontal||n.horizontal;o=!n.flush&&o;var a={staticClass:"list-group",class:Mb({"list-group-flush":n.flush,"list-group-horizontal":!0===o},"list-group-horizontal-".concat(o),Object(Me["n"])(o))};return t(n.tag,Object(Vn["a"])(r,a),i)}});function Sb(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function xb(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Sb(Object(n),!0).forEach((function(e){Tb(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Sb(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Tb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Pb=["a","router-link","button","b-link"],Ib=Object(zn["j"])(pi,["event","routerTag"]);delete Ib.href.default,delete Ib.to.default;var Eb=Object(kn["d"])(Object(zn["m"])(xb(xb({},Ib),{},{action:Object(kn["c"])(pt["g"],!1),button:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div"),variant:Object(kn["c"])(pt["u"])})),a["yb"]),Lb=i["default"].extend({name:a["yb"],functional:!0,props:Eb,render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.button,s=r.variant,c=r.active,l=r.disabled,u=jr(r),d=a?"button":u?mi:r.tag,h=!!(r.action||u||a||Ve(Pb,r.tag)),f={},p={};return qe(d,"button")?(i.attrs&&i.attrs.type||(f.type="button"),r.disabled&&(f.disabled=!0)):p=Object(kn["e"])(Ib,r),t(d,Object(Vn["a"])(i,{attrs:f,props:p,staticClass:"list-group-item",class:(n={},Tb(n,"list-group-item-".concat(s),s),Tb(n,"list-group-item-action",h),Tb(n,"active",c),Tb(n,"disabled",l),n)}),o)}}),Bb=Object(r["b"])({components:{BListGroup:Vb,BListGroupItem:Lb}});function Hb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Fb=Object(kn["d"])({right:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div"),verticalAlign:Object(kn["c"])(pt["u"],"top")},a["Ab"]),Db=i["default"].extend({name:a["Ab"],functional:!0,props:Fb,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.verticalAlign,a="top"===o?"start":"bottom"===o?"end":o;return t(n.tag,Object(Vn["a"])(r,{staticClass:"media-aside",class:Hb({"media-aside-right":n.right},"align-self-".concat(a),a)}),i)}}),Rb=Object(kn["d"])({tag:Object(kn["c"])(pt["u"],"div")},a["Bb"]),Nb=i["default"].extend({name:a["Bb"],functional:!0,props:Rb,render:function(t,e){var n=e.props,r=e.data,i=e.children;return t(n.tag,Object(Vn["a"])(r,{staticClass:"media-body"}),i)}}),$b=Object(kn["d"])({noBody:Object(kn["c"])(pt["g"],!1),rightAlign:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div"),verticalAlign:Object(kn["c"])(pt["u"],"top")},a["zb"]),Ub=i["default"].extend({name:a["zb"],functional:!0,props:$b,render:function(t,e){var n=e.props,r=e.data,i=e.slots,o=e.scopedSlots,a=e.children,s=n.noBody,c=n.rightAlign,l=n.verticalAlign,u=s?a:[];if(!s){var d={},h=i(),f=o||{};u.push(t(Nb,Mn(Ot,d,f,h)));var p=Mn(gt,d,f,h);p&&u[c?"push":"unshift"](t(Db,{props:{right:c,verticalAlign:l}},p))}return t(n.tag,Object(Vn["a"])(r,{staticClass:"media"}),u)}}),qb=Object(r["b"])({components:{BMedia:Ub,BMediaAside:Db,BMediaBody:Nb}}),Wb="$_bv_documentHandlers_",Gb=i["default"].extend({created:function(){var t=this;Ae["i"]&&(this[Wb]={},this.$once(st,(function(){var e=t[Wb]||{};delete t[Wb],Object(zn["h"])(e).forEach((function(t){var n=e[t]||[];n.forEach((function(e){return Pn(document,t,e,ft)}))}))})))},methods:{listenDocument:function(t,e,n){t?this.listenOnDocument(e,n):this.listenOffDocument(e,n)},listenOnDocument:function(t,e){this[Wb]&&Object(Me["n"])(t)&&Object(Me["f"])(e)&&(this[Wb][t]=this[Wb][t]||[],Ve(this[Wb][t],e)||(this[Wb][t].push(e),Tn(document,t,e,ft)))},listenOffDocument:function(t,e){this[Wb]&&Object(Me["n"])(t)&&Object(Me["f"])(e)&&(Pn(document,t,e,ft),this[Wb][t]=(this[Wb][t]||[]).filter((function(t){return t!==e})))}}}),Yb="$_bv_windowHandlers_",Kb=i["default"].extend({beforeCreate:function(){this[Yb]={}},beforeDestroy:function(){if(Ae["i"]){var t=this[Yb];delete this[Yb],Object(zn["h"])(t).forEach((function(e){var n=t[e]||[];n.forEach((function(t){return Pn(window,e,t,ft)}))}))}},methods:{listenWindow:function(t,e,n){t?this.listenOnWindow(e,n):this.listenOffWindow(e,n)},listenOnWindow:function(t,e){Ae["i"]&&this[Yb]&&Object(Me["n"])(t)&&Object(Me["f"])(e)&&(this[Yb][t]=this[Yb][t]||[],Ve(this[Yb][t],e)||(this[Yb][t].push(e),Tn(window,t,e,ft)))},listenOffWindow:function(t,e){Ae["i"]&&this[Yb]&&Object(Me["n"])(t)&&Object(Me["f"])(e)&&(Pn(window,t,e,ft),this[Yb][t]=(this[Yb][t]||[]).filter((function(t){return t!==e})))}}}),Qb=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;return t&&t.$options._scopeId||e};function Xb(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Jb=i["default"].extend({computed:{scopedStyleAttrs:function(){var t=Qb(this.$parent);return t?Xb({},t,""):{}}}}),Zb=i["default"].extend({abstract:!0,name:a["zc"],props:{nodes:Object(kn["c"])(pt["c"])},data:function(t){return{updatedNodes:t.nodes}},destroyed:function(){Ne(this.$el)},render:function(t){var e=this.updatedNodes,n=Object(Me["f"])(e)?e({}):e;return n=Se(n).filter(An["a"]),n&&n.length>0&&!n[0].text?n[0]:t()}}),tg={container:Object(kn["c"])([je["c"],pt["u"]],"body"),disabled:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div")},eg=i["default"].extend({name:a["yc"],mixins:[Cn],props:tg,watch:{disabled:{immediate:!0,handler:function(t){t?this.unmountTarget():this.$nextTick(this.mountTarget)}}},created:function(){this.$_defaultFn=null,this.$_target=null},beforeMount:function(){this.mountTarget()},updated:function(){this.updateTarget()},beforeDestroy:function(){this.unmountTarget(),this.$_defaultFn=null},methods:{getContainer:function(){if(Ae["i"]){var t=this.container;return Object(Me["n"])(t)?Xe(t):t}return null},mountTarget:function(){if(!this.$_target){var t=this.getContainer();if(t){var e=document.createElement("div");t.appendChild(e),this.$_target=new Zb({el:e,parent:this,propsData:{nodes:Se(this.normalizeSlot())}})}}},updateTarget:function(){if(Ae["i"]&&this.$_target){var t=this.$scopedSlots.default;this.disabled||(t&&this.$_defaultFn!==t?this.$_target.updatedNodes=t:t||(this.$_target.updatedNodes=this.$slots.default)),this.$_defaultFn=t}},unmountTarget:function(){this.$_target&&this.$_target.$destroy(),this.$_target=null}},render:function(t){if(this.disabled){var e=Se(this.normalizeSlot()).filter(An["a"]);if(e.length>0&&!e[0].text)return e[0]}return t()}});function ng(t){return ng="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"===typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},ng(t)}function rg(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ig(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?rg(Object(n),!0).forEach((function(e){og(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):rg(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function og(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function ag(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function sg(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function cg(t,e,n){return e&&sg(t.prototype,e),n&&sg(t,n),t}function lg(t,e,n){return lg="undefined"!==typeof Reflect&&Reflect.get?Reflect.get:function(t,e,n){var r=ug(t,e);if(r){var i=Object.getOwnPropertyDescriptor(r,e);return i.get?i.get.call(n):i.value}},lg(t,e,n||t)}function ug(t,e){while(!Object.prototype.hasOwnProperty.call(t,e))if(t=gg(t),null===t)break;return t}function dg(t,e){if("function"!==typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),e&&hg(t,e)}function hg(t,e){return hg=Object.setPrototypeOf||function(t,e){return t.__proto__=e,t},hg(t,e)}function fg(t){var e=bg();return function(){var n,r=gg(t);if(e){var i=gg(this).constructor;n=Reflect.construct(r,arguments,i)}else n=r.apply(this,arguments);return pg(this,n)}}function pg(t,e){return!e||"object"!==ng(e)&&"function"!==typeof e?mg(t):e}function mg(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}function bg(){if("undefined"===typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],(function(){}))),!0}catch(t){return!1}}function gg(t){return gg=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)},gg(t)}var vg=function(t){dg(n,t);var e=fg(n);function n(t){var r,i=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return ag(this,n),r=e.call(this,t,i),Object(zn["d"])(mg(r),{trigger:Object(zn["l"])()}),r}return cg(n,null,[{key:"Defaults",get:function(){return ig(ig({},lg(gg(n),"Defaults",this)),{},{trigger:null})}}]),n}(gl),wg=1040,yg=".fixed-top, .fixed-bottom, .is-fixed, .sticky-top",kg=".sticky-top",_g=".navbar-toggler",Og=i["default"].extend({data:function(){return{modals:[],baseZIndex:null,scrollbarWidth:null,isBodyOverflowing:!1}},computed:{modalCount:function(){return this.modals.length},modalsAreOpen:function(){return this.modalCount>0}},watch:{modalCount:function(t,e){Ae["i"]&&(this.getScrollbarWidth(),t>0&&0===e?(this.checkScrollbar(),this.setScrollbar(),nn(document.body,"modal-open")):0===t&&e>0&&(this.resetScrollbar(),rn(document.body,"modal-open")),an(document.body,"data-modal-open-count",String(t)))},modals:function(t){var e=this;this.checkScrollbar(),De((function(){e.updateModals(t||[])}))}},methods:{registerModal:function(t){var e=this;t&&-1===this.modals.indexOf(t)&&(this.modals.push(t),t.$once(st,(function(){e.unregisterModal(t)})))},unregisterModal:function(t){var e=this.modals.indexOf(t);e>-1&&(this.modals.splice(e,1),t._isBeingDestroyed||t._isDestroyed||this.resetModal(t))},getBaseZIndex:function(){if(Object(Me["g"])(this.baseZIndex)&&Ae["i"]){var t=document.createElement("div");nn(t,"modal-backdrop"),nn(t,"d-none"),un(t,"display","none"),document.body.appendChild(t),this.baseZIndex=Object(Ie["c"])(pn(t).zIndex,wg),document.body.removeChild(t)}return this.baseZIndex||wg},getScrollbarWidth:function(){if(Object(Me["g"])(this.scrollbarWidth)&&Ae["i"]){var t=document.createElement("div");nn(t,"modal-scrollbar-measure"),document.body.appendChild(t),this.scrollbarWidth=fn(t).width-t.clientWidth,document.body.removeChild(t)}return this.scrollbarWidth||0},updateModals:function(t){var e=this,n=this.getBaseZIndex(),r=this.getScrollbarWidth();t.forEach((function(t,i){t.zIndex=n+i,t.scrollbarWidth=r,t.isTop=i===e.modals.length-1,t.isBodyOverflowing=e.isBodyOverflowing}))},resetModal:function(t){t&&(t.zIndex=this.getBaseZIndex(),t.isTop=!0,t.isBodyOverflowing=!1)},checkScrollbar:function(){var t=fn(document.body),e=t.left,n=t.right;this.isBodyOverflowing=e+n<window.innerWidth},setScrollbar:function(){var t=document.body;if(t._paddingChangedForModal=t._paddingChangedForModal||[],t._marginChangedForModal=t._marginChangedForModal||[],this.isBodyOverflowing){var e=this.scrollbarWidth;Qe(yg).forEach((function(n){var r=hn(n,"paddingRight")||"";an(n,"data-padding-right",r),un(n,"paddingRight","".concat(Object(Ie["b"])(pn(n).paddingRight,0)+e,"px")),t._paddingChangedForModal.push(n)})),Qe(kg).forEach((function(n){var r=hn(n,"marginRight")||"";an(n,"data-margin-right",r),un(n,"marginRight","".concat(Object(Ie["b"])(pn(n).marginRight,0)-e,"px")),t._marginChangedForModal.push(n)})),Qe(_g).forEach((function(n){var r=hn(n,"marginRight")||"";an(n,"data-margin-right",r),un(n,"marginRight","".concat(Object(Ie["b"])(pn(n).marginRight,0)+e,"px")),t._marginChangedForModal.push(n)}));var n=hn(t,"paddingRight")||"";an(t,"data-padding-right",n),un(t,"paddingRight","".concat(Object(Ie["b"])(pn(t).paddingRight,0)+e,"px"))}},resetScrollbar:function(){var t=document.body;t._paddingChangedForModal&&t._paddingChangedForModal.forEach((function(t){ln(t,"data-padding-right")&&(un(t,"paddingRight",cn(t,"data-padding-right")||""),sn(t,"data-padding-right"))})),t._marginChangedForModal&&t._marginChangedForModal.forEach((function(t){ln(t,"data-margin-right")&&(un(t,"marginRight",cn(t,"data-margin-right")||""),sn(t,"data-margin-right"))})),t._paddingChangedForModal=null,t._marginChangedForModal=null,ln(t,"data-padding-right")&&(un(t,"paddingRight",cn(t,"data-padding-right")||""),sn(t,"data-padding-right"))}}}),zg=new Og;function Ag(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function jg(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ag(Object(n),!0).forEach((function(e){Mg(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ag(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Mg(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Cg=On("visible",{type:pt["g"],defaultValue:!1,event:u}),Vg=Cg.mixin,Sg=Cg.props,xg=Cg.prop,Tg=Cg.event,Pg="backdrop",Ig="esc",Eg="FORCE",Lg="toggle",Bg="cancel",Hg="headerclose",Fg="ok",Dg=[Bg,Hg,Fg],Rg={subtree:!0,childList:!0,characterData:!0,attributes:!0,attributeFilter:["style","class"]},Ng=Object(kn["d"])(Object(zn["m"])(jg(jg(jg({},ia),Sg),{},{ariaLabel:Object(kn["c"])(pt["u"]),autoFocusButton:Object(kn["c"])(pt["u"],null,(function(t){return Object(Me["p"])(t)||Ve(Dg,t)})),bodyBgVariant:Object(kn["c"])(pt["u"]),bodyClass:Object(kn["c"])(pt["e"]),bodyTextVariant:Object(kn["c"])(pt["u"]),busy:Object(kn["c"])(pt["g"],!1),buttonSize:Object(kn["c"])(pt["u"]),cancelDisabled:Object(kn["c"])(pt["g"],!1),cancelTitle:Object(kn["c"])(pt["u"],"Cancel"),cancelTitleHtml:Object(kn["c"])(pt["u"]),cancelVariant:Object(kn["c"])(pt["u"],"secondary"),centered:Object(kn["c"])(pt["g"],!1),contentClass:Object(kn["c"])(pt["e"]),dialogClass:Object(kn["c"])(pt["e"]),footerBgVariant:Object(kn["c"])(pt["u"]),footerBorderVariant:Object(kn["c"])(pt["u"]),footerClass:Object(kn["c"])(pt["e"]),footerTextVariant:Object(kn["c"])(pt["u"]),headerBgVariant:Object(kn["c"])(pt["u"]),headerBorderVariant:Object(kn["c"])(pt["u"]),headerClass:Object(kn["c"])(pt["e"]),headerCloseContent:Object(kn["c"])(pt["u"],"&times;"),headerCloseLabel:Object(kn["c"])(pt["u"],"Close"),headerCloseVariant:Object(kn["c"])(pt["u"]),headerTextVariant:Object(kn["c"])(pt["u"]),hideBackdrop:Object(kn["c"])(pt["g"],!1),hideFooter:Object(kn["c"])(pt["g"],!1),hideHeader:Object(kn["c"])(pt["g"],!1),hideHeaderClose:Object(kn["c"])(pt["g"],!1),ignoreEnforceFocusSelector:Object(kn["c"])(pt["f"]),lazy:Object(kn["c"])(pt["g"],!1),modalClass:Object(kn["c"])(pt["e"]),noCloseOnBackdrop:Object(kn["c"])(pt["g"],!1),noCloseOnEsc:Object(kn["c"])(pt["g"],!1),noEnforceFocus:Object(kn["c"])(pt["g"],!1),noFade:Object(kn["c"])(pt["g"],!1),noStacking:Object(kn["c"])(pt["g"],!1),okDisabled:Object(kn["c"])(pt["g"],!1),okOnly:Object(kn["c"])(pt["g"],!1),okTitle:Object(kn["c"])(pt["u"],"OK"),okTitleHtml:Object(kn["c"])(pt["u"]),okVariant:Object(kn["c"])(pt["u"],"primary"),returnFocus:Object(kn["c"])([je["c"],pt["q"],pt["u"]]),scrollable:Object(kn["c"])(pt["g"],!1),size:Object(kn["c"])(pt["u"],"md"),static:Object(kn["c"])(pt["g"],!1),title:Object(kn["c"])(pt["u"]),titleClass:Object(kn["c"])(pt["e"]),titleHtml:Object(kn["c"])(pt["u"]),titleSrOnly:Object(kn["c"])(pt["g"],!1),titleTag:Object(kn["c"])(pt["u"],"h5")})),a["Cb"]),$g=i["default"].extend({name:a["Cb"],mixins:[Zr,oa,Vg,Gb,ti,Kb,Cn,Jb],inheritAttrs:!1,props:Ng,data:function(){return{isHidden:!0,isVisible:!1,isTransitioning:!1,isShow:!1,isBlock:!1,isOpening:!1,isClosing:!1,ignoreBackdropClick:!1,isModalOverflowing:!1,scrollbarWidth:0,zIndex:zg.getBaseZIndex(),isTop:!0,isBodyOverflowing:!1}},computed:{modalId:function(){return this.safeId()},modalOuterId:function(){return this.safeId("__BV_modal_outer_")},modalHeaderId:function(){return this.safeId("__BV_modal_header_")},modalBodyId:function(){return this.safeId("__BV_modal_body_")},modalTitleId:function(){return this.safeId("__BV_modal_title_")},modalContentId:function(){return this.safeId("__BV_modal_content_")},modalFooterId:function(){return this.safeId("__BV_modal_footer_")},modalBackdropId:function(){return this.safeId("__BV_modal_backdrop_")},modalClasses:function(){return[{fade:!this.noFade,show:this.isShow},this.modalClass]},modalStyles:function(){var t="".concat(this.scrollbarWidth,"px");return{paddingLeft:!this.isBodyOverflowing&&this.isModalOverflowing?t:"",paddingRight:this.isBodyOverflowing&&!this.isModalOverflowing?t:"",display:this.isBlock?"block":"none"}},dialogClasses:function(){var t;return[(t={},Mg(t,"modal-".concat(this.size),this.size),Mg(t,"modal-dialog-centered",this.centered),Mg(t,"modal-dialog-scrollable",this.scrollable),t),this.dialogClass]},headerClasses:function(){var t;return[(t={},Mg(t,"bg-".concat(this.headerBgVariant),this.headerBgVariant),Mg(t,"text-".concat(this.headerTextVariant),this.headerTextVariant),Mg(t,"border-".concat(this.headerBorderVariant),this.headerBorderVariant),t),this.headerClass]},titleClasses:function(){return[{"sr-only":this.titleSrOnly},this.titleClass]},bodyClasses:function(){var t;return[(t={},Mg(t,"bg-".concat(this.bodyBgVariant),this.bodyBgVariant),Mg(t,"text-".concat(this.bodyTextVariant),this.bodyTextVariant),t),this.bodyClass]},footerClasses:function(){var t;return[(t={},Mg(t,"bg-".concat(this.footerBgVariant),this.footerBgVariant),Mg(t,"text-".concat(this.footerTextVariant),this.footerTextVariant),Mg(t,"border-".concat(this.footerBorderVariant),this.footerBorderVariant),t),this.footerClass]},modalOuterStyle:function(){return{position:"absolute",zIndex:this.zIndex}},slotScope:function(){return{cancel:this.onCancel,close:this.onClose,hide:this.hide,ok:this.onOk,visible:this.isVisible}},computeIgnoreEnforceFocusSelector:function(){return Se(this.ignoreEnforceFocusSelector).filter(An["a"]).join(",").trim()},computedAttrs:function(){var t=this.static?{}:this.scopedStyleAttrs;return jg(jg(jg({},t),this.bvAttrs),{},{id:this.modalOuterId})},computedModalAttrs:function(){var t=this.isVisible,e=this.ariaLabel;return{id:this.modalId,role:"dialog","aria-hidden":t?null:"true","aria-modal":t?"true":null,"aria-label":e,"aria-labelledby":this.hideHeader||e||!(this.hasNormalizedSlot(Zt)||this.titleHtml||this.title)?null:this.modalTitleId,"aria-describedby":this.modalBodyId}}},watch:Mg({},xg,(function(t,e){t!==e&&this[t?"show":"hide"]()})),created:function(){this.$_observer=null,this.$_returnFocus=this.returnFocus||null},mounted:function(){this.zIndex=zg.getBaseZIndex(),this.listenOnRoot(Hn(a["Cb"],J),this.showHandler),this.listenOnRoot(Hn(a["Cb"],V),this.hideHandler),this.listenOnRoot(Hn(a["Cb"],it),this.toggleHandler),this.listenOnRoot(Bn(a["Cb"],J),this.modalListener),!0===this[xg]&&this.$nextTick(this.show)},beforeDestroy:function(){this.setObserver(!1),this.isVisible&&(this.isVisible=!1,this.isShow=!1,this.isTransitioning=!1)},methods:{setObserver:function(){var t=arguments.length>0&&void 0!==arguments[0]&&arguments[0];this.$_observer&&this.$_observer.disconnect(),this.$_observer=null,t&&(this.$_observer=Is(this.$refs.content,this.checkModalOverflow.bind(this),Rg))},updateModel:function(t){t!==this[xg]&&this.$emit(Tg,t)},buildEvent:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return new vg(t,jg(jg({cancelable:!1,target:this.$refs.modal||this.$el||null,relatedTarget:null,trigger:null},e),{},{vueTarget:this,componentId:this.modalId}))},show:function(){if(!this.isVisible&&!this.isOpening)if(this.isClosing)this.$once(C,this.show);else{this.isOpening=!0,this.$_returnFocus=this.$_returnFocus||this.getActiveElement();var t=this.buildEvent(J,{cancelable:!0});if(this.emitEvent(t),t.defaultPrevented||this.isVisible)return this.isOpening=!1,void this.updateModel(!1);this.doShow()}},hide:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"";if(this.isVisible&&!this.isClosing){this.isClosing=!0;var e=this.buildEvent(V,{cancelable:t!==Eg,trigger:t||null});if(t===Fg?this.$emit(L,e):t===Bg?this.$emit(l,e):t===Hg&&this.$emit(f,e),this.emitEvent(e),e.defaultPrevented||!this.isVisible)return this.isClosing=!1,void this.updateModel(!0);this.setObserver(!1),this.isVisible=!1,this.updateModel(!1)}},toggle:function(t){t&&(this.$_returnFocus=t),this.isVisible?this.hide(Lg):this.show()},getActiveElement:function(){var t=Ue(Ae["i"]?[document.body]:[]);return t&&t.focus?t:null},doShow:function(){var t=this;zg.modalsAreOpen&&this.noStacking?this.listenOnRootOnce(Bn(a["Cb"],C),this.doShow):(zg.registerModal(this),this.isHidden=!1,this.$nextTick((function(){t.isVisible=!0,t.isOpening=!1,t.updateModel(!0),t.$nextTick((function(){t.setObserver(!0)}))})))},onBeforeEnter:function(){this.isTransitioning=!0,this.setResizeEvent(!0)},onEnter:function(){var t=this;this.isBlock=!0,De((function(){De((function(){t.isShow=!0}))}))},onAfterEnter:function(){var t=this;this.checkModalOverflow(),this.isTransitioning=!1,De((function(){t.emitEvent(t.buildEvent(Z)),t.setEnforceFocus(!0),t.$nextTick((function(){t.focusFirst()}))}))},onBeforeLeave:function(){this.isTransitioning=!0,this.setResizeEvent(!1),this.setEnforceFocus(!1)},onLeave:function(){this.isShow=!1},onAfterLeave:function(){var t=this;this.isBlock=!1,this.isTransitioning=!1,this.isModalOverflowing=!1,this.isHidden=!0,this.$nextTick((function(){t.isClosing=!1,zg.unregisterModal(t),t.returnFocusTo(),t.emitEvent(t.buildEvent(C))}))},emitEvent:function(t){var e=t.type;this.emitOnRoot(Bn(a["Cb"],e),t,t.componentId),this.$emit(e,t)},onDialogMousedown:function(){var t=this,e=this.$refs.modal,n=function n(r){Pn(e,"mouseup",n,ft),r.target===e&&(t.ignoreBackdropClick=!0)};Tn(e,"mouseup",n,ft)},onClickOut:function(t){this.ignoreBackdropClick?this.ignoreBackdropClick=!1:this.isVisible&&!this.noCloseOnBackdrop&&tn(document.body,t.target)&&(tn(this.$refs.content,t.target)||this.hide(Pg))},onOk:function(){this.hide(Fg)},onCancel:function(){this.hide(Bg)},onClose:function(){this.hide(Hg)},onEsc:function(t){t.keyCode===Hr&&this.isVisible&&!this.noCloseOnEsc&&this.hide(Ig)},focusHandler:function(t){var e=this.$refs.content,n=t.target;if(!(this.noEnforceFocus||!this.isTop||!this.isVisible||!e||document===n||tn(e,n)||this.computeIgnoreEnforceFocusSelector&&Ze(this.computeIgnoreEnforceFocusSelector,n,!0))){var r=vn(this.$refs.content),i=this.$refs["bottom-trap"],o=this.$refs["top-trap"];if(i&&n===i){if(wn(r[0]))return}else if(o&&n===o&&wn(r[r.length-1]))return;wn(e,{preventScroll:!0})}},setEnforceFocus:function(t){this.listenDocument(t,"focusin",this.focusHandler)},setResizeEvent:function(t){this.listenWindow(t,"resize",this.checkModalOverflow),this.listenWindow(t,"orientationchange",this.checkModalOverflow)},showHandler:function(t,e){t===this.modalId&&(this.$_returnFocus=e||this.getActiveElement(),this.show())},hideHandler:function(t){t===this.modalId&&this.hide("event")},toggleHandler:function(t,e){t===this.modalId&&this.toggle(e)},modalListener:function(t){this.noStacking&&t.vueTarget!==this&&this.hide()},focusFirst:function(){var t=this;Ae["i"]&&De((function(){var e=t.$refs.modal,n=t.$refs.content,r=t.getActiveElement();if(e&&n&&(!r||!tn(n,r))){var i=t.$refs["ok-button"],o=t.$refs["cancel-button"],a=t.$refs["close-button"],s=t.autoFocusButton,c=s===Fg&&i?i.$el||i:s===Bg&&o?o.$el||o:s===Hg&&a?a.$el||a:n;wn(c),c===n&&t.$nextTick((function(){e.scrollTop=0}))}}))},returnFocusTo:function(){var t=this.returnFocus||this.$_returnFocus||null;this.$_returnFocus=null,this.$nextTick((function(){t=Object(Me["n"])(t)?Xe(t):t,t&&(t=t.$el||t,wn(t))}))},checkModalOverflow:function(){if(this.isVisible){var t=this.$refs.modal;this.isModalOverflowing=t.scrollHeight>document.documentElement.clientHeight}},makeModal:function(t){var e=t();if(!this.hideHeader){var n=this.normalizeSlot(Qt,this.slotScope);if(!n){var r=t();this.hideHeaderClose||(r=t(Rn,{props:{content:this.headerCloseContent,disabled:this.isTransitioning,ariaLabel:this.headerCloseLabel,textVariant:this.headerCloseVariant||this.headerTextVariant},on:{click:this.onClose},ref:"close-button"},[this.normalizeSlot(Xt)])),n=[t(this.titleTag,{staticClass:"modal-title",class:this.titleClasses,attrs:{id:this.modalTitleId},domProps:this.hasNormalizedSlot(Zt)?{}:Ji(this.titleHtml,this.title)},this.normalizeSlot(Zt,this.slotScope)),r]}e=t("header",{staticClass:"modal-header",class:this.headerClasses,attrs:{id:this.modalHeaderId},ref:"header"},[n])}var i=t("div",{staticClass:"modal-body",class:this.bodyClasses,attrs:{id:this.modalBodyId},ref:"body"},this.normalizeSlot(Ot,this.slotScope)),a=t();if(!this.hideFooter){var s=this.normalizeSlot(Kt,this.slotScope);if(!s){var c=t();this.okOnly||(c=t(Vi,{props:{variant:this.cancelVariant,size:this.buttonSize,disabled:this.cancelDisabled||this.busy||this.isTransitioning},domProps:this.hasNormalizedSlot(Yt)?{}:Ji(this.cancelTitleHtml,this.cancelTitle),on:{click:this.onCancel},ref:"cancel-button"},this.normalizeSlot(Yt)));var l=t(Vi,{props:{variant:this.okVariant,size:this.buttonSize,disabled:this.okDisabled||this.busy||this.isTransitioning},domProps:this.hasNormalizedSlot(Jt)?{}:Ji(this.okTitleHtml,this.okTitle),on:{click:this.onOk},ref:"ok-button"},this.normalizeSlot(Jt));s=[c,l]}a=t("footer",{staticClass:"modal-footer",class:this.footerClasses,attrs:{id:this.modalFooterId},ref:"footer"},[s])}var u=t("div",{staticClass:"modal-content",class:this.contentClass,attrs:{id:this.modalContentId,tabindex:"-1"},ref:"content"},[e,i,a]),d=t(),h=t();this.isVisible&&!this.noEnforceFocus&&(d=t("span",{attrs:{tabindex:"0"},ref:"top-trap"}),h=t("span",{attrs:{tabindex:"0"},ref:"bottom-trap"}));var f=t("div",{staticClass:"modal-dialog",class:this.dialogClasses,on:{mousedown:this.onDialogMousedown},ref:"dialog"},[d,u,h]),p=t("div",{staticClass:"modal",class:this.modalClasses,style:this.modalStyles,attrs:this.computedModalAttrs,on:{keydown:this.onEsc,click:this.onClickOut},directives:[{name:"show",value:this.isVisible}],ref:"modal"},[f]);p=t("transition",{props:{enterClass:"",enterToClass:"",enterActiveClass:"",leaveClass:"",leaveActiveClass:"",leaveToClass:""},on:{beforeEnter:this.onBeforeEnter,enter:this.onEnter,afterEnter:this.onAfterEnter,beforeLeave:this.onBeforeLeave,leave:this.onLeave,afterLeave:this.onAfterLeave}},[p]);var m=t();return!this.hideBackdrop&&this.isVisible&&(m=t("div",{staticClass:"modal-backdrop",attrs:{id:this.modalBackdropId}},this.normalizeSlot(Gt))),m=t(Kn,{props:{noFade:this.noFade}},[m]),t("div",{style:this.modalOuterStyle,attrs:this.computedAttrs,key:"modal-outer-".concat(this[o["a"]])},[p,m])}},render:function(t){return this.static?this.lazy&&this.isHidden?t():this.makeModal(t):this.isHidden?t():t(eg,[this.makeModal(t)])}}),Ug=Hn(a["Cb"],J),qg="__bv_modal_directive__",Wg=function(t){var e=t.modifiers,n=void 0===e?{}:e,r=t.arg,i=t.value;return Object(Me["n"])(i)?i:Object(Me["n"])(r)?r:Object(zn["h"])(n).reverse()[0]},Gg=function(t){return t&&Je(t,".dropdown-menu > li, li.nav-item")&&Xe("a, button",t)||t},Yg=function(t){t&&"BUTTON"!==t.tagName&&(ln(t,"role")||an(t,"role","button"),"A"===t.tagName||ln(t,"tabindex")||an(t,"tabindex","0"))},Kg=function(t,e,n){var r=Wg(e),i=Gg(t);if(r&&i){var o=function(t){var e=t.currentTarget;if(!Ye(e)){var i=t.type,o=t.keyCode;"click"!==i&&("keydown"!==i||o!==Br&&o!==Ur)||n.context.$root.$emit(Ug,r,e)}};t[qg]={handler:o,target:r,trigger:i},Yg(i),Tn(i,"click",o,ht),"BUTTON"!==i.tagName&&"button"===cn(i,"role")&&Tn(i,"keydown",o,ht)}},Qg=function(t){var e=t[qg]||{},n=e.trigger,r=e.handler;n&&r&&(Pn(n,"click",r,ht),Pn(n,"keydown",r,ht),Pn(t,"click",r,ht),Pn(t,"keydown",r,ht)),delete t[qg]},Xg=function(t,e,n){var r=t[qg]||{},i=Wg(e),o=Gg(t);i===r.target&&o===r.trigger||(Qg(t,e,n),Kg(t,e,n)),Yg(o)},Jg=function(){},Zg={inserted:Xg,updated:Jg,componentUpdated:Xg,unbind:Qg};function tv(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function ev(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function nv(t,e,n){return e&&ev(t.prototype,e),n&&ev(t,n),t}function rv(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function iv(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?rv(Object(n),!0).forEach((function(e){ov(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):rv(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function ov(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function av(t){return uv(t)||lv(t)||cv(t)||sv()}function sv(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function cv(t,e){if(t){if("string"===typeof t)return dv(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?dv(t,e):void 0}}function lv(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function uv(t){if(Array.isArray(t))return dv(t)}function dv(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}var hv="$bvModal",fv="_bv__modal",pv=["id"].concat(av(Object(zn["h"])(Object(zn["j"])(Ng,["busy","lazy","noStacking","static","visible"])))),mv=function(){},bv={msgBoxContent:"default",title:"modal-title",okTitle:"modal-ok",cancelTitle:"modal-cancel"},gv=function(t){return pv.reduce((function(e,n){return Object(Me["o"])(t[n])||(e[n]=t[n]),e}),{})},vv=function(t){var e=t.extend({name:a["Db"],extends:$g,destroyed:function(){this.$el&&this.$el.parentNode&&this.$el.parentNode.removeChild(this.$el)},mounted:function(){var t=this,e=function(){t.$nextTick((function(){De((function(){t.$destroy()}))}))};this.$parent.$once(ct,e),this.$once(C,e),this.$router&&this.$route&&this.$once(st,this.$watch("$router",e)),this.show()}}),n=function(t,n){var r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:mv;if(!Object(Vs["d"])(hv)&&!Object(Vs["c"])(hv)){var i=new e({parent:t,propsData:iv(iv(iv({},gv(Object(xh["c"])(a["Cb"]))),{},{hideHeaderClose:!0,hideHeader:!(n.title||n.titleHtml)},Object(zn["j"])(n,Object(zn["h"])(bv))),{},{lazy:!1,busy:!1,visible:!1,noStacking:!1,noEnforceFocus:!1})});return Object(zn["h"])(bv).forEach((function(t){Object(Me["o"])(n[t])||(i.$slots[bv[t]]=Se(n[t]))})),new Promise((function(t,e){var n=!1;i.$once(ct,(function(){n||e(new Error("BootstrapVue MsgBox destroyed before resolve"))})),i.$on(V,(function(e){if(!e.defaultPrevented){var i=r(e);e.defaultPrevented||(n=!0,t(i))}}));var o=document.createElement("div");document.body.appendChild(o),i.$mount(o)}))}},r=function(t,e){var r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},i=arguments.length>3&&void 0!==arguments[3]?arguments[3]:null;if(e&&!Object(Vs["c"])(hv)&&!Object(Vs["d"])(hv)&&Object(Me["f"])(i))return n(t,iv(iv({},gv(r)),{},{msgBoxContent:e}),i)},i=function(){function t(e){tv(this,t),Object(zn["a"])(this,{_vm:e,_root:e.$root}),Object(zn["d"])(this,{_vm:Object(zn["l"])(),_root:Object(zn["l"])()})}return nv(t,[{key:"show",value:function(t){if(t&&this._root){for(var e,n=arguments.length,r=new Array(n>1?n-1:0),i=1;i<n;i++)r[i-1]=arguments[i];(e=this._root).$emit.apply(e,[Hn(a["Cb"],"show"),t].concat(r))}}},{key:"hide",value:function(t){if(t&&this._root){for(var e,n=arguments.length,r=new Array(n>1?n-1:0),i=1;i<n;i++)r[i-1]=arguments[i];(e=this._root).$emit.apply(e,[Hn(a["Cb"],"hide"),t].concat(r))}}},{key:"msgBoxOk",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=iv(iv({},e),{},{okOnly:!0,okDisabled:!1,hideFooter:!1,msgBoxContent:t});return r(this._vm,t,n,(function(){return!0}))}},{key:"msgBoxConfirm",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=iv(iv({},e),{},{okOnly:!1,okDisabled:!1,cancelDisabled:!1,hideFooter:!1});return r(this._vm,t,n,(function(t){var e=t.trigger;return"ok"===e||"cancel"!==e&&null}))}}]),t}();t.mixin({beforeCreate:function(){this[fv]=new i(this)}}),Object(zn["g"])(t.prototype,hv)||Object(zn["e"])(t.prototype,hv,{get:function(){return this&&this[fv]||Object(Vs["a"])('"'.concat(hv,'" must be accessed from a Vue instance "this" context.'),a["Cb"]),this[fv]}})},wv=Object(r["b"])({plugins:{plugin:vv}}),yv=Object(r["b"])({components:{BModal:$g},directives:{VBModal:Zg},plugins:{BVModalPlugin:wv}});function kv(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var _v=function(t){return t="left"===t?"start":"right"===t?"end":t,"justify-content-".concat(t)},Ov=Object(kn["d"])({align:Object(kn["c"])(pt["u"]),cardHeader:Object(kn["c"])(pt["g"],!1),fill:Object(kn["c"])(pt["g"],!1),justified:Object(kn["c"])(pt["g"],!1),pills:Object(kn["c"])(pt["g"],!1),small:Object(kn["c"])(pt["g"],!1),tabs:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"ul"),vertical:Object(kn["c"])(pt["g"],!1)},a["Eb"]),zv=i["default"].extend({name:a["Eb"],functional:!0,props:Ov,render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.tabs,s=r.pills,c=r.vertical,l=r.align,u=r.cardHeader;return t(r.tag,Object(Vn["a"])(i,{staticClass:"nav",class:(n={"nav-tabs":a,"nav-pills":s&&!a,"card-header-tabs":!c&&u&&a,"card-header-pills":!c&&u&&s&&!a,"flex-column":c,"nav-fill":!c&&r.fill,"nav-justified":!c&&r.justified},kv(n,_v(l),!c&&l),kv(n,"small",r.small),n)}),o)}});function Av(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function jv(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Av(Object(n),!0).forEach((function(e){Mv(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Av(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Mv(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Cv=Object(zn["j"])(pi,["event","routerTag"]),Vv=Object(kn["d"])(Object(zn["m"])(jv(jv({},Cv),{},{linkAttrs:Object(kn["c"])(pt["q"],{}),linkClasses:Object(kn["c"])(pt["e"])})),a["Kb"]),Sv=i["default"].extend({name:a["Kb"],functional:!0,props:Vv,render:function(t,e){var n=e.props,r=e.data,i=e.listeners,o=e.children;return t("li",Object(Vn["a"])(Object(zn["j"])(r,["on"]),{staticClass:"nav-item"}),[t(mi,{staticClass:"nav-link",class:n.linkClasses,attrs:n.linkAttrs,props:Object(kn["e"])(Cv,n),on:i},o)])}}),xv={},Tv=i["default"].extend({name:a["Mb"],functional:!0,props:xv,render:function(t,e){var n=e.data,r=e.children;return t("li",Object(Vn["a"])(n,{staticClass:"navbar-text"}),r)}});function Pv(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Iv(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Pv(Object(n),!0).forEach((function(e){Ev(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Pv(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Ev(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Lv=Object(zn["j"])(nu,["inline"]),Bv=Object(kn["d"])(Object(zn["m"])(Iv(Iv({},Lv),{},{formClass:Object(kn["c"])(pt["e"])})),a["Jb"]),Hv=i["default"].extend({name:a["Jb"],functional:!0,props:Bv,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=e.listeners,a=t(ru,{class:n.formClass,props:Iv(Iv({},Object(kn["e"])(Lv,n)),{},{inline:!0}),attrs:r.attrs,on:o},i);return t("li",Object(Vn["a"])(Object(zn["j"])(r,["attrs","on"]),{staticClass:"form-inline"}),[a])}});function Fv(t){return $v(t)||Nv(t)||Rv(t)||Dv()}function Dv(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function Rv(t,e){if(t){if("string"===typeof t)return Uv(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Uv(t,e):void 0}}function Nv(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function $v(t){if(Array.isArray(t))return Uv(t)}function Uv(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function qv(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Wv(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?qv(Object(n),!0).forEach((function(e){Gv(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):qv(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Gv(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Yv=Object(kn["d"])(Object(zn["m"])(Wv(Wv({},ia),Object(zn["k"])(Pl,[].concat(Fv(Object(zn["h"])(Cl)),["html","lazy","menuClass","noCaret","role","text","toggleClass"])))),a["Lb"]),Kv=i["default"].extend({name:a["Lb"],mixins:[oa,Vl,Cn],props:Yv,computed:{toggleId:function(){return this.safeId("_BV_toggle_")},dropdownClasses:function(){return[this.directionClass,this.boundaryClass,{show:this.visible}]},menuClasses:function(){return[this.menuClass,{"dropdown-menu-right":this.right,show:this.visible}]},toggleClasses:function(){return[this.toggleClass,{"dropdown-toggle-no-caret":this.noCaret}]}},render:function(t){var e=this.toggleId,n=this.visible,r=this.hide,i=t(mi,{staticClass:"nav-link dropdown-toggle",class:this.toggleClasses,props:{href:"#".concat(this.id||""),disabled:this.disabled},attrs:{id:e,role:"button","aria-haspopup":"true","aria-expanded":n?"true":"false"},on:{mousedown:this.onMousedown,click:this.toggle,keydown:this.toggle},ref:"toggle"},[this.normalizeSlot([yt,we])||t("span",{domProps:Ji(this.html,this.text)})]),o=t("ul",{staticClass:"dropdown-menu",class:this.menuClasses,attrs:{tabindex:"-1","aria-labelledby":e},on:{keydown:this.onKeydown},ref:"menu"},!this.lazy||n?this.normalizeSlot(Ot,{hide:r}):[t()]);return t("li",{staticClass:"nav-item b-nav-dropdown dropdown",class:this.dropdownClasses,attrs:{id:this.safeId()}},[i,o])}}),Qv=Object(r["b"])({components:{BNav:zv,BNavItem:Sv,BNavText:Tv,BNavForm:Hv,BNavItemDropdown:Kv,BNavItemDd:Kv,BNavDropdown:Kv,BNavDd:Kv},plugins:{DropdownPlugin:gu}});function Xv(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Jv=Object(kn["d"])({fixed:Object(kn["c"])(pt["u"]),print:Object(kn["c"])(pt["g"],!1),sticky:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"nav"),toggleable:Object(kn["c"])(pt["j"],!1),type:Object(kn["c"])(pt["u"],"light"),variant:Object(kn["c"])(pt["u"])},a["Fb"]),Zv=i["default"].extend({name:a["Fb"],mixins:[Cn],provide:function(){return{bvNavbar:this}},props:Jv,computed:{breakpointClass:function(){var t=this.toggleable,e=Object(xh["a"])()[0],n=null;return t&&Object(Me["n"])(t)&&t!==e?n="navbar-expand-".concat(t):!1===t&&(n="navbar-expand"),n}},render:function(t){var e,n=this.tag,r=this.type,i=this.variant,o=this.fixed;return t(n,{staticClass:"navbar",class:[(e={"d-print":this.print,"sticky-top":this.sticky},Xv(e,"navbar-".concat(r),r),Xv(e,"bg-".concat(i),i),Xv(e,"fixed-".concat(o),o),e),this.breakpointClass],attrs:{role:qe(n,"nav")?null:"navigation"}},[this.normalizeSlot()])}});function tw(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ew=function(t){return t="left"===t?"start":"right"===t?"end":t,"justify-content-".concat(t)},nw=Object(kn["d"])(Object(zn["k"])(Ov,["tag","fill","justified","align","small"]),a["Hb"]),rw=i["default"].extend({name:a["Hb"],functional:!0,props:nw,render:function(t,e){var n,r=e.props,i=e.data,o=e.children,a=r.align;return t(r.tag,Object(Vn["a"])(i,{staticClass:"navbar-nav",class:(n={"nav-fill":r.fill,"nav-justified":r.justified},tw(n,ew(a),a),tw(n,"small",r.small),n)}),o)}});function iw(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ow(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?iw(Object(n),!0).forEach((function(e){aw(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):iw(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function aw(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var sw=Object(zn["j"])(pi,["event","routerTag"]);sw.href.default=void 0,sw.to.default=void 0;var cw=Object(kn["d"])(Object(zn["m"])(ow(ow({},sw),{},{tag:Object(kn["c"])(pt["u"],"div")})),a["Gb"]),lw=i["default"].extend({name:a["Gb"],functional:!0,props:cw,render:function(t,e){var n=e.props,r=e.data,i=e.children,o=n.to||n.href,a=o?mi:n.tag;return t(a,Object(Vn["a"])(r,{staticClass:"navbar-brand",props:o?Object(kn["e"])(sw,n):{}}),i)}}),uw="navbar-toggler",dw=Bn(a["A"],"state"),hw=Bn(a["A"],"sync-state"),fw=Object(kn["d"])({disabled:Object(kn["c"])(pt["g"],!1),label:Object(kn["c"])(pt["u"],"Toggle navigation"),target:Object(kn["c"])(pt["f"],void 0,!0)},a["Ib"]),pw=i["default"].extend({name:a["Ib"],directives:{VBToggle:il},mixins:[ti,Cn],props:fw,data:function(){return{toggleState:!1}},created:function(){this.listenOnRoot(dw,this.handleStateEvt),this.listenOnRoot(hw,this.handleStateEvt)},methods:{onClick:function(t){this.disabled||this.$emit(h,t)},handleStateEvt:function(t,e){t===this.target&&(this.toggleState=e)}},render:function(t){var e=this.disabled;return t("button",{staticClass:uw,class:{disabled:e},directives:[{name:"VBToggle",value:this.target}],attrs:{type:"button",disabled:e,"aria-label":this.label},on:{click:this.onClick}},[this.normalizeSlot(Ot,{expanded:this.toggleState})||t("span",{staticClass:"".concat(uw,"-icon")})])}}),mw=Object(r["b"])({components:{BNavbar:Zv,BNavbarNav:rw,BNavbarBrand:lw,BNavbarToggle:pw,BNavToggle:pw},plugins:{NavPlugin:Qv,CollapsePlugin:al,DropdownPlugin:gu}});function bw(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var gw=Object(kn["d"])({label:Object(kn["c"])(pt["u"]),role:Object(kn["c"])(pt["u"],"status"),small:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"span"),type:Object(kn["c"])(pt["u"],"border"),variant:Object(kn["c"])(pt["u"])},a["dc"]),vw=i["default"].extend({name:a["dc"],functional:!0,props:gw,render:function(t,e){var n,r=e.props,i=e.data,o=e.slots,a=e.scopedSlots,s=o(),c=a||{},l=Mn($t,{},c,s)||r.label;return l&&(l=t("span",{staticClass:"sr-only"},l)),t(r.tag,Object(Vn["a"])(i,{attrs:{role:l?r.role||"status":null,"aria-hidden":l?null:"true"},class:(n={},bw(n,"spinner-".concat(r.type),r.type),bw(n,"spinner-".concat(r.type,"-sm"),r.small),bw(n,"text-".concat(r.variant),r.variant),n)}),[l||t()])}});function ww(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function yw(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?ww(Object(n),!0).forEach((function(e){kw(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):ww(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function kw(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var _w,Ow={top:0,left:0,bottom:0,right:0},zw=Object(kn["d"])({bgColor:Object(kn["c"])(pt["u"]),blur:Object(kn["c"])(pt["u"],"2px"),fixed:Object(kn["c"])(pt["g"],!1),noCenter:Object(kn["c"])(pt["g"],!1),noFade:Object(kn["c"])(pt["g"],!1),noWrap:Object(kn["c"])(pt["g"],!1),opacity:Object(kn["c"])(pt["p"],.85,(function(t){var e=Object(Ie["b"])(t,0);return e>=0&&e<=1})),overlayTag:Object(kn["c"])(pt["u"],"div"),rounded:Object(kn["c"])(pt["j"],!1),show:Object(kn["c"])(pt["g"],!1),spinnerSmall:Object(kn["c"])(pt["g"],!1),spinnerType:Object(kn["c"])(pt["u"],"border"),spinnerVariant:Object(kn["c"])(pt["u"]),variant:Object(kn["c"])(pt["u"],"light"),wrapTag:Object(kn["c"])(pt["u"],"div"),zIndex:Object(kn["c"])(pt["p"],10)},a["Nb"]),Aw=i["default"].extend({name:a["Nb"],mixins:[Cn],props:zw,computed:{computedRounded:function(){var t=this.rounded;return!0===t||""===t?"rounded":t?"rounded-".concat(t):""},computedVariant:function(){var t=this.variant;return t&&!this.bgColor?"bg-".concat(t):""},slotScope:function(){return{spinnerType:this.spinnerType||null,spinnerVariant:this.spinnerVariant||null,spinnerSmall:this.spinnerSmall}}},methods:{defaultOverlayFn:function(t){var e=t.spinnerType,n=t.spinnerVariant,r=t.spinnerSmall;return this.$createElement(vw,{props:{type:e,variant:n,small:r}})}},render:function(t){var e=this,n=this.show,r=this.fixed,i=this.noFade,o=this.noWrap,a=this.slotScope,s=t();if(n){var c=t("div",{staticClass:"position-absolute",class:[this.computedVariant,this.computedRounded],style:yw(yw({},Ow),{},{opacity:this.opacity,backgroundColor:this.bgColor||null,backdropFilter:this.blur?"blur(".concat(this.blur,")"):null})}),l=t("div",{staticClass:"position-absolute",style:this.noCenter?yw({},Ow):{top:"50%",left:"50%",transform:"translateX(-50%) translateY(-50%)"}},[this.normalizeSlot(ce,a)||this.defaultOverlayFn(a)]);s=t(this.overlayTag,{staticClass:"b-overlay",class:{"position-absolute":!o||o&&!r,"position-fixed":o&&r},style:yw(yw({},Ow),{},{zIndex:this.zIndex||10}),on:{click:function(t){return e.$emit(h,t)}},key:"overlay"},[c,l])}return s=t(Kn,{props:{noFade:i,appear:!0},on:{"after-enter":function(){return e.$emit(Z)},"after-leave":function(){return e.$emit(C)}}},[s]),o?s:t(this.wrapTag,{staticClass:"b-overlay-wrap position-relative",attrs:{"aria-busy":n?"true":null}},o?[s]:[this.normalizeSlot(),s])}}),jw=Object(r["b"])({components:{BOverlay:Aw}});function Mw(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Cw(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Mw(Object(n),!0).forEach((function(e){Vw(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Mw(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Vw(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Sw=On("value",{type:pt["i"],defaultValue:null,validator:function(t){return!(!Object(Me["g"])(t)&&Object(Ie["c"])(t,0)<1)||(Object(Vs["a"])('"v-model" value must be a number greater than "0"',a["Ob"]),!1)}}),xw=Sw.mixin,Tw=Sw.props,Pw=Sw.prop,Iw=Sw.event,Ew=3,Lw=5,Bw=function(t,e){return xe(e,(function(e,n){return{number:t+n,classes:null}}))},Hw=function(t){var e=Object(Ie["c"])(t)||1;return e<1?Lw:e},Fw=function(t,e){var n=Object(Ie["c"])(t)||1;return n>e?e:n<1?1:n},Dw=function(t){if(t.keyCode===Ur)return En(t,{immediatePropagation:!0}),t.currentTarget.click(),!1},Rw=Object(kn["d"])(Object(zn["m"])(Cw(Cw({},Tw),{},{align:Object(kn["c"])(pt["u"],"left"),ariaLabel:Object(kn["c"])(pt["u"],"Pagination"),disabled:Object(kn["c"])(pt["g"],!1),ellipsisClass:Object(kn["c"])(pt["e"]),ellipsisText:Object(kn["c"])(pt["u"],"…"),firstClass:Object(kn["c"])(pt["e"]),firstNumber:Object(kn["c"])(pt["g"],!1),firstText:Object(kn["c"])(pt["u"],"«"),hideEllipsis:Object(kn["c"])(pt["g"],!1),hideGotoEndButtons:Object(kn["c"])(pt["g"],!1),labelFirstPage:Object(kn["c"])(pt["u"],"Go to first page"),labelLastPage:Object(kn["c"])(pt["u"],"Go to last page"),labelNextPage:Object(kn["c"])(pt["u"],"Go to next page"),labelPage:Object(kn["c"])(pt["m"],"Go to page"),labelPrevPage:Object(kn["c"])(pt["u"],"Go to previous page"),lastClass:Object(kn["c"])(pt["e"]),lastNumber:Object(kn["c"])(pt["g"],!1),lastText:Object(kn["c"])(pt["u"],"»"),limit:Object(kn["c"])(pt["p"],Lw,(function(t){return!(Object(Ie["c"])(t,0)<1)||(Object(Vs["a"])('Prop "limit" must be a number greater than "0"',a["Ob"]),!1)})),nextClass:Object(kn["c"])(pt["e"]),nextText:Object(kn["c"])(pt["u"],"›"),pageClass:Object(kn["c"])(pt["e"]),pills:Object(kn["c"])(pt["g"],!1),prevClass:Object(kn["c"])(pt["e"]),prevText:Object(kn["c"])(pt["u"],"‹"),size:Object(kn["c"])(pt["u"])})),"pagination"),Nw=i["default"].extend({mixins:[xw,Cn],props:Rw,data:function(){var t=Object(Ie["c"])(this[Pw],0);return t=t>0?t:-1,{currentPage:t,localNumberOfPages:1,localLimit:Lw}},computed:{btnSize:function(){var t=this.size;return t?"pagination-".concat(t):""},alignment:function(){var t=this.align;return"center"===t?"justify-content-center":"end"===t||"right"===t?"justify-content-end":"fill"===t?"text-center":""},styleClass:function(){return this.pills?"b-pagination-pills":""},computedCurrentPage:function(){return Fw(this.currentPage,this.localNumberOfPages)},paginationParams:function(){var t=this.localLimit,e=this.localNumberOfPages,n=this.computedCurrentPage,r=this.hideEllipsis,i=this.firstNumber,o=this.lastNumber,a=!1,s=!1,c=t,l=1;e<=t?c=e:n<t-1&&t>Ew?(r&&!o||(s=!0,c=t-(i?0:1)),c=Object(lr["e"])(c,t)):e-n+2<t&&t>Ew?(r&&!i||(a=!0,c=t-(o?0:1)),l=e-c+1):(t>Ew&&(c=t-(r?0:2),a=!(r&&!i),s=!(r&&!o)),l=n-Object(lr["c"])(c/2)),l<1?(l=1,a=!1):l>e-c&&(l=e-c+1,s=!1),a&&i&&l<4&&(c+=2,l=1,a=!1);var u=l+c-1;return s&&o&&u>e-3&&(c+=u===e-2?2:3,s=!1),t<=Ew&&(i&&1===l?c=Object(lr["e"])(c+1,e,t+1):o&&e===l+c-1&&(l=Object(lr["d"])(l-1,1),c=Object(lr["e"])(e-l+1,e,t+1))),c=Object(lr["e"])(c,e-l+1),{showFirstDots:a,showLastDots:s,numberOfLinks:c,startNumber:l}},pageList:function(){var t=this.paginationParams,e=t.numberOfLinks,n=t.startNumber,r=this.computedCurrentPage,i=Bw(n,e);if(i.length>3){var o=r-n,a="bv-d-xs-down-none";if(0===o)for(var s=3;s<i.length;s++)i[s].classes=a;else if(o===i.length-1)for(var c=0;c<i.length-3;c++)i[c].classes=a;else{for(var l=0;l<o-1;l++)i[l].classes=a;for(var u=i.length-1;u>o+1;u--)i[u].classes=a}}return i}},watch:(_w={},Vw(_w,Pw,(function(t,e){t!==e&&(this.currentPage=Fw(t,this.localNumberOfPages))})),Vw(_w,"currentPage",(function(t,e){t!==e&&this.$emit(Iw,t>0?t:null)})),Vw(_w,"limit",(function(t,e){t!==e&&(this.localLimit=Hw(t))})),_w),created:function(){var t=this;this.localLimit=Hw(this.limit),this.$nextTick((function(){t.currentPage=t.currentPage>t.localNumberOfPages?t.localNumberOfPages:t.currentPage}))},methods:{handleKeyNav:function(t){var e=t.keyCode,n=t.shiftKey;this.isNav||(e===Dr||e===qr?(En(t,{propagation:!1}),n?this.focusFirst():this.focusPrev()):e!==$r&&e!==Er||(En(t,{propagation:!1}),n?this.focusLast():this.focusNext()))},getButtons:function(){return Qe("button.page-link, a.page-link",this.$el).filter((function(t){return Ge(t)}))},focusCurrent:function(){var t=this;this.$nextTick((function(){var e=t.getButtons().find((function(e){return Object(Ie["c"])(cn(e,"aria-posinset"),0)===t.computedCurrentPage}));wn(e)||t.focusFirst()}))},focusFirst:function(){var t=this;this.$nextTick((function(){var e=t.getButtons().find((function(t){return!Ye(t)}));wn(e)}))},focusLast:function(){var t=this;this.$nextTick((function(){var e=t.getButtons().reverse().find((function(t){return!Ye(t)}));wn(e)}))},focusPrev:function(){var t=this;this.$nextTick((function(){var e=t.getButtons(),n=e.indexOf(Ue());n>0&&!Ye(e[n-1])&&wn(e[n-1])}))},focusNext:function(){var t=this;this.$nextTick((function(){var e=t.getButtons(),n=e.indexOf(Ue());n<e.length-1&&!Ye(e[n+1])&&wn(e[n+1])}))}},render:function(t){var e=this,n=this.disabled,r=this.labelPage,i=this.ariaLabel,o=this.isNav,a=this.localNumberOfPages,s=this.computedCurrentPage,c=this.pageList.map((function(t){return t.number})),l=this.paginationParams,u=l.showFirstDots,d=l.showLastDots,h="fill"===this.align,f=[],p=function(t){return t===s},m=this.currentPage<1,b=function(r,i,s,c,l,u,d){var f=n||p(u)||m||r<1||r>a,b=r<1?1:r>a?a:r,g={disabled:f,page:b,index:b-1},v=e.normalizeSlot(s,g)||Object(Ee["g"])(c)||t(),w=t(f?"span":o?mi:"button",{staticClass:"page-link",class:{"flex-grow-1":!o&&!f&&h},props:f||!o?{}:e.linkProps(r),attrs:{role:o?null:"menuitem",type:o||f?null:"button",tabindex:f||o?null:"-1","aria-label":i,"aria-controls":e.ariaControls||null,"aria-disabled":f?"true":null},on:f?{}:{"!click":function(t){e.onClick(t,r)},keydown:Dw}},[v]);return t("li",{key:d,staticClass:"page-item",class:[{disabled:f,"flex-fill":h,"d-flex":h&&!o&&!f},l],attrs:{role:o?null:"presentation","aria-hidden":f?"true":null}},[w])},g=function(n){return t("li",{staticClass:"page-item",class:["disabled","bv-d-xs-down-none",h?"flex-fill":"",e.ellipsisClass],attrs:{role:"separator"},key:"ellipsis-".concat(n?"last":"first")},[t("span",{staticClass:"page-link"},[e.normalizeSlot(Mt)||Object(Ee["g"])(e.ellipsisText)||t()])])},v=function(i,s){var c=i.number,l=p(c)&&!m,u=n?null:l||m&&0===s?"0":"-1",d={role:o?null:"menuitemradio",type:o||n?null:"button","aria-disabled":n?"true":null,"aria-controls":e.ariaControls||null,"aria-label":Object(kn["b"])(r)?r(c):"".concat(Object(Me["f"])(r)?r():r," ").concat(c),"aria-checked":o?null:l?"true":"false","aria-current":o&&l?"page":null,"aria-posinset":o?null:c,"aria-setsize":o?null:a,tabindex:o?null:u},f=Object(Ee["g"])(e.makePage(c)),b={page:c,index:c-1,content:f,active:l,disabled:n},g=t(n?"span":o?mi:"button",{props:n||!o?{}:e.linkProps(c),staticClass:"page-link",class:{"flex-grow-1":!o&&!n&&h},attrs:d,on:n?{}:{"!click":function(t){e.onClick(t,c)},keydown:Dw}},[e.normalizeSlot(le,b)||f]);return t("li",{staticClass:"page-item",class:[{disabled:n,active:l,"flex-fill":h,"d-flex":h&&!o&&!n},i.classes,e.pageClass],attrs:{role:o?null:"presentation"},key:"page-".concat(c)},[g])},w=t();this.firstNumber||this.hideGotoEndButtons||(w=b(1,this.labelFirstPage,Tt,this.firstText,this.firstClass,1,"pagination-goto-first")),f.push(w),f.push(b(s-1,this.labelPrevPage,he,this.prevText,this.prevClass,1,"pagination-goto-prev")),f.push(this.firstNumber&&1!==c[0]?v({number:1},0):t()),f.push(u?g(!1):t()),this.pageList.forEach((function(t,n){var r=u&&e.firstNumber&&1!==c[0]?1:0;f.push(v(t,n+r))})),f.push(d?g(!0):t()),f.push(this.lastNumber&&c[c.length-1]!==a?v({number:a},-1):t()),f.push(b(s+1,this.labelNextPage,se,this.nextText,this.nextClass,a,"pagination-goto-next"));var y=t();this.lastNumber||this.hideGotoEndButtons||(y=b(a,this.labelLastPage,Ut,this.lastText,this.lastClass,a,"pagination-goto-last")),f.push(y);var k=t("ul",{staticClass:"pagination",class:["b-pagination",this.btnSize,this.alignment,this.styleClass],attrs:{role:o?null:"menubar","aria-disabled":n?"true":"false","aria-label":o?null:i||null},on:o?{}:{keydown:this.handleKeyNav},ref:"ul"},f);return o?t("nav",{attrs:{"aria-disabled":n?"true":null,"aria-hidden":n?"true":"false","aria-label":o&&i||null}},[k]):k}});function $w(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Uw(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?$w(Object(n),!0).forEach((function(e){qw(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):$w(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function qw(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Ww=20,Gw=0,Yw=function(t){return Object(lr["d"])(Object(Ie["c"])(t)||Ww,1)},Kw=function(t){return Object(lr["d"])(Object(Ie["c"])(t)||Gw,0)},Qw=Object(kn["d"])(Object(zn["m"])(Uw(Uw({},Rw),{},{ariaControls:Object(kn["c"])(pt["u"]),perPage:Object(kn["c"])(pt["p"],Ww),totalRows:Object(kn["c"])(pt["p"],Gw)})),a["Ob"]),Xw=i["default"].extend({name:a["Ob"],mixins:[Nw],props:Qw,computed:{numberOfPages:function(){var t=Object(lr["b"])(Kw(this.totalRows)/Yw(this.perPage));return t<1?1:t},pageSizeNumberOfPages:function(){return{perPage:Yw(this.perPage),totalRows:Kw(this.totalRows),numberOfPages:this.numberOfPages}}},watch:{pageSizeNumberOfPages:function(t,e){Object(Me["p"])(e)||(t.perPage!==e.perPage&&t.totalRows===e.totalRows||t.numberOfPages!==e.numberOfPages&&this.currentPage>t.numberOfPages)&&(this.currentPage=1),this.localNumberOfPages=t.numberOfPages}},created:function(){var t=this;this.localNumberOfPages=this.numberOfPages;var e=Object(Ie["c"])(this[Pw],0);e>0?this.currentPage=e:this.$nextTick((function(){t.currentPage=0}))},methods:{onClick:function(t,e){var n=this;if(e!==this.currentPage){var r=t.target,i=new gl(H,{cancelable:!0,vueTarget:this,target:r});this.$emit(i.type,i,e),i.defaultPrevented||(this.currentPage=e,this.$emit(u,this.currentPage),this.$nextTick((function(){Ge(r)&&n.$el.contains(r)?wn(r):n.focusCurrent()})))}},makePage:function(t){return t},linkProps:function(){return{}}}}),Jw=Object(r["b"])({components:{BPagination:Xw}});function Zw(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function ty(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Zw(Object(n),!0).forEach((function(e){ey(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Zw(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function ey(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ny=function(t){return Object(lr["d"])(Object(Ie["c"])(t,0),1)},ry=Object(zn["j"])(pi,["event","routerTag"]),iy=Object(kn["d"])(Object(zn["m"])(ty(ty(ty({},Rw),ry),{},{baseUrl:Object(kn["c"])(pt["u"],"/"),linkGen:Object(kn["c"])(pt["l"]),noPageDetect:Object(kn["c"])(pt["g"],!1),numberOfPages:Object(kn["c"])(pt["p"],1,(function(t){var e=Object(Ie["c"])(t,0);return!(e<1)||(Object(Vs["a"])('Prop "number-of-pages" must be a number greater than "0"',a["Pb"]),!1)})),pageGen:Object(kn["c"])(pt["l"]),pages:Object(kn["c"])(pt["b"]),useRouter:Object(kn["c"])(pt["g"],!1)})),a["Pb"]),oy=i["default"].extend({name:a["Pb"],mixins:[Nw],props:iy,computed:{isNav:function(){return!0},computedValue:function(){var t=Object(Ie["c"])(this.value,0);return t<1?null:t}},watch:{numberOfPages:function(){var t=this;this.$nextTick((function(){t.setNumberOfPages()}))},pages:function(){var t=this;this.$nextTick((function(){t.setNumberOfPages()}))}},created:function(){this.setNumberOfPages()},mounted:function(){var t=this;this.$router&&this.$watch("$route",(function(){t.$nextTick((function(){De((function(){t.guessCurrentPage()}))}))}))},methods:{setNumberOfPages:function(){var t=this;Object(Me["a"])(this.pages)&&this.pages.length>0?this.localNumberOfPages=this.pages.length:this.localNumberOfPages=ny(this.numberOfPages),this.$nextTick((function(){t.guessCurrentPage()}))},onClick:function(t,e){var n=this;if(e!==this.currentPage){var r=t.currentTarget||t.target,i=new gl(H,{cancelable:!0,vueTarget:this,target:r});this.$emit(i.type,i,e),i.defaultPrevented||(De((function(){n.currentPage=e,n.$emit(u,e)})),this.$nextTick((function(){yn(r)})))}},getPageInfo:function(t){if(!Object(Me["a"])(this.pages)||0===this.pages.length||Object(Me["o"])(this.pages[t-1])){var e="".concat(this.baseUrl).concat(t);return{link:this.useRouter?{path:e}:e,text:Object(Ee["g"])(t)}}var n=this.pages[t-1];if(Object(Me["j"])(n)){var r=n.link;return{link:Object(Me["j"])(r)?r:this.useRouter?{path:r}:r,text:Object(Ee["g"])(n.text||t)}}return{link:Object(Ee["g"])(n),text:Object(Ee["g"])(t)}},makePage:function(t){var e=this.pageGen,n=this.getPageInfo(t);return Object(kn["b"])(e)?e(t,n):n.text},makeLink:function(t){var e=this.linkGen,n=this.getPageInfo(t);return Object(kn["b"])(e)?e(t,n):n.link},linkProps:function(t){var e=Object(kn["e"])(ry,this),n=this.makeLink(t);return this.useRouter||Object(Me["j"])(n)?e.to=n:e.href=n,e},resolveLink:function(){var t,e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"";try{t=document.createElement("a"),t.href=Sr({to:e},"a","/","/"),document.body.appendChild(t);var n=t,r=n.pathname,i=n.hash,o=n.search;return document.body.removeChild(t),{path:r,hash:i,query:Ar(o)}}catch(a){try{t&&t.parentNode&&t.parentNode.removeChild(t)}catch(s){}return{}}},resolveRoute:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"";try{var e=this.$router.resolve(t,this.$route).route;return{path:e.path,hash:e.hash,query:e.query}}catch(n){return{}}},guessCurrentPage:function(){var t=this.$router,e=this.$route,n=this.computedValue;if(!this.noPageDetect&&!n&&(Ae["i"]||!Ae["i"]&&t))for(var r=t&&e?{path:e.path,hash:e.hash,query:e.query}:{},i=Ae["i"]?window.location||document.location:null,o=i?{path:i.pathname,hash:i.hash,query:Ar(i.search)}:{},a=1;!n&&a<=this.localNumberOfPages;a++){var s=this.makeLink(a);n=t&&(Object(Me["j"])(s)||this.useRouter)?Yr(this.resolveRoute(s),r)?a:null:Ae["i"]?Yr(this.resolveLink(s),o)?a:null:-1}this.currentPage=n>0?n:0}}}),ay=Object(r["b"])({components:{BPaginationNav:oy}}),sy={AUTO:"auto",TOP:"top",RIGHT:"right",BOTTOM:"bottom",LEFT:"left",TOPLEFT:"top",TOPRIGHT:"top",RIGHTTOP:"right",RIGHTBOTTOM:"right",BOTTOMLEFT:"bottom",BOTTOMRIGHT:"bottom",LEFTTOP:"left",LEFTBOTTOM:"left"},cy={AUTO:0,TOPLEFT:-1,TOP:0,TOPRIGHT:1,RIGHTTOP:-1,RIGHT:0,RIGHTBOTTOM:1,BOTTOMLEFT:-1,BOTTOM:0,BOTTOMRIGHT:1,LEFTTOP:-1,LEFT:0,LEFTBOTTOM:1},ly={arrowPadding:Object(kn["c"])(pt["p"],6),boundary:Object(kn["c"])([je["c"],pt["u"]],"scrollParent"),boundaryPadding:Object(kn["c"])(pt["p"],5),fallbackPlacement:Object(kn["c"])(pt["f"],"flip"),offset:Object(kn["c"])(pt["p"],0),placement:Object(kn["c"])(pt["u"],"top"),target:Object(kn["c"])([je["c"],je["d"]])},uy=i["default"].extend({name:a["Tb"],props:ly,data:function(){return{noFade:!1,localShow:!0,attachment:this.getAttachment(this.placement)}},computed:{templateType:function(){return"unknown"},popperConfig:function(){var t=this,e=this.placement;return{placement:this.getAttachment(e),modifiers:{offset:{offset:this.getOffset(e)},flip:{behavior:this.fallbackPlacement},arrow:{element:".arrow"},preventOverflow:{padding:this.boundaryPadding,boundariesElement:this.boundary}},onCreate:function(e){e.originalPlacement!==e.placement&&t.popperPlacementChange(e)},onUpdate:function(e){t.popperPlacementChange(e)}}}},created:function(){var t=this;this.$_popper=null,this.localShow=!0,this.$on(J,(function(e){t.popperCreate(e)}));var e=function(){t.$nextTick((function(){De((function(){t.$destroy()}))}))};this.$parent.$once(ct,e),this.$once(C,e)},beforeMount:function(){this.attachment=this.getAttachment(this.placement)},updated:function(){this.updatePopper()},beforeDestroy:function(){this.destroyPopper()},destroyed:function(){var t=this.$el;t&&t.parentNode&&t.parentNode.removeChild(t)},methods:{hide:function(){this.localShow=!1},getAttachment:function(t){return sy[String(t).toUpperCase()]||"auto"},getOffset:function(t){if(!this.offset){var e=this.$refs.arrow||Xe(".arrow",this.$el),n=Object(Ie["b"])(pn(e).width,0)+Object(Ie["b"])(this.arrowPadding,0);switch(cy[String(t).toUpperCase()]||0){case 1:return"+50%p - ".concat(n,"px");case-1:return"-50%p + ".concat(n,"px");default:return 0}}return this.offset},popperCreate:function(t){this.destroyPopper(),this.$_popper=new sl["a"](this.target,t,this.popperConfig)},destroyPopper:function(){this.$_popper&&this.$_popper.destroy(),this.$_popper=null},updatePopper:function(){this.$_popper&&this.$_popper.scheduleUpdate()},popperPlacementChange:function(t){this.attachment=this.getAttachment(t.placement)},renderTemplate:function(t){return t("div")}},render:function(t){var e=this,n=this.noFade;return t(Kn,{props:{appear:!0,noFade:n},on:{beforeEnter:function(t){return e.$emit(J,t)},afterEnter:function(t){return e.$emit(Z,t)},beforeLeave:function(t){return e.$emit(V,t)},afterLeave:function(t){return e.$emit(C,t)}}},[this.localShow?this.renderTemplate(t):t()])}});function dy(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function hy(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?dy(Object(n),!0).forEach((function(e){fy(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):dy(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function fy(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var py={html:Object(kn["c"])(pt["g"],!1),id:Object(kn["c"])(pt["u"])},my=i["default"].extend({name:a["vc"],extends:uy,mixins:[Jb],props:py,data:function(){return{title:"",content:"",variant:null,customClass:null,interactive:!0}},computed:{templateType:function(){return"tooltip"},templateClasses:function(){var t,e=this.variant,n=this.attachment,r=this.templateType;return[(t={noninteractive:!this.interactive},fy(t,"b-".concat(r,"-").concat(e),e),fy(t,"bs-".concat(r,"-").concat(n),n),t),this.customClass]},templateAttributes:function(){var t=this.id;return hy(hy({},this.$parent.$parent.$attrs),{},{id:t,role:"tooltip",tabindex:"-1"},this.scopedStyleAttrs)},templateListeners:function(){var t=this;return{mouseenter:function(e){t.$emit(P,e)},mouseleave:function(e){t.$emit(I,e)},focusin:function(e){t.$emit(A,e)},focusout:function(e){t.$emit(j,e)}}}},methods:{renderTemplate:function(t){var e=this.title,n=Object(Me["f"])(e)?e({}):e,r=this.html&&!Object(Me["f"])(e)?{innerHTML:e}:{};return t("div",{staticClass:"tooltip b-tooltip",class:this.templateClasses,attrs:this.templateAttributes,on:this.templateListeners},[t("div",{staticClass:"arrow",ref:"arrow"}),t("div",{staticClass:"tooltip-inner",domProps:r},[n])])}}});function by(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function gy(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?by(Object(n),!0).forEach((function(e){vy(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):by(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function vy(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var wy,yy,ky=".modal-content",_y=Bn(a["Cb"],C),Oy=".b-sidebar",zy=[ky,Oy].join(", "),Ay="dropdown",jy=".dropdown-menu.show",My="data-original-title",Cy={title:"",content:"",variant:null,customClass:null,triggers:"",placement:"auto",fallbackPlacement:"flip",target:null,container:null,noFade:!1,boundary:"scrollParent",boundaryPadding:5,offset:0,delay:0,arrowPadding:6,interactive:!0,disabled:!1,id:null,html:!1},Vy=i["default"].extend({name:a["uc"],mixins:[ti],data:function(){return gy(gy({},Cy),{},{activeTrigger:{hover:!1,click:!1,focus:!1},localShow:!1})},computed:{templateType:function(){return"tooltip"},computedId:function(){return this.id||"__bv_".concat(this.templateType,"_").concat(this[o["a"]],"__")},computedDelay:function(){var t={show:0,hide:0};return Object(Me["k"])(this.delay)?(t.show=Object(lr["d"])(Object(Ie["c"])(this.delay.show,0),0),t.hide=Object(lr["d"])(Object(Ie["c"])(this.delay.hide,0),0)):(Object(Me["h"])(this.delay)||Object(Me["n"])(this.delay))&&(t.show=t.hide=Object(lr["d"])(Object(Ie["c"])(this.delay,0),0)),t},computedTriggers:function(){return Se(this.triggers).filter(An["a"]).join(" ").trim().toLowerCase().split(/\s+/).sort()},isWithActiveTrigger:function(){for(var t in this.activeTrigger)if(this.activeTrigger[t])return!0;return!1},computedTemplateData:function(){var t=this.title,e=this.content,n=this.variant,r=this.customClass,i=this.noFade,o=this.interactive;return{title:t,content:e,variant:n,customClass:r,noFade:i,interactive:o}}},watch:{computedTriggers:function(t,e){var n=this;Yr(t,e)||this.$nextTick((function(){n.unListen(),e.forEach((function(e){Ve(t,e)||n.activeTrigger[e]&&(n.activeTrigger[e]=!1)})),n.listen()}))},computedTemplateData:function(){this.handleTemplateUpdate()},title:function(t,e){t===e||t||this.hide()},disabled:function(t){t?this.disable():this.enable()}},created:function(){var t=this;this.$_tip=null,this.$_hoverTimeout=null,this.$_hoverState="",this.$_visibleInterval=null,this.$_enabled=!this.disabled,this.$_noop=Cs.bind(this),this.$parent&&this.$parent.$once(st,(function(){t.$nextTick((function(){De((function(){t.$destroy()}))}))})),this.$nextTick((function(){var e=t.getTarget();e&&tn(document.body,e)?(t.scopeId=Qb(t.$parent),t.listen()):Object(Vs["a"])(Object(Me["n"])(t.target)?'Unable to find target element by ID "#'.concat(t.target,'" in document.'):"The provided target is no valid HTML element.",t.templateType)}))},updated:function(){this.$nextTick(this.handleTemplateUpdate)},deactivated:function(){this.forceHide()},beforeDestroy:function(){this.unListen(),this.setWhileOpenListeners(!1),this.clearHoverTimeout(),this.clearVisibilityInterval(),this.destroyTemplate(),this.$_noop=null},methods:{getTemplate:function(){return my},updateData:function(){var t=this,e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},n=!1;Object(zn["h"])(Cy).forEach((function(r){Object(Me["o"])(e[r])||t[r]===e[r]||(t[r]=e[r],"title"===r&&(n=!0))})),n&&this.localShow&&this.fixTitle()},createTemplateAndShow:function(){var t=this.getContainer(),e=this.getTemplate(),n=this.$_tip=new e({parent:this,propsData:{id:this.computedId,html:this.html,placement:this.placement,fallbackPlacement:this.fallbackPlacement,target:this.getPlacementTarget(),boundary:this.getBoundary(),offset:Object(Ie["c"])(this.offset,0),arrowPadding:Object(Ie["c"])(this.arrowPadding,0),boundaryPadding:Object(Ie["c"])(this.boundaryPadding,0)}});this.handleTemplateUpdate(),n.$once(J,this.onTemplateShow),n.$once(Z,this.onTemplateShown),n.$once(V,this.onTemplateHide),n.$once(C,this.onTemplateHidden),n.$once(ct,this.destroyTemplate),n.$on(A,this.handleEvent),n.$on(j,this.handleEvent),n.$on(P,this.handleEvent),n.$on(I,this.handleEvent),n.$mount(t.appendChild(document.createElement("div")))},hideTemplate:function(){this.$_tip&&this.$_tip.hide(),this.clearActiveTriggers(),this.$_hoverState=""},destroyTemplate:function(){this.setWhileOpenListeners(!1),this.clearHoverTimeout(),this.$_hoverState="",this.clearActiveTriggers(),this.localPlacementTarget=null;try{this.$_tip.$destroy()}catch(t){}this.$_tip=null,this.removeAriaDescribedby(),this.restoreTitle(),this.localShow=!1},getTemplateElement:function(){return this.$_tip?this.$_tip.$el:null},handleTemplateUpdate:function(){var t=this,e=this.$_tip;if(e){var n=["title","content","variant","customClass","noFade","interactive"];n.forEach((function(n){e[n]!==t[n]&&(e[n]=t[n])}))}},show:function(){var t=this.getTarget();if(t&&tn(document.body,t)&&Ge(t)&&!this.dropdownOpen()&&(!Object(Me["p"])(this.title)&&""!==this.title||!Object(Me["p"])(this.content)&&""!==this.content)&&!this.$_tip&&!this.localShow){this.localShow=!0;var e=this.buildEvent(J,{cancelable:!0});this.emitEvent(e),e.defaultPrevented?this.destroyTemplate():(this.fixTitle(),this.addAriaDescribedby(),this.createTemplateAndShow())}},hide:function(){var t=arguments.length>0&&void 0!==arguments[0]&&arguments[0],e=this.getTemplateElement();if(e&&this.localShow){var n=this.buildEvent(V,{cancelable:!t});this.emitEvent(n),n.defaultPrevented||this.hideTemplate()}else this.restoreTitle()},forceHide:function(){var t=this.getTemplateElement();t&&this.localShow&&(this.setWhileOpenListeners(!1),this.clearHoverTimeout(),this.$_hoverState="",this.clearActiveTriggers(),this.$_tip&&(this.$_tip.noFade=!0),this.hide(!0))},enable:function(){this.$_enabled=!0,this.emitEvent(this.buildEvent(_))},disable:function(){this.$_enabled=!1,this.emitEvent(this.buildEvent(v))},onTemplateShow:function(){this.setWhileOpenListeners(!0)},onTemplateShown:function(){var t=this.$_hoverState;this.$_hoverState="","out"===t&&this.leave(null),this.emitEvent(this.buildEvent(Z))},onTemplateHide:function(){this.setWhileOpenListeners(!1)},onTemplateHidden:function(){this.destroyTemplate(),this.emitEvent(this.buildEvent(C))},getTarget:function(){var t=this.target;return Object(Me["n"])(t)?t=en(t.replace(/^#/,"")):Object(Me["f"])(t)?t=t():t&&(t=t.$el||t),$e(t)?t:null},getPlacementTarget:function(){return this.getTarget()},getTargetId:function(){var t=this.getTarget();return t&&t.id?t.id:null},getContainer:function(){var t=!!this.container&&(this.container.$el||this.container),e=document.body,n=this.getTarget();return!1===t?Ze(zy,n)||e:Object(Me["n"])(t)&&en(t.replace(/^#/,""))||e},getBoundary:function(){return this.boundary?this.boundary.$el||this.boundary:"scrollParent"},isInModal:function(){var t=this.getTarget();return t&&Ze(ky,t)},isDropdown:function(){var t=this.getTarget();return t&&on(t,Ay)},dropdownOpen:function(){var t=this.getTarget();return this.isDropdown()&&t&&Xe(jy,t)},clearHoverTimeout:function(){clearTimeout(this.$_hoverTimeout),this.$_hoverTimeout=null},clearVisibilityInterval:function(){clearInterval(this.$_visibleInterval),this.$_visibleInterval=null},clearActiveTriggers:function(){for(var t in this.activeTrigger)this.activeTrigger[t]=!1},addAriaDescribedby:function(){var t=this.getTarget(),e=cn(t,"aria-describedby")||"";e=e.split(/\s+/).concat(this.computedId).join(" ").trim(),an(t,"aria-describedby",e)},removeAriaDescribedby:function(){var t=this,e=this.getTarget(),n=cn(e,"aria-describedby")||"";n=n.split(/\s+/).filter((function(e){return e!==t.computedId})).join(" ").trim(),n?an(e,"aria-describedby",n):sn(e,"aria-describedby")},fixTitle:function(){var t=this.getTarget();if(ln(t,"title")){var e=cn(t,"title");an(t,"title",""),e&&an(t,My,e)}},restoreTitle:function(){var t=this.getTarget();if(ln(t,My)){var e=cn(t,My);sn(t,My),e&&an(t,"title",e)}},buildEvent:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return new gl(t,gy({cancelable:!1,target:this.getTarget(),relatedTarget:this.getTemplateElement()||null,componentId:this.computedId,vueTarget:this},e))},emitEvent:function(t){var e=t.type;this.emitOnRoot(Bn(this.templateType,e),t),this.$emit(e,t)},listen:function(){var t=this,e=this.getTarget();e&&(this.setRootListener(!0),this.computedTriggers.forEach((function(n){"click"===n?Tn(e,"click",t.handleEvent,ft):"focus"===n?(Tn(e,"focusin",t.handleEvent,ft),Tn(e,"focusout",t.handleEvent,ft)):"blur"===n?Tn(e,"focusout",t.handleEvent,ft):"hover"===n&&(Tn(e,"mouseenter",t.handleEvent,ft),Tn(e,"mouseleave",t.handleEvent,ft))}),this))},unListen:function(){var t=this,e=["click","focusin","focusout","mouseenter","mouseleave"],n=this.getTarget();this.setRootListener(!1),e.forEach((function(e){n&&Pn(n,e,t.handleEvent,ft)}),this)},setRootListener:function(t){var e=this.$root;if(e){var n=t?"$on":"$off",r=this.templateType;e[n](Hn(r,V),this.doHide),e[n](Hn(r,J),this.doShow),e[n](Hn(r,g),this.doDisable),e[n](Hn(r,k),this.doEnable)}},setWhileOpenListeners:function(t){this.setModalListener(t),this.setDropdownListener(t),this.visibleCheck(t),this.setOnTouchStartListener(t)},visibleCheck:function(t){var e=this;this.clearVisibilityInterval();var n=this.getTarget(),r=this.getTemplateElement();t&&(this.$_visibleInterval=setInterval((function(){!r||!e.localShow||n.parentNode&&Ge(n)||e.forceHide()}),100))},setModalListener:function(t){this.isInModal()&&this.$root[t?"$on":"$off"](_y,this.forceHide)},setOnTouchStartListener:function(t){var e=this;"ontouchstart"in document.documentElement&&Ce(document.body.children).forEach((function(n){In(t,n,"mouseover",e.$_noop)}))},setDropdownListener:function(t){var e=this.getTarget();e&&this.$root&&this.isDropdown&&e.__vue__&&e.__vue__[t?"$on":"$off"](Z,this.forceHide)},handleEvent:function(t){var e=this.getTarget();if(e&&!Ye(e)&&this.$_enabled&&!this.dropdownOpen()){var n=t.type,r=this.computedTriggers;if("click"===n&&Ve(r,"click"))this.click(t);else if("mouseenter"===n&&Ve(r,"hover"))this.enter(t);else if("focusin"===n&&Ve(r,"focus"))this.enter(t);else if("focusout"===n&&(Ve(r,"focus")||Ve(r,"blur"))||"mouseleave"===n&&Ve(r,"hover")){var i=this.getTemplateElement(),o=t.target,a=t.relatedTarget;if(i&&tn(i,o)&&tn(e,a)||i&&tn(e,o)&&tn(i,a)||i&&tn(i,o)&&tn(i,a)||tn(e,o)&&tn(e,a))return;this.leave(t)}}},doHide:function(t){t&&this.getTargetId()!==t&&this.computedId!==t||this.forceHide()},doShow:function(t){t&&this.getTargetId()!==t&&this.computedId!==t||this.show()},doDisable:function(t){t&&this.getTargetId()!==t&&this.computedId!==t||this.disable()},doEnable:function(t){t&&this.getTargetId()!==t&&this.computedId!==t||this.enable()},click:function(t){this.$_enabled&&!this.dropdownOpen()&&(wn(t.currentTarget),this.activeTrigger.click=!this.activeTrigger.click,this.isWithActiveTrigger?this.enter(null):this.leave(null))},toggle:function(){this.$_enabled&&!this.dropdownOpen()&&(this.localShow?this.leave(null):this.enter(null))},enter:function(){var t=this,e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null;e&&(this.activeTrigger["focusin"===e.type?"focus":"hover"]=!0),this.localShow||"in"===this.$_hoverState?this.$_hoverState="in":(this.clearHoverTimeout(),this.$_hoverState="in",this.computedDelay.show?(this.fixTitle(),this.$_hoverTimeout=setTimeout((function(){"in"===t.$_hoverState?t.show():t.localShow||t.restoreTitle()}),this.computedDelay.show)):this.show())},leave:function(){var t=this,e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null;e&&(this.activeTrigger["focusout"===e.type?"focus":"hover"]=!1,"focusout"===e.type&&Ve(this.computedTriggers,"blur")&&(this.activeTrigger.click=!1,this.activeTrigger.hover=!1)),this.isWithActiveTrigger||(this.clearHoverTimeout(),this.$_hoverState="out",this.computedDelay.hide?this.$_hoverTimeout=setTimeout((function(){"out"===t.$_hoverState&&t.hide()}),this.computedDelay.hide):this.hide())}}});function Sy(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function xy(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Sy(Object(n),!0).forEach((function(e){Ty(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Sy(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Ty(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Py="disabled",Iy=lt+Py,Ey="show",Ly=lt+Ey,By=Object(kn["d"])((wy={boundary:Object(kn["c"])([je["c"],pt["q"],pt["u"]],"scrollParent"),boundaryPadding:Object(kn["c"])(pt["p"],50),container:Object(kn["c"])([je["c"],pt["q"],pt["u"]]),customClass:Object(kn["c"])(pt["u"]),delay:Object(kn["c"])(pt["o"],50)},Ty(wy,Py,Object(kn["c"])(pt["g"],!1)),Ty(wy,"fallbackPlacement",Object(kn["c"])(pt["f"],"flip")),Ty(wy,"id",Object(kn["c"])(pt["u"])),Ty(wy,"noFade",Object(kn["c"])(pt["g"],!1)),Ty(wy,"noninteractive",Object(kn["c"])(pt["g"],!1)),Ty(wy,"offset",Object(kn["c"])(pt["p"],0)),Ty(wy,"placement",Object(kn["c"])(pt["u"],"top")),Ty(wy,Ey,Object(kn["c"])(pt["g"],!1)),Ty(wy,"target",Object(kn["c"])([je["c"],je["d"],pt["l"],pt["q"],pt["u"]],void 0,!0)),Ty(wy,"title",Object(kn["c"])(pt["u"])),Ty(wy,"triggers",Object(kn["c"])(pt["f"],"hover focus")),Ty(wy,"variant",Object(kn["c"])(pt["u"])),wy),a["tc"]),Hy=i["default"].extend({name:a["tc"],mixins:[Cn],inheritAttrs:!1,props:By,data:function(){return{localShow:this[Ey],localTitle:"",localContent:""}},computed:{templateData:function(){return xy({title:this.localTitle,content:this.localContent,interactive:!this.noninteractive},Object(zn["k"])(this.$props,["boundary","boundaryPadding","container","customClass","delay","fallbackPlacement","id","noFade","offset","placement","target","target","triggers","variant",Py]))},templateTitleContent:function(){var t=this.title,e=this.content;return{title:t,content:e}}},watch:(yy={},Ty(yy,Ey,(function(t,e){t!==e&&t!==this.localShow&&this.$_toolpop&&(t?this.$_toolpop.show():this.$_toolpop.forceHide())})),Ty(yy,Py,(function(t){t?this.doDisable():this.doEnable()})),Ty(yy,"localShow",(function(t){this.$emit(Ly,t)})),Ty(yy,"templateData",(function(){var t=this;this.$nextTick((function(){t.$_toolpop&&t.$_toolpop.updateData(t.templateData)}))})),Ty(yy,"templateTitleContent",(function(){this.$nextTick(this.updateContent)})),yy),created:function(){this.$_toolpop=null},updated:function(){this.$nextTick(this.updateContent)},beforeDestroy:function(){this.$off(B,this.doOpen),this.$off(f,this.doClose),this.$off(g,this.doDisable),this.$off(k,this.doEnable),this.$_toolpop&&(this.$_toolpop.$destroy(),this.$_toolpop=null)},mounted:function(){var t=this;this.$nextTick((function(){var e=t.getComponent();t.updateContent();var n=Qb(t)||Qb(t.$parent),r=t.$_toolpop=new e({parent:t,_scopeId:n||void 0});r.updateData(t.templateData),r.$on(J,t.onShow),r.$on(Z,t.onShown),r.$on(V,t.onHide),r.$on(C,t.onHidden),r.$on(v,t.onDisabled),r.$on(_,t.onEnabled),t[Py]&&t.doDisable(),t.$on(B,t.doOpen),t.$on(f,t.doClose),t.$on(g,t.doDisable),t.$on(k,t.doEnable),t.localShow&&r.show()}))},methods:{getComponent:function(){return Vy},updateContent:function(){this.setTitle(this.normalizeSlot()||this.title)},setTitle:function(t){t=Object(Me["p"])(t)?"":t,this.localTitle!==t&&(this.localTitle=t)},setContent:function(t){t=Object(Me["p"])(t)?"":t,this.localContent!==t&&(this.localContent=t)},onShow:function(t){this.$emit(J,t),t&&(this.localShow=!t.defaultPrevented)},onShown:function(t){this.localShow=!0,this.$emit(Z,t)},onHide:function(t){this.$emit(V,t)},onHidden:function(t){this.$emit(C,t),this.localShow=!1},onDisabled:function(t){t&&t.type===v&&(this.$emit(Iy,!0),this.$emit(v,t))},onEnabled:function(t){t&&t.type===_&&(this.$emit(Iy,!1),this.$emit(_,t))},doOpen:function(){!this.localShow&&this.$_toolpop&&this.$_toolpop.show()},doClose:function(){this.localShow&&this.$_toolpop&&this.$_toolpop.hide()},doDisable:function(){this.$_toolpop&&this.$_toolpop.disable()},doEnable:function(){this.$_toolpop&&this.$_toolpop.enable()}},render:function(t){return t()}}),Fy=i["default"].extend({name:a["Sb"],extends:my,computed:{templateType:function(){return"popover"}},methods:{renderTemplate:function(t){var e=this.title,n=this.content,r=Object(Me["f"])(e)?e({}):e,i=Object(Me["f"])(n)?n({}):n,o=this.html&&!Object(Me["f"])(e)?{innerHTML:e}:{},a=this.html&&!Object(Me["f"])(n)?{innerHTML:n}:{};return t("div",{staticClass:"popover b-popover",class:this.templateClasses,attrs:this.templateAttributes,on:this.templateListeners},[t("div",{staticClass:"arrow",ref:"arrow"}),Object(Me["p"])(r)||""===r?t():t("h3",{staticClass:"popover-header",domProps:o},[r]),Object(Me["p"])(i)||""===i?t():t("div",{staticClass:"popover-body",domProps:a},[i])])}}}),Dy=i["default"].extend({name:a["Rb"],extends:Vy,computed:{templateType:function(){return"popover"}},methods:{getTemplate:function(){return Fy}}});function Ry(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ny(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Ry(Object(n),!0).forEach((function(e){$y(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Ry(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function $y(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Uy=Object(kn["d"])(Object(zn["m"])(Ny(Ny({},By),{},{content:Object(kn["c"])(pt["u"]),placement:Object(kn["c"])(pt["u"],"right"),triggers:Object(kn["c"])(pt["f"],h)})),a["Qb"]),qy=i["default"].extend({name:a["Qb"],extends:Hy,inheritAttrs:!1,props:Uy,methods:{getComponent:function(){return Dy},updateContent:function(){this.setContent(this.normalizeSlot()||this.content),this.setTitle(this.normalizeSlot(ke)||this.title)}}});function Wy(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Gy(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Wy(Object(n),!0).forEach((function(e){Yy(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Wy(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Yy(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Ky="__BV_Popover__",Qy="click",Xy={focus:!0,hover:!0,click:!0,blur:!0,manual:!0},Jy=/^html$/i,Zy=/^nofade$/i,tk=/^(auto|top(left|right)?|bottom(left|right)?|left(top|bottom)?|right(top|bottom)?)$/i,ek=/^(window|viewport|scrollParent)$/i,nk=/^d\d+$/i,rk=/^ds\d+$/i,ik=/^dh\d+$/i,ok=/^o-?\d+$/i,ak=/^v-.+$/i,sk=/\s+/,ck=function(t,e){var n={title:void 0,content:void 0,trigger:"",placement:"right",fallbackPlacement:"flip",container:!1,animation:!0,offset:0,disabled:!1,id:null,html:!1,delay:Object(xh["c"])(a["Qb"],"delay",50),boundary:String(Object(xh["c"])(a["Qb"],"boundary","scrollParent")),boundaryPadding:Object(Ie["c"])(Object(xh["c"])(a["Qb"],"boundaryPadding",5),0),variant:Object(xh["c"])(a["Qb"],"variant"),customClass:Object(xh["c"])(a["Qb"],"customClass")};if(Object(Me["n"])(t.value)||Object(Me["h"])(t.value)||Object(Me["f"])(t.value)?n.content=t.value:Object(Me["k"])(t.value)&&(n=Gy(Gy({},n),t.value)),t.arg&&(n.container="#".concat(t.arg)),Object(Me["o"])(n.title)){var r=e.data||{};n.title=r.attrs&&!Object(Me["p"])(r.attrs.title)?r.attrs.title:void 0}Object(Me["k"])(n.delay)||(n.delay={show:Object(Ie["c"])(n.delay,0),hide:Object(Ie["c"])(n.delay,0)}),Object(zn["h"])(t.modifiers).forEach((function(t){if(Jy.test(t))n.html=!0;else if(Zy.test(t))n.animation=!1;else if(tk.test(t))n.placement=t;else if(ek.test(t))t="scrollparent"===t?"scrollParent":t,n.boundary=t;else if(nk.test(t)){var e=Object(Ie["c"])(t.slice(1),0);n.delay.show=e,n.delay.hide=e}else rk.test(t)?n.delay.show=Object(Ie["c"])(t.slice(2),0):ik.test(t)?n.delay.hide=Object(Ie["c"])(t.slice(2),0):ok.test(t)?n.offset=Object(Ie["c"])(t.slice(1),0):ak.test(t)&&(n.variant=t.slice(2)||null)}));var i={};return Se(n.trigger||"").filter(An["a"]).join(" ").trim().toLowerCase().split(sk).forEach((function(t){Xy[t]&&(i[t]=!0)})),Object(zn["h"])(t.modifiers).forEach((function(t){t=t.toLowerCase(),Xy[t]&&(i[t]=!0)})),n.trigger=Object(zn["h"])(i).join(" "),"blur"===n.trigger&&(n.trigger="focus"),n.trigger||(n.trigger=Qy),n},lk=function(t,e,n){if(Ae["i"]){var r=ck(e,n);if(!t[Ky]){var i=n.context;t[Ky]=new Dy({parent:i,_scopeId:Qb(i,void 0)}),t[Ky].__bv_prev_data__={},t[Ky].$on(J,(function(){var e={};Object(Me["f"])(r.title)&&(e.title=r.title(t)),Object(Me["f"])(r.content)&&(e.content=r.content(t)),Object(zn["h"])(e).length>0&&t[Ky].updateData(e)}))}var o={title:r.title,content:r.content,triggers:r.trigger,placement:r.placement,fallbackPlacement:r.fallbackPlacement,variant:r.variant,customClass:r.customClass,container:r.container,boundary:r.boundary,delay:r.delay,offset:r.offset,noFade:!r.animation,id:r.id,disabled:r.disabled,html:r.html},a=t[Ky].__bv_prev_data__;if(t[Ky].__bv_prev_data__=o,!Yr(o,a)){var s={target:t};Object(zn["h"])(o).forEach((function(e){o[e]!==a[e]&&(s[e]="title"!==e&&"content"!==e||!Object(Me["f"])(o[e])?o[e]:o[e](t))})),t[Ky].updateData(s)}}},uk=function(t){t[Ky]&&(t[Ky].$destroy(),t[Ky]=null),delete t[Ky]},dk={bind:function(t,e,n){lk(t,e,n)},componentUpdated:function(t,e,n){n.context.$nextTick((function(){lk(t,e,n)}))},unbind:function(t){uk(t)}},hk=Object(r["b"])({directives:{VBPopover:dk}}),fk=Object(r["b"])({components:{BPopover:qy},plugins:{VBPopoverPlugin:hk}}),pk=Object(kn["d"])({animated:Object(kn["c"])(pt["g"],null),label:Object(kn["c"])(pt["u"]),labelHtml:Object(kn["c"])(pt["u"]),max:Object(kn["c"])(pt["p"],null),precision:Object(kn["c"])(pt["p"],null),showProgress:Object(kn["c"])(pt["g"],null),showValue:Object(kn["c"])(pt["g"],null),striped:Object(kn["c"])(pt["g"],null),value:Object(kn["c"])(pt["p"],0),variant:Object(kn["c"])(pt["u"])},a["Vb"]),mk=i["default"].extend({name:a["Vb"],mixins:[Cn],inject:{bvProgress:{default:function(){return{}}}},props:pk,computed:{progressBarClasses:function(){var t=this.computedAnimated,e=this.computedVariant;return[e?"bg-".concat(e):"",this.computedStriped||t?"progress-bar-striped":"",t?"progress-bar-animated":""]},progressBarStyles:function(){return{width:this.computedValue/this.computedMax*100+"%"}},computedValue:function(){return Object(Ie["b"])(this.value,0)},computedMax:function(){var t=Object(Ie["b"])(this.max)||Object(Ie["b"])(this.bvProgress.max,0);return t>0?t:100},computedPrecision:function(){return Object(lr["d"])(Object(Ie["c"])(this.precision,Object(Ie["c"])(this.bvProgress.precision,0)),0)},computedProgress:function(){var t=this.computedPrecision,e=Object(lr["f"])(10,t);return Object(Ie["a"])(100*e*this.computedValue/this.computedMax/e,t)},computedVariant:function(){return this.variant||this.bvProgress.variant},computedStriped:function(){return Object(Me["b"])(this.striped)?this.striped:this.bvProgress.striped||!1},computedAnimated:function(){return Object(Me["b"])(this.animated)?this.animated:this.bvProgress.animated||!1},computedShowProgress:function(){return Object(Me["b"])(this.showProgress)?this.showProgress:this.bvProgress.showProgress||!1},computedShowValue:function(){return Object(Me["b"])(this.showValue)?this.showValue:this.bvProgress.showValue||!1}},render:function(t){var e,n=this.label,r=this.labelHtml,i=this.computedValue,o=this.computedPrecision,a={};return this.hasNormalizedSlot()?e=this.normalizeSlot():n||r?a=Ji(r,n):this.computedShowProgress?e=this.computedProgress:this.computedShowValue&&(e=Object(Ie["a"])(i,o)),t("div",{staticClass:"progress-bar",class:this.progressBarClasses,style:this.progressBarStyles,attrs:{role:"progressbar","aria-valuemin":"0","aria-valuemax":Object(Ee["g"])(this.computedMax),"aria-valuenow":Object(Ie["a"])(i,o)},domProps:a},e)}});function bk(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function gk(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?bk(Object(n),!0).forEach((function(e){vk(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):bk(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function vk(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var wk,yk=Object(zn["j"])(pk,["label","labelHtml"]),kk=Object(kn["d"])(Object(zn["m"])(gk(gk({},yk),{},{animated:Object(kn["c"])(pt["g"],!1),height:Object(kn["c"])(pt["u"]),max:Object(kn["c"])(pt["p"],100),precision:Object(kn["c"])(pt["p"],0),showProgress:Object(kn["c"])(pt["g"],!1),showValue:Object(kn["c"])(pt["g"],!1),striped:Object(kn["c"])(pt["g"],!1)})),a["Ub"]),_k=i["default"].extend({name:a["Ub"],mixins:[Cn],provide:function(){return{bvProgress:this}},props:kk,computed:{progressHeight:function(){return{height:this.height||null}}},render:function(t){var e=this.normalizeSlot();return e||(e=t(mk,{props:Object(kn["e"])(yk,this.$props)})),t("div",{staticClass:"progress",style:this.progressHeight},[e])}}),Ok=Object(r["b"])({components:{BProgress:_k,BProgressBar:mk}});function zk(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ak(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?zk(Object(n),!0).forEach((function(e){jk(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):zk(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function jk(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Mk="b-sidebar",Ck=Hn(a["A"],"request-state"),Vk=Hn(a["A"],"toggle"),Sk=Bn(a["A"],"state"),xk=Bn(a["A"],"sync-state"),Tk=On("visible",{type:pt["g"],defaultValue:!1,event:u}),Pk=Tk.mixin,Ik=Tk.props,Ek=Tk.prop,Lk=Tk.event,Bk=Object(kn["d"])(Object(zn["m"])(Ak(Ak(Ak({},ia),Ik),{},{ariaLabel:Object(kn["c"])(pt["u"]),ariaLabelledby:Object(kn["c"])(pt["u"]),backdrop:Object(kn["c"])(pt["g"],!1),backdropVariant:Object(kn["c"])(pt["u"],"dark"),bgVariant:Object(kn["c"])(pt["u"],"light"),bodyClass:Object(kn["c"])(pt["e"]),closeLabel:Object(kn["c"])(pt["u"]),footerClass:Object(kn["c"])(pt["e"]),headerClass:Object(kn["c"])(pt["e"]),lazy:Object(kn["c"])(pt["g"],!1),noCloseOnBackdrop:Object(kn["c"])(pt["g"],!1),noCloseOnEsc:Object(kn["c"])(pt["g"],!1),noCloseOnRouteChange:Object(kn["c"])(pt["g"],!1),noEnforceFocus:Object(kn["c"])(pt["g"],!1),noHeader:Object(kn["c"])(pt["g"],!1),noHeaderClose:Object(kn["c"])(pt["g"],!1),noSlide:Object(kn["c"])(pt["g"],!1),right:Object(kn["c"])(pt["g"],!1),shadow:Object(kn["c"])(pt["j"],!1),sidebarClass:Object(kn["c"])(pt["e"]),tag:Object(kn["c"])(pt["u"],"div"),textVariant:Object(kn["c"])(pt["u"],"dark"),title:Object(kn["c"])(pt["u"]),width:Object(kn["c"])(pt["u"]),zIndex:Object(kn["c"])(pt["p"])})),a["Xb"]),Hk=function(t,e){var n=e.normalizeSlot(ke,e.slotScope)||e.title;return n?t("strong",{attrs:{id:e.safeId("__title__")}},[n]):t("span")},Fk=function(t,e){if(e.noHeaderClose)return t();var n=e.closeLabel,r=e.textVariant,i=e.hide;return t(Rn,{props:{ariaLabel:n,textVariant:r},on:{click:i},ref:"close-button"},[e.normalizeSlot(Et)||t(Tr["Uw"])])},Dk=function(t,e){if(e.noHeader)return t();var n=e.normalizeSlot(It,e.slotScope);if(!n){var r=Hk(t,e),i=Fk(t,e);n=e.right?[i,r]:[r,i]}return t("header",{staticClass:"".concat(Mk,"-header"),class:e.headerClass,key:"header"},n)},Rk=function(t,e){return t("div",{staticClass:"".concat(Mk,"-body"),class:e.bodyClass,key:"body"},[e.normalizeSlot(Ot,e.slotScope)])},Nk=function(t,e){var n=e.normalizeSlot(Pt,e.slotScope);return n?t("footer",{staticClass:"".concat(Mk,"-footer"),class:e.footerClass,key:"footer"},[n]):t()},$k=function(t,e){var n=Dk(t,e);return e.lazy&&!e.isOpen?n:[n,Rk(t,e),Nk(t,e)]},Uk=function(t,e){if(!e.backdrop)return t();var n=e.backdropVariant;return t("div",{directives:[{name:"show",value:e.localShow}],staticClass:"b-sidebar-backdrop",class:jk({},"bg-".concat(n),n),on:{click:e.onBackdropClick}})},qk=i["default"].extend({name:a["Xb"],mixins:[Zr,oa,Pk,ti,Cn],inheritAttrs:!1,props:Bk,data:function(){var t=!!this[Ek];return{localShow:t,isOpen:t}},computed:{transitionProps:function(){return this.noSlide?{css:!0}:{css:!0,enterClass:"",enterActiveClass:"slide",enterToClass:"show",leaveClass:"show",leaveActiveClass:"slide",leaveToClass:""}},slotScope:function(){var t=this.hide,e=this.right,n=this.localShow;return{hide:t,right:e,visible:n}},hasTitle:function(){var t=this.$scopedSlots,e=this.$slots;return!this.noHeader&&!this.hasNormalizedSlot(It)&&!(!this.normalizeSlot(ke,this.slotScope,t,e)&&!this.title)},titleId:function(){return this.hasTitle?this.safeId("__title__"):null},computedAttrs:function(){return Ak(Ak({},this.bvAttrs),{},{id:this.safeId(),tabindex:"-1",role:"dialog","aria-modal":this.backdrop?"true":"false","aria-hidden":this.localShow?null:"true","aria-label":this.ariaLabel||null,"aria-labelledby":this.ariaLabelledby||this.titleId||null})}},watch:(wk={},jk(wk,Ek,(function(t,e){t!==e&&(this.localShow=t)})),jk(wk,"localShow",(function(t,e){t!==e&&(this.emitState(t),this.$emit(Lk,t))})),jk(wk,"$route",(function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};this.noCloseOnRouteChange||t.fullPath===e.fullPath||this.hide()})),wk),created:function(){this.$_returnFocusEl=null},mounted:function(){var t=this;this.listenOnRoot(Vk,this.handleToggle),this.listenOnRoot(Ck,this.handleSync),this.$nextTick((function(){t.emitState(t.localShow)}))},activated:function(){this.emitSync()},beforeDestroy:function(){this.localShow=!1,this.$_returnFocusEl=null},methods:{hide:function(){this.localShow=!1},emitState:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:this.localShow;this.emitOnRoot(Sk,this.safeId(),t)},emitSync:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:this.localShow;this.emitOnRoot(xk,this.safeId(),t)},handleToggle:function(t){t&&t===this.safeId()&&(this.localShow=!this.localShow)},handleSync:function(t){var e=this;t&&t===this.safeId()&&this.$nextTick((function(){e.emitSync(e.localShow)}))},onKeydown:function(t){var e=t.keyCode;!this.noCloseOnEsc&&e===Hr&&this.localShow&&this.hide()},onBackdropClick:function(){this.localShow&&!this.noCloseOnBackdrop&&this.hide()},onTopTrapFocus:function(){var t=vn(this.$refs.content);this.enforceFocus(t.reverse()[0])},onBottomTrapFocus:function(){var t=vn(this.$refs.content);this.enforceFocus(t[0])},onBeforeEnter:function(){this.$_returnFocusEl=Ue(Ae["i"]?[document.body]:[]),this.isOpen=!0},onAfterEnter:function(t){tn(t,Ue())||this.enforceFocus(t),this.$emit(Z)},onAfterLeave:function(){this.enforceFocus(this.$_returnFocusEl),this.$_returnFocusEl=null,this.isOpen=!1,this.$emit(C)},enforceFocus:function(t){this.noEnforceFocus||wn(t)}},render:function(t){var e,n=this.bgVariant,r=this.width,i=this.textVariant,o=this.localShow,a=""===this.shadow||this.shadow,s=t(this.tag,{staticClass:Mk,class:[(e={shadow:!0===a},jk(e,"shadow-".concat(a),a&&!0!==a),jk(e,"".concat(Mk,"-right"),this.right),jk(e,"bg-".concat(n),n),jk(e,"text-".concat(i),i),e),this.sidebarClass],style:{width:r},attrs:this.computedAttrs,directives:[{name:"show",value:o}],ref:"content"},[$k(t,this)]);s=t("transition",{props:this.transitionProps,on:{beforeEnter:this.onBeforeEnter,afterEnter:this.onAfterEnter,afterLeave:this.onAfterLeave}},[s]);var c=t(Kn,{props:{noFade:this.noSlide}},[Uk(t,this)]),l=t(),u=t();return this.backdrop&&o&&(l=t("div",{attrs:{tabindex:"0"},on:{focus:this.onTopTrapFocus}}),u=t("div",{attrs:{tabindex:"0"},on:{focus:this.onBottomTrapFocus}})),t("div",{staticClass:"b-sidebar-outer",style:{zIndex:this.zIndex},attrs:{tabindex:"-1"},on:{keydown:this.onKeydown}},[l,s,u,c])}}),Wk=Object(r["b"])({components:{BSidebar:qk},plugins:{VBTogglePlugin:ol}});function Gk(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Yk=Object(kn["d"])({animation:Object(kn["c"])(pt["u"],"wave"),height:Object(kn["c"])(pt["u"]),size:Object(kn["c"])(pt["u"]),type:Object(kn["c"])(pt["u"],"text"),variant:Object(kn["c"])(pt["u"]),width:Object(kn["c"])(pt["u"])},a["Yb"]),Kk=i["default"].extend({name:a["Yb"],functional:!0,props:Yk,render:function(t,e){var n,r=e.data,i=e.props,o=i.size,a=i.animation,s=i.variant;return t("div",Object(Vn["a"])(r,{staticClass:"b-skeleton",style:{width:o||i.width,height:o||i.height},class:(n={},Gk(n,"b-skeleton-".concat(i.type),!0),Gk(n,"b-skeleton-animate-".concat(a),a),Gk(n,"bg-".concat(s),s),n)}))}});function Qk(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Xk(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Qk(Object(n),!0).forEach((function(e){Jk(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Qk(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Jk(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Zk=Object(kn["d"])({animation:Object(kn["c"])(pt["u"],"wave"),icon:Object(kn["c"])(pt["u"]),iconProps:Object(kn["c"])(pt["q"],{})},a["Zb"]),t_=i["default"].extend({name:a["Zb"],functional:!0,props:Zk,render:function(t,e){var n=e.props,r=n.icon,i=n.animation,o=t(xr["a"],{staticClass:"b-skeleton-icon",props:Xk(Xk({},n.iconProps),{},{icon:r})});return t("div",{staticClass:"b-skeleton-icon-wrapper position-relative d-inline-block overflow-hidden",class:Jk({},"b-skeleton-animate-".concat(i),i)},[o])}});function e_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var n_=Object(kn["d"])({animation:Object(kn["c"])(pt["u"]),aspect:Object(kn["c"])(pt["u"],"16:9"),cardImg:Object(kn["c"])(pt["u"]),height:Object(kn["c"])(pt["u"]),noAspect:Object(kn["c"])(pt["g"],!1),variant:Object(kn["c"])(pt["u"]),width:Object(kn["c"])(pt["u"])},a["ac"]),r_=i["default"].extend({name:a["ac"],functional:!0,props:n_,render:function(t,e){var n=e.props,r=n.aspect,i=n.width,o=n.height,a=n.animation,s=n.variant,c=n.cardImg,l=t(Kk,{props:{type:"img",width:i,height:o,animation:a,variant:s},class:e_({},"card-img-".concat(c),c)});return n.noAspect?l:t(vr,{props:{aspect:r}},[l])}}),i_=i["default"].extend({methods:{hasListener:function(t){var e=this.$listeners||{},n=this._events||{};return!Object(Me["o"])(e[t])||Object(Me["a"])(n[t])&&n[t].length>0}}});function o_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var a_={stacked:Object(kn["c"])(pt["j"],!1)},s_=i["default"].extend({props:a_,computed:{isStacked:function(){var t=this.stacked;return""===t||t},isStackedAlways:function(){return!0===this.isStacked},stackedTableClasses:function(){var t=this.isStackedAlways;return o_({"b-table-stacked":t},"b-table-stacked-".concat(this.stacked),!t&&this.isStacked)}}});function c_(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function l_(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?c_(Object(n),!0).forEach((function(e){u_(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):c_(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function u_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var d_={bordered:Object(kn["c"])(pt["g"],!1),borderless:Object(kn["c"])(pt["g"],!1),captionTop:Object(kn["c"])(pt["g"],!1),dark:Object(kn["c"])(pt["g"],!1),fixed:Object(kn["c"])(pt["g"],!1),hover:Object(kn["c"])(pt["g"],!1),noBorderCollapse:Object(kn["c"])(pt["g"],!1),outlined:Object(kn["c"])(pt["g"],!1),responsive:Object(kn["c"])(pt["j"],!1),small:Object(kn["c"])(pt["g"],!1),stickyHeader:Object(kn["c"])(pt["j"],!1),striped:Object(kn["c"])(pt["g"],!1),tableClass:Object(kn["c"])(pt["e"]),tableVariant:Object(kn["c"])(pt["u"])},h_=i["default"].extend({mixins:[Zr],provide:function(){return{bvTable:this}},inheritAttrs:!1,props:d_,computed:{isResponsive:function(){var t=this.responsive;return""===t||t},isStickyHeader:function(){var t=this.stickyHeader;return t=""===t||t,!this.isStacked&&t},wrapperClasses:function(){var t=this.isResponsive;return[this.isStickyHeader?"b-table-sticky-header":"",!0===t?"table-responsive":t?"table-responsive-".concat(this.responsive):""].filter(An["a"])},wrapperStyles:function(){var t=this.isStickyHeader;return t&&!Object(Me["b"])(t)?{maxHeight:t}:{}},tableClasses:function(){var t=this.hover,e=this.tableVariant;return t=this.isTableSimple?t:t&&this.computedItems.length>0&&!this.computedBusy,[this.tableClass,{"table-striped":this.striped,"table-hover":t,"table-dark":this.dark,"table-bordered":this.bordered,"table-borderless":this.borderless,"table-sm":this.small,border:this.outlined,"b-table-fixed":this.fixed,"b-table-caption-top":this.captionTop,"b-table-no-border-collapse":this.noBorderCollapse},e?"".concat(this.dark?"bg":"table","-").concat(e):"",this.stackedTableClasses,this.selectableTableClasses]},tableAttrs:function(){var t=this.computedItems,e=this.filteredItems,n=this.computedFields,r=this.selectableTableAttrs,i=this.isTableSimple?{}:{"aria-busy":this.computedBusy?"true":"false","aria-colcount":Object(Ee["g"])(n.length),"aria-describedby":this.bvAttrs["aria-describedby"]||this.$refs.caption?this.captionId:null},o=t&&e&&e.length>t.length?Object(Ee["g"])(e.length):null;return l_(l_(l_({"aria-rowcount":o},this.bvAttrs),{},{id:this.safeId(),role:"table"},i),r)}},render:function(t){var e=this.wrapperClasses,n=this.renderCaption,r=this.renderColgroup,i=this.renderThead,o=this.renderTbody,a=this.renderTfoot,s=[];this.isTableSimple?s.push(this.normalizeSlot()):(s.push(n?n():null),s.push(r?r():null),s.push(i?i():null),s.push(o?o():null),s.push(a?a():null));var c=t("table",{staticClass:"table b-table",class:this.tableClasses,attrs:this.tableAttrs,key:"b-table"},s.filter(An["a"]));return e.length>0?t("div",{class:e,style:this.wrapperStyles,key:"wrap"},[c]):c}});function f_(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function p_(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?f_(Object(n),!0).forEach((function(e){m_(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):f_(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function m_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var b_=Object(kn["d"])(Object(zn["m"])(p_(p_(p_({},ia),a_),d_)),a["ic"]),g_=i["default"].extend({name:a["ic"],mixins:[Zr,i_,oa,Cn,h_,s_],props:b_,computed:{isTableSimple:function(){return!0}}});function v_(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function w_(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?v_(Object(n),!0).forEach((function(e){y_(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):v_(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function y_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var k_=function(t){return t>0},__=Object(kn["d"])({animation:Object(kn["c"])(pt["u"]),columns:Object(kn["c"])(pt["n"],5,k_),hideHeader:Object(kn["c"])(pt["g"],!1),rows:Object(kn["c"])(pt["n"],3,k_),showFooter:Object(kn["c"])(pt["g"],!1),tableProps:Object(kn["c"])(pt["q"],{})},a["bc"]),O_=i["default"].extend({name:a["bc"],functional:!0,props:__,render:function(t,e){var n=e.props,r=n.animation,i=n.columns,o=t("th",[t(Kk,{props:{animation:r}})]),a=t("tr",xe(i,o)),s=t("td",[t(Kk,{props:{width:"75%",animation:r}})]),c=t("tr",xe(i,s)),l=t("tbody",xe(n.rows,c)),u=n.hideHeader?t():t("thead",[a]),d=n.showFooter?t("tfoot",[a]):t();return t(g_,{props:w_({},n.tableProps)},[u,l,d])}}),z_=Object(kn["d"])({loading:Object(kn["c"])(pt["g"],!1)},a["cc"]),A_=i["default"].extend({name:a["cc"],functional:!0,props:z_,render:function(t,e){var n=e.data,r=e.props,i=e.slots,o=e.scopedSlots,a=i(),s=o||{},c={};return r.loading?t("div",Object(Vn["a"])(n,{attrs:{role:"alert","aria-live":"polite","aria-busy":!0},staticClass:"b-skeleton-wrapper",key:"loading"}),Mn(Wt,c,s,a)):Mn(Ot,c,s,a)}}),j_=Object(r["b"])({components:{BSkeleton:Kk,BSkeletonIcon:t_,BSkeletonImg:r_,BSkeletonTable:O_,BSkeletonWrapper:A_}}),M_=Object(r["b"])({components:{BSpinner:vw}});function C_(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function V_(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?C_(Object(n),!0).forEach((function(e){S_(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):C_(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function S_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var x_="light",T_="dark",P_=Object(kn["d"])({variant:Object(kn["c"])(pt["u"])},a["wc"]),I_=i["default"].extend({name:a["wc"],mixins:[Zr,ei,Cn],provide:function(){return{bvTableTr:this}},inject:{bvTableRowGroup:{default:function(){return{}}}},inheritAttrs:!1,props:P_,computed:{inTbody:function(){return this.bvTableRowGroup.isTbody},inThead:function(){return this.bvTableRowGroup.isThead},inTfoot:function(){return this.bvTableRowGroup.isTfoot},isDark:function(){return this.bvTableRowGroup.isDark},isStacked:function(){return this.bvTableRowGroup.isStacked},isResponsive:function(){return this.bvTableRowGroup.isResponsive},isStickyHeader:function(){return this.bvTableRowGroup.isStickyHeader},hasStickyHeader:function(){return!this.isStacked&&this.bvTableRowGroup.hasStickyHeader},tableVariant:function(){return this.bvTableRowGroup.tableVariant},headVariant:function(){return this.inThead?this.bvTableRowGroup.headVariant:null},footVariant:function(){return this.inTfoot?this.bvTableRowGroup.footVariant:null},isRowDark:function(){return this.headVariant!==x_&&this.footVariant!==x_&&(this.headVariant===T_||this.footVariant===T_||this.isDark)},trClasses:function(){var t=this.variant;return[t?"".concat(this.isRowDark?"bg":"table","-").concat(t):null]},trAttrs:function(){return V_({role:"row"},this.bvAttrs)}},render:function(t){return t("tr",{class:this.trClasses,attrs:this.trAttrs,on:this.bvListeners},this.normalizeSlot())}}),E_={},L_=i["default"].extend({props:E_,methods:{renderBottomRow:function(){var t=this.computedFields,e=this.stacked,n=this.tbodyTrClass,r=this.tbodyTrAttr,i=this.$createElement;return this.hasNormalizedSlot(wt)&&!0!==e&&""!==e?i(I_,{staticClass:"b-table-bottom-row",class:[Object(Me["f"])(n)?n(null,"row-bottom"):n],attrs:Object(Me["f"])(r)?r(null,"row-bottom"):r,key:"b-bottom-row"},this.normalizeSlot(wt,{columns:t.length,fields:t})):i()}}});function B_(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function H_(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?B_(Object(n),!0).forEach((function(e){F_(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):B_(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function F_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var D_=function(t){return t=Object(Ie["c"])(t,0),t>0?t:null},R_=function(t){return Object(Me["p"])(t)||D_(t)>0},N_=Object(kn["d"])({colspan:Object(kn["c"])(pt["p"],null,R_),rowspan:Object(kn["c"])(pt["p"],null,R_),stackedHeading:Object(kn["c"])(pt["u"]),stickyColumn:Object(kn["c"])(pt["g"],!1),variant:Object(kn["c"])(pt["u"])},a["gc"]),$_=i["default"].extend({name:a["gc"],mixins:[Zr,ei,Cn],inject:{bvTableTr:{default:function(){return{}}}},inheritAttrs:!1,props:N_,computed:{tag:function(){return"td"},inTbody:function(){return this.bvTableTr.inTbody},inThead:function(){return this.bvTableTr.inThead},inTfoot:function(){return this.bvTableTr.inTfoot},isDark:function(){return this.bvTableTr.isDark},isStacked:function(){return this.bvTableTr.isStacked},isStackedCell:function(){return this.inTbody&&this.isStacked},isResponsive:function(){return this.bvTableTr.isResponsive},isStickyHeader:function(){return this.bvTableTr.isStickyHeader},hasStickyHeader:function(){return this.bvTableTr.hasStickyHeader},isStickyColumn:function(){return!this.isStacked&&(this.isResponsive||this.hasStickyHeader)&&this.stickyColumn},rowVariant:function(){return this.bvTableTr.variant},headVariant:function(){return this.bvTableTr.headVariant},footVariant:function(){return this.bvTableTr.footVariant},tableVariant:function(){return this.bvTableTr.tableVariant},computedColspan:function(){return D_(this.colspan)},computedRowspan:function(){return D_(this.rowspan)},cellClasses:function(){var t=this.variant,e=this.headVariant,n=this.isStickyColumn;return(!t&&this.isStickyHeader&&!e||!t&&n&&this.inTfoot&&!this.footVariant||!t&&n&&this.inThead&&!e||!t&&n&&this.inTbody)&&(t=this.rowVariant||this.tableVariant||"b-table-default"),[t?"".concat(this.isDark?"bg":"table","-").concat(t):null,n?"b-table-sticky-column":null]},cellAttrs:function(){var t=this.stackedHeading,e=this.inThead||this.inTfoot,n=this.computedColspan,r=this.computedRowspan,i="cell",o=null;return e?(i="columnheader",o=n>0?"colspan":"col"):qe(this.tag,"th")&&(i="rowheader",o=r>0?"rowgroup":"row"),H_(H_({colspan:n,rowspan:r,role:i,scope:o},this.bvAttrs),{},{"data-label":this.isStackedCell&&!Object(Me["p"])(t)?Object(Ee["g"])(t):null})}},render:function(t){var e=[this.normalizeSlot()];return t(this.tag,{class:this.cellClasses,attrs:this.cellAttrs,on:this.bvListeners},[this.isStackedCell?t("div",[e]):e])}});function U_(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var q_="busy",W_=lt+q_,G_=U_({},q_,Object(kn["c"])(pt["g"],!1)),Y_=i["default"].extend({props:G_,data:function(){return{localBusy:!1}},computed:{computedBusy:function(){return this[q_]||this.localBusy}},watch:{localBusy:function(t,e){t!==e&&this.$emit(W_,t)}},methods:{stopIfBusy:function(t){return!!this.computedBusy&&(En(t),!0)},renderBusy:function(){var t=this.tbodyTrClass,e=this.tbodyTrAttr,n=this.$createElement;return this.computedBusy&&this.hasNormalizedSlot(pe)?n(I_,{staticClass:"b-table-busy-slot",class:[Object(Me["f"])(t)?t(null,pe):t],attrs:Object(Me["f"])(e)?e(null,pe):e,key:"table-busy-slot"},[n($_,{props:{colspan:this.computedFields.length||null}},[this.normalizeSlot(pe)])]):null}}}),K_={caption:Object(kn["c"])(pt["u"]),captionHtml:Object(kn["c"])(pt["u"])},Q_=i["default"].extend({props:K_,computed:{captionId:function(){return this.isStacked?this.safeId("_caption_"):null}},methods:{renderCaption:function(){var t=this.caption,e=this.captionHtml,n=this.$createElement,r=n(),i=this.hasNormalizedSlot(me);return(i||t||e)&&(r=n("caption",{attrs:{id:this.captionId},domProps:i?{}:Ji(e,t),key:"caption",ref:"caption"},this.normalizeSlot(me))),r}}}),X_={},J_=i["default"].extend({methods:{renderColgroup:function(){var t=this.computedFields,e=this.$createElement,n=e();return this.hasNormalizedSlot(be)&&(n=e("colgroup",{key:"colgroup"},[this.normalizeSlot(be,{columns:t.length,fields:t})])),n}}}),Z_={emptyFilteredHtml:Object(kn["c"])(pt["u"]),emptyFilteredText:Object(kn["c"])(pt["u"],"There are no records matching your request"),emptyHtml:Object(kn["c"])(pt["u"]),emptyText:Object(kn["c"])(pt["u"],"There are no records to show"),showEmpty:Object(kn["c"])(pt["g"],!1)},tO=i["default"].extend({props:Z_,methods:{renderEmpty:function(){var t=this.computedItems,e=this.$createElement,n=e();if(this.showEmpty&&(!t||0===t.length)&&(!this.computedBusy||!this.hasNormalizedSlot(pe))){var r=this.computedFields,i=this.isFiltered,o=this.emptyText,a=this.emptyHtml,s=this.emptyFilteredText,c=this.emptyFilteredHtml,l=this.tbodyTrClass,u=this.tbodyTrAttr;n=this.normalizeSlot(i?Vt:Ct,{emptyFilteredHtml:c,emptyFilteredText:s,emptyHtml:a,emptyText:o,fields:r,items:t}),n||(n=e("div",{class:["text-center","my-2"],domProps:i?Ji(c,s):Ji(a,o)})),n=e($_,{props:{colspan:r.length||null}},[e("div",{attrs:{role:"alert","aria-live":"polite"}},[n])]),n=e(I_,{staticClass:"b-table-empty-row",class:[Object(Me["f"])(l)?l(null,"row-empty"):l],attrs:Object(Me["f"])(u)?u(null,"row-empty"):u,key:i?"b-empty-filtered-row":"b-empty-row"},[n])}return n}}}),eO=function t(e){return Object(Me["p"])(e)?"":Object(Me["j"])(e)&&!Object(Me["c"])(e)?Object(zn["h"])(e).sort().map((function(n){return t(e[n])})).filter((function(t){return!!t})).join(" "):Object(Ee["g"])(e)};function nO(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function rO(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?nO(Object(n),!0).forEach((function(e){iO(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):nO(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function iO(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var oO="_cellVariants",aO="_rowVariant",sO="_showDetails",cO=[oO,aO,sO].reduce((function(t,e){return rO(rO({},t),{},iO({},e,!0))}),{}),lO=["a","a *","button","button *","input:not(.disabled):not([disabled])","select:not(.disabled):not([disabled])","textarea:not(.disabled):not([disabled])",'[role="link"]','[role="link"] *','[role="button"]','[role="button"] *',"[tabindex]:not(.disabled):not([disabled])"].join(","),uO=function(t,e,n){var r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},i=Object(zn["h"])(r).reduce((function(e,n){var i=r[n],o=i.filterByFormatted,a=Object(Me["f"])(o)?o:o?i.formatter:null;return Object(Me["f"])(a)&&(e[n]=a(t[n],n,t)),e}),Object(zn["b"])(t)),o=Object(zn["h"])(i).filter((function(t){return!cO[t]&&!(Object(Me["a"])(e)&&e.length>0&&Ve(e,t))&&!(Object(Me["a"])(n)&&n.length>0&&!Ve(n,t))}));return Object(zn["k"])(i,o)},dO=function(t,e,n,r){return Object(Me["j"])(t)?eO(uO(t,e,n,r)):""};function hO(t){return bO(t)||mO(t)||pO(t)||fO()}function fO(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function pO(t,e){if(t){if("string"===typeof t)return gO(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?gO(t,e):void 0}}function mO(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function bO(t){if(Array.isArray(t))return gO(t)}function gO(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}var vO='Prop "filter-debounce" is deprecated. Use the debounce feature of "<b-form-input>" instead.',wO={filter:Object(kn["c"])([].concat(hO(pt["e"]),[pt["t"]])),filterDebounce:Object(kn["c"])(pt["p"],0,(function(t){return Sn["h"].test(String(t))})),filterFunction:Object(kn["c"])(pt["l"]),filterIgnoredFields:Object(kn["c"])(pt["b"],[]),filterIncludedFields:Object(kn["c"])(pt["b"],[])},yO=i["default"].extend({props:wO,data:function(){return{isFiltered:!1,localFilter:this.filterSanitize(this.filter)}},computed:{computedFilterIgnored:function(){return Se(this.filterIgnoredFields||[]).filter(An["a"])},computedFilterIncluded:function(){return Se(this.filterIncludedFields||[]).filter(An["a"])},computedFilterDebounce:function(){var t=Object(Ie["c"])(this.filterDebounce,0);return t>0&&Object(Vs["a"])(vO,a["fc"]),t},localFiltering:function(){return!this.hasProvider||!!this.noProviderFiltering},filteredCheck:function(){var t=this.filteredItems,e=this.localItems,n=this.localFilter;return{filteredItems:t,localItems:e,localFilter:n}},localFilterFn:function(){var t=this.filterFunction;return Object(kn["b"])(t)?t:null},filteredItems:function(){var t=this.localItems,e=this.localFilter,n=this.localFiltering?this.filterFnFactory(this.localFilterFn,e)||this.defaultFilterFnFactory(e):null;return n&&t.length>0?t.filter(n):t}},watch:{computedFilterDebounce:function(t){!t&&this.$_filterTimer&&(this.clearFilterTimer(),this.localFilter=this.filterSanitize(this.filter))},filter:{deep:!0,handler:function(t){var e=this,n=this.computedFilterDebounce;this.clearFilterTimer(),n&&n>0?this.$_filterTimer=setTimeout((function(){e.localFilter=e.filterSanitize(t)}),n):this.localFilter=this.filterSanitize(t)}},filteredCheck:function(t){var e=t.filteredItems,n=t.localFilter,r=!1;n?Yr(n,[])||Yr(n,{})?r=!1:n&&(r=!0):r=!1,r&&this.$emit(O,e,e.length),this.isFiltered=r},isFiltered:function(t,e){if(!1===t&&!0===e){var n=this.localItems;this.$emit(O,n,n.length)}}},created:function(){var t=this;this.$_filterTimer=null,this.$nextTick((function(){t.isFiltered=Boolean(t.localFilter)}))},beforeDestroy:function(){this.clearFilterTimer()},methods:{clearFilterTimer:function(){clearTimeout(this.$_filterTimer),this.$_filterTimer=null},filterSanitize:function(t){return!this.localFiltering||this.localFilterFn||Object(Me["n"])(t)||Object(Me["m"])(t)?Object(Wr["a"])(t):""},filterFnFactory:function(t,e){if(!t||!Object(Me["f"])(t)||!e||Yr(e,[])||Yr(e,{}))return null;var n=function(n){return t(n,e)};return n},defaultFilterFnFactory:function(t){var e=this;if(!t||!Object(Me["n"])(t)&&!Object(Me["m"])(t))return null;var n=t;if(Object(Me["n"])(n)){var r=Object(Ee["a"])(t).replace(Sn["w"],"\\s+");n=new RegExp(".*".concat(r,".*"),"i")}var i=function(t){return n.lastIndex=0,n.test(dO(t,e.computedFilterIgnored,e.computedFilterIncluded,e.computedFieldsObj))};return i}}}),kO=function(t,e){var n=null;return Object(Me["n"])(e)?n={key:t,label:e}:Object(Me["f"])(e)?n={key:t,formatter:e}:Object(Me["j"])(e)?(n=Object(zn["b"])(e),n.key=n.key||t):!1!==e&&(n={key:t}),n},_O=function(t,e){var n=[];if(Object(Me["a"])(t)&&t.filter(An["a"]).forEach((function(t){if(Object(Me["n"])(t))n.push({key:t,label:Object(Ee["f"])(t)});else if(Object(Me["j"])(t)&&t.key&&Object(Me["n"])(t.key))n.push(Object(zn["b"])(t));else if(Object(Me["j"])(t)&&1===Object(zn["h"])(t).length){var e=Object(zn["h"])(t)[0],r=kO(e,t[e]);r&&n.push(r)}})),0===n.length&&Object(Me["a"])(e)&&e.length>0){var r=e[0];Object(zn["h"])(r).forEach((function(t){cO[t]||n.push({key:t,label:Object(Ee["f"])(t)})}))}var i={};return n.filter((function(t){return!i[t.key]&&(i[t.key]=!0,t.label=Object(Me["n"])(t.label)?t.label:Object(Ee["f"])(t.key),!0)}))};function OO(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function zO(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?OO(Object(n),!0).forEach((function(e){AO(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):OO(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function AO(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var jO=On("value",{type:pt["b"],defaultValue:[]}),MO=jO.mixin,CO=jO.props,VO=jO.prop,SO=jO.event,xO=Object(zn["m"])(zO(zO({},CO),{},AO({fields:Object(kn["c"])(pt["b"],null),items:Object(kn["c"])(pt["b"],[]),primaryKey:Object(kn["c"])(pt["u"])},VO,Object(kn["c"])(pt["b"],[])))),TO=i["default"].extend({mixins:[MO],props:xO,data:function(){var t=this.items;return{localItems:Object(Me["a"])(t)?t.slice():[]}},computed:{computedFields:function(){return _O(this.fields,this.localItems)},computedFieldsObj:function(){var t=this.$parent;return this.computedFields.reduce((function(e,n){if(e[n.key]=Object(zn["b"])(n),n.formatter){var r=n.formatter;Object(Me["n"])(r)&&Object(Me["f"])(t[r])?r=t[r]:Object(Me["f"])(r)||(r=void 0),e[n.key].formatter=r}return e}),{})},computedItems:function(){return(this.paginatedItems||this.sortedItems||this.filteredItems||this.localItems||[]).slice()},context:function(){return{filter:this.localFilter,sortBy:this.localSortBy,sortDesc:this.localSortDesc,perPage:Object(lr["d"])(Object(Ie["c"])(this.perPage,0),0),currentPage:Object(lr["d"])(Object(Ie["c"])(this.currentPage,0),1),apiUrl:this.apiUrl}}},watch:{items:function(t){this.localItems=Object(Me["a"])(t)?t.slice():[]},computedItems:function(t,e){Yr(t,e)||this.$emit(SO,t)},context:function(t,e){Yr(t,e)||this.$emit(m,t)}},mounted:function(){this.$emit(SO,this.computedItems)},methods:{getFieldFormatter:function(t){var e=this.computedFieldsObj[t];return e?e.formatter:void 0}}}),PO={currentPage:Object(kn["c"])(pt["p"],1),perPage:Object(kn["c"])(pt["p"],0)},IO=i["default"].extend({props:PO,computed:{localPaging:function(){return!this.hasProvider||!!this.noProviderPaging},paginatedItems:function(){var t=this.sortedItems||this.filteredItems||this.localItems||[],e=Object(lr["d"])(Object(Ie["c"])(this.currentPage,1),1),n=Object(lr["d"])(Object(Ie["c"])(this.perPage,0),0);return this.localPaging&&n&&(t=t.slice((e-1)*n,e*n)),t}}}),EO=Bn(a["fc"],N),LO=Hn(a["fc"],R),BO={apiUrl:Object(kn["c"])(pt["u"]),items:Object(kn["c"])(pt["c"],[]),noProviderFiltering:Object(kn["c"])(pt["g"],!1),noProviderPaging:Object(kn["c"])(pt["g"],!1),noProviderSorting:Object(kn["c"])(pt["g"],!1)},HO=i["default"].extend({mixins:[ti],props:BO,computed:{hasProvider:function(){return Object(Me["f"])(this.items)},providerTriggerContext:function(){var t={apiUrl:this.apiUrl,filter:null,sortBy:null,sortDesc:null,perPage:null,currentPage:null};return this.noProviderFiltering||(t.filter=this.localFilter),this.noProviderSorting||(t.sortBy=this.localSortBy,t.sortDesc=this.localSortDesc),this.noProviderPaging||(t.perPage=this.perPage,t.currentPage=this.currentPage),Object(zn["b"])(t)}},watch:{items:function(t){(this.hasProvider||Object(Me["f"])(t))&&this.$nextTick(this._providerUpdate)},providerTriggerContext:function(t,e){Yr(t,e)||this.$nextTick(this._providerUpdate)}},mounted:function(){var t=this;!this.hasProvider||this.localItems&&0!==this.localItems.length||this._providerUpdate(),this.listenOnRoot(LO,(function(e){e!==t.id&&e!==t||t.refresh()}))},methods:{refresh:function(){var t=this.items,e=this.refresh;this.$off(N,e),this.computedBusy?this.localBusy&&this.hasProvider&&this.$on(N,e):(this.clearSelected(),this.hasProvider?this.$nextTick(this._providerUpdate):this.localItems=Object(Me["a"])(t)?t.slice():[])},_providerSetLocal:function(t){this.localItems=Object(Me["a"])(t)?t.slice():[],this.localBusy=!1,this.$emit(N),this.id&&this.emitOnRoot(EO,this.id)},_providerUpdate:function(){var t=this;this.hasProvider&&(this.computedBusy?this.$nextTick(this.refresh):(this.localBusy=!0,this.$nextTick((function(){try{var e=t.items(t.context,t._providerSetLocal);Object(Me["l"])(e)?e.then((function(e){t._providerSetLocal(e)})):Object(Me["a"])(e)?t._providerSetLocal(e):2!==t.items.length&&(Object(Vs["a"])("Provider function didn't request callback and did not return a promise or data.",a["fc"]),t.localBusy=!1)}catch(n){Object(Vs["a"])("Provider function error [".concat(n.name,"] ").concat(n.message,"."),a["fc"]),t.localBusy=!1,t.$off(N,t.refresh)}}))))}}});function FO(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var DO,RO,NO=["range","multi","single"],$O={noSelectOnClick:Object(kn["c"])(pt["g"],!1),selectMode:Object(kn["c"])(pt["u"],"multi",(function(t){return Ve(NO,t)})),selectable:Object(kn["c"])(pt["g"],!1),selectedVariant:Object(kn["c"])(pt["u"],"active")},UO=i["default"].extend({props:$O,data:function(){return{selectedRows:[],selectedLastRow:-1}},computed:{isSelectable:function(){return this.selectable&&this.selectMode},hasSelectableRowClick:function(){return this.isSelectable&&!this.noSelectOnClick},supportsSelectableRows:function(){return!0},selectableHasSelection:function(){var t=this.selectedRows;return this.isSelectable&&t&&t.length>0&&t.some(An["a"])},selectableIsMultiSelect:function(){return this.isSelectable&&Ve(["range","multi"],this.selectMode)},selectableTableClasses:function(){var t,e=this.isSelectable;return t={"b-table-selectable":e},FO(t,"b-table-select-".concat(this.selectMode),e),FO(t,"b-table-selecting",this.selectableHasSelection),FO(t,"b-table-selectable-no-click",e&&!this.hasSelectableRowClick),t},selectableTableAttrs:function(){return{"aria-multiselectable":this.isSelectable?this.selectableIsMultiSelect?"true":"false":null}}},watch:{computedItems:function(t,e){var n=!1;if(this.isSelectable&&this.selectedRows.length>0){n=Object(Me["a"])(t)&&Object(Me["a"])(e)&&t.length===e.length;for(var r=0;n&&r<t.length;r++)n=Yr(uO(t[r]),uO(e[r]))}n||this.clearSelected()},selectable:function(t){this.clearSelected(),this.setSelectionHandlers(t)},selectMode:function(){this.clearSelected()},hasSelectableRowClick:function(t){this.clearSelected(),this.setSelectionHandlers(!t)},selectedRows:function(t,e){var n=this;if(this.isSelectable&&!Yr(t,e)){var r=[];t.forEach((function(t,e){t&&r.push(n.computedItems[e])})),this.$emit(K,r)}}},beforeMount:function(){this.isSelectable&&this.setSelectionHandlers(!0)},methods:{selectRow:function(t){if(this.isSelectable&&Object(Me["h"])(t)&&t>=0&&t<this.computedItems.length&&!this.isRowSelected(t)){var e=this.selectableIsMultiSelect?this.selectedRows.slice():[];e[t]=!0,this.selectedLastClicked=-1,this.selectedRows=e}},unselectRow:function(t){if(this.isSelectable&&Object(Me["h"])(t)&&this.isRowSelected(t)){var e=this.selectedRows.slice();e[t]=!1,this.selectedLastClicked=-1,this.selectedRows=e}},selectAllRows:function(){var t=this.computedItems.length;this.isSelectable&&t>0&&(this.selectedLastClicked=-1,this.selectedRows=this.selectableIsMultiSelect?xe(t,!0):[!0])},isRowSelected:function(t){return!(!Object(Me["h"])(t)||!this.selectedRows[t])},clearSelected:function(){this.selectedLastClicked=-1,this.selectedRows=[]},selectableRowClasses:function(t){if(this.isSelectable&&this.isRowSelected(t)){var e=this.selectedVariant;return FO({"b-table-row-selected":!0},"".concat(this.dark?"bg":"table","-").concat(e),e)}return{}},selectableRowAttrs:function(t){return{"aria-selected":this.isSelectable?this.isRowSelected(t)?"true":"false":null}},setSelectionHandlers:function(t){var e=t&&!this.noSelectOnClick?"$on":"$off";this[e](U,this.selectionHandler),this[e](O,this.clearSelected),this[e](m,this.clearSelected)},selectionHandler:function(t,e,n){if(this.isSelectable&&!this.noSelectOnClick){var r=this.selectMode,i=this.selectedLastRow,o=this.selectedRows.slice(),a=!o[e];if("single"===r)o=[];else if("range"===r)if(i>-1&&n.shiftKey){for(var s=Object(lr["e"])(i,e);s<=Object(lr["d"])(i,e);s++)o[s]=!0;a=!0}else n.ctrlKey||n.metaKey||(o=[],a=!0),this.selectedLastRow=a?e:-1;o[e]=a,this.selectedRows=o}else this.clearSelected()}}}),qO=function(t,e){return t.map((function(t,e){return[e,t]})).sort(function(t,e){return this(t[1],e[1])||t[0]-e[0]}.bind(e)).map((function(t){return t[1]}))},WO=function(t){return Object(Me["p"])(t)?"":Object(Me["i"])(t)?Object(Ie["b"])(t,t):t},GO=function(t,e){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},r=n.sortBy,i=void 0===r?null:r,o=n.formatter,a=void 0===o?null:o,s=n.locale,c=void 0===s?void 0:s,l=n.localeOptions,u=void 0===l?{}:l,d=n.nullLast,h=void 0!==d&&d,f=Object(Ou["a"])(t,i,null),p=Object(Ou["a"])(e,i,null);return Object(Me["f"])(a)&&(f=a(f,i,t),p=a(p,i,e)),f=WO(f),p=WO(p),Object(Me["c"])(f)&&Object(Me["c"])(p)||Object(Me["h"])(f)&&Object(Me["h"])(p)?f<p?-1:f>p?1:0:h&&""===f&&""!==p?1:h&&""!==f&&""===p?-1:eO(f).localeCompare(eO(p),c,u)};function YO(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function KO(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?YO(Object(n),!0).forEach((function(e){QO(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):YO(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function QO(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var XO="sortBy",JO=lt+XO,ZO="sortDesc",tz=lt+ZO,ez="asc",nz="desc",rz="last",iz=[ez,nz,rz],oz=(DO={labelSortAsc:Object(kn["c"])(pt["u"],"Click to sort Ascending"),labelSortClear:Object(kn["c"])(pt["u"],"Click to clear sorting"),labelSortDesc:Object(kn["c"])(pt["u"],"Click to sort Descending"),noFooterSorting:Object(kn["c"])(pt["g"],!1),noLocalSorting:Object(kn["c"])(pt["g"],!1),noSortReset:Object(kn["c"])(pt["g"],!1)},QO(DO,XO,Object(kn["c"])(pt["u"])),QO(DO,"sortCompare",Object(kn["c"])(pt["l"])),QO(DO,"sortCompareLocale",Object(kn["c"])(pt["f"])),QO(DO,"sortCompareOptions",Object(kn["c"])(pt["q"],{numeric:!0})),QO(DO,ZO,Object(kn["c"])(pt["g"],!1)),QO(DO,"sortDirection",Object(kn["c"])(pt["u"],ez,(function(t){return Ve(iz,t)}))),QO(DO,"sortIconLeft",Object(kn["c"])(pt["g"],!1)),QO(DO,"sortNullLast",Object(kn["c"])(pt["g"],!1)),DO),az=i["default"].extend({props:oz,data:function(){return{localSortBy:this[XO]||"",localSortDesc:this[ZO]||!1}},computed:{localSorting:function(){return this.hasProvider?!!this.noProviderSorting:!this.noLocalSorting},isSortable:function(){return this.computedFields.some((function(t){return t.sortable}))},sortedItems:function(){var t=this.localSortBy,e=this.localSortDesc,n=this.sortCompareLocale,r=this.sortNullLast,i=this.sortCompare,o=this.localSorting,a=(this.filteredItems||this.localItems||[]).slice(),s=KO(KO({},this.sortCompareOptions),{},{usage:"sort"});if(t&&o){var c=this.computedFieldsObj[t]||{},l=c.sortByFormatted,u=Object(Me["f"])(l)?l:l?this.getFieldFormatter(t):void 0;return qO(a,(function(o,a){var c=null;return Object(Me["f"])(i)&&(c=i(o,a,t,e,u,s,n)),(Object(Me["p"])(c)||!1===c)&&(c=GO(o,a,{sortBy:t,formatter:u,locale:n,localeOptions:s,nullLast:r})),(c||0)*(e?-1:1)}))}return a}},watch:(RO={isSortable:function(t){t?this.isSortable&&this.$on(M,this.handleSort):this.$off(M,this.handleSort)}},QO(RO,ZO,(function(t){t!==this.localSortDesc&&(this.localSortDesc=t||!1)})),QO(RO,XO,(function(t){t!==this.localSortBy&&(this.localSortBy=t||"")})),QO(RO,"localSortDesc",(function(t,e){t!==e&&this.$emit(tz,t)})),QO(RO,"localSortBy",(function(t,e){t!==e&&this.$emit(JO,t)})),RO),created:function(){this.isSortable&&this.$on(M,this.handleSort)},methods:{handleSort:function(t,e,n,r){var i=this;if(this.isSortable&&(!r||!this.noFooterSorting)){var o=!1,a=function(){var t=e.sortDirection||i.sortDirection;t===ez?i.localSortDesc=!1:t===nz&&(i.localSortDesc=!0)};if(e.sortable){var s=!this.localSorting&&e.sortKey?e.sortKey:t;this.localSortBy===s?this.localSortDesc=!this.localSortDesc:(this.localSortBy=s,a()),o=!0}else this.localSortBy&&!this.noSortReset&&(this.localSortBy="",a(),o=!0);o&&this.$emit(nt,this.context)}},sortTheadThClasses:function(t,e,n){return{"b-table-sort-icon-left":e.sortable&&this.sortIconLeft&&!(n&&this.noFooterSorting)}},sortTheadThAttrs:function(t,e,n){if(!this.isSortable||n&&this.noFooterSorting)return{};var r=e.sortable,i=r&&this.localSortBy===t?this.localSortDesc?"descending":"ascending":r?"none":null;return{"aria-sort":i}},sortTheadThLabel:function(t,e,n){if(!this.isSortable||n&&this.noFooterSorting)return null;var r=e.sortable,i="";if(r)if(this.localSortBy===t)i=this.localSortDesc?this.labelSortAsc:this.labelSortDesc;else{i=this.localSortDesc?this.labelSortDesc:this.labelSortAsc;var o=this.sortDirection||e.sortDirection;o===ez?i=this.labelSortAsc:o===nz&&(i=this.labelSortDesc)}else this.noSortReset||(i=this.localSortBy?this.labelSortClear:"");return Object(Ee["h"])(i)||null}}});function sz(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function cz(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?sz(Object(n),!0).forEach((function(e){lz(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):sz(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function lz(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var uz=Object(kn["d"])({tbodyTransitionHandlers:Object(kn["c"])(pt["q"]),tbodyTransitionProps:Object(kn["c"])(pt["q"])},a["lc"]),dz=i["default"].extend({name:a["lc"],mixins:[Zr,ei,Cn],provide:function(){return{bvTableRowGroup:this}},inject:{bvTable:{default:function(){return{}}}},inheritAttrs:!1,props:uz,computed:{isTbody:function(){return!0},isDark:function(){return this.bvTable.dark},isStacked:function(){return this.bvTable.isStacked},isResponsive:function(){return this.bvTable.isResponsive},isStickyHeader:function(){return!1},hasStickyHeader:function(){return!this.isStacked&&this.bvTable.stickyHeader},tableVariant:function(){return this.bvTable.tableVariant},isTransitionGroup:function(){return this.tbodyTransitionProps||this.tbodyTransitionHandlers},tbodyAttrs:function(){return cz({role:"rowgroup"},this.bvAttrs)},tbodyProps:function(){var t=this.tbodyTransitionProps;return t?cz(cz({},t),{},{tag:"tbody"}):{}}},render:function(t){var e={props:this.tbodyProps,attrs:this.tbodyAttrs};return this.isTransitionGroup?(e.on=this.tbodyTransitionHandlers||{},e.nativeOn=this.bvListeners):e.on=this.bvListeners,t(this.isTransitionGroup?"transition-group":"tbody",e,this.normalizeSlot())}}),hz=["TD","TH","TR"],fz=function(t){if(!t||!t.target)return!1;var e=t.target;if(e.disabled||-1!==hz.indexOf(e.tagName))return!1;if(Ze(".dropdown-menu",e))return!0;var n="LABEL"===e.tagName?e:Ze("label",e);if(n){var r=cn(n,"for"),i=r?en(r):Xe("input, select, textarea",n);if(i&&!i.disabled)return!0}return Je(e,lO)},pz=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:document,e=mn();return!!(e&&""!==e.toString().trim()&&e.containsNode&&$e(t))&&e.containsNode(t,!0)},mz=Object(kn["d"])(N_,a["nc"]),bz=i["default"].extend({name:a["nc"],extends:$_,props:mz,computed:{tag:function(){return"th"}}});function gz(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function vz(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?gz(Object(n),!0).forEach((function(e){wz(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):gz(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function wz(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function yz(t){return zz(t)||Oz(t)||_z(t)||kz()}function kz(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function _z(t,e){if(t){if("string"===typeof t)return Az(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Az(t,e):void 0}}function Oz(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function zz(t){if(Array.isArray(t))return Az(t)}function Az(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}var jz={detailsTdClass:Object(kn["c"])(pt["e"]),tbodyTrAttr:Object(kn["c"])(pt["r"]),tbodyTrClass:Object(kn["c"])([].concat(yz(pt["e"]),[pt["l"]]))},Mz=i["default"].extend({props:jz,methods:{getTdValues:function(t,e,n,r){var i=this.$parent;if(n){var o=Object(Ou["a"])(t,e,"");return Object(Me["f"])(n)?n(o,e,t):Object(Me["n"])(n)&&Object(Me["f"])(i[n])?i[n](o,e,t):n}return r},getThValues:function(t,e,n,r,i){var o=this.$parent;if(n){var a=Object(Ou["a"])(t,e,"");return Object(Me["f"])(n)?n(a,e,t,r):Object(Me["n"])(n)&&Object(Me["f"])(o[n])?o[n](a,e,t,r):n}return i},getFormattedValue:function(t,e){var n=e.key,r=this.getFieldFormatter(n),i=Object(Ou["a"])(t,n,null);return Object(Me["f"])(r)&&(i=r(i,n,t)),Object(Me["p"])(i)?"":i},toggleDetailsFactory:function(t,e){var n=this;return function(){t&&n.$set(e,sO,!e[sO])}},rowHovered:function(t){this.tbodyRowEvtStopped(t)||this.emitTbodyRowEvent(G,t)},rowUnhovered:function(t){this.tbodyRowEvtStopped(t)||this.emitTbodyRowEvent(Q,t)},renderTbodyRowCell:function(t,e,n,r){var i=this,o=this.isStacked,a=t.key,s=t.label,c=t.isRowHeader,l=this.$createElement,u=this.hasNormalizedSlot(fe),d=this.getFormattedValue(n,t),h=!o&&(this.isResponsive||this.stickyHeader)&&t.stickyColumn,f=h?c?bz:$_:c?"th":"td",p=n[oO]&&n[oO][a]?n[oO][a]:t.variant||null,m={class:[t.class?t.class:"",this.getTdValues(n,a,t.tdClass,"")],props:{},attrs:vz({"aria-colindex":String(e+1)},c?this.getThValues(n,a,t.thAttr,"row",{}):this.getTdValues(n,a,t.tdAttr,{})),key:"row-".concat(r,"-cell-").concat(e,"-").concat(a)};h?m.props={stackedHeading:o?s:null,stickyColumn:!0,variant:p}:(m.attrs["data-label"]=o&&!Object(Me["p"])(s)?Object(Ee["g"])(s):null,m.attrs.role=c?"rowheader":"cell",m.attrs.scope=c?"row":null,p&&m.class.push("".concat(this.dark?"bg":"table","-").concat(p)));var b={item:n,index:r,field:t,unformatted:Object(Ou["a"])(n,a,""),value:d,toggleDetails:this.toggleDetailsFactory(u,n),detailsShowing:Boolean(n[sO])};this.supportsSelectableRows&&(b.rowSelected=this.isRowSelected(r),b.selectRow=function(){return i.selectRow(r)},b.unselectRow=function(){return i.unselectRow(r)});var g=this.$_bodyFieldSlotNameCache[a],v=g?this.normalizeSlot(g,b):Object(Ee["g"])(d);return this.isStacked&&(v=[l("div",[v])]),l(f,m,[v])},renderTbodyRow:function(t,e){var n=this,r=this.computedFields,i=this.striped,o=this.primaryKey,a=this.currentPage,s=this.perPage,c=this.tbodyTrClass,l=this.tbodyTrAttr,u=this.$createElement,d=this.hasNormalizedSlot(fe),h=t[sO]&&d,f=this.$listeners[U]||this.hasSelectableRowClick,p=[],m=h?this.safeId("_details_".concat(e,"_")):null,b=r.map((function(r,i){return n.renderTbodyRowCell(r,i,t,e)})),g=null;a&&s&&s>0&&(g=String((a-1)*s+e+1));var v=Object(Ee["g"])(Object(Ou["a"])(t,o))||null,w=v||Object(Ee["g"])(e),y=v?this.safeId("_row_".concat(v)):null,k=this.selectableRowClasses?this.selectableRowClasses(e):{},_=this.selectableRowAttrs?this.selectableRowAttrs(e):{},O=Object(Me["f"])(c)?c(t,"row"):c,z=Object(Me["f"])(l)?l(t,"row"):l;if(p.push(u(I_,{class:[O,k,h?"b-table-has-details":""],props:{variant:t[aO]||null},attrs:vz(vz({id:y},z),{},{tabindex:f?"0":null,"data-pk":v||null,"aria-details":m,"aria-owns":m,"aria-rowindex":g},_),on:{mouseenter:this.rowHovered,mouseleave:this.rowUnhovered},key:"__b-table-row-".concat(w,"__"),ref:"item-rows",refInFor:!0},b)),h){var A={item:t,index:e,fields:r,toggleDetails:this.toggleDetailsFactory(d,t)};this.supportsSelectableRows&&(A.rowSelected=this.isRowSelected(e),A.selectRow=function(){return n.selectRow(e)},A.unselectRow=function(){return n.unselectRow(e)});var j=u($_,{props:{colspan:r.length},class:this.detailsTdClass},[this.normalizeSlot(fe,A)]);i&&p.push(u("tr",{staticClass:"d-none",attrs:{"aria-hidden":"true",role:"presentation"},key:"__b-table-details-stripe__".concat(w)}));var M=Object(Me["f"])(this.tbodyTrClass)?this.tbodyTrClass(t,fe):this.tbodyTrClass,C=Object(Me["f"])(this.tbodyTrAttr)?this.tbodyTrAttr(t,fe):this.tbodyTrAttr;p.push(u(I_,{staticClass:"b-table-details",class:[M],props:{variant:t[aO]||null},attrs:vz(vz({},C),{},{id:m,tabindex:"-1"}),key:"__b-table-details__".concat(w)},[j]))}else d&&(p.push(u()),i&&p.push(u()));return p}}});function Cz(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Vz(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Cz(Object(n),!0).forEach((function(e){Sz(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Cz(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Sz(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var xz=function(t){return"cell(".concat(t||"",")")},Tz=Object(zn["m"])(Vz(Vz(Vz({},uz),jz),{},{tbodyClass:Object(kn["c"])(pt["e"])})),Pz=i["default"].extend({mixins:[Mz],props:Tz,beforeDestroy:function(){this.$_bodyFieldSlotNameCache=null},methods:{getTbodyTrs:function(){var t=this.$refs,e=t.tbody?t.tbody.$el||t.tbody:null,n=(t["item-rows"]||[]).map((function(t){return t.$el||t}));return e&&e.children&&e.children.length>0&&n&&n.length>0?Ce(e.children).filter((function(t){return Ve(n,t)})):[]},getTbodyTrIndex:function(t){if(!$e(t))return-1;var e="TR"===t.tagName?t:Ze("tr",t,!0);return e?this.getTbodyTrs().indexOf(e):-1},emitTbodyRowEvent:function(t,e){if(t&&this.hasListener(t)&&e&&e.target){var n=this.getTbodyTrIndex(e.target);if(n>-1){var r=this.computedItems[n];this.$emit(t,r,n,e)}}},tbodyRowEvtStopped:function(t){return this.stopIfBusy&&this.stopIfBusy(t)},onTbodyRowKeydown:function(t){var e=t.target,n=t.keyCode;if(!this.tbodyRowEvtStopped(t)&&"TR"===e.tagName&&We(e)&&0===e.tabIndex)if(Ve([Br,Ur],n))En(t),this.onTBodyRowClicked(t);else if(Ve([qr,Er,Fr,Lr],n)){var r=this.getTbodyTrIndex(e);if(r>-1){En(t);var i=this.getTbodyTrs(),o=t.shiftKey;n===Fr||o&&n===qr?wn(i[0]):n===Lr||o&&n===Er?wn(i[i.length-1]):n===qr&&r>0?wn(i[r-1]):n===Er&&r<i.length-1&&wn(i[r+1])}}},onTBodyRowClicked:function(t){this.tbodyRowEvtStopped(t)||fz(t)||pz(this.$el)||this.emitTbodyRowEvent(U,t)},onTbodyRowMiddleMouseRowClicked:function(t){this.tbodyRowEvtStopped(t)||2!==t.which||this.emitTbodyRowEvent(Y,t)},onTbodyRowContextmenu:function(t){this.tbodyRowEvtStopped(t)||this.emitTbodyRowEvent(q,t)},onTbodyRowDblClicked:function(t){this.tbodyRowEvtStopped(t)||fz(t)||this.emitTbodyRowEvent(W,t)},renderTbody:function(){var t=this,e=this.computedItems,n=this.renderBusy,r=this.renderTopRow,i=this.renderEmpty,o=this.renderBottomRow,a=this.$createElement,s=this.hasListener(U)||this.hasSelectableRowClick,c=[],l=n?n():null;if(l)c.push(l);else{var u={},d=xz();d=this.hasNormalizedSlot(d)?d:null,this.computedFields.forEach((function(e){var n=e.key,r=xz(n),i=xz(n.toLowerCase());u[n]=t.hasNormalizedSlot(r)?r:t.hasNormalizedSlot(i)?i:d})),this.$_bodyFieldSlotNameCache=u,c.push(r?r():a()),e.forEach((function(e,n){c.push(t.renderTbodyRow(e,n))})),c.push(i?i():a()),c.push(o?o():a())}var h={auxclick:this.onTbodyRowMiddleMouseRowClicked,contextmenu:this.onTbodyRowContextmenu,dblclick:this.onTbodyRowDblClicked};s&&(h.click=this.onTBodyRowClicked,h.keydown=this.onTbodyRowKeydown);var f=a(dz,{class:this.tbodyClass||null,props:Object(kn["e"])(uz,this.$props),on:h,ref:"tbody"},c);return f}}});function Iz(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Ez(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Iz(Object(n),!0).forEach((function(e){Lz(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Iz(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Lz(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Bz=Object(kn["d"])({footVariant:Object(kn["c"])(pt["u"])},a["mc"]),Hz=i["default"].extend({name:a["mc"],mixins:[Zr,ei,Cn],provide:function(){return{bvTableRowGroup:this}},inject:{bvTable:{default:function(){return{}}}},inheritAttrs:!1,props:Bz,computed:{isTfoot:function(){return!0},isDark:function(){return this.bvTable.dark},isStacked:function(){return this.bvTable.isStacked},isResponsive:function(){return this.bvTable.isResponsive},isStickyHeader:function(){return!1},hasStickyHeader:function(){return!this.isStacked&&this.bvTable.stickyHeader},tableVariant:function(){return this.bvTable.tableVariant},tfootClasses:function(){return[this.footVariant?"thead-".concat(this.footVariant):null]},tfootAttrs:function(){return Ez(Ez({},this.bvAttrs),{},{role:"rowgroup"})}},render:function(t){return t("tfoot",{class:this.tfootClasses,attrs:this.tfootAttrs,on:this.bvListeners},this.normalizeSlot())}}),Fz={footClone:Object(kn["c"])(pt["g"],!1),footRowVariant:Object(kn["c"])(pt["u"]),footVariant:Object(kn["c"])(pt["u"]),tfootClass:Object(kn["c"])(pt["e"]),tfootTrClass:Object(kn["c"])(pt["e"])},Dz=i["default"].extend({props:Fz,methods:{renderTFootCustom:function(){var t=this.$createElement;return this.hasNormalizedSlot(kt)?t(Hz,{class:this.tfootClass||null,props:{footVariant:this.footVariant||this.headVariant||null},key:"bv-tfoot-custom"},this.normalizeSlot(kt,{items:this.computedItems.slice(),fields:this.computedFields.slice(),columns:this.computedFields.length})):t()},renderTfoot:function(){return this.footClone?this.renderThead(!0):this.renderTFootCustom()}}});function Rz(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Nz(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Rz(Object(n),!0).forEach((function(e){$z(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Rz(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function $z(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var Uz=Object(kn["d"])({headVariant:Object(kn["c"])(pt["u"])},a["oc"]),qz=i["default"].extend({name:a["oc"],mixins:[Zr,ei,Cn],provide:function(){return{bvTableRowGroup:this}},inject:{bvTable:{default:function(){return{}}}},inheritAttrs:!1,props:Uz,computed:{isThead:function(){return!0},isDark:function(){return this.bvTable.dark},isStacked:function(){return this.bvTable.isStacked},isResponsive:function(){return this.bvTable.isResponsive},isStickyHeader:function(){return!this.isStacked&&this.bvTable.stickyHeader},hasStickyHeader:function(){return!this.isStacked&&this.bvTable.stickyHeader},tableVariant:function(){return this.bvTable.tableVariant},theadClasses:function(){return[this.headVariant?"thead-".concat(this.headVariant):null]},theadAttrs:function(){return Nz({role:"rowgroup"},this.bvAttrs)}},render:function(t){return t("thead",{class:this.theadClasses,attrs:this.theadAttrs,on:this.bvListeners},this.normalizeSlot())}});function Wz(t){return Qz(t)||Kz(t)||Yz(t)||Gz()}function Gz(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function Yz(t,e){if(t){if("string"===typeof t)return Xz(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Xz(t,e):void 0}}function Kz(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function Qz(t){if(Array.isArray(t))return Xz(t)}function Xz(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}function Jz(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Zz(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Jz(Object(n),!0).forEach((function(e){tA(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Jz(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function tA(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var eA=function(t){return"head(".concat(t||"",")")},nA=function(t){return"foot(".concat(t||"",")")},rA={headRowVariant:Object(kn["c"])(pt["u"]),headVariant:Object(kn["c"])(pt["u"]),theadClass:Object(kn["c"])(pt["e"]),theadTrClass:Object(kn["c"])(pt["e"])},iA=i["default"].extend({props:rA,methods:{fieldClasses:function(t){return[t.class?t.class:"",t.thClass?t.thClass:""]},headClicked:function(t,e,n){this.stopIfBusy&&this.stopIfBusy(t)||fz(t)||pz(this.$el)||(En(t),this.$emit(M,e.key,e,t,n))},renderThead:function(){var t=this,e=arguments.length>0&&void 0!==arguments[0]&&arguments[0],n=this.computedFields,r=this.isSortable,i=this.isSelectable,o=this.headVariant,a=this.footVariant,s=this.headRowVariant,c=this.footRowVariant,l=this.$createElement;if(this.isStackedAlways||0===n.length)return l();var u=r||this.hasListener(M),d=i?this.selectAllRows:Cs,h=i?this.clearSelected:Cs,f=function(n,i){var o=n.label,a=n.labelHtml,s=n.variant,c=n.stickyColumn,f=n.key,p=null;n.label.trim()||n.headerTitle||(p=Object(Ee["f"])(n.key));var m={};u&&(m.click=function(r){t.headClicked(r,n,e)},m.keydown=function(r){var i=r.keyCode;i!==Br&&i!==Ur||t.headClicked(r,n,e)});var b=r?t.sortTheadThAttrs(f,n,e):{},g=r?t.sortTheadThClasses(f,n,e):null,v=r?t.sortTheadThLabel(f,n,e):null,w={class:[t.fieldClasses(n),g],props:{variant:s,stickyColumn:c},style:n.thStyle||{},attrs:Zz(Zz({tabindex:u&&n.sortable?"0":null,abbr:n.headerAbbr||null,title:n.headerTitle||null,"aria-colindex":i+1,"aria-label":p},t.getThValues(null,f,n.thAttr,e?"foot":"head",{})),b),on:m,key:f},y=[eA(f),eA(f.toLowerCase()),eA()];e&&(y=[nA(f),nA(f.toLowerCase()),nA()].concat(Wz(y)));var k={label:o,column:f,field:n,isFoot:e,selectAllRows:d,clearSelected:h},_=t.normalizeSlot(y,k)||l("div",{domProps:Ji(a,o)}),O=v?l("span",{staticClass:"sr-only"}," (".concat(v,")")):null;return l(bz,w,[_,O].filter(An["a"]))},p=n.map(f).filter(An["a"]),m=[];if(e)m.push(l(I_,{class:this.tfootTrClass,props:{variant:Object(Me["p"])(c)?s:c}},p));else{var b={columns:n.length,fields:n,selectAllRows:d,clearSelected:h};m.push(this.normalizeSlot(ye,b)||l()),m.push(l(I_,{class:this.theadTrClass,props:{variant:s}},p))}return l(e?Hz:qz,{class:(e?this.tfootClass:this.theadClass)||null,props:e?{footVariant:a||o||null}:{headVariant:o||null},key:e?"bv-tfoot":"bv-thead"},m)}}}),oA={},aA=i["default"].extend({methods:{renderTopRow:function(){var t=this.computedFields,e=this.stacked,n=this.tbodyTrClass,r=this.tbodyTrAttr,i=this.$createElement;return this.hasNormalizedSlot(Oe)&&!0!==e&&""!==e?i(I_,{staticClass:"b-table-top-row",class:[Object(Me["f"])(n)?n(null,"row-top"):n],attrs:Object(Me["f"])(r)?r(null,"row-top"):r,key:"b-top-row"},[this.normalizeSlot(Oe,{columns:t.length,fields:t})]):i()}}});function sA(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function cA(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?sA(Object(n),!0).forEach((function(e){lA(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):sA(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function lA(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var uA=Object(kn["d"])(Object(zn["m"])(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA(cA({},ia),E_),G_),K_),X_),Z_),wO),xO),PO),BO),$O),oz),a_),d_),Tz),Fz),rA),oA)),a["fc"]),dA=i["default"].extend({name:a["fc"],mixins:[Zr,i_,oa,Cn,TO,h_,s_,iA,Dz,Pz,s_,yO,az,IO,Q_,J_,UO,tO,aA,L_,Y_,HO],props:uA});function hA(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function fA(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?hA(Object(n),!0).forEach((function(e){pA(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):hA(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function pA(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var mA,bA=Object(kn["d"])(Object(zn["m"])(fA(fA(fA(fA(fA(fA(fA(fA(fA({},ia),K_),X_),xO),a_),d_),Tz),Fz),rA)),a["hc"]),gA=i["default"].extend({name:a["hc"],mixins:[Zr,i_,oa,Cn,TO,h_,s_,iA,Dz,Pz,Q_,J_],props:bA}),vA=Object(r["b"])({components:{BTableLite:gA}}),wA=Object(r["b"])({components:{BTableSimple:g_,BTbody:dz,BThead:qz,BTfoot:Hz,BTr:I_,BTd:$_,BTh:bz}}),yA=Object(r["b"])({components:{BTable:dA},plugins:{TableLitePlugin:vA,TableSimplePlugin:wA}});function kA(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function _A(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?kA(Object(n),!0).forEach((function(e){OA(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):kA(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function OA(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var zA,AA,jA=On("value",{type:pt["n"]}),MA=jA.mixin,CA=jA.props,VA=jA.prop,SA=jA.event,xA=function(t){return!t.disabled},TA=i["default"].extend({name:a["kc"],inject:{bvTabs:{default:function(){return{}}}},props:{controls:Object(kn["c"])(pt["u"]),id:Object(kn["c"])(pt["u"]),noKeyNav:Object(kn["c"])(pt["g"],!1),posInSet:Object(kn["c"])(pt["n"]),setSize:Object(kn["c"])(pt["n"]),tab:Object(kn["c"])(),tabIndex:Object(kn["c"])(pt["n"])},methods:{focus:function(){wn(this.$refs.link)},handleEvt:function(t){if(!this.tab.disabled){var e=t.type,n=t.keyCode,r=t.shiftKey;"click"===e||"keydown"===e&&n===Ur?(En(t),this.$emit(h,t)):"keydown"!==e||this.noKeyNav||(-1!==[qr,Dr,Fr].indexOf(n)?(En(t),r||n===Fr?this.$emit(z,t):this.$emit(D,t)):-1!==[Er,$r,Lr].indexOf(n)&&(En(t),r||n===Lr?this.$emit(T,t):this.$emit(E,t)))}}},render:function(t){var e=this.id,n=this.tabIndex,r=this.setSize,i=this.posInSet,o=this.controls,a=this.handleEvt,s=this.tab,c=s.title,l=s.localActive,u=s.disabled,d=s.titleItemClass,h=s.titleLinkClass,f=s.titleLinkAttributes,p=t(mi,{staticClass:"nav-link",class:[{active:l&&!u,disabled:u},h,l?this.bvTabs.activeNavItemClass:null],props:{disabled:u},attrs:_A(_A({},f),{},{id:e,role:"tab",tabindex:n,"aria-selected":l&&!u?"true":"false","aria-setsize":r,"aria-posinset":i,"aria-controls":o}),on:{click:a,keydown:a},ref:"link"},[this.tab.normalizeSlot(ke)||c]);return t("li",{staticClass:"nav-item",class:[d],attrs:{role:"presentation"}},[p])}}),PA=Object(zn["j"])(Ov,["tabs","isNavBar","cardHeader"]),IA=Object(kn["d"])(Object(zn["m"])(_A(_A(_A(_A({},ia),CA),PA),{},{activeNavItemClass:Object(kn["c"])(pt["e"]),activeTabClass:Object(kn["c"])(pt["e"]),card:Object(kn["c"])(pt["g"],!1),contentClass:Object(kn["c"])(pt["e"]),end:Object(kn["c"])(pt["g"],!1),lazy:Object(kn["c"])(pt["g"],!1),navClass:Object(kn["c"])(pt["e"]),navWrapperClass:Object(kn["c"])(pt["e"]),noFade:Object(kn["c"])(pt["g"],!1),noKeyNav:Object(kn["c"])(pt["g"],!1),noNavStyle:Object(kn["c"])(pt["g"],!1),tag:Object(kn["c"])(pt["u"],"div")})),a["jc"]),EA=i["default"].extend({name:a["jc"],mixins:[oa,MA,Cn],provide:function(){return{bvTabs:this}},props:IA,data:function(){return{currentTab:Object(Ie["c"])(this[VA],-1),tabs:[],registeredTabs:[]}},computed:{fade:function(){return!this.noFade},localNavClass:function(){var t=[];return this.card&&this.vertical&&t.push("card-header","h-100","border-bottom-0","rounded-0"),[].concat(t,[this.navClass])}},watch:(mA={},OA(mA,VA,(function(t,e){if(t!==e){t=Object(Ie["c"])(t,-1),e=Object(Ie["c"])(e,0);var n=this.tabs[t];n&&!n.disabled?this.activateTab(n):t<e?this.previousTab():this.nextTab()}})),OA(mA,"currentTab",(function(t){var e=-1;this.tabs.forEach((function(n,r){r!==t||n.disabled?n.localActive=!1:(n.localActive=!0,e=r)})),this.$emit(SA,e)})),OA(mA,"tabs",(function(t,e){var n=this;Yr(t.map((function(t){return t[o["a"]]})),e.map((function(t){return t[o["a"]]})))||this.$nextTick((function(){n.$emit(d,t.slice(),e.slice())}))})),OA(mA,"registeredTabs",(function(){this.updateTabs()})),mA),created:function(){this.$_observer=null},mounted:function(){this.setObserver(!0)},beforeDestroy:function(){this.setObserver(!1),this.tabs=[]},methods:{registerTab:function(t){Ve(this.registeredTabs,t)||this.registeredTabs.push(t)},unregisterTab:function(t){this.registeredTabs=this.registeredTabs.slice().filter((function(e){return e!==t}))},setObserver:function(){var t=this,e=!(arguments.length>0&&void 0!==arguments[0])||arguments[0];if(this.$_observer&&this.$_observer.disconnect(),this.$_observer=null,e){var n=function(){t.$nextTick((function(){De((function(){t.updateTabs()}))}))};this.$_observer=Is(this.$refs.content,n,{childList:!0,subtree:!1,attributes:!0,attributeFilter:["id"]})}},getTabs:function(){var t=this.registeredTabs.filter((function(t){return 0===t.$children.filter((function(t){return t._isTab})).length})),e=[];if(Ae["i"]&&t.length>0){var n=t.map((function(t){return"#".concat(t.safeId())})).join(", ");e=Qe(n,this.$el).map((function(t){return t.id})).filter(An["a"])}return qO(t,(function(t,n){return e.indexOf(t.safeId())-e.indexOf(n.safeId())}))},updateTabs:function(){var t=this.getTabs(),e=t.indexOf(t.slice().reverse().find((function(t){return t.localActive&&!t.disabled})));if(e<0){var n=this.currentTab;n>=t.length?e=t.indexOf(t.slice().reverse().find(xA)):t[n]&&!t[n].disabled&&(e=n)}e<0&&(e=t.indexOf(t.find(xA))),t.forEach((function(t,n){t.localActive=n===e})),this.tabs=t,this.currentTab=e},getButtonForTab:function(t){return(this.$refs.buttons||[]).find((function(e){return e.tab===t}))},updateButton:function(t){var e=this.getButtonForTab(t);e&&e.$forceUpdate&&e.$forceUpdate()},activateTab:function(t){var e=this.currentTab,n=this.tabs,r=!1;if(t){var i=n.indexOf(t);if(i!==e&&i>-1&&!t.disabled){var o=new gl(s,{cancelable:!0,vueTarget:this,componentId:this.safeId()});this.$emit(o.type,i,e,o),o.defaultPrevented||(this.currentTab=i,r=!0)}}return r||this[VA]===e||this.$emit(SA,e),r},deactivateTab:function(t){return!!t&&this.activateTab(this.tabs.filter((function(e){return e!==t})).find(xA))},focusButton:function(t){var e=this;this.$nextTick((function(){wn(e.getButtonForTab(t))}))},emitTabClick:function(t,e){Object(Me["d"])(e)&&t&&t.$emit&&!t.disabled&&t.$emit(h,e)},clickTab:function(t,e){this.activateTab(t),this.emitTabClick(t,e)},firstTab:function(t){var e=this.tabs.find(xA);this.activateTab(e)&&t&&(this.focusButton(e),this.emitTabClick(e,t))},previousTab:function(t){var e=Object(lr["d"])(this.currentTab,0),n=this.tabs.slice(0,e).reverse().find(xA);this.activateTab(n)&&t&&(this.focusButton(n),this.emitTabClick(n,t))},nextTab:function(t){var e=Object(lr["d"])(this.currentTab,-1),n=this.tabs.slice(e+1).find(xA);this.activateTab(n)&&t&&(this.focusButton(n),this.emitTabClick(n,t))},lastTab:function(t){var e=this.tabs.slice().reverse().find(xA);this.activateTab(e)&&t&&(this.focusButton(e),this.emitTabClick(e,t))}},render:function(t){var e=this,n=this.align,r=this.card,i=this.end,a=this.fill,s=this.firstTab,c=this.justified,l=this.lastTab,u=this.nextTab,d=this.noKeyNav,f=this.noNavStyle,p=this.pills,m=this.previousTab,b=this.small,g=this.tabs,v=this.vertical,w=g.find((function(t){return t.localActive&&!t.disabled})),y=g.find((function(t){return!t.disabled})),k=g.map((function(n,r){var i,a=n.safeId,c=null;return d||(c=-1,(n===w||!w&&n===y)&&(c=null)),t(TA,{props:{controls:a?a():null,id:n.controlledBy||(a?a("_BV_tab_button_"):null),noKeyNav:d,posInSet:r+1,setSize:g.length,tab:n,tabIndex:c},on:(i={},OA(i,h,(function(t){e.clickTab(n,t)})),OA(i,z,s),OA(i,D,m),OA(i,E,u),OA(i,T,l),i),key:n[o["a"]]||r,ref:"buttons",refInFor:!0})})),_=t(zv,{class:this.localNavClass,attrs:{role:"tablist",id:this.safeId("_BV_tab_controls_")},props:{fill:a,justified:c,align:n,tabs:!f&&!p,pills:!f&&p,vertical:v,small:b,cardHeader:r&&!v},ref:"nav"},[this.normalizeSlot(ve)||t(),k,this.normalizeSlot(ge)||t()]);_=t("div",{class:[{"card-header":r&&!v&&!i,"card-footer":r&&!v&&i,"col-auto":v},this.navWrapperClass],key:"bv-tabs-nav"},[_]);var O=this.normalizeSlot()||[],A=t();0===O.length&&(A=t("div",{class:["tab-pane","active",{"card-body":r}],key:"bv-empty-tab"},this.normalizeSlot(Ct)));var j=t("div",{staticClass:"tab-content",class:[{col:v},this.contentClass],attrs:{id:this.safeId("_BV_tab_container_")},key:"bv-content",ref:"content"},[O,A]);return t(this.tag,{staticClass:"tabs",class:{row:v,"no-gutters":v&&r},attrs:{id:this.safeId()}},[i?j:t(),_,i?t():j])}});function LA(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function BA(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?LA(Object(n),!0).forEach((function(e){HA(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):LA(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function HA(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var FA,DA="active",RA=lt+DA,NA=Object(kn["d"])(Object(zn["m"])(BA(BA({},ia),{},(zA={},HA(zA,DA,Object(kn["c"])(pt["g"],!1)),HA(zA,"buttonId",Object(kn["c"])(pt["u"])),HA(zA,"disabled",Object(kn["c"])(pt["g"],!1)),HA(zA,"lazy",Object(kn["c"])(pt["g"],!1)),HA(zA,"noBody",Object(kn["c"])(pt["g"],!1)),HA(zA,"tag",Object(kn["c"])(pt["u"],"div")),HA(zA,"title",Object(kn["c"])(pt["u"])),HA(zA,"titleItemClass",Object(kn["c"])(pt["e"])),HA(zA,"titleLinkAttributes",Object(kn["c"])(pt["q"])),HA(zA,"titleLinkClass",Object(kn["c"])(pt["e"])),zA))),a["ec"]),$A=i["default"].extend({name:a["ec"],mixins:[oa,Cn],inject:{bvTabs:{default:function(){return{}}}},props:NA,data:function(){return{localActive:this[DA]&&!this.disabled}},computed:{_isTab:function(){return!0},tabClasses:function(){var t=this.localActive,e=this.disabled;return[{active:t,disabled:e,"card-body":this.bvTabs.card&&!this.noBody},t?this.bvTabs.activeTabClass:null]},controlledBy:function(){return this.buttonId||this.safeId("__BV_tab_button__")},computedNoFade:function(){return!this.bvTabs.fade},computedLazy:function(){return this.bvTabs.lazy||this.lazy}},watch:(AA={},HA(AA,DA,(function(t,e){t!==e&&(t?this.activate():this.deactivate()||this.$emit(RA,this.localActive))})),HA(AA,"disabled",(function(t,e){if(t!==e){var n=this.bvTabs.firstTab;t&&this.localActive&&n&&(this.localActive=!1,n())}})),HA(AA,"localActive",(function(t){this.$emit(RA,t)})),AA),mounted:function(){this.registerTab()},updated:function(){var t=this.bvTabs.updateButton;t&&this.hasNormalizedSlot(ke)&&t(this)},beforeDestroy:function(){this.unregisterTab()},methods:{registerTab:function(){var t=this.bvTabs.registerTab;t&&t(this)},unregisterTab:function(){var t=this.bvTabs.unregisterTab;t&&t(this)},activate:function(){var t=this.bvTabs.activateTab;return!(!t||this.disabled)&&t(this)},deactivate:function(){var t=this.bvTabs.deactivateTab;return!(!t||!this.localActive)&&t(this)}},render:function(t){var e=this.localActive,n=t(this.tag,{staticClass:"tab-pane",class:this.tabClasses,directives:[{name:"show",value:e}],attrs:{role:"tabpanel",id:this.safeId(),"aria-hidden":e?"false":"true","aria-labelledby":this.controlledBy||null},ref:"panel"},[e||!this.computedLazy?this.normalizeSlot():t()]);return t(Kn,{props:{mode:"out-in",noFade:this.computedNoFade}},[n])}}),UA=Object(r["b"])({components:{BTabs:EA,BTab:$A}}),qA=Object(r["b"])({components:{BTime:Sm}}),WA=n("2b88"),GA=i["default"].extend({mixins:[Cn],data:function(){return{name:"b-toaster"}},methods:{onAfterEnter:function(t){var e=this;De((function(){rn(t,"".concat(e.name,"-enter-to"))}))}},render:function(t){return t("transition-group",{props:{tag:"div",name:this.name},on:{afterEnter:this.onAfterEnter}},this.normalizeSlot())}}),YA=Object(kn["d"])({ariaAtomic:Object(kn["c"])(pt["u"]),ariaLive:Object(kn["c"])(pt["u"]),name:Object(kn["c"])(pt["u"],void 0,!0),role:Object(kn["c"])(pt["u"])},a["rc"]),KA=i["default"].extend({name:a["rc"],mixins:[ti],props:YA,data:function(){return{doRender:!1,dead:!1,staticName:this.name}},beforeMount:function(){var t=this,e=this.name;this.staticName=e,WA["Wormhole"].hasTarget(e)?(Object(Vs["a"])('A "<portal-target>" with name "'.concat(e,'" already exists in the document.'),a["rc"]),this.dead=!0):(this.doRender=!0,this.$once(st,(function(){t.emitOnRoot(Bn(a["rc"],b),e)})))},destroyed:function(){var t=this.$el;t&&t.parentNode&&t.parentNode.removeChild(t)},render:function(t){var e=t("div",{class:["d-none",{"b-dead-toaster":this.dead}]});if(this.doRender){var n=t(WA["PortalTarget"],{staticClass:"b-toaster-slot",props:{name:this.staticName,multiple:!0,tag:"div",slim:!1,transition:GA}});e=t("div",{staticClass:"b-toaster",class:[this.staticName],attrs:{id:this.staticName,role:this.role||null,"aria-live":this.ariaLive,"aria-atomic":this.ariaAtomic}},[n])}return e}});function QA(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function XA(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?QA(Object(n),!0).forEach((function(e){JA(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):QA(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function JA(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var ZA=On("visible",{type:pt["g"],defaultValue:!1,event:u}),tj=ZA.mixin,ej=ZA.props,nj=ZA.prop,rj=ZA.event,ij=1e3,oj=Object(zn["k"])(pi,["href","to"]),aj=Object(kn["d"])(Object(zn["m"])(XA(XA(XA(XA({},ia),ej),oj),{},{appendToast:Object(kn["c"])(pt["g"],!1),autoHideDelay:Object(kn["c"])(pt["p"],5e3),bodyClass:Object(kn["c"])(pt["e"]),headerClass:Object(kn["c"])(pt["e"]),isStatus:Object(kn["c"])(pt["g"],!1),noAutoHide:Object(kn["c"])(pt["g"],!1),noCloseButton:Object(kn["c"])(pt["g"],!1),noFade:Object(kn["c"])(pt["g"],!1),noHoverPause:Object(kn["c"])(pt["g"],!1),solid:Object(kn["c"])(pt["g"],!1),static:Object(kn["c"])(pt["g"],!1),title:Object(kn["c"])(pt["u"]),toastClass:Object(kn["c"])(pt["e"]),toaster:Object(kn["c"])(pt["u"],"b-toaster-top-right"),variant:Object(kn["c"])(pt["u"])})),a["qc"]),sj=i["default"].extend({name:a["qc"],mixins:[Zr,oa,tj,ti,Cn,Jb],inheritAttrs:!1,props:aj,data:function(){return{isMounted:!1,doRender:!1,localShow:!1,isTransitioning:!1,isHiding:!1,order:0,dismissStarted:0,resumeDismiss:0}},computed:{toastClasses:function(){var t=this.appendToast,e=this.variant;return JA({"b-toast-solid":this.solid,"b-toast-append":t,"b-toast-prepend":!t},"b-toast-".concat(e),e)},slotScope:function(){var t=this.hide;return{hide:t}},computedDuration:function(){return Object(lr["d"])(Object(Ie["c"])(this.autoHideDelay,0),ij)},computedToaster:function(){return String(this.toaster)},transitionHandlers:function(){return{beforeEnter:this.onBeforeEnter,afterEnter:this.onAfterEnter,beforeLeave:this.onBeforeLeave,afterLeave:this.onAfterLeave}},computedAttrs:function(){return XA(XA({},this.bvAttrs),{},{id:this.safeId(),tabindex:"0"})}},watch:(FA={},JA(FA,nj,(function(t){this[t?"show":"hide"]()})),JA(FA,"localShow",(function(t){t!==this[nj]&&this.$emit(rj,t)})),JA(FA,"toaster",(function(){this.$nextTick(this.ensureToaster)})),JA(FA,"static",(function(t){t&&this.localShow&&this.ensureToaster()})),FA),created:function(){this.$_dismissTimer=null},mounted:function(){var t=this;this.isMounted=!0,this.$nextTick((function(){t[nj]&&De((function(){t.show()}))})),this.listenOnRoot(Hn(a["qc"],J),(function(e){e===t.safeId()&&t.show()})),this.listenOnRoot(Hn(a["qc"],V),(function(e){e&&e!==t.safeId()||t.hide()})),this.listenOnRoot(Bn(a["rc"],b),(function(e){e===t.computedToaster&&t.hide()}))},beforeDestroy:function(){this.clearDismissTimer()},methods:{show:function(){var t=this;if(!this.localShow){this.ensureToaster();var e=this.buildEvent(J);this.emitEvent(e),this.dismissStarted=this.resumeDismiss=0,this.order=Date.now()*(this.appendToast?1:-1),this.isHiding=!1,this.doRender=!0,this.$nextTick((function(){De((function(){t.localShow=!0}))}))}},hide:function(){var t=this;if(this.localShow){var e=this.buildEvent(V);this.emitEvent(e),this.setHoverHandler(!1),this.dismissStarted=this.resumeDismiss=0,this.clearDismissTimer(),this.isHiding=!0,De((function(){t.localShow=!1}))}},buildEvent:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return new gl(t,XA(XA({cancelable:!1,target:this.$el||null,relatedTarget:null},e),{},{vueTarget:this,componentId:this.safeId()}))},emitEvent:function(t){var e=t.type;this.emitOnRoot(Bn(a["qc"],e),t),this.$emit(e,t)},ensureToaster:function(){if(!this.static){var t=this.computedToaster;if(!WA["Wormhole"].hasTarget(t)){var e=document.createElement("div");document.body.appendChild(e);var n=new KA({parent:this.$root,propsData:{name:t}});n.$mount(e)}}},startDismissTimer:function(){this.clearDismissTimer(),this.noAutoHide||(this.$_dismissTimer=setTimeout(this.hide,this.resumeDismiss||this.computedDuration),this.dismissStarted=Date.now(),this.resumeDismiss=0)},clearDismissTimer:function(){clearTimeout(this.$_dismissTimer),this.$_dismissTimer=null},setHoverHandler:function(t){var e=this.$refs["b-toast"];In(t,e,"mouseenter",this.onPause,ft),In(t,e,"mouseleave",this.onUnPause,ft)},onPause:function(){if(!this.noAutoHide&&!this.noHoverPause&&this.$_dismissTimer&&!this.resumeDismiss){var t=Date.now()-this.dismissStarted;t>0&&(this.clearDismissTimer(),this.resumeDismiss=Object(lr["d"])(this.computedDuration-t,ij))}},onUnPause:function(){this.noAutoHide||this.noHoverPause||!this.resumeDismiss?this.resumeDismiss=this.dismissStarted=0:this.startDismissTimer()},onLinkClick:function(){var t=this;this.$nextTick((function(){De((function(){t.hide()}))}))},onBeforeEnter:function(){this.isTransitioning=!0},onAfterEnter:function(){this.isTransitioning=!1;var t=this.buildEvent(Z);this.emitEvent(t),this.startDismissTimer(),this.setHoverHandler(!0)},onBeforeLeave:function(){this.isTransitioning=!0},onAfterLeave:function(){this.isTransitioning=!1,this.order=0,this.resumeDismiss=this.dismissStarted=0;var t=this.buildEvent(C);this.emitEvent(t),this.doRender=!1},makeToast:function(t){var e=this,n=this.title,r=this.slotScope,i=jr(this),a=[],s=this.normalizeSlot(_e,r);s?a.push(s):n&&a.push(t("strong",{staticClass:"mr-2"},n)),this.noCloseButton||a.push(t(Rn,{staticClass:"ml-auto mb-1",on:{click:function(){e.hide()}}}));var c=t();a.length>0&&(c=t("header",{staticClass:"toast-header",class:this.headerClass},a));var l=t(i?mi:"div",{staticClass:"toast-body",class:this.bodyClass,props:i?Object(kn["e"])(oj,this):{},on:i?{click:this.onLinkClick}:{}},this.normalizeSlot(Ot,r));return t("div",{staticClass:"toast",class:this.toastClass,attrs:this.computedAttrs,key:"toast-".concat(this[o["a"]]),ref:"toast"},[c,l])}},render:function(t){if(!this.doRender||!this.isMounted)return t();var e=this.order,n=this.static,r=this.isHiding,i=this.isStatus,a="b-toast-".concat(this[o["a"]]),s=t("div",{staticClass:"b-toast",class:this.toastClasses,attrs:XA(XA({},n?{}:this.scopedStyleAttrs),{},{id:this.safeId("_toast_outer"),role:r?null:i?"status":"alert","aria-live":r?null:i?"polite":"assertive","aria-atomic":r?null:"true"}),key:a,ref:"b-toast"},[t(Kn,{props:{noFade:this.noFade},on:this.transitionHandlers},[this.localShow?this.makeToast(t):t()])]);return t(WA["Portal"],{props:{name:a,to:this.computedToaster,order:e,slim:!0,disabled:n}},[s])}});function cj(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function lj(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function uj(t,e,n){return e&&lj(t.prototype,e),n&&lj(t,n),t}function dj(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function hj(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?dj(Object(n),!0).forEach((function(e){fj(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):dj(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function fj(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function pj(t){return vj(t)||gj(t)||bj(t)||mj()}function mj(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function bj(t,e){if(t){if("string"===typeof t)return wj(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?wj(t,e):void 0}}function gj(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function vj(t){if(Array.isArray(t))return wj(t)}function wj(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}var yj="$bvToast",kj="_bv__toast",_j=["id"].concat(pj(Object(zn["h"])(Object(zn["j"])(aj,["static","visible"])))),Oj={toastContent:"default",title:"toast-title"},zj=function(t){return _j.reduce((function(e,n){return Object(Me["o"])(t[n])||(e[n]=t[n]),e}),{})},Aj=function(t){var e=t.extend({name:a["sc"],extends:sj,destroyed:function(){var t=this.$el;t&&t.parentNode&&t.parentNode.removeChild(t)},mounted:function(){var t=this,e=function(){t.localShow=!1,t.doRender=!1,t.$nextTick((function(){t.$nextTick((function(){De((function(){t.$destroy()}))}))}))};this.$parent.$once(ct,e),this.$once(C,e),this.listenOnRoot(Bn(a["rc"],b),(function(n){n===t.toaster&&e()}))}}),n=function(t,n){if(!Object(Vs["d"])(yj)){var r=new e({parent:n,propsData:hj(hj(hj({},zj(Object(xh["c"])(a["qc"]))),Object(zn["j"])(t,Object(zn["h"])(Oj))),{},{static:!1,visible:!0})});Object(zn["h"])(Oj).forEach((function(e){var i=t[e];Object(Me["o"])(i)||("title"===e&&Object(Me["n"])(i)&&(i=[n.$createElement("strong",{class:"mr-2"},i)]),r.$slots[Oj[e]]=Se(i))}));var i=document.createElement("div");document.body.appendChild(i),r.$mount(i)}},r=function(){function t(e){cj(this,t),Object(zn["a"])(this,{_vm:e,_root:e.$root}),Object(zn["d"])(this,{_vm:Object(zn["l"])(),_root:Object(zn["l"])()})}return uj(t,[{key:"toast",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};t&&!Object(Vs["d"])(yj)&&n(hj(hj({},zj(e)),{},{toastContent:t}),this._vm)}},{key:"show",value:function(t){t&&this._root.$emit(Hn(a["qc"],J),t)}},{key:"hide",value:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:null;this._root.$emit(Hn(a["qc"],V),t)}}]),t}();t.mixin({beforeCreate:function(){this[kj]=new r(this)}}),Object(zn["g"])(t.prototype,yj)||Object(zn["e"])(t.prototype,yj,{get:function(){return this&&this[kj]||Object(Vs["a"])('"'.concat(yj,'" must be accessed from a Vue instance "this" context.'),a["qc"]),this[kj]}})},jj=Object(r["b"])({plugins:{plugin:Aj}}),Mj=Object(r["b"])({components:{BToast:sj,BToaster:KA},plugins:{BVToastPlugin:jj}});function Cj(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function Vj(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?Cj(Object(n),!0).forEach((function(e){Sj(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):Cj(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function Sj(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var xj="__BV_Tooltip__",Tj="hover focus",Pj={focus:!0,hover:!0,click:!0,blur:!0,manual:!0},Ij=/^html$/i,Ej=/^noninteractive$/i,Lj=/^nofade$/i,Bj=/^(auto|top(left|right)?|bottom(left|right)?|left(top|bottom)?|right(top|bottom)?)$/i,Hj=/^(window|viewport|scrollParent)$/i,Fj=/^d\d+$/i,Dj=/^ds\d+$/i,Rj=/^dh\d+$/i,Nj=/^o-?\d+$/i,$j=/^v-.+$/i,Uj=/\s+/,qj=function(t,e){var n={title:void 0,trigger:"",placement:"top",fallbackPlacement:"flip",container:!1,animation:!0,offset:0,id:null,html:!1,interactive:!0,disabled:!1,delay:Object(xh["c"])(a["tc"],"delay",50),boundary:String(Object(xh["c"])(a["tc"],"boundary","scrollParent")),boundaryPadding:Object(Ie["c"])(Object(xh["c"])(a["tc"],"boundaryPadding",5),0),variant:Object(xh["c"])(a["tc"],"variant"),customClass:Object(xh["c"])(a["tc"],"customClass")};if(Object(Me["n"])(t.value)||Object(Me["h"])(t.value)||Object(Me["f"])(t.value)?n.title=t.value:Object(Me["k"])(t.value)&&(n=Vj(Vj({},n),t.value)),Object(Me["o"])(n.title)){var r=e.data||{};n.title=r.attrs&&!Object(Me["p"])(r.attrs.title)?r.attrs.title:void 0}Object(Me["k"])(n.delay)||(n.delay={show:Object(Ie["c"])(n.delay,0),hide:Object(Ie["c"])(n.delay,0)}),t.arg&&(n.container="#".concat(t.arg)),Object(zn["h"])(t.modifiers).forEach((function(t){if(Ij.test(t))n.html=!0;else if(Ej.test(t))n.interactive=!1;else if(Lj.test(t))n.animation=!1;else if(Bj.test(t))n.placement=t;else if(Hj.test(t))t="scrollparent"===t?"scrollParent":t,n.boundary=t;else if(Fj.test(t)){var e=Object(Ie["c"])(t.slice(1),0);n.delay.show=e,n.delay.hide=e}else Dj.test(t)?n.delay.show=Object(Ie["c"])(t.slice(2),0):Rj.test(t)?n.delay.hide=Object(Ie["c"])(t.slice(2),0):Nj.test(t)?n.offset=Object(Ie["c"])(t.slice(1),0):$j.test(t)&&(n.variant=t.slice(2)||null)}));var i={};return Se(n.trigger||"").filter(An["a"]).join(" ").trim().toLowerCase().split(Uj).forEach((function(t){Pj[t]&&(i[t]=!0)})),Object(zn["h"])(t.modifiers).forEach((function(t){t=t.toLowerCase(),Pj[t]&&(i[t]=!0)})),n.trigger=Object(zn["h"])(i).join(" "),"blur"===n.trigger&&(n.trigger="focus"),n.trigger||(n.trigger=Tj),n},Wj=function(t,e,n){if(Ae["i"]){var r=qj(e,n);if(!t[xj]){var i=n.context;t[xj]=new Vy({parent:i,_scopeId:Qb(i,void 0)}),t[xj].__bv_prev_data__={},t[xj].$on(J,(function(){Object(Me["f"])(r.title)&&t[xj].updateData({title:r.title(t)})}))}var o={title:r.title,triggers:r.trigger,placement:r.placement,fallbackPlacement:r.fallbackPlacement,variant:r.variant,customClass:r.customClass,container:r.container,boundary:r.boundary,delay:r.delay,offset:r.offset,noFade:!r.animation,id:r.id,interactive:r.interactive,disabled:r.disabled,html:r.html},a=t[xj].__bv_prev_data__;if(t[xj].__bv_prev_data__=o,!Yr(o,a)){var s={target:t};Object(zn["h"])(o).forEach((function(e){o[e]!==a[e]&&(s[e]="title"===e&&Object(Me["f"])(o[e])?o[e](t):o[e])})),t[xj].updateData(s)}}},Gj=function(t){t[xj]&&(t[xj].$destroy(),t[xj]=null),delete t[xj]},Yj={bind:function(t,e,n){Wj(t,e,n)},componentUpdated:function(t,e,n){n.context.$nextTick((function(){Wj(t,e,n)}))},unbind:function(t){Gj(t)}},Kj=Object(r["b"])({directives:{VBTooltip:Yj}}),Qj=Object(r["b"])({components:{BTooltip:Hy},plugins:{VBTooltipPlugin:Kj}}),Xj=Object(r["b"])({plugins:{AlertPlugin:cr,AspectPlugin:wr,AvatarPlugin:$i,BadgePlugin:Qi,BreadcrumbPlugin:ho,ButtonPlugin:fo,ButtonGroupPlugin:wo,ButtonToolbarPlugin:Oo,CalendarPlugin:ba,CardPlugin:Ms,CarouselPlugin:oc,CollapsePlugin:al,DropdownPlugin:gu,EmbedPlugin:_u,FormPlugin:$u,FormCheckboxPlugin:Rd,FormDatepickerPlugin:ph,FormFilePlugin:Sh,FormGroupPlugin:Jh,FormInputPlugin:wf,FormRadioPlugin:_f,FormRatingPlugin:Hf,FormSelectPlugin:cp,FormSpinbuttonPlugin:Mp,FormTagsPlugin:nm,FormTextareaPlugin:lm,FormTimepickerPlugin:$m,ImagePlugin:Um,InputGroupPlugin:cb,JumbotronPlugin:mb,LayoutPlugin:Ab,LinkPlugin:jb,ListGroupPlugin:Bb,MediaPlugin:qb,ModalPlugin:yv,NavPlugin:Qv,NavbarPlugin:mw,OverlayPlugin:jw,PaginationPlugin:Jw,PaginationNavPlugin:ay,PopoverPlugin:fk,ProgressPlugin:Ok,SidebarPlugin:Wk,SkeletonPlugin:j_,SpinnerPlugin:M_,TablePlugin:yA,TabsPlugin:UA,TimePlugin:qA,ToastPlugin:Mj,TooltipPlugin:Qj}}),Jj=Object(r["b"])({directives:{VBHover:Yd}}),Zj=Object(r["b"])({directives:{VBModal:Zg}});function tM(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function eM(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?tM(Object(n),!0).forEach((function(e){nM(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):tM(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function nM(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function rM(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function iM(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function oM(t,e,n){return e&&iM(t.prototype,e),n&&iM(t,n),t}var aM="v-b-scrollspy",sM="dropdown-item",cM="active",lM=".nav, .list-group",uM=".nav-link",dM=".nav-item",hM=".list-group-item",fM=".dropdown, .dropup",pM=".dropdown-item",mM=".dropdown-toggle",bM=Bn("BVScrollspy","activate"),gM="offset",vM="position",wM={element:"body",offset:10,method:"auto",throttle:75},yM={element:"(string|element|component)",offset:"number",method:"string",throttle:"number"},kM=["webkitTransitionEnd","transitionend","otransitionend","oTransitionEnd"],_M=function(t){return Object(zn["n"])(t).match(/\s([a-zA-Z]+)/)[1].toLowerCase()},OM=function(t,e,n){for(var r in n)if(Object(zn["g"])(n,r)){var i=n[r],o=e[r],a=o&&$e(o)?"element":_M(o);a=o&&o._isVue?"component":a,new RegExp(i).test(a)||Object(Vs["a"])("".concat(t,': Option "').concat(r,'" provided type "').concat(a,'" but expected type "').concat(i,'"'))}},zM=function(){function t(e,n,r){rM(this,t),this.$el=e,this.$scroller=null,this.$selector=[uM,hM,pM].join(","),this.$offsets=[],this.$targets=[],this.$activeTarget=null,this.$scrollHeight=0,this.$resizeTimeout=null,this.$scrollerObserver=null,this.$targetsObserver=null,this.$root=r||null,this.$config=null,this.updateConfig(n)}return oM(t,[{key:"updateConfig",value:function(t,e){this.$scroller&&(this.unlisten(),this.$scroller=null);var n=eM(eM({},this.constructor.Default),t);if(e&&(this.$root=e),OM(this.constructor.Name,n,this.constructor.DefaultType),this.$config=n,this.$root){var r=this;this.$root.$nextTick((function(){r.listen()}))}else this.listen()}},{key:"dispose",value:function(){this.unlisten(),clearTimeout(this.$resizeTimeout),this.$resizeTimeout=null,this.$el=null,this.$config=null,this.$scroller=null,this.$selector=null,this.$offsets=null,this.$targets=null,this.$activeTarget=null,this.$scrollHeight=null}},{key:"listen",value:function(){var t=this,e=this.getScroller();e&&"BODY"!==e.tagName&&Tn(e,"scroll",this,ft),Tn(window,"scroll",this,ft),Tn(window,"resize",this,ft),Tn(window,"orientationchange",this,ft),kM.forEach((function(e){Tn(window,e,t,ft)})),this.setObservers(!0),this.handleEvent("refresh")}},{key:"unlisten",value:function(){var t=this,e=this.getScroller();this.setObservers(!1),e&&"BODY"!==e.tagName&&Pn(e,"scroll",this,ft),Pn(window,"scroll",this,ft),Pn(window,"resize",this,ft),Pn(window,"orientationchange",this,ft),kM.forEach((function(e){Pn(window,e,t,ft)}))}},{key:"setObservers",value:function(t){var e=this;this.$scrollerObserver&&this.$scrollerObserver.disconnect(),this.$targetsObserver&&this.$targetsObserver.disconnect(),this.$scrollerObserver=null,this.$targetsObserver=null,t&&(this.$targetsObserver=Is(this.$el,(function(){e.handleEvent("mutation")}),{subtree:!0,childList:!0,attributes:!0,attributeFilter:["href"]}),this.$scrollerObserver=Is(this.getScroller(),(function(){e.handleEvent("mutation")}),{subtree:!0,childList:!0,characterData:!0,attributes:!0,attributeFilter:["id","style","class"]}))}},{key:"handleEvent",value:function(t){var e=Object(Me["n"])(t)?t:t.type,n=this,r=function(){n.$resizeTimeout||(n.$resizeTimeout=setTimeout((function(){n.refresh(),n.process(),n.$resizeTimeout=null}),n.$config.throttle))};"scroll"===e?(this.$scrollerObserver||this.listen(),this.process()):/(resize|orientationchange|mutation|refresh)/.test(e)&&r()}},{key:"refresh",value:function(){var t=this,e=this.getScroller();if(e){var n=e!==e.window?vM:gM,r="auto"===this.$config.method?n:this.$config.method,i=r===vM?gn:bn,o=r===vM?this.getScrollTop():0;return this.$offsets=[],this.$targets=[],this.$scrollHeight=this.getScrollHeight(),Qe(this.$selector,this.$el).map((function(t){return cn(t,"href")})).filter((function(t){return t&&Sn["n"].test(t||"")})).map((function(t){var n=t.replace(Sn["n"],"$1").trim();if(!n)return null;var r=Xe(n,e);return r&&Ge(r)?{offset:Object(Ie["c"])(i(r).top,0)+o,target:n}:null})).filter(An["a"]).sort((function(t,e){return t.offset-e.offset})).reduce((function(e,n){return e[n.target]||(t.$offsets.push(n.offset),t.$targets.push(n.target),e[n.target]=!0),e}),{}),this}}},{key:"process",value:function(){var t=this.getScrollTop()+this.$config.offset,e=this.getScrollHeight(),n=this.$config.offset+e-this.getOffsetHeight();if(this.$scrollHeight!==e&&this.refresh(),t>=n){var r=this.$targets[this.$targets.length-1];this.$activeTarget!==r&&this.activate(r)}else{if(this.$activeTarget&&t<this.$offsets[0]&&this.$offsets[0]>0)return this.$activeTarget=null,void this.clear();for(var i=this.$offsets.length;i--;){var o=this.$activeTarget!==this.$targets[i]&&t>=this.$offsets[i]&&(Object(Me["o"])(this.$offsets[i+1])||t<this.$offsets[i+1]);o&&this.activate(this.$targets[i])}}}},{key:"getScroller",value:function(){if(this.$scroller)return this.$scroller;var t=this.$config.element;return t?($e(t.$el)?t=t.$el:Object(Me["n"])(t)&&(t=Xe(t)),t?(this.$scroller="BODY"===t.tagName?window:t,this.$scroller):null):null}},{key:"getScrollTop",value:function(){var t=this.getScroller();return t===window?t.pageYOffset:t.scrollTop}},{key:"getScrollHeight",value:function(){return this.getScroller().scrollHeight||Object(lr["d"])(document.body.scrollHeight,document.documentElement.scrollHeight)}},{key:"getOffsetHeight",value:function(){var t=this.getScroller();return t===window?window.innerHeight:fn(t).height}},{key:"activate",value:function(t){var e=this;this.$activeTarget=t,this.clear();var n=Qe(this.$selector.split(",").map((function(e){return"".concat(e,'[href$="').concat(t,'"]')})).join(","),this.$el);n.forEach((function(t){if(on(t,sM)){var n=Ze(fM,t);n&&e.setActiveState(Xe(mM,n),!0),e.setActiveState(t,!0)}else{e.setActiveState(t,!0),Je(t.parentElement,dM)&&e.setActiveState(t.parentElement,!0);var r=t;while(r){r=Ze(lM,r);var i=r?r.previousElementSibling:null;i&&Je(i,"".concat(uM,", ").concat(hM))&&e.setActiveState(i,!0),i&&Je(i,dM)&&(e.setActiveState(Xe(uM,i),!0),e.setActiveState(i,!0))}}})),n&&n.length>0&&this.$root&&this.$root.$emit(bM,t,n)}},{key:"clear",value:function(){var t=this;Qe("".concat(this.$selector,", ").concat(dM),this.$el).filter((function(t){return on(t,cM)})).forEach((function(e){return t.setActiveState(e,!1)}))}},{key:"setActiveState",value:function(t,e){t&&(e?nn(t,cM):rn(t,cM))}}],[{key:"Name",get:function(){return aM}},{key:"Default",get:function(){return wM}},{key:"DefaultType",get:function(){return yM}}]),t}(),AM="__BV_ScrollSpy__",jM=/^\d+$/,MM=/^(auto|position|offset)$/,CM=function(t){var e={};return t.arg&&(e.element="#".concat(t.arg)),Object(zn["h"])(t.modifiers).forEach((function(t){jM.test(t)?e.offset=Object(Ie["c"])(t,0):MM.test(t)&&(e.method=t)})),Object(Me["n"])(t.value)?e.element=t.value:Object(Me["h"])(t.value)?e.offset=Object(lr["g"])(t.value):Object(Me["j"])(t.value)&&Object(zn["h"])(t.value).filter((function(t){return!!zM.DefaultType[t]})).forEach((function(n){e[n]=t.value[n]})),e},VM=function(t,e,n){if(Ae["i"]){var r=CM(e);t[AM]?t[AM].updateConfig(r,n.context.$root):t[AM]=new zM(t,r,n.context.$root)}},SM=function(t){t[AM]&&(t[AM].dispose(),t[AM]=null,delete t[AM])},xM={bind:function(t,e,n){VM(t,e,n)},inserted:function(t,e,n){VM(t,e,n)},update:function(t,e,n){e.value!==e.oldValue&&VM(t,e,n)},componentUpdated:function(t,e,n){e.value!==e.oldValue&&VM(t,e,n)},unbind:function(t){SM(t)}},TM=Object(r["b"])({directives:{VBScrollspy:xM}}),PM=Object(r["b"])({directives:{VBVisible:ls}}),IM=Object(r["b"])({plugins:{VBHoverPlugin:Jj,VBModalPlugin:Zj,VBPopoverPlugin:hk,VBScrollspyPlugin:TM,VBTogglePlugin:ol,VBTooltipPlugin:Kj,VBVisiblePlugin:PM}}),EM="BootstrapVue",LM=Object(r["a"])({plugins:{componentsPlugin:Xj,directivesPlugin:IM}}),BM={install:LM,NAME:EM}},"686b":function(t,e,n){"use strict";n.d(e,"a",(function(){return o})),n.d(e,"d",(function(){return a})),n.d(e,"c",(function(){return s})),n.d(e,"b",(function(){return c}));var r=n("e863"),i=n("938d"),o=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;Object(i["a"])()||console.warn("[BootstrapVue warn]: ".concat(e?"".concat(e," - "):"").concat(t))},a=function(t){return!r["i"]&&(o("".concat(t,": Can not be called during SSR.")),!0)},s=function(t){return!r["f"]&&(o("".concat(t,": Requires Promise support.")),!0)},c=function(t){return!r["c"]&&(o("".concat(t,": Requires MutationObserver support.")),!0)}},6930:function(t,e,n){
/*!
 * @license Copyright (c) 2003-2020, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md.
 */
!function(e,r){t.exports=r(n("2b0e"))}(window,(function(t){return function(t){var e={};function n(r){if(e[r])return e[r].exports;var i=e[r]={i:r,l:!1,exports:{}};return t[r].call(i.exports,i,i.exports,n),i.l=!0,i.exports}return n.m=t,n.c=e,n.d=function(t,e,r){n.o(t,e)||Object.defineProperty(t,e,{enumerable:!0,get:r})},n.r=function(t){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},n.t=function(t,e){if(1&e&&(t=n(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var i in t)n.d(r,i,function(e){return t[e]}.bind(null,i));return r},n.n=function(t){var e=t&&t.__esModule?function(){return t.default}:function(){return t};return n.d(e,"a",e),e},n.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},n.p="",n(n.s=3)}([function(e,n){e.exports=t},function(t,e,n){"use strict";(function(t){var n="object"==typeof t&&t&&t.Object===Object&&t;e.a=n}).call(this,n(2))},function(t,e){var n;n=function(){return this}();try{n=n||new Function("return this")()}catch(t){"object"==typeof window&&(n=window)}t.exports=n},function(t,e,n){"use strict";n.r(e);var r=n(0),i=n.n(r),o=function(t){var e=typeof t;return null!=t&&("object"==e||"function"==e)},a=n(1),s="object"==typeof self&&self&&self.Object===Object&&self,c=a.a||s||Function("return this")(),l=function(){return c.Date.now()},u=c.Symbol,d=Object.prototype,h=d.hasOwnProperty,f=d.toString,p=u?u.toStringTag:void 0,m=function(t){var e=h.call(t,p),n=t[p];try{t[p]=void 0;var r=!0}catch(t){}var i=f.call(t);return r&&(e?t[p]=n:delete t[p]),i},b=Object.prototype.toString,g=function(t){return b.call(t)},v=u?u.toStringTag:void 0,w=function(t){return null==t?void 0===t?"[object Undefined]":"[object Null]":v&&v in Object(t)?m(t):g(t)},y=function(t){return null!=t&&"object"==typeof t},k=function(t){return"symbol"==typeof t||y(t)&&"[object Symbol]"==w(t)},_=/^\s+|\s+$/g,O=/^[-+]0x[0-9a-f]+$/i,z=/^0b[01]+$/i,A=/^0o[0-7]+$/i,j=parseInt,M=function(t){if("number"==typeof t)return t;if(k(t))return NaN;if(o(t)){var e="function"==typeof t.valueOf?t.valueOf():t;t=o(e)?e+"":e}if("string"!=typeof t)return 0===t?t:+t;t=t.replace(_,"");var n=z.test(t);return n||A.test(t)?j(t.slice(2),n?2:8):O.test(t)?NaN:+t},C=Math.max,V=Math.min,S=function(t,e,n){var r,i,a,s,c,u,d=0,h=!1,f=!1,p=!0;if("function"!=typeof t)throw new TypeError("Expected a function");function m(e){var n=r,o=i;return r=i=void 0,d=e,s=t.apply(o,n)}function b(t){return d=t,c=setTimeout(v,e),h?m(t):s}function g(t){var n=t-u;return void 0===u||n>=e||n<0||f&&t-d>=a}function v(){var t=l();if(g(t))return w(t);c=setTimeout(v,function(t){var n=e-(t-u);return f?V(n,a-(t-d)):n}(t))}function w(t){return c=void 0,p&&r?m(t):(r=i=void 0,s)}function y(){var t=l(),n=g(t);if(r=arguments,i=this,u=t,n){if(void 0===c)return b(u);if(f)return clearTimeout(c),c=setTimeout(v,e),m(u)}return void 0===c&&(c=setTimeout(v,e)),s}return e=M(e)||0,o(n)&&(h=!!n.leading,a=(f="maxWait"in n)?C(M(n.maxWait)||0,e):a,p="trailing"in n?!!n.trailing:p),y.cancel=function(){void 0!==c&&clearTimeout(c),d=0,r=u=i=c=void 0},y.flush=function(){return void 0===c?s:w(l())},y},x={name:"ckeditor",render(t){return t(this.tagName)},props:{editor:{type:Function,default:null},value:{type:String,default:""},config:{type:Object,default:()=>({})},tagName:{type:String,default:"div"},disabled:{type:Boolean,default:!1}},data:()=>({$_instance:null,$_lastEditorData:{type:String,default:""}}),mounted(){const t=Object.assign({},this.config);this.value&&(t.initialData=this.value),this.editor.create(this.$el,t).then(t=>{this.$_instance=t,t.isReadOnly=this.disabled,this.$_setUpEditorEvents(),this.$emit("ready",t)}).catch(t=>{console.error(t)})},beforeDestroy(){this.$_instance&&(this.$_instance.destroy(),this.$_instance=null),this.$emit("destroy",this.$_instance)},watch:{value(t,e){t!==e&&t!==this.$_lastEditorData&&this.$_instance.setData(t)},disabled(t){this.$_instance.isReadOnly=t}},methods:{$_setUpEditorEvents(){const t=this.$_instance,e=S(e=>{const n=this.$_lastEditorData=t.getData();this.$emit("input",n,e,t)},300,{leading:!0});t.model.document.on("change:data",e),t.editing.view.document.on("focus",e=>{this.$emit("focus",e,t)}),t.editing.view.document.on("blur",e=>{this.$emit("blur",e,t)})}}};const T=i.a?i.a.version:r.version,[P]=T.split(".").map(t=>parseInt(t,10));if(2!==P)throw new Error("The CKEditor plugin works only with Vue 2.x. For more information, please refer to https://ckeditor.com/docs/ckeditor5/latest/builds/guides/integration/frameworks/vuejs-v2.html");const I={install(t){t.component("ckeditor",x)},component:x};e.default=I}]).default}))},"6c06":function(t,e,n){"use strict";n.d(e,"a",(function(){return r}));var r=function(t){return t}},"6dfc":function(t,e,n){},7386:function(t,e,n){"use strict";n.d(e,"Fc",(function(){return h})),n.d(e,"a",(function(){return f})),n.d(e,"b",(function(){return p})),n.d(e,"c",(function(){return m})),n.d(e,"d",(function(){return b})),n.d(e,"e",(function(){return g})),n.d(e,"f",(function(){return v})),n.d(e,"g",(function(){return w})),n.d(e,"h",(function(){return y})),n.d(e,"i",(function(){return k})),n.d(e,"j",(function(){return _})),n.d(e,"k",(function(){return O})),n.d(e,"l",(function(){return z})),n.d(e,"m",(function(){return A})),n.d(e,"n",(function(){return j})),n.d(e,"o",(function(){return M})),n.d(e,"p",(function(){return C})),n.d(e,"q",(function(){return V})),n.d(e,"r",(function(){return S})),n.d(e,"s",(function(){return x})),n.d(e,"t",(function(){return T})),n.d(e,"u",(function(){return P})),n.d(e,"v",(function(){return I})),n.d(e,"w",(function(){return E})),n.d(e,"x",(function(){return L})),n.d(e,"y",(function(){return B})),n.d(e,"z",(function(){return H})),n.d(e,"A",(function(){return F})),n.d(e,"B",(function(){return D})),n.d(e,"C",(function(){return R})),n.d(e,"D",(function(){return N})),n.d(e,"E",(function(){return $})),n.d(e,"F",(function(){return U})),n.d(e,"G",(function(){return q})),n.d(e,"H",(function(){return W})),n.d(e,"I",(function(){return G})),n.d(e,"J",(function(){return Y})),n.d(e,"K",(function(){return K})),n.d(e,"L",(function(){return Q})),n.d(e,"M",(function(){return X})),n.d(e,"N",(function(){return J})),n.d(e,"O",(function(){return Z})),n.d(e,"P",(function(){return tt})),n.d(e,"Q",(function(){return et})),n.d(e,"R",(function(){return nt})),n.d(e,"S",(function(){return rt})),n.d(e,"T",(function(){return it})),n.d(e,"U",(function(){return ot})),n.d(e,"V",(function(){return at})),n.d(e,"W",(function(){return st})),n.d(e,"X",(function(){return ct})),n.d(e,"Y",(function(){return lt})),n.d(e,"Z",(function(){return ut})),n.d(e,"ab",(function(){return dt})),n.d(e,"bb",(function(){return ht})),n.d(e,"cb",(function(){return ft})),n.d(e,"db",(function(){return pt})),n.d(e,"eb",(function(){return mt})),n.d(e,"fb",(function(){return bt})),n.d(e,"gb",(function(){return gt})),n.d(e,"hb",(function(){return vt})),n.d(e,"ib",(function(){return wt})),n.d(e,"jb",(function(){return yt})),n.d(e,"kb",(function(){return kt})),n.d(e,"lb",(function(){return _t})),n.d(e,"mb",(function(){return Ot})),n.d(e,"nb",(function(){return zt})),n.d(e,"ob",(function(){return At})),n.d(e,"pb",(function(){return jt})),n.d(e,"qb",(function(){return Mt})),n.d(e,"rb",(function(){return Ct})),n.d(e,"sb",(function(){return Vt})),n.d(e,"tb",(function(){return St})),n.d(e,"ub",(function(){return xt})),n.d(e,"vb",(function(){return Tt})),n.d(e,"wb",(function(){return Pt})),n.d(e,"xb",(function(){return It})),n.d(e,"yb",(function(){return Et})),n.d(e,"zb",(function(){return Lt})),n.d(e,"Ab",(function(){return Bt})),n.d(e,"Bb",(function(){return Ht})),n.d(e,"Cb",(function(){return Ft})),n.d(e,"Db",(function(){return Dt})),n.d(e,"Eb",(function(){return Rt})),n.d(e,"Fb",(function(){return Nt})),n.d(e,"Gb",(function(){return $t})),n.d(e,"Hb",(function(){return Ut})),n.d(e,"Ib",(function(){return qt})),n.d(e,"Jb",(function(){return Wt})),n.d(e,"Kb",(function(){return Gt})),n.d(e,"Lb",(function(){return Yt})),n.d(e,"Mb",(function(){return Kt})),n.d(e,"Nb",(function(){return Qt})),n.d(e,"Ob",(function(){return Xt})),n.d(e,"Pb",(function(){return Jt})),n.d(e,"Qb",(function(){return Zt})),n.d(e,"Rb",(function(){return te})),n.d(e,"Sb",(function(){return ee})),n.d(e,"Tb",(function(){return ne})),n.d(e,"Ub",(function(){return re})),n.d(e,"Vb",(function(){return ie})),n.d(e,"Wb",(function(){return oe})),n.d(e,"Xb",(function(){return ae})),n.d(e,"Yb",(function(){return se})),n.d(e,"Zb",(function(){return ce})),n.d(e,"ac",(function(){return le})),n.d(e,"bc",(function(){return ue})),n.d(e,"cc",(function(){return de})),n.d(e,"dc",(function(){return he})),n.d(e,"ec",(function(){return fe})),n.d(e,"fc",(function(){return pe})),n.d(e,"gc",(function(){return me})),n.d(e,"hc",(function(){return be})),n.d(e,"ic",(function(){return ge})),n.d(e,"jc",(function(){return ve})),n.d(e,"kc",(function(){return we})),n.d(e,"lc",(function(){return ye})),n.d(e,"mc",(function(){return ke})),n.d(e,"nc",(function(){return _e})),n.d(e,"oc",(function(){return Oe})),n.d(e,"pc",(function(){return ze})),n.d(e,"qc",(function(){return Ae})),n.d(e,"rc",(function(){return je})),n.d(e,"sc",(function(){return Me})),n.d(e,"tc",(function(){return Ce})),n.d(e,"uc",(function(){return Ve})),n.d(e,"vc",(function(){return Se})),n.d(e,"wc",(function(){return xe})),n.d(e,"xc",(function(){return Te})),n.d(e,"yc",(function(){return Pe})),n.d(e,"zc",(function(){return Ie})),n.d(e,"Ac",(function(){return Ee})),n.d(e,"Bc",(function(){return Le})),n.d(e,"Cc",(function(){return Be})),n.d(e,"Dc",(function(){return He})),n.d(e,"Ec",(function(){return Fe})),n.d(e,"Gc",(function(){return De})),n.d(e,"Hc",(function(){return Re})),n.d(e,"Ic",(function(){return Ne})),n.d(e,"Jc",(function(){return $e})),n.d(e,"Kc",(function(){return Ue})),n.d(e,"Lc",(function(){return qe})),n.d(e,"Mc",(function(){return We})),n.d(e,"Nc",(function(){return Ge})),n.d(e,"Oc",(function(){return Ye})),n.d(e,"Pc",(function(){return Ke})),n.d(e,"Qc",(function(){return Qe})),n.d(e,"Rc",(function(){return Xe})),n.d(e,"Sc",(function(){return Je})),n.d(e,"Tc",(function(){return Ze})),n.d(e,"Uc",(function(){return tn})),n.d(e,"Vc",(function(){return en})),n.d(e,"Wc",(function(){return nn})),n.d(e,"Xc",(function(){return rn})),n.d(e,"Yc",(function(){return on})),n.d(e,"Zc",(function(){return an})),n.d(e,"ad",(function(){return sn})),n.d(e,"bd",(function(){return cn})),n.d(e,"cd",(function(){return ln})),n.d(e,"dd",(function(){return un})),n.d(e,"ed",(function(){return dn})),n.d(e,"fd",(function(){return hn})),n.d(e,"gd",(function(){return fn})),n.d(e,"hd",(function(){return pn})),n.d(e,"id",(function(){return mn})),n.d(e,"jd",(function(){return bn})),n.d(e,"kd",(function(){return gn})),n.d(e,"ld",(function(){return vn})),n.d(e,"md",(function(){return wn})),n.d(e,"nd",(function(){return yn})),n.d(e,"od",(function(){return kn})),n.d(e,"pd",(function(){return _n})),n.d(e,"qd",(function(){return On})),n.d(e,"rd",(function(){return zn})),n.d(e,"sd",(function(){return An})),n.d(e,"td",(function(){return jn})),n.d(e,"ud",(function(){return Mn})),n.d(e,"vd",(function(){return Cn})),n.d(e,"wd",(function(){return Vn})),n.d(e,"xd",(function(){return Sn})),n.d(e,"yd",(function(){return xn})),n.d(e,"zd",(function(){return Tn})),n.d(e,"Ad",(function(){return Pn})),n.d(e,"Bd",(function(){return In})),n.d(e,"Cd",(function(){return En})),n.d(e,"Dd",(function(){return Ln})),n.d(e,"Ed",(function(){return Bn})),n.d(e,"Fd",(function(){return Hn})),n.d(e,"Gd",(function(){return Fn})),n.d(e,"Hd",(function(){return Dn})),n.d(e,"Id",(function(){return Rn})),n.d(e,"Jd",(function(){return Nn})),n.d(e,"Kd",(function(){return $n})),n.d(e,"Ld",(function(){return Un})),n.d(e,"Md",(function(){return qn})),n.d(e,"Nd",(function(){return Wn})),n.d(e,"Od",(function(){return Gn})),n.d(e,"Pd",(function(){return Yn})),n.d(e,"Qd",(function(){return Kn})),n.d(e,"Rd",(function(){return Qn})),n.d(e,"Sd",(function(){return Xn})),n.d(e,"Td",(function(){return Jn})),n.d(e,"Ud",(function(){return Zn})),n.d(e,"Vd",(function(){return tr})),n.d(e,"Wd",(function(){return er})),n.d(e,"Xd",(function(){return nr})),n.d(e,"Yd",(function(){return rr})),n.d(e,"Zd",(function(){return ir})),n.d(e,"ae",(function(){return or})),n.d(e,"be",(function(){return ar})),n.d(e,"ce",(function(){return sr})),n.d(e,"de",(function(){return cr})),n.d(e,"ee",(function(){return lr})),n.d(e,"fe",(function(){return ur})),n.d(e,"ge",(function(){return dr})),n.d(e,"he",(function(){return hr})),n.d(e,"ie",(function(){return fr})),n.d(e,"je",(function(){return pr})),n.d(e,"ke",(function(){return mr})),n.d(e,"le",(function(){return br})),n.d(e,"me",(function(){return gr})),n.d(e,"ne",(function(){return vr})),n.d(e,"oe",(function(){return wr})),n.d(e,"pe",(function(){return yr})),n.d(e,"qe",(function(){return kr})),n.d(e,"re",(function(){return _r})),n.d(e,"se",(function(){return Or})),n.d(e,"te",(function(){return zr})),n.d(e,"ue",(function(){return Ar})),n.d(e,"ve",(function(){return jr})),n.d(e,"we",(function(){return Mr})),n.d(e,"xe",(function(){return Cr})),n.d(e,"ye",(function(){return Vr})),n.d(e,"ze",(function(){return Sr})),n.d(e,"Ae",(function(){return xr})),n.d(e,"Be",(function(){return Tr})),n.d(e,"Ce",(function(){return Pr})),n.d(e,"De",(function(){return Ir})),n.d(e,"Ee",(function(){return Er})),n.d(e,"Fe",(function(){return Lr})),n.d(e,"Ge",(function(){return Br})),n.d(e,"He",(function(){return Hr})),n.d(e,"Ie",(function(){return Fr})),n.d(e,"Je",(function(){return Dr})),n.d(e,"Ke",(function(){return Rr})),n.d(e,"Le",(function(){return Nr})),n.d(e,"Me",(function(){return $r})),n.d(e,"Ne",(function(){return Ur})),n.d(e,"Oe",(function(){return qr})),n.d(e,"Pe",(function(){return Wr})),n.d(e,"Qe",(function(){return Gr})),n.d(e,"Re",(function(){return Yr})),n.d(e,"Se",(function(){return Kr})),n.d(e,"Te",(function(){return Qr})),n.d(e,"Ue",(function(){return Xr})),n.d(e,"Ve",(function(){return Jr})),n.d(e,"We",(function(){return Zr})),n.d(e,"Xe",(function(){return ti})),n.d(e,"Ye",(function(){return ei})),n.d(e,"Ze",(function(){return ni})),n.d(e,"af",(function(){return ri})),n.d(e,"bf",(function(){return ii})),n.d(e,"cf",(function(){return oi})),n.d(e,"df",(function(){return ai})),n.d(e,"ef",(function(){return si})),n.d(e,"ff",(function(){return ci})),n.d(e,"gf",(function(){return li})),n.d(e,"hf",(function(){return ui})),n.d(e,"if",(function(){return di})),n.d(e,"jf",(function(){return hi})),n.d(e,"kf",(function(){return fi})),n.d(e,"lf",(function(){return pi})),n.d(e,"mf",(function(){return mi})),n.d(e,"nf",(function(){return bi})),n.d(e,"of",(function(){return gi})),n.d(e,"pf",(function(){return vi})),n.d(e,"qf",(function(){return wi})),n.d(e,"rf",(function(){return yi})),n.d(e,"sf",(function(){return ki})),n.d(e,"tf",(function(){return _i})),n.d(e,"uf",(function(){return Oi})),n.d(e,"vf",(function(){return zi})),n.d(e,"wf",(function(){return Ai})),n.d(e,"xf",(function(){return ji})),n.d(e,"yf",(function(){return Mi})),n.d(e,"zf",(function(){return Ci})),n.d(e,"Af",(function(){return Vi})),n.d(e,"Bf",(function(){return Si})),n.d(e,"Cf",(function(){return xi})),n.d(e,"Df",(function(){return Ti})),n.d(e,"Ef",(function(){return Pi})),n.d(e,"Ff",(function(){return Ii})),n.d(e,"Gf",(function(){return Ei})),n.d(e,"Hf",(function(){return Li})),n.d(e,"If",(function(){return Bi})),n.d(e,"Jf",(function(){return Hi})),n.d(e,"Kf",(function(){return Fi})),n.d(e,"Lf",(function(){return Di})),n.d(e,"Mf",(function(){return Ri})),n.d(e,"Nf",(function(){return Ni})),n.d(e,"Of",(function(){return $i})),n.d(e,"Pf",(function(){return Ui})),n.d(e,"Qf",(function(){return qi})),n.d(e,"Rf",(function(){return Wi})),n.d(e,"Sf",(function(){return Gi})),n.d(e,"Tf",(function(){return Yi})),n.d(e,"Uf",(function(){return Ki})),n.d(e,"Vf",(function(){return Qi})),n.d(e,"Wf",(function(){return Xi})),n.d(e,"Xf",(function(){return Ji})),n.d(e,"Yf",(function(){return Zi})),n.d(e,"Zf",(function(){return to})),n.d(e,"ag",(function(){return eo})),n.d(e,"bg",(function(){return no})),n.d(e,"cg",(function(){return ro})),n.d(e,"dg",(function(){return io})),n.d(e,"eg",(function(){return oo})),n.d(e,"fg",(function(){return ao})),n.d(e,"gg",(function(){return so})),n.d(e,"hg",(function(){return co})),n.d(e,"ig",(function(){return lo})),n.d(e,"jg",(function(){return uo})),n.d(e,"kg",(function(){return ho})),n.d(e,"lg",(function(){return fo})),n.d(e,"mg",(function(){return po})),n.d(e,"ng",(function(){return mo})),n.d(e,"og",(function(){return bo})),n.d(e,"pg",(function(){return go})),n.d(e,"qg",(function(){return vo})),n.d(e,"rg",(function(){return wo})),n.d(e,"sg",(function(){return yo})),n.d(e,"tg",(function(){return ko})),n.d(e,"ug",(function(){return _o})),n.d(e,"vg",(function(){return Oo})),n.d(e,"wg",(function(){return zo})),n.d(e,"xg",(function(){return Ao})),n.d(e,"yg",(function(){return jo})),n.d(e,"zg",(function(){return Mo})),n.d(e,"Ag",(function(){return Co})),n.d(e,"Bg",(function(){return Vo})),n.d(e,"Cg",(function(){return So})),n.d(e,"Dg",(function(){return xo})),n.d(e,"Eg",(function(){return To})),n.d(e,"Fg",(function(){return Po})),n.d(e,"Gg",(function(){return Io})),n.d(e,"Hg",(function(){return Eo})),n.d(e,"Ig",(function(){return Lo})),n.d(e,"Jg",(function(){return Bo})),n.d(e,"Kg",(function(){return Ho})),n.d(e,"Lg",(function(){return Fo})),n.d(e,"Mg",(function(){return Do})),n.d(e,"Ng",(function(){return Ro})),n.d(e,"Og",(function(){return No})),n.d(e,"Pg",(function(){return $o})),n.d(e,"Qg",(function(){return Uo})),n.d(e,"Rg",(function(){return qo})),n.d(e,"Sg",(function(){return Wo})),n.d(e,"Tg",(function(){return Go})),n.d(e,"Ug",(function(){return Yo})),n.d(e,"Vg",(function(){return Ko})),n.d(e,"Wg",(function(){return Qo})),n.d(e,"Xg",(function(){return Xo})),n.d(e,"Yg",(function(){return Jo})),n.d(e,"Zg",(function(){return Zo})),n.d(e,"ah",(function(){return ta})),n.d(e,"bh",(function(){return ea})),n.d(e,"ch",(function(){return na})),n.d(e,"dh",(function(){return ra})),n.d(e,"eh",(function(){return ia})),n.d(e,"fh",(function(){return oa})),n.d(e,"gh",(function(){return aa})),n.d(e,"hh",(function(){return sa})),n.d(e,"ih",(function(){return ca})),n.d(e,"jh",(function(){return la})),n.d(e,"kh",(function(){return ua})),n.d(e,"lh",(function(){return da})),n.d(e,"mh",(function(){return ha})),n.d(e,"nh",(function(){return fa})),n.d(e,"oh",(function(){return pa})),n.d(e,"ph",(function(){return ma})),n.d(e,"qh",(function(){return ba})),n.d(e,"rh",(function(){return ga})),n.d(e,"sh",(function(){return va})),n.d(e,"th",(function(){return wa})),n.d(e,"uh",(function(){return ya})),n.d(e,"vh",(function(){return ka})),n.d(e,"wh",(function(){return _a})),n.d(e,"xh",(function(){return Oa})),n.d(e,"yh",(function(){return za})),n.d(e,"zh",(function(){return Aa})),n.d(e,"Ah",(function(){return ja})),n.d(e,"Bh",(function(){return Ma})),n.d(e,"Ch",(function(){return Ca})),n.d(e,"Dh",(function(){return Va})),n.d(e,"Eh",(function(){return Sa})),n.d(e,"Fh",(function(){return xa})),n.d(e,"Gh",(function(){return Ta})),n.d(e,"Hh",(function(){return Pa})),n.d(e,"Ih",(function(){return Ia})),n.d(e,"Jh",(function(){return Ea})),n.d(e,"Kh",(function(){return La})),n.d(e,"Lh",(function(){return Ba})),n.d(e,"Mh",(function(){return Ha})),n.d(e,"Nh",(function(){return Fa})),n.d(e,"Oh",(function(){return Da})),n.d(e,"Ph",(function(){return Ra})),n.d(e,"Qh",(function(){return Na})),n.d(e,"Rh",(function(){return $a})),n.d(e,"Sh",(function(){return Ua})),n.d(e,"Th",(function(){return qa})),n.d(e,"Uh",(function(){return Wa})),n.d(e,"Vh",(function(){return Ga})),n.d(e,"Wh",(function(){return Ya})),n.d(e,"Xh",(function(){return Ka})),n.d(e,"Yh",(function(){return Qa})),n.d(e,"Zh",(function(){return Xa})),n.d(e,"ai",(function(){return Ja})),n.d(e,"bi",(function(){return Za})),n.d(e,"ci",(function(){return ts})),n.d(e,"di",(function(){return es})),n.d(e,"ei",(function(){return ns})),n.d(e,"fi",(function(){return rs})),n.d(e,"gi",(function(){return is})),n.d(e,"hi",(function(){return os})),n.d(e,"ii",(function(){return as})),n.d(e,"ji",(function(){return ss})),n.d(e,"ki",(function(){return cs})),n.d(e,"li",(function(){return ls})),n.d(e,"mi",(function(){return us})),n.d(e,"ni",(function(){return ds})),n.d(e,"oi",(function(){return hs})),n.d(e,"pi",(function(){return fs})),n.d(e,"qi",(function(){return ps})),n.d(e,"ri",(function(){return ms})),n.d(e,"si",(function(){return bs})),n.d(e,"ti",(function(){return gs})),n.d(e,"ui",(function(){return vs})),n.d(e,"vi",(function(){return ws})),n.d(e,"wi",(function(){return ys})),n.d(e,"xi",(function(){return ks})),n.d(e,"yi",(function(){return _s})),n.d(e,"zi",(function(){return Os})),n.d(e,"Ai",(function(){return zs})),n.d(e,"Bi",(function(){return As})),n.d(e,"Ci",(function(){return js})),n.d(e,"Di",(function(){return Ms})),n.d(e,"Ei",(function(){return Cs})),n.d(e,"Fi",(function(){return Vs})),n.d(e,"Gi",(function(){return Ss})),n.d(e,"Hi",(function(){return xs})),n.d(e,"Ii",(function(){return Ts})),n.d(e,"Ji",(function(){return Ps})),n.d(e,"Ki",(function(){return Is})),n.d(e,"Li",(function(){return Es})),n.d(e,"Mi",(function(){return Ls})),n.d(e,"Ni",(function(){return Bs})),n.d(e,"Oi",(function(){return Hs})),n.d(e,"Pi",(function(){return Fs})),n.d(e,"Qi",(function(){return Ds})),n.d(e,"Ri",(function(){return Rs})),n.d(e,"Si",(function(){return Ns})),n.d(e,"Ti",(function(){return $s})),n.d(e,"Ui",(function(){return Us})),n.d(e,"Vi",(function(){return qs})),n.d(e,"Wi",(function(){return Ws})),n.d(e,"Xi",(function(){return Gs})),n.d(e,"Yi",(function(){return Ys})),n.d(e,"Zi",(function(){return Ks})),n.d(e,"aj",(function(){return Qs})),n.d(e,"bj",(function(){return Xs})),n.d(e,"cj",(function(){return Js})),n.d(e,"dj",(function(){return Zs})),n.d(e,"ej",(function(){return tc})),n.d(e,"fj",(function(){return ec})),n.d(e,"gj",(function(){return nc})),n.d(e,"hj",(function(){return rc})),n.d(e,"ij",(function(){return ic})),n.d(e,"jj",(function(){return oc})),n.d(e,"kj",(function(){return ac})),n.d(e,"lj",(function(){return sc})),n.d(e,"mj",(function(){return cc})),n.d(e,"nj",(function(){return lc})),n.d(e,"oj",(function(){return uc})),n.d(e,"pj",(function(){return dc})),n.d(e,"qj",(function(){return hc})),n.d(e,"rj",(function(){return fc})),n.d(e,"sj",(function(){return pc})),n.d(e,"tj",(function(){return mc})),n.d(e,"uj",(function(){return bc})),n.d(e,"vj",(function(){return gc})),n.d(e,"wj",(function(){return vc})),n.d(e,"xj",(function(){return wc})),n.d(e,"yj",(function(){return yc})),n.d(e,"zj",(function(){return kc})),n.d(e,"Aj",(function(){return _c})),n.d(e,"Bj",(function(){return Oc})),n.d(e,"Cj",(function(){return zc})),n.d(e,"Dj",(function(){return Ac})),n.d(e,"Ej",(function(){return jc})),n.d(e,"Fj",(function(){return Mc})),n.d(e,"Gj",(function(){return Cc})),n.d(e,"Hj",(function(){return Vc})),n.d(e,"Ij",(function(){return Sc})),n.d(e,"Jj",(function(){return xc})),n.d(e,"Kj",(function(){return Tc})),n.d(e,"Lj",(function(){return Pc})),n.d(e,"Mj",(function(){return Ic})),n.d(e,"Nj",(function(){return Ec})),n.d(e,"Oj",(function(){return Lc})),n.d(e,"Pj",(function(){return Bc})),n.d(e,"Qj",(function(){return Hc})),n.d(e,"Rj",(function(){return Fc})),n.d(e,"Sj",(function(){return Dc})),n.d(e,"Tj",(function(){return Rc})),n.d(e,"Uj",(function(){return Nc})),n.d(e,"Vj",(function(){return $c})),n.d(e,"Wj",(function(){return Uc})),n.d(e,"Xj",(function(){return qc})),n.d(e,"Yj",(function(){return Wc})),n.d(e,"Zj",(function(){return Gc})),n.d(e,"ak",(function(){return Yc})),n.d(e,"bk",(function(){return Kc})),n.d(e,"ck",(function(){return Qc})),n.d(e,"dk",(function(){return Xc})),n.d(e,"ek",(function(){return Jc})),n.d(e,"fk",(function(){return Zc})),n.d(e,"gk",(function(){return tl})),n.d(e,"hk",(function(){return el})),n.d(e,"ik",(function(){return nl})),n.d(e,"jk",(function(){return rl})),n.d(e,"kk",(function(){return il})),n.d(e,"lk",(function(){return ol})),n.d(e,"mk",(function(){return al})),n.d(e,"nk",(function(){return sl})),n.d(e,"ok",(function(){return cl})),n.d(e,"pk",(function(){return ll})),n.d(e,"qk",(function(){return ul})),n.d(e,"rk",(function(){return dl})),n.d(e,"sk",(function(){return hl})),n.d(e,"tk",(function(){return fl})),n.d(e,"uk",(function(){return pl})),n.d(e,"vk",(function(){return ml})),n.d(e,"wk",(function(){return bl})),n.d(e,"xk",(function(){return gl})),n.d(e,"yk",(function(){return vl})),n.d(e,"zk",(function(){return wl})),n.d(e,"Ak",(function(){return yl})),n.d(e,"Bk",(function(){return kl})),n.d(e,"Ck",(function(){return _l})),n.d(e,"Dk",(function(){return Ol})),n.d(e,"Ek",(function(){return zl})),n.d(e,"Fk",(function(){return Al})),n.d(e,"Gk",(function(){return jl})),n.d(e,"Hk",(function(){return Ml})),n.d(e,"Ik",(function(){return Cl})),n.d(e,"Jk",(function(){return Vl})),n.d(e,"Kk",(function(){return Sl})),n.d(e,"Lk",(function(){return xl})),n.d(e,"Mk",(function(){return Tl})),n.d(e,"Nk",(function(){return Pl})),n.d(e,"Ok",(function(){return Il})),n.d(e,"Pk",(function(){return El})),n.d(e,"Qk",(function(){return Ll})),n.d(e,"Rk",(function(){return Bl})),n.d(e,"Sk",(function(){return Hl})),n.d(e,"Tk",(function(){return Fl})),n.d(e,"Uk",(function(){return Dl})),n.d(e,"Vk",(function(){return Rl})),n.d(e,"Wk",(function(){return Nl})),n.d(e,"Xk",(function(){return $l})),n.d(e,"Yk",(function(){return Ul})),n.d(e,"Zk",(function(){return ql})),n.d(e,"al",(function(){return Wl})),n.d(e,"bl",(function(){return Gl})),n.d(e,"cl",(function(){return Yl})),n.d(e,"dl",(function(){return Kl})),n.d(e,"el",(function(){return Ql})),n.d(e,"fl",(function(){return Xl})),n.d(e,"gl",(function(){return Jl})),n.d(e,"hl",(function(){return Zl})),n.d(e,"il",(function(){return tu})),n.d(e,"jl",(function(){return eu})),n.d(e,"kl",(function(){return nu})),n.d(e,"ll",(function(){return ru})),n.d(e,"ml",(function(){return iu})),n.d(e,"nl",(function(){return ou})),n.d(e,"ol",(function(){return au})),n.d(e,"pl",(function(){return su})),n.d(e,"ql",(function(){return cu})),n.d(e,"rl",(function(){return lu})),n.d(e,"sl",(function(){return uu})),n.d(e,"tl",(function(){return du})),n.d(e,"ul",(function(){return hu})),n.d(e,"vl",(function(){return fu})),n.d(e,"wl",(function(){return pu})),n.d(e,"xl",(function(){return mu})),n.d(e,"yl",(function(){return bu})),n.d(e,"zl",(function(){return gu})),n.d(e,"Al",(function(){return vu})),n.d(e,"Bl",(function(){return wu})),n.d(e,"Cl",(function(){return yu})),n.d(e,"Dl",(function(){return ku})),n.d(e,"El",(function(){return _u})),n.d(e,"Fl",(function(){return Ou})),n.d(e,"Gl",(function(){return zu})),n.d(e,"Hl",(function(){return Au})),n.d(e,"Il",(function(){return ju})),n.d(e,"Jl",(function(){return Mu})),n.d(e,"Kl",(function(){return Cu})),n.d(e,"Ll",(function(){return Vu})),n.d(e,"Ml",(function(){return Su})),n.d(e,"Nl",(function(){return xu})),n.d(e,"Ol",(function(){return Tu})),n.d(e,"Pl",(function(){return Pu})),n.d(e,"Ql",(function(){return Iu})),n.d(e,"Rl",(function(){return Eu})),n.d(e,"Sl",(function(){return Lu})),n.d(e,"Tl",(function(){return Bu})),n.d(e,"Ul",(function(){return Hu})),n.d(e,"Vl",(function(){return Fu})),n.d(e,"Wl",(function(){return Du})),n.d(e,"Xl",(function(){return Ru})),n.d(e,"Yl",(function(){return Nu})),n.d(e,"Zl",(function(){return $u})),n.d(e,"am",(function(){return Uu})),n.d(e,"bm",(function(){return qu})),n.d(e,"cm",(function(){return Wu})),n.d(e,"dm",(function(){return Gu})),n.d(e,"em",(function(){return Yu})),n.d(e,"fm",(function(){return Ku})),n.d(e,"gm",(function(){return Qu})),n.d(e,"hm",(function(){return Xu})),n.d(e,"im",(function(){return Ju})),n.d(e,"jm",(function(){return Zu})),n.d(e,"km",(function(){return td})),n.d(e,"lm",(function(){return ed})),n.d(e,"mm",(function(){return nd})),n.d(e,"nm",(function(){return rd})),n.d(e,"om",(function(){return id})),n.d(e,"pm",(function(){return od})),n.d(e,"qm",(function(){return ad})),n.d(e,"rm",(function(){return sd})),n.d(e,"sm",(function(){return cd})),n.d(e,"tm",(function(){return ld})),n.d(e,"um",(function(){return ud})),n.d(e,"vm",(function(){return dd})),n.d(e,"wm",(function(){return hd})),n.d(e,"xm",(function(){return fd})),n.d(e,"ym",(function(){return pd})),n.d(e,"zm",(function(){return md})),n.d(e,"Am",(function(){return bd})),n.d(e,"Bm",(function(){return gd})),n.d(e,"Cm",(function(){return vd})),n.d(e,"Dm",(function(){return wd})),n.d(e,"Em",(function(){return yd})),n.d(e,"Fm",(function(){return kd})),n.d(e,"Gm",(function(){return _d})),n.d(e,"Hm",(function(){return Od})),n.d(e,"Im",(function(){return zd})),n.d(e,"Jm",(function(){return Ad})),n.d(e,"Km",(function(){return jd})),n.d(e,"Lm",(function(){return Md})),n.d(e,"Mm",(function(){return Cd})),n.d(e,"Nm",(function(){return Vd})),n.d(e,"Om",(function(){return Sd})),n.d(e,"Pm",(function(){return xd})),n.d(e,"Qm",(function(){return Td})),n.d(e,"Rm",(function(){return Pd})),n.d(e,"Sm",(function(){return Id})),n.d(e,"Tm",(function(){return Ed})),n.d(e,"Um",(function(){return Ld})),n.d(e,"Vm",(function(){return Bd})),n.d(e,"Wm",(function(){return Hd})),n.d(e,"Xm",(function(){return Fd})),n.d(e,"Ym",(function(){return Dd})),n.d(e,"Zm",(function(){return Rd})),n.d(e,"an",(function(){return Nd})),n.d(e,"bn",(function(){return $d})),n.d(e,"cn",(function(){return Ud})),n.d(e,"dn",(function(){return qd})),n.d(e,"en",(function(){return Wd})),n.d(e,"fn",(function(){return Gd})),n.d(e,"gn",(function(){return Yd})),n.d(e,"hn",(function(){return Kd})),n.d(e,"in",(function(){return Qd})),n.d(e,"jn",(function(){return Xd})),n.d(e,"kn",(function(){return Jd})),n.d(e,"ln",(function(){return Zd})),n.d(e,"mn",(function(){return th})),n.d(e,"nn",(function(){return eh})),n.d(e,"on",(function(){return nh})),n.d(e,"pn",(function(){return rh})),n.d(e,"qn",(function(){return ih})),n.d(e,"rn",(function(){return oh})),n.d(e,"sn",(function(){return ah})),n.d(e,"tn",(function(){return sh})),n.d(e,"un",(function(){return ch})),n.d(e,"vn",(function(){return lh})),n.d(e,"wn",(function(){return uh})),n.d(e,"xn",(function(){return dh})),n.d(e,"yn",(function(){return hh})),n.d(e,"zn",(function(){return fh})),n.d(e,"An",(function(){return ph})),n.d(e,"Bn",(function(){return mh})),n.d(e,"Cn",(function(){return bh})),n.d(e,"Dn",(function(){return gh})),n.d(e,"En",(function(){return vh})),n.d(e,"Fn",(function(){return wh})),n.d(e,"Gn",(function(){return yh})),n.d(e,"Hn",(function(){return kh})),n.d(e,"In",(function(){return _h})),n.d(e,"Jn",(function(){return Oh})),n.d(e,"Kn",(function(){return zh})),n.d(e,"Ln",(function(){return Ah})),n.d(e,"Mn",(function(){return jh})),n.d(e,"Nn",(function(){return Mh})),n.d(e,"On",(function(){return Ch})),n.d(e,"Pn",(function(){return Vh})),n.d(e,"Qn",(function(){return Sh})),n.d(e,"Rn",(function(){return xh})),n.d(e,"Sn",(function(){return Th})),n.d(e,"Tn",(function(){return Ph})),n.d(e,"Un",(function(){return Ih})),n.d(e,"Vn",(function(){return Eh})),n.d(e,"Wn",(function(){return Lh})),n.d(e,"Xn",(function(){return Bh})),n.d(e,"Yn",(function(){return Hh})),n.d(e,"Zn",(function(){return Fh})),n.d(e,"ao",(function(){return Dh})),n.d(e,"bo",(function(){return Rh})),n.d(e,"co",(function(){return Nh})),n.d(e,"do",(function(){return $h})),n.d(e,"eo",(function(){return Uh})),n.d(e,"fo",(function(){return qh})),n.d(e,"go",(function(){return Wh})),n.d(e,"ho",(function(){return Gh})),n.d(e,"io",(function(){return Yh})),n.d(e,"jo",(function(){return Kh})),n.d(e,"ko",(function(){return Qh})),n.d(e,"lo",(function(){return Xh})),n.d(e,"mo",(function(){return Jh})),n.d(e,"no",(function(){return Zh})),n.d(e,"oo",(function(){return tf})),n.d(e,"po",(function(){return ef})),n.d(e,"qo",(function(){return nf})),n.d(e,"ro",(function(){return rf})),n.d(e,"so",(function(){return of})),n.d(e,"to",(function(){return af})),n.d(e,"uo",(function(){return sf})),n.d(e,"vo",(function(){return cf})),n.d(e,"wo",(function(){return lf})),n.d(e,"xo",(function(){return uf})),n.d(e,"yo",(function(){return df})),n.d(e,"zo",(function(){return hf})),n.d(e,"Ao",(function(){return ff})),n.d(e,"Bo",(function(){return pf})),n.d(e,"Co",(function(){return mf})),n.d(e,"Do",(function(){return bf})),n.d(e,"Eo",(function(){return gf})),n.d(e,"Fo",(function(){return vf})),n.d(e,"Go",(function(){return wf})),n.d(e,"Ho",(function(){return yf})),n.d(e,"Io",(function(){return kf})),n.d(e,"Jo",(function(){return _f})),n.d(e,"Ko",(function(){return Of})),n.d(e,"Lo",(function(){return zf})),n.d(e,"Mo",(function(){return Af})),n.d(e,"No",(function(){return jf})),n.d(e,"Oo",(function(){return Mf})),n.d(e,"Po",(function(){return Cf})),n.d(e,"Qo",(function(){return Vf})),n.d(e,"Ro",(function(){return Sf})),n.d(e,"So",(function(){return xf})),n.d(e,"To",(function(){return Tf})),n.d(e,"Uo",(function(){return Pf})),n.d(e,"Vo",(function(){return If})),n.d(e,"Wo",(function(){return Ef})),n.d(e,"Xo",(function(){return Lf})),n.d(e,"Yo",(function(){return Bf})),n.d(e,"Zo",(function(){return Hf})),n.d(e,"ap",(function(){return Ff})),n.d(e,"bp",(function(){return Df})),n.d(e,"cp",(function(){return Rf})),n.d(e,"dp",(function(){return Nf})),n.d(e,"ep",(function(){return $f})),n.d(e,"fp",(function(){return Uf})),n.d(e,"gp",(function(){return qf})),n.d(e,"hp",(function(){return Wf})),n.d(e,"ip",(function(){return Gf})),n.d(e,"jp",(function(){return Yf})),n.d(e,"kp",(function(){return Kf})),n.d(e,"lp",(function(){return Qf})),n.d(e,"mp",(function(){return Xf})),n.d(e,"np",(function(){return Jf})),n.d(e,"op",(function(){return Zf})),n.d(e,"pp",(function(){return tp})),n.d(e,"qp",(function(){return ep})),n.d(e,"rp",(function(){return np})),n.d(e,"sp",(function(){return rp})),n.d(e,"tp",(function(){return ip}));n.d(e,"up",(function(){return op})),n.d(e,"vp",(function(){return ap})),n.d(e,"wp",(function(){return sp})),n.d(e,"xp",(function(){return cp})),n.d(e,"yp",(function(){return lp})),n.d(e,"zp",(function(){return up})),n.d(e,"Ap",(function(){return dp})),n.d(e,"Bp",(function(){return hp})),n.d(e,"Cp",(function(){return fp})),n.d(e,"Dp",(function(){return pp})),n.d(e,"Ep",(function(){return mp})),n.d(e,"Fp",(function(){return bp})),n.d(e,"Gp",(function(){return gp})),n.d(e,"Hp",(function(){return vp})),n.d(e,"Ip",(function(){return wp})),n.d(e,"Jp",(function(){return yp})),n.d(e,"Kp",(function(){return kp})),n.d(e,"Lp",(function(){return _p})),n.d(e,"Mp",(function(){return Op})),n.d(e,"Np",(function(){return zp})),n.d(e,"Op",(function(){return Ap})),n.d(e,"Pp",(function(){return jp})),n.d(e,"Qp",(function(){return Mp})),n.d(e,"Rp",(function(){return Cp})),n.d(e,"Sp",(function(){return Vp})),n.d(e,"Tp",(function(){return Sp})),n.d(e,"Up",(function(){return xp})),n.d(e,"Vp",(function(){return Tp})),n.d(e,"Wp",(function(){return Pp})),n.d(e,"Xp",(function(){return Ip})),n.d(e,"Yp",(function(){return Ep})),n.d(e,"Zp",(function(){return Lp})),n.d(e,"aq",(function(){return Bp})),n.d(e,"bq",(function(){return Hp})),n.d(e,"cq",(function(){return Fp})),n.d(e,"dq",(function(){return Dp})),n.d(e,"eq",(function(){return Rp})),n.d(e,"fq",(function(){return Np})),n.d(e,"gq",(function(){return $p})),n.d(e,"hq",(function(){return Up})),n.d(e,"iq",(function(){return qp})),n.d(e,"jq",(function(){return Wp})),n.d(e,"kq",(function(){return Gp})),n.d(e,"lq",(function(){return Yp})),n.d(e,"mq",(function(){return Kp})),n.d(e,"nq",(function(){return Qp})),n.d(e,"oq",(function(){return Xp})),n.d(e,"pq",(function(){return Jp})),n.d(e,"qq",(function(){return Zp})),n.d(e,"rq",(function(){return tm})),n.d(e,"sq",(function(){return em})),n.d(e,"tq",(function(){return nm})),n.d(e,"uq",(function(){return rm})),n.d(e,"vq",(function(){return im})),n.d(e,"wq",(function(){return om})),n.d(e,"xq",(function(){return am})),n.d(e,"yq",(function(){return sm})),n.d(e,"zq",(function(){return cm})),n.d(e,"Aq",(function(){return lm})),n.d(e,"Bq",(function(){return um})),n.d(e,"Cq",(function(){return dm})),n.d(e,"Dq",(function(){return hm})),n.d(e,"Eq",(function(){return fm})),n.d(e,"Fq",(function(){return pm})),n.d(e,"Gq",(function(){return mm})),n.d(e,"Hq",(function(){return bm})),n.d(e,"Iq",(function(){return gm})),n.d(e,"Jq",(function(){return vm})),n.d(e,"Kq",(function(){return wm})),n.d(e,"Lq",(function(){return ym})),n.d(e,"Mq",(function(){return km})),n.d(e,"Nq",(function(){return _m})),n.d(e,"Oq",(function(){return Om})),n.d(e,"Pq",(function(){return zm})),n.d(e,"Qq",(function(){return Am})),n.d(e,"Rq",(function(){return jm})),n.d(e,"Sq",(function(){return Mm})),n.d(e,"Tq",(function(){return Cm})),n.d(e,"Uq",(function(){return Vm})),n.d(e,"Vq",(function(){return Sm})),n.d(e,"Wq",(function(){return xm})),n.d(e,"Xq",(function(){return Tm})),n.d(e,"Yq",(function(){return Pm})),n.d(e,"Zq",(function(){return Im})),n.d(e,"ar",(function(){return Em})),n.d(e,"br",(function(){return Lm})),n.d(e,"cr",(function(){return Bm})),n.d(e,"dr",(function(){return Hm})),n.d(e,"er",(function(){return Fm})),n.d(e,"fr",(function(){return Dm})),n.d(e,"gr",(function(){return Rm})),n.d(e,"hr",(function(){return Nm})),n.d(e,"ir",(function(){return $m})),n.d(e,"jr",(function(){return Um})),n.d(e,"kr",(function(){return qm})),n.d(e,"lr",(function(){return Wm})),n.d(e,"mr",(function(){return Gm})),n.d(e,"nr",(function(){return Ym})),n.d(e,"or",(function(){return Km})),n.d(e,"pr",(function(){return Qm})),n.d(e,"qr",(function(){return Xm})),n.d(e,"rr",(function(){return Jm})),n.d(e,"sr",(function(){return Zm})),n.d(e,"tr",(function(){return tb})),n.d(e,"ur",(function(){return eb})),n.d(e,"vr",(function(){return nb})),n.d(e,"wr",(function(){return rb})),n.d(e,"xr",(function(){return ib})),n.d(e,"yr",(function(){return ob})),n.d(e,"zr",(function(){return ab})),n.d(e,"Ar",(function(){return sb})),n.d(e,"Br",(function(){return cb})),n.d(e,"Cr",(function(){return lb})),n.d(e,"Dr",(function(){return ub})),n.d(e,"Er",(function(){return db})),n.d(e,"Fr",(function(){return hb})),n.d(e,"Gr",(function(){return fb})),n.d(e,"Hr",(function(){return pb})),n.d(e,"Ir",(function(){return mb})),n.d(e,"Jr",(function(){return bb})),n.d(e,"Kr",(function(){return gb})),n.d(e,"Lr",(function(){return vb})),n.d(e,"Mr",(function(){return wb})),n.d(e,"Nr",(function(){return yb})),n.d(e,"Or",(function(){return kb})),n.d(e,"Pr",(function(){return _b})),n.d(e,"Qr",(function(){return Ob})),n.d(e,"Rr",(function(){return zb})),n.d(e,"Sr",(function(){return Ab})),n.d(e,"Tr",(function(){return jb})),n.d(e,"Ur",(function(){return Mb})),n.d(e,"Vr",(function(){return Cb})),n.d(e,"Wr",(function(){return Vb})),n.d(e,"Xr",(function(){return Sb})),n.d(e,"Yr",(function(){return xb})),n.d(e,"Zr",(function(){return Tb})),n.d(e,"as",(function(){return Pb})),n.d(e,"bs",(function(){return Ib})),n.d(e,"cs",(function(){return Eb})),n.d(e,"ds",(function(){return Lb})),n.d(e,"es",(function(){return Bb})),n.d(e,"fs",(function(){return Hb})),n.d(e,"gs",(function(){return Fb})),n.d(e,"hs",(function(){return Db})),n.d(e,"is",(function(){return Rb})),n.d(e,"js",(function(){return Nb})),n.d(e,"ks",(function(){return $b})),n.d(e,"ls",(function(){return Ub})),n.d(e,"ms",(function(){return qb})),n.d(e,"ns",(function(){return Wb})),n.d(e,"os",(function(){return Gb})),n.d(e,"ps",(function(){return Yb})),n.d(e,"qs",(function(){return Kb})),n.d(e,"rs",(function(){return Qb})),n.d(e,"ss",(function(){return Xb})),n.d(e,"ts",(function(){return Jb})),n.d(e,"us",(function(){return Zb})),n.d(e,"vs",(function(){return tg})),n.d(e,"ws",(function(){return eg})),n.d(e,"xs",(function(){return ng})),n.d(e,"ys",(function(){return rg})),n.d(e,"zs",(function(){return ig})),n.d(e,"As",(function(){return og})),n.d(e,"Bs",(function(){return ag})),n.d(e,"Cs",(function(){return sg})),n.d(e,"Ds",(function(){return cg})),n.d(e,"Es",(function(){return lg})),n.d(e,"Fs",(function(){return ug})),n.d(e,"Gs",(function(){return dg})),n.d(e,"Hs",(function(){return hg})),n.d(e,"Is",(function(){return fg})),n.d(e,"Js",(function(){return pg})),n.d(e,"Ks",(function(){return mg})),n.d(e,"Ls",(function(){return bg})),n.d(e,"Ms",(function(){return gg})),n.d(e,"Ns",(function(){return vg})),n.d(e,"Os",(function(){return wg})),n.d(e,"Ps",(function(){return yg})),n.d(e,"Qs",(function(){return kg})),n.d(e,"Rs",(function(){return _g})),n.d(e,"Ss",(function(){return Og})),n.d(e,"Ts",(function(){return zg})),n.d(e,"Us",(function(){return Ag})),n.d(e,"Vs",(function(){return jg})),n.d(e,"Ws",(function(){return Mg})),n.d(e,"Xs",(function(){return Cg})),n.d(e,"Ys",(function(){return Vg})),n.d(e,"Zs",(function(){return Sg})),n.d(e,"at",(function(){return xg})),n.d(e,"bt",(function(){return Tg})),n.d(e,"ct",(function(){return Pg})),n.d(e,"dt",(function(){return Ig})),n.d(e,"et",(function(){return Eg})),n.d(e,"ft",(function(){return Lg})),n.d(e,"gt",(function(){return Bg})),n.d(e,"ht",(function(){return Hg})),n.d(e,"it",(function(){return Fg})),n.d(e,"jt",(function(){return Dg})),n.d(e,"kt",(function(){return Rg})),n.d(e,"lt",(function(){return Ng})),n.d(e,"mt",(function(){return $g})),n.d(e,"nt",(function(){return Ug})),n.d(e,"ot",(function(){return qg})),n.d(e,"pt",(function(){return Wg})),n.d(e,"qt",(function(){return Gg})),n.d(e,"rt",(function(){return Yg})),n.d(e,"st",(function(){return Kg})),n.d(e,"tt",(function(){return Qg})),n.d(e,"ut",(function(){return Xg})),n.d(e,"vt",(function(){return Jg})),n.d(e,"wt",(function(){return Zg})),n.d(e,"xt",(function(){return tv})),n.d(e,"yt",(function(){return ev})),n.d(e,"zt",(function(){return nv})),n.d(e,"At",(function(){return rv})),n.d(e,"Bt",(function(){return iv})),n.d(e,"Ct",(function(){return ov})),n.d(e,"Dt",(function(){return av})),n.d(e,"Et",(function(){return sv})),n.d(e,"Ft",(function(){return cv})),n.d(e,"Gt",(function(){return lv})),n.d(e,"Ht",(function(){return uv})),n.d(e,"It",(function(){return dv})),n.d(e,"Jt",(function(){return hv})),n.d(e,"Kt",(function(){return fv})),n.d(e,"Lt",(function(){return pv})),n.d(e,"Mt",(function(){return mv})),n.d(e,"Nt",(function(){return bv})),n.d(e,"Ot",(function(){return gv})),n.d(e,"Pt",(function(){return vv})),n.d(e,"Qt",(function(){return wv})),n.d(e,"Rt",(function(){return yv})),n.d(e,"St",(function(){return kv})),n.d(e,"Tt",(function(){return _v})),n.d(e,"Ut",(function(){return Ov})),n.d(e,"Vt",(function(){return zv})),n.d(e,"Wt",(function(){return Av})),n.d(e,"Xt",(function(){return jv})),n.d(e,"Yt",(function(){return Mv})),n.d(e,"Zt",(function(){return Cv})),n.d(e,"au",(function(){return Vv})),n.d(e,"bu",(function(){return Sv})),n.d(e,"cu",(function(){return xv})),n.d(e,"du",(function(){return Tv})),n.d(e,"eu",(function(){return Pv})),n.d(e,"fu",(function(){return Iv})),n.d(e,"gu",(function(){return Ev})),n.d(e,"hu",(function(){return Lv})),n.d(e,"iu",(function(){return Bv})),n.d(e,"ju",(function(){return Hv})),n.d(e,"ku",(function(){return Fv})),n.d(e,"lu",(function(){return Dv})),n.d(e,"mu",(function(){return Rv})),n.d(e,"nu",(function(){return Nv})),n.d(e,"ou",(function(){return $v})),n.d(e,"pu",(function(){return Uv})),n.d(e,"qu",(function(){return qv})),n.d(e,"ru",(function(){return Wv})),n.d(e,"su",(function(){return Gv})),n.d(e,"tu",(function(){return Yv})),n.d(e,"uu",(function(){return Kv})),n.d(e,"vu",(function(){return Qv})),n.d(e,"wu",(function(){return Xv})),n.d(e,"xu",(function(){return Jv})),n.d(e,"yu",(function(){return Zv})),n.d(e,"zu",(function(){return tw})),n.d(e,"Au",(function(){return ew})),n.d(e,"Bu",(function(){return nw})),n.d(e,"Cu",(function(){return rw})),n.d(e,"Du",(function(){return iw})),n.d(e,"Eu",(function(){return ow})),n.d(e,"Fu",(function(){return aw})),n.d(e,"Gu",(function(){return sw})),n.d(e,"Hu",(function(){return cw})),n.d(e,"Iu",(function(){return lw})),n.d(e,"Ju",(function(){return uw})),n.d(e,"Ku",(function(){return dw})),n.d(e,"Lu",(function(){return hw})),n.d(e,"Mu",(function(){return fw})),n.d(e,"Nu",(function(){return pw})),n.d(e,"Ou",(function(){return mw})),n.d(e,"Pu",(function(){return bw})),n.d(e,"Qu",(function(){return gw})),n.d(e,"Ru",(function(){return vw})),n.d(e,"Su",(function(){return ww})),n.d(e,"Tu",(function(){return yw})),n.d(e,"Uu",(function(){return kw})),n.d(e,"Vu",(function(){return _w})),n.d(e,"Wu",(function(){return Ow})),n.d(e,"Xu",(function(){return zw})),n.d(e,"Yu",(function(){return Aw})),n.d(e,"Zu",(function(){return jw})),n.d(e,"av",(function(){return Mw})),n.d(e,"bv",(function(){return Cw})),n.d(e,"cv",(function(){return Vw})),n.d(e,"dv",(function(){return Sw})),n.d(e,"ev",(function(){return xw})),n.d(e,"fv",(function(){return Tw})),n.d(e,"gv",(function(){return Pw})),n.d(e,"hv",(function(){return Iw})),n.d(e,"iv",(function(){return Ew})),n.d(e,"jv",(function(){return Lw})),n.d(e,"kv",(function(){return Bw})),n.d(e,"lv",(function(){return Hw})),n.d(e,"mv",(function(){return Fw})),n.d(e,"nv",(function(){return Dw})),n.d(e,"ov",(function(){return Rw})),n.d(e,"pv",(function(){return Nw})),n.d(e,"qv",(function(){return $w})),n.d(e,"rv",(function(){return Uw})),n.d(e,"sv",(function(){return qw})),n.d(e,"tv",(function(){return Ww})),n.d(e,"uv",(function(){return Gw})),n.d(e,"vv",(function(){return Yw})),n.d(e,"wv",(function(){return Kw})),n.d(e,"xv",(function(){return Qw})),n.d(e,"yv",(function(){return Xw})),n.d(e,"zv",(function(){return Jw})),n.d(e,"Av",(function(){return Zw})),n.d(e,"Bv",(function(){return ty})),n.d(e,"Cv",(function(){return ey})),n.d(e,"Dv",(function(){return ny})),n.d(e,"Ev",(function(){return ry})),n.d(e,"Fv",(function(){return iy})),n.d(e,"Gv",(function(){return oy})),n.d(e,"Hv",(function(){return ay})),n.d(e,"Iv",(function(){return sy})),n.d(e,"Jv",(function(){return cy})),n.d(e,"Kv",(function(){return ly})),n.d(e,"Lv",(function(){return uy})),n.d(e,"Mv",(function(){return dy})),n.d(e,"Nv",(function(){return hy})),n.d(e,"Ov",(function(){return fy})),n.d(e,"Pv",(function(){return py})),n.d(e,"Qv",(function(){return my})),n.d(e,"Rv",(function(){return by})),n.d(e,"Sv",(function(){return gy})),n.d(e,"Tv",(function(){return vy})),n.d(e,"Uv",(function(){return wy})),n.d(e,"Vv",(function(){return yy})),n.d(e,"Wv",(function(){return ky})),n.d(e,"Xv",(function(){return _y})),n.d(e,"Yv",(function(){return Oy})),n.d(e,"Zv",(function(){return zy})),n.d(e,"aw",(function(){return Ay})),n.d(e,"bw",(function(){return jy})),n.d(e,"cw",(function(){return My})),n.d(e,"dw",(function(){return Cy})),n.d(e,"ew",(function(){return Vy})),n.d(e,"fw",(function(){return Sy})),n.d(e,"gw",(function(){return xy})),n.d(e,"hw",(function(){return Ty})),n.d(e,"iw",(function(){return Py})),n.d(e,"jw",(function(){return Iy})),n.d(e,"kw",(function(){return Ey})),n.d(e,"lw",(function(){return Ly})),n.d(e,"mw",(function(){return By})),n.d(e,"nw",(function(){return Hy})),n.d(e,"ow",(function(){return Fy})),n.d(e,"pw",(function(){return Dy})),n.d(e,"qw",(function(){return Ry})),n.d(e,"rw",(function(){return Ny})),n.d(e,"sw",(function(){return $y})),n.d(e,"tw",(function(){return Uy})),n.d(e,"uw",(function(){return qy})),n.d(e,"vw",(function(){return Wy})),n.d(e,"ww",(function(){return Gy})),n.d(e,"xw",(function(){return Yy})),n.d(e,"yw",(function(){return Ky})),n.d(e,"zw",(function(){return Qy})),n.d(e,"Aw",(function(){return Xy})),n.d(e,"Bw",(function(){return Jy})),n.d(e,"Cw",(function(){return Zy})),n.d(e,"Dw",(function(){return tk})),n.d(e,"Ew",(function(){return ek})),n.d(e,"Fw",(function(){return nk})),n.d(e,"Gw",(function(){return rk})),n.d(e,"Hw",(function(){return ik})),n.d(e,"Iw",(function(){return ok})),n.d(e,"Jw",(function(){return ak})),n.d(e,"Kw",(function(){return sk})),n.d(e,"Lw",(function(){return ck})),n.d(e,"Mw",(function(){return lk})),n.d(e,"Nw",(function(){return uk})),n.d(e,"Ow",(function(){return dk})),n.d(e,"Pw",(function(){return hk})),n.d(e,"Qw",(function(){return fk})),n.d(e,"Rw",(function(){return pk})),n.d(e,"Sw",(function(){return mk})),n.d(e,"Tw",(function(){return bk})),n.d(e,"Uw",(function(){return gk})),n.d(e,"Vw",(function(){return vk})),n.d(e,"Ww",(function(){return wk})),n.d(e,"Xw",(function(){return yk})),n.d(e,"Yw",(function(){return kk})),n.d(e,"Zw",(function(){return _k})),n.d(e,"ax",(function(){return Ok})),n.d(e,"bx",(function(){return zk})),n.d(e,"cx",(function(){return Ak})),n.d(e,"dx",(function(){return jk})),n.d(e,"ex",(function(){return Mk})),n.d(e,"fx",(function(){return Ck}));var r=n("2b0e"),i=n("b42e"),o=n("d82f"),a=n("fa73"),s=n("aa0d");function c(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function l(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?c(Object(n),!0).forEach((function(e){u(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):c(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function u(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var d=function(t,e){var n=Object(a["b"])(t),c="BIcon".concat(Object(a["e"])(t)),u="bi-".concat(n),d=n.replace(/-/g," "),h=Object(a["h"])(e||"");return r["default"].extend({name:c,functional:!0,props:Object(o["j"])(s["b"],["content"]),render:function(t,e){var n=e.data,r=e.props;return t(s["a"],Object(i["a"])({props:{title:d},attrs:{"aria-label":d}},n,{staticClass:u,props:l(l({},r),{},{content:h})}))}})},h=d("Blank",""),f=d("Alarm",'<path d="M8.5 5.5a.5.5 0 0 0-1 0v3.362l-1.429 2.38a.5.5 0 1 0 .858.515l1.5-2.5A.5.5 0 0 0 8.5 9V5.5z"/><path d="M6.5 0a.5.5 0 0 0 0 1H7v1.07a7.001 7.001 0 0 0-3.273 12.474l-.602.602a.5.5 0 0 0 .707.708l.746-.746A6.97 6.97 0 0 0 8 16a6.97 6.97 0 0 0 3.422-.892l.746.746a.5.5 0 0 0 .707-.708l-.601-.602A7.001 7.001 0 0 0 9 2.07V1h.5a.5.5 0 0 0 0-1h-3zm1.038 3.018a6.093 6.093 0 0 1 .924 0 6 6 0 1 1-.924 0zM0 3.5c0 .753.333 1.429.86 1.887A8.035 8.035 0 0 1 4.387 1.86 2.5 2.5 0 0 0 0 3.5zM13.5 1c-.753 0-1.429.333-1.887.86a8.035 8.035 0 0 1 3.527 3.527A2.5 2.5 0 0 0 13.5 1z"/>'),p=d("AlarmFill",'<path d="M6 .5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1H9v1.07a7.001 7.001 0 0 1 3.274 12.474l.601.602a.5.5 0 0 1-.707.708l-.746-.746A6.97 6.97 0 0 1 8 16a6.97 6.97 0 0 1-3.422-.892l-.746.746a.5.5 0 0 1-.707-.708l.602-.602A7.001 7.001 0 0 1 7 2.07V1h-.5A.5.5 0 0 1 6 .5zm2.5 5a.5.5 0 0 0-1 0v3.362l-1.429 2.38a.5.5 0 1 0 .858.515l1.5-2.5A.5.5 0 0 0 8.5 9V5.5zM.86 5.387A2.5 2.5 0 1 1 4.387 1.86 8.035 8.035 0 0 0 .86 5.387zM11.613 1.86a2.5 2.5 0 1 1 3.527 3.527 8.035 8.035 0 0 0-3.527-3.527z"/>'),m=d("AlignBottom",'<rect width="4" height="12" x="6" y="1" rx="1"/><path d="M1.5 14a.5.5 0 0 0 0 1v-1zm13 1a.5.5 0 0 0 0-1v1zm-13 0h13v-1h-13v1z"/>'),b=d("AlignCenter",'<path d="M8 1a.5.5 0 0 1 .5.5V6h-1V1.5A.5.5 0 0 1 8 1zm0 14a.5.5 0 0 1-.5-.5V10h1v4.5a.5.5 0 0 1-.5.5zM2 7a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V7z"/>'),g=d("AlignEnd",'<path fill-rule="evenodd" d="M14.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5z"/><path d="M13 7a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V7z"/>'),v=d("AlignMiddle",'<path d="M6 13a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v10zM1 8a.5.5 0 0 0 .5.5H6v-1H1.5A.5.5 0 0 0 1 8zm14 0a.5.5 0 0 1-.5.5H10v-1h4.5a.5.5 0 0 1 .5.5z"/>'),w=d("AlignStart",'<path fill-rule="evenodd" d="M1.5 1a.5.5 0 0 1 .5.5v13a.5.5 0 0 1-1 0v-13a.5.5 0 0 1 .5-.5z"/><path d="M3 7a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V7z"/>'),y=d("AlignTop",'<rect width="4" height="12" rx="1" transform="matrix(1 0 0 -1 6 15)"/><path d="M1.5 2a.5.5 0 0 1 0-1v1zm13-1a.5.5 0 0 1 0 1V1zm-13 0h13v1h-13V1z"/>'),k=d("Alt",'<path d="M1 13.5a.5.5 0 0 0 .5.5h3.797a.5.5 0 0 0 .439-.26L11 3h3.5a.5.5 0 0 0 0-1h-3.797a.5.5 0 0 0-.439.26L5 13H1.5a.5.5 0 0 0-.5.5zm10 0a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 0-1h-3a.5.5 0 0 0-.5.5z"/>'),_=d("App",'<path d="M11 2a3 3 0 0 1 3 3v6a3 3 0 0 1-3 3H5a3 3 0 0 1-3-3V5a3 3 0 0 1 3-3h6zM5 1a4 4 0 0 0-4 4v6a4 4 0 0 0 4 4h6a4 4 0 0 0 4-4V5a4 4 0 0 0-4-4H5z"/>'),O=d("AppIndicator",'<path d="M5.5 2A3.5 3.5 0 0 0 2 5.5v5A3.5 3.5 0 0 0 5.5 14h5a3.5 3.5 0 0 0 3.5-3.5V8a.5.5 0 0 1 1 0v2.5a4.5 4.5 0 0 1-4.5 4.5h-5A4.5 4.5 0 0 1 1 10.5v-5A4.5 4.5 0 0 1 5.5 1H8a.5.5 0 0 1 0 1H5.5z"/><path d="M16 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/>'),z=d("Archive",'<path d="M0 2a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v7.5a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 12.5V5a1 1 0 0 1-1-1V2zm2 3v7.5A1.5 1.5 0 0 0 3.5 14h9a1.5 1.5 0 0 0 1.5-1.5V5H2zm13-3H1v2h14V2zM5 7.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>'),A=d("ArchiveFill",'<path d="M12.643 15C13.979 15 15 13.845 15 12.5V5H1v7.5C1 13.845 2.021 15 3.357 15h9.286zM5.5 7h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zM.8 1a.8.8 0 0 0-.8.8V3a.8.8 0 0 0 .8.8h14.4A.8.8 0 0 0 16 3V1.8a.8.8 0 0 0-.8-.8H.8z"/>'),j=d("Arrow90degDown",'<path fill-rule="evenodd" d="M4.854 14.854a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 .708-.708L4 13.293V3.5A2.5 2.5 0 0 1 6.5 1h8a.5.5 0 0 1 0 1h-8A1.5 1.5 0 0 0 5 3.5v9.793l3.146-3.147a.5.5 0 0 1 .708.708l-4 4z"/>'),M=d("Arrow90degLeft",'<path fill-rule="evenodd" d="M1.146 4.854a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 4H12.5A2.5 2.5 0 0 1 15 6.5v8a.5.5 0 0 1-1 0v-8A1.5 1.5 0 0 0 12.5 5H2.707l3.147 3.146a.5.5 0 1 1-.708.708l-4-4z"/>'),C=d("Arrow90degRight",'<path fill-rule="evenodd" d="M14.854 4.854a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 4H3.5A2.5 2.5 0 0 0 1 6.5v8a.5.5 0 0 0 1 0v-8A1.5 1.5 0 0 1 3.5 5h9.793l-3.147 3.146a.5.5 0 0 0 .708.708l4-4z"/>'),V=d("Arrow90degUp",'<path fill-rule="evenodd" d="M4.854 1.146a.5.5 0 0 0-.708 0l-4 4a.5.5 0 1 0 .708.708L4 2.707V12.5A2.5 2.5 0 0 0 6.5 15h8a.5.5 0 0 0 0-1h-8A1.5 1.5 0 0 1 5 12.5V2.707l3.146 3.147a.5.5 0 1 0 .708-.708l-4-4z"/>'),S=d("ArrowBarDown",'<path fill-rule="evenodd" d="M1 3.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13a.5.5 0 0 1-.5-.5zM8 6a.5.5 0 0 1 .5.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-3-3a.5.5 0 0 1 .708-.708L7.5 12.293V6.5A.5.5 0 0 1 8 6z"/>'),x=d("ArrowBarLeft",'<path fill-rule="evenodd" d="M12.5 15a.5.5 0 0 1-.5-.5v-13a.5.5 0 0 1 1 0v13a.5.5 0 0 1-.5.5zM10 8a.5.5 0 0 1-.5.5H3.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L3.707 7.5H9.5a.5.5 0 0 1 .5.5z"/>'),T=d("ArrowBarRight",'<path fill-rule="evenodd" d="M6 8a.5.5 0 0 0 .5.5h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 0 0-.708.708L12.293 7.5H6.5A.5.5 0 0 0 6 8zm-2.5 7a.5.5 0 0 1-.5-.5v-13a.5.5 0 0 1 1 0v13a.5.5 0 0 1-.5.5z"/>'),P=d("ArrowBarUp",'<path fill-rule="evenodd" d="M8 10a.5.5 0 0 0 .5-.5V3.707l2.146 2.147a.5.5 0 0 0 .708-.708l-3-3a.5.5 0 0 0-.708 0l-3 3a.5.5 0 1 0 .708.708L7.5 3.707V9.5a.5.5 0 0 0 .5.5zm-7 2.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13a.5.5 0 0 1-.5-.5z"/>'),I=d("ArrowClockwise",'<path fill-rule="evenodd" d="M8 3a5 5 0 1 0 4.546 2.914.5.5 0 0 1 .908-.417A6 6 0 1 1 8 2v1z"/><path d="M8 4.466V.534a.25.25 0 0 1 .41-.192l2.36 1.966c.12.1.12.284 0 .384L8.41 4.658A.25.25 0 0 1 8 4.466z"/>'),E=d("ArrowCounterclockwise",'<path fill-rule="evenodd" d="M8 3a5 5 0 1 1-4.546 2.914.5.5 0 0 0-.908-.417A6 6 0 1 0 8 2v1z"/><path d="M8 4.466V.534a.25.25 0 0 0-.41-.192L5.23 2.308a.25.25 0 0 0 0 .384l2.36 1.966A.25.25 0 0 0 8 4.466z"/>'),L=d("ArrowDown",'<path fill-rule="evenodd" d="M8 1a.5.5 0 0 1 .5.5v11.793l3.146-3.147a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 .708-.708L7.5 13.293V1.5A.5.5 0 0 1 8 1z"/>'),B=d("ArrowDownCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v5.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V4.5z"/>'),H=d("ArrowDownCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v5.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V4.5z"/>'),F=d("ArrowDownLeft",'<path fill-rule="evenodd" d="M2 13.5a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 0-1H3.707L13.854 2.854a.5.5 0 0 0-.708-.708L3 12.293V7.5a.5.5 0 0 0-1 0v6z"/>'),D=d("ArrowDownLeftCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904-2.854a.5.5 0 1 1 .707.708L6.707 9.95h2.768a.5.5 0 1 1 0 1H5.5a.5.5 0 0 1-.5-.5V6.475a.5.5 0 1 1 1 0v2.768l4.096-4.097z"/>'),R=d("ArrowDownLeftCircleFill",'<path d="M16 8A8 8 0 1 0 0 8a8 8 0 0 0 16 0zm-5.904-2.803a.5.5 0 1 1 .707.707L6.707 10h2.768a.5.5 0 0 1 0 1H5.5a.5.5 0 0 1-.5-.5V6.525a.5.5 0 0 1 1 0v2.768l4.096-4.096z"/>'),N=d("ArrowDownLeftSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904-2.854a.5.5 0 1 1 .707.708L6.707 9.95h2.768a.5.5 0 1 1 0 1H5.5a.5.5 0 0 1-.5-.5V6.475a.5.5 0 1 1 1 0v2.768l4.096-4.097z"/>'),$=d("ArrowDownLeftSquareFill",'<path d="M2 16a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2zm8.096-10.803L6 9.293V6.525a.5.5 0 0 0-1 0V10.5a.5.5 0 0 0 .5.5h3.975a.5.5 0 0 0 0-1H6.707l4.096-4.096a.5.5 0 1 0-.707-.707z"/>'),U=d("ArrowDownRight",'<path fill-rule="evenodd" d="M14 13.5a.5.5 0 0 1-.5.5h-6a.5.5 0 0 1 0-1h4.793L2.146 2.854a.5.5 0 1 1 .708-.708L13 12.293V7.5a.5.5 0 0 1 1 0v6z"/>'),q=d("ArrowDownRightCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 5.146a.5.5 0 1 0-.708.708L9.243 9.95H6.475a.5.5 0 1 0 0 1h3.975a.5.5 0 0 0 .5-.5V6.475a.5.5 0 1 0-1 0v2.768L5.854 5.146z"/>'),W=d("ArrowDownRightCircleFill",'<path d="M0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8zm5.904-2.803a.5.5 0 1 0-.707.707L9.293 10H6.525a.5.5 0 0 0 0 1H10.5a.5.5 0 0 0 .5-.5V6.525a.5.5 0 0 0-1 0v2.768L5.904 5.197z"/>'),G=d("ArrowDownRightSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 5.146a.5.5 0 1 0-.708.708L9.243 9.95H6.475a.5.5 0 1 0 0 1h3.975a.5.5 0 0 0 .5-.5V6.475a.5.5 0 1 0-1 0v2.768L5.854 5.146z"/>'),Y=d("ArrowDownRightSquareFill",'<path d="M14 16a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12zM5.904 5.197L10 9.293V6.525a.5.5 0 0 1 1 0V10.5a.5.5 0 0 1-.5.5H6.525a.5.5 0 0 1 0-1h2.768L5.197 5.904a.5.5 0 0 1 .707-.707z"/>'),K=d("ArrowDownShort",'<path fill-rule="evenodd" d="M8 4a.5.5 0 0 1 .5.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-3-3a.5.5 0 1 1 .708-.708L7.5 10.293V4.5A.5.5 0 0 1 8 4z"/>'),Q=d("ArrowDownSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v5.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V4.5z"/>'),X=d("ArrowDownSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm6.5 4.5v5.793l2.146-2.147a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-3-3a.5.5 0 1 1 .708-.708L7.5 10.293V4.5a.5.5 0 0 1 1 0z"/>'),J=d("ArrowDownUp",'<path fill-rule="evenodd" d="M11.5 15a.5.5 0 0 0 .5-.5V2.707l3.146 3.147a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 1 0 .708.708L11 2.707V14.5a.5.5 0 0 0 .5.5zm-7-14a.5.5 0 0 1 .5.5v11.793l3.146-3.147a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 .708-.708L4 13.293V1.5a.5.5 0 0 1 .5-.5z"/>'),Z=d("ArrowLeft",'<path fill-rule="evenodd" d="M15 8a.5.5 0 0 0-.5-.5H2.707l3.147-3.146a.5.5 0 1 0-.708-.708l-4 4a.5.5 0 0 0 0 .708l4 4a.5.5 0 0 0 .708-.708L2.707 8.5H14.5A.5.5 0 0 0 15 8z"/>'),tt=d("ArrowLeftCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.5-.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5z"/>'),et=d("ArrowLeftCircleFill",'<path d="M8 0a8 8 0 1 0 0 16A8 8 0 0 0 8 0zm3.5 7.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5z"/>'),nt=d("ArrowLeftRight",'<path fill-rule="evenodd" d="M1 11.5a.5.5 0 0 0 .5.5h11.793l-3.147 3.146a.5.5 0 0 0 .708.708l4-4a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 11H1.5a.5.5 0 0 0-.5.5zm14-7a.5.5 0 0 1-.5.5H2.707l3.147 3.146a.5.5 0 1 1-.708.708l-4-4a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 4H14.5a.5.5 0 0 1 .5.5z"/>'),rt=d("ArrowLeftShort",'<path fill-rule="evenodd" d="M12 8a.5.5 0 0 1-.5.5H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5a.5.5 0 0 1 .5.5z"/>'),it=d("ArrowLeftSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.5-.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H11.5z"/>'),ot=d("ArrowLeftSquareFill",'<path d="M16 14a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12zm-4.5-6.5H5.707l2.147-2.146a.5.5 0 1 0-.708-.708l-3 3a.5.5 0 0 0 0 .708l3 3a.5.5 0 0 0 .708-.708L5.707 8.5H11.5a.5.5 0 0 0 0-1z"/>'),at=d("ArrowRepeat",'<path d="M11.534 7h3.932a.25.25 0 0 1 .192.41l-1.966 2.36a.25.25 0 0 1-.384 0l-1.966-2.36a.25.25 0 0 1 .192-.41zm-11 2h3.932a.25.25 0 0 0 .192-.41L2.692 6.23a.25.25 0 0 0-.384 0L.342 8.59A.25.25 0 0 0 .534 9z"/><path fill-rule="evenodd" d="M8 3c-1.552 0-2.94.707-3.857 1.818a.5.5 0 1 1-.771-.636A6.002 6.002 0 0 1 13.917 7H12.9A5.002 5.002 0 0 0 8 3zM3.1 9a5.002 5.002 0 0 0 8.757 2.182.5.5 0 1 1 .771.636A6.002 6.002 0 0 1 2.083 9H3.1z"/>'),st=d("ArrowReturnLeft",'<path fill-rule="evenodd" d="M14.5 1.5a.5.5 0 0 1 .5.5v4.8a2.5 2.5 0 0 1-2.5 2.5H2.707l3.347 3.346a.5.5 0 0 1-.708.708l-4.2-4.2a.5.5 0 0 1 0-.708l4-4a.5.5 0 1 1 .708.708L2.707 8.3H12.5A1.5 1.5 0 0 0 14 6.8V2a.5.5 0 0 1 .5-.5z"/>'),ct=d("ArrowReturnRight",'<path fill-rule="evenodd" d="M1.5 1.5A.5.5 0 0 0 1 2v4.8a2.5 2.5 0 0 0 2.5 2.5h9.793l-3.347 3.346a.5.5 0 0 0 .708.708l4.2-4.2a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708.708L13.293 8.3H3.5A1.5 1.5 0 0 1 2 6.8V2a.5.5 0 0 0-.5-.5z"/>'),lt=d("ArrowRight",'<path fill-rule="evenodd" d="M1 8a.5.5 0 0 1 .5-.5h11.793l-3.147-3.146a.5.5 0 0 1 .708-.708l4 4a.5.5 0 0 1 0 .708l-4 4a.5.5 0 0 1-.708-.708L13.293 8.5H1.5A.5.5 0 0 1 1 8z"/>'),ut=d("ArrowRightCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.5 7.5a.5.5 0 0 0 0 1h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H4.5z"/>'),dt=d("ArrowRightCircleFill",'<path d="M8 0a8 8 0 1 1 0 16A8 8 0 0 1 8 0zM4.5 7.5a.5.5 0 0 0 0 1h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H4.5z"/>'),ht=d("ArrowRightShort",'<path fill-rule="evenodd" d="M4 8a.5.5 0 0 1 .5-.5h5.793L8.146 5.354a.5.5 0 1 1 .708-.708l3 3a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708-.708L10.293 8.5H4.5A.5.5 0 0 1 4 8z"/>'),ft=d("ArrowRightSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.5 7.5a.5.5 0 0 0 0 1h5.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H4.5z"/>'),pt=d("ArrowRightSquareFill",'<path d="M0 14a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12zm4.5-6.5h5.793L8.146 5.354a.5.5 0 1 1 .708-.708l3 3a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708-.708L10.293 8.5H4.5a.5.5 0 0 1 0-1z"/>'),mt=d("ArrowUp",'<path fill-rule="evenodd" d="M8 15a.5.5 0 0 0 .5-.5V2.707l3.146 3.147a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 1 0 .708.708L7.5 2.707V14.5a.5.5 0 0 0 .5.5z"/>'),bt=d("ArrowUpCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-7.5 3.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11.5z"/>'),gt=d("ArrowUpCircleFill",'<path d="M16 8A8 8 0 1 0 0 8a8 8 0 0 0 16 0zm-7.5 3.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11.5z"/>'),vt=d("ArrowUpLeft",'<path fill-rule="evenodd" d="M2 2.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1H3.707l10.147 10.146a.5.5 0 0 1-.708.708L3 3.707V8.5a.5.5 0 0 1-1 0v-6z"/>'),wt=d("ArrowUpLeftCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904 2.803a.5.5 0 1 0 .707-.707L6.707 6h2.768a.5.5 0 1 0 0-1H5.5a.5.5 0 0 0-.5.5v3.975a.5.5 0 0 0 1 0V6.707l4.096 4.096z"/>'),yt=d("ArrowUpLeftCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904 2.803a.5.5 0 1 0 .707-.707L6.707 6h2.768a.5.5 0 1 0 0-1H5.5a.5.5 0 0 0-.5.5v3.975a.5.5 0 0 0 1 0V6.707l4.096 4.096z"/>'),kt=d("ArrowUpLeftSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-5.904 2.803a.5.5 0 1 0 .707-.707L6.707 6h2.768a.5.5 0 1 0 0-1H5.5a.5.5 0 0 0-.5.5v3.975a.5.5 0 0 0 1 0V6.707l4.096 4.096z"/>'),_t=d("ArrowUpLeftSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm8.096 10.803L6 6.707v2.768a.5.5 0 0 1-1 0V5.5a.5.5 0 0 1 .5-.5h3.975a.5.5 0 1 1 0 1H6.707l4.096 4.096a.5.5 0 1 1-.707.707z"/>'),Ot=d("ArrowUpRight",'<path fill-rule="evenodd" d="M14 2.5a.5.5 0 0 0-.5-.5h-6a.5.5 0 0 0 0 1h4.793L2.146 13.146a.5.5 0 0 0 .708.708L13 3.707V8.5a.5.5 0 0 0 1 0v-6z"/>'),zt=d("ArrowUpRightCircle",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 10.803a.5.5 0 1 1-.708-.707L9.243 6H6.475a.5.5 0 1 1 0-1h3.975a.5.5 0 0 1 .5.5v3.975a.5.5 0 1 1-1 0V6.707l-4.096 4.096z"/>'),At=d("ArrowUpRightCircleFill",'<path d="M0 8a8 8 0 1 0 16 0A8 8 0 0 0 0 8zm5.904 2.803a.5.5 0 1 1-.707-.707L9.293 6H6.525a.5.5 0 1 1 0-1H10.5a.5.5 0 0 1 .5.5v3.975a.5.5 0 0 1-1 0V6.707l-4.096 4.096z"/>'),jt=d("ArrowUpRightSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.854 10.803a.5.5 0 1 1-.708-.707L9.243 6H6.475a.5.5 0 1 1 0-1h3.975a.5.5 0 0 1 .5.5v3.975a.5.5 0 1 1-1 0V6.707l-4.096 4.096z"/>'),Mt=d("ArrowUpRightSquareFill",'<path d="M14 0a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12zM5.904 10.803L10 6.707v2.768a.5.5 0 0 0 1 0V5.5a.5.5 0 0 0-.5-.5H6.525a.5.5 0 1 0 0 1h2.768l-4.096 4.096a.5.5 0 0 0 .707.707z"/>'),Ct=d("ArrowUpShort",'<path fill-rule="evenodd" d="M8 12a.5.5 0 0 0 .5-.5V5.707l2.146 2.147a.5.5 0 0 0 .708-.708l-3-3a.5.5 0 0 0-.708 0l-3 3a.5.5 0 1 0 .708.708L7.5 5.707V11.5a.5.5 0 0 0 .5.5z"/>'),Vt=d("ArrowUpSquare",'<path fill-rule="evenodd" d="M1 8a7 7 0 1 0 14 0A7 7 0 0 0 1 8zm15 0A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-7.5 3.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11.5z"/>'),St=d("ArrowUpSquareFill",'<path d="M2 16a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2zm6.5-4.5V5.707l2.146 2.147a.5.5 0 0 0 .708-.708l-3-3a.5.5 0 0 0-.708 0l-3 3a.5.5 0 1 0 .708.708L7.5 5.707V11.5a.5.5 0 0 0 1 0z"/>'),xt=d("ArrowsAngleContract",'<path fill-rule="evenodd" d="M.172 15.828a.5.5 0 0 0 .707 0l4.096-4.096V14.5a.5.5 0 1 0 1 0v-3.975a.5.5 0 0 0-.5-.5H1.5a.5.5 0 0 0 0 1h2.768L.172 15.121a.5.5 0 0 0 0 .707zM15.828.172a.5.5 0 0 0-.707 0l-4.096 4.096V1.5a.5.5 0 1 0-1 0v3.975a.5.5 0 0 0 .5.5H14.5a.5.5 0 0 0 0-1h-2.768L15.828.879a.5.5 0 0 0 0-.707z"/>'),Tt=d("ArrowsAngleExpand",'<path fill-rule="evenodd" d="M5.828 10.172a.5.5 0 0 0-.707 0l-4.096 4.096V11.5a.5.5 0 0 0-1 0v3.975a.5.5 0 0 0 .5.5H4.5a.5.5 0 0 0 0-1H1.732l4.096-4.096a.5.5 0 0 0 0-.707zm4.344-4.344a.5.5 0 0 0 .707 0l4.096-4.096V4.5a.5.5 0 1 0 1 0V.525a.5.5 0 0 0-.5-.5H11.5a.5.5 0 0 0 0 1h2.768l-4.096 4.096a.5.5 0 0 0 0 .707z"/>'),Pt=d("ArrowsCollapse",'<path fill-rule="evenodd" d="M1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8zm7-8a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 4.293V.5A.5.5 0 0 1 8 0zm-.5 11.707l-1.146 1.147a.5.5 0 0 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 11.707V15.5a.5.5 0 0 1-1 0v-3.793z"/>'),It=d("ArrowsExpand",'<path fill-rule="evenodd" d="M1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8zM7.646.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 1.707V5.5a.5.5 0 0 1-1 0V1.707L6.354 2.854a.5.5 0 1 1-.708-.708l2-2zM8 10a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 .708-.708L7.5 14.293V10.5A.5.5 0 0 1 8 10z"/>'),Et=d("ArrowsFullscreen",'<path fill-rule="evenodd" d="M5.828 10.172a.5.5 0 0 0-.707 0l-4.096 4.096V11.5a.5.5 0 0 0-1 0v3.975a.5.5 0 0 0 .5.5H4.5a.5.5 0 0 0 0-1H1.732l4.096-4.096a.5.5 0 0 0 0-.707zm4.344 0a.5.5 0 0 1 .707 0l4.096 4.096V11.5a.5.5 0 1 1 1 0v3.975a.5.5 0 0 1-.5.5H11.5a.5.5 0 0 1 0-1h2.768l-4.096-4.096a.5.5 0 0 1 0-.707zm0-4.344a.5.5 0 0 0 .707 0l4.096-4.096V4.5a.5.5 0 1 0 1 0V.525a.5.5 0 0 0-.5-.5H11.5a.5.5 0 0 0 0 1h2.768l-4.096 4.096a.5.5 0 0 0 0 .707zm-4.344 0a.5.5 0 0 1-.707 0L1.025 1.732V4.5a.5.5 0 0 1-1 0V.525a.5.5 0 0 1 .5-.5H4.5a.5.5 0 0 1 0 1H1.732l4.096 4.096a.5.5 0 0 1 0 .707z"/>'),Lt=d("ArrowsMove",'<path fill-rule="evenodd" d="M7.646.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 1.707V5.5a.5.5 0 0 1-1 0V1.707L6.354 2.854a.5.5 0 1 1-.708-.708l2-2zM8 10a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 .708-.708L7.5 14.293V10.5A.5.5 0 0 1 8 10zM.146 8.354a.5.5 0 0 1 0-.708l2-2a.5.5 0 1 1 .708.708L1.707 7.5H5.5a.5.5 0 0 1 0 1H1.707l1.147 1.146a.5.5 0 0 1-.708.708l-2-2zM10 8a.5.5 0 0 1 .5-.5h3.793l-1.147-1.146a.5.5 0 0 1 .708-.708l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L14.293 8.5H10.5A.5.5 0 0 1 10 8z"/>'),Bt=d("AspectRatio",'<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5v-9zM1.5 3a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-13z"/><path d="M2 4.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1H3v2.5a.5.5 0 0 1-1 0v-3zm12 7a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1 0-1H13V8.5a.5.5 0 0 1 1 0v3z"/>'),Ht=d("AspectRatioFill",'<path d="M0 12.5v-9A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5zM2.5 4a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 1 0V5h2.5a.5.5 0 0 0 0-1h-3zm11 8a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-1 0V11h-2.5a.5.5 0 0 0 0 1h3z"/>'),Ft=d("Asterisk",'<path d="M8 0a1 1 0 0 1 1 1v5.268l4.562-2.634a1 1 0 1 1 1 1.732L10 8l4.562 2.634a1 1 0 1 1-1 1.732L9 9.732V15a1 1 0 1 1-2 0V9.732l-4.562 2.634a1 1 0 1 1-1-1.732L6 8 1.438 5.366a1 1 0 0 1 1-1.732L7 6.268V1a1 1 0 0 1 1-1z"/>'),Dt=d("At",'<path d="M13.106 7.222c0-2.967-2.249-5.032-5.482-5.032-3.35 0-5.646 2.318-5.646 5.702 0 3.493 2.235 5.708 5.762 5.708.862 0 1.689-.123 2.304-.335v-.862c-.43.199-1.354.328-2.29.328-2.926 0-4.813-1.88-4.813-4.798 0-2.844 1.921-4.881 4.594-4.881 2.735 0 4.608 1.688 4.608 4.156 0 1.682-.554 2.769-1.416 2.769-.492 0-.772-.28-.772-.76V5.206H8.923v.834h-.11c-.266-.595-.881-.964-1.6-.964-1.4 0-2.378 1.162-2.378 2.823 0 1.737.957 2.906 2.379 2.906.8 0 1.415-.39 1.709-1.087h.11c.081.67.703 1.148 1.503 1.148 1.572 0 2.57-1.415 2.57-3.643zm-7.177.704c0-1.197.54-1.907 1.456-1.907.93 0 1.524.738 1.524 1.907S8.308 9.84 7.371 9.84c-.895 0-1.442-.725-1.442-1.914z"/>'),Rt=d("Award",'<path d="M9.669.864L8 0 6.331.864l-1.858.282-.842 1.68-1.337 1.32L2.6 6l-.306 1.854 1.337 1.32.842 1.68 1.858.282L8 12l1.669-.864 1.858-.282.842-1.68 1.337-1.32L13.4 6l.306-1.854-1.337-1.32-.842-1.68L9.669.864zm1.196 1.193l.684 1.365 1.086 1.072L12.387 6l.248 1.506-1.086 1.072-.684 1.365-1.51.229L8 10.874l-1.355-.702-1.51-.229-.684-1.365-1.086-1.072L3.614 6l-.25-1.506 1.087-1.072.684-1.365 1.51-.229L8 1.126l1.356.702 1.509.229z"/><path d="M4 11.794V16l4-1 4 1v-4.206l-2.018.306L8 13.126 6.018 12.1 4 11.794z"/>'),Nt=d("AwardFill",'<path d="M8 0l1.669.864 1.858.282.842 1.68 1.337 1.32L13.4 6l.306 1.854-1.337 1.32-.842 1.68-1.858.282L8 12l-1.669-.864-1.858-.282-.842-1.68-1.337-1.32L2.6 6l-.306-1.854 1.337-1.32.842-1.68L6.331.864 8 0z"/><path d="M4 11.794V16l4-1 4 1v-4.206l-2.018.306L8 13.126 6.018 12.1 4 11.794z"/>'),$t=d("Back",'<path fill-rule="evenodd" d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H2z"/>'),Ut=d("Backspace",'<path d="M5.83 5.146a.5.5 0 0 0 0 .708L7.975 8l-2.147 2.146a.5.5 0 0 0 .707.708l2.147-2.147 2.146 2.147a.5.5 0 0 0 .707-.708L9.39 8l2.146-2.146a.5.5 0 0 0-.707-.708L8.683 7.293 6.536 5.146a.5.5 0 0 0-.707 0z"/><path d="M13.683 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-7.08a2 2 0 0 1-1.519-.698L.241 8.65a1 1 0 0 1 0-1.302L5.084 1.7A2 2 0 0 1 6.603 1h7.08zm-7.08 1a1 1 0 0 0-.76.35L1 8l4.844 5.65a1 1 0 0 0 .759.35h7.08a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1h-7.08z"/>'),qt=d("BackspaceFill",'<path d="M15.683 3a2 2 0 0 0-2-2h-7.08a2 2 0 0 0-1.519.698L.241 7.35a1 1 0 0 0 0 1.302l4.843 5.65A2 2 0 0 0 6.603 15h7.08a2 2 0 0 0 2-2V3zM5.829 5.854a.5.5 0 1 1 .707-.708l2.147 2.147 2.146-2.147a.5.5 0 1 1 .707.708L9.39 8l2.146 2.146a.5.5 0 0 1-.707.708L8.683 8.707l-2.147 2.147a.5.5 0 0 1-.707-.708L7.976 8 5.829 5.854z"/>'),Wt=d("BackspaceReverse",'<path d="M9.854 5.146a.5.5 0 0 1 0 .708L7.707 8l2.147 2.146a.5.5 0 0 1-.708.708L7 8.707l-2.146 2.147a.5.5 0 0 1-.708-.708L6.293 8 4.146 5.854a.5.5 0 1 1 .708-.708L7 7.293l2.146-2.147a.5.5 0 0 1 .708 0z"/><path d="M2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h7.08a2 2 0 0 0 1.519-.698l4.843-5.651a1 1 0 0 0 0-1.302L10.6 1.7A2 2 0 0 0 9.08 1H2zm7.08 1a1 1 0 0 1 .76.35L14.682 8l-4.844 5.65a1 1 0 0 1-.759.35H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h7.08z"/>'),Gt=d("BackspaceReverseFill",'<path d="M0 3a2 2 0 0 1 2-2h7.08a2 2 0 0 1 1.519.698l4.843 5.651a1 1 0 0 1 0 1.302L10.6 14.3a2 2 0 0 1-1.52.7H2a2 2 0 0 1-2-2V3zm9.854 2.854a.5.5 0 0 0-.708-.708L7 7.293 4.854 5.146a.5.5 0 1 0-.708.708L6.293 8l-2.147 2.146a.5.5 0 0 0 .708.708L7 8.707l2.146 2.147a.5.5 0 0 0 .708-.708L7.707 8l2.147-2.146z"/>'),Yt=d("Badge4k",'<path d="M4.807 5.001C4.021 6.298 3.203 7.6 2.5 8.917v.971h2.905V11h1.112V9.888h.733V8.93h-.733V5.001h-1.71zm-1.23 3.93v-.032a46.781 46.781 0 0 1 1.766-3.001h.062V8.93H3.577zm9.831-3.93h-1.306L9.835 7.687h-.057V5H8.59v6h1.187V9.075l.615-.699L12.072 11H13.5l-2.232-3.415 2.14-2.584z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>'),Kt=d("Badge4kFill",'<path d="M3.577 8.9v.03h1.828V5.898h-.062a46.781 46.781 0 0 0-1.766 3.001z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm2.372 3.715l.435-.714h1.71v3.93h.733v.957h-.733V11H5.405V9.888H2.5v-.971c.574-1.077 1.225-2.142 1.872-3.202zm7.73-.714h1.306l-2.14 2.584L13.5 11h-1.428l-1.679-2.624-.615.7V11H8.59V5.001h1.187v2.686h.057L12.102 5z"/>'),Qt=d("Badge8k",'<path d="M4.837 11.114c1.406 0 2.333-.725 2.333-1.766 0-.945-.712-1.38-1.256-1.49v-.053c.496-.15 1.02-.55 1.02-1.331 0-.914-.831-1.587-2.084-1.587-1.257 0-2.087.673-2.087 1.587 0 .773.51 1.177 1.02 1.331v.053c-.546.11-1.258.54-1.258 1.494 0 1.042.906 1.762 2.312 1.762zm.013-3.643c-.545 0-.95-.356-.95-.866s.405-.852.95-.852c.545 0 .945.343.945.852 0 .51-.4.866-.945.866zm0 2.786c-.65 0-1.142-.395-1.142-.984S4.2 8.28 4.85 8.28c.646 0 1.143.404 1.143.993s-.497.984-1.143.984zM13.408 5h-1.306L9.835 7.685h-.057V5H8.59v5.998h1.187V9.075l.615-.699 1.679 2.623H13.5l-2.232-3.414L13.408 5z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>'),Xt=d("Badge8kFill",'<path d="M3.9 6.605c0 .51.405.866.95.866.545 0 .945-.356.945-.866s-.4-.852-.945-.852c-.545 0-.95.343-.95.852zm-.192 2.668c0 .589.492.984 1.142.984.646 0 1.143-.395 1.143-.984S5.496 8.28 4.85 8.28c-.65 0-1.142.404-1.142.993z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm5.17 7.348c0 1.041-.927 1.766-2.333 1.766-1.406 0-2.312-.72-2.312-1.762 0-.954.712-1.384 1.257-1.494v-.053c-.51-.154-1.02-.558-1.02-1.331 0-.914.831-1.587 2.088-1.587 1.253 0 2.083.673 2.083 1.587 0 .782-.523 1.182-1.02 1.331v.053c.545.11 1.257.545 1.257 1.49zM12.102 5h1.306l-2.14 2.584 2.232 3.415h-1.428l-1.679-2.624-.615.699v1.925H8.59V5h1.187v2.685h.057L12.102 5z"/>'),Jt=d("BadgeAd",'<path d="M3.7 11l.47-1.542h2.004L6.644 11h1.261L5.901 5.001H4.513L2.5 11h1.2zm1.503-4.852l.734 2.426H4.416l.734-2.426h.053zm4.759.128c-1.059 0-1.753.765-1.753 2.043v.695c0 1.279.685 2.043 1.74 2.043.677 0 1.222-.33 1.367-.804h.057V11h1.138V4.685h-1.16v2.36h-.053c-.18-.475-.68-.77-1.336-.77zm.387.923c.58 0 1.002.44 1.002 1.138v.602c0 .76-.396 1.2-.984 1.2-.598 0-.972-.449-.972-1.248v-.453c0-.795.37-1.24.954-1.24z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>'),Zt=d("BadgeAdFill",'<path d="M11.35 8.337c0-.699-.42-1.138-1.001-1.138-.584 0-.954.444-.954 1.239v.453c0 .8.374 1.248.972 1.248.588 0 .984-.44.984-1.2v-.602zm-5.413.237l-.734-2.426H5.15l-.734 2.426h1.52z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm6.209 6.32c0-1.28.694-2.044 1.753-2.044.655 0 1.156.294 1.336.769h.053v-2.36h1.16V11h-1.138v-.747h-.057c-.145.474-.69.804-1.367.804-1.055 0-1.74-.764-1.74-2.043v-.695zm-4.04 1.138L3.7 11H2.5l2.013-5.999H5.9L7.905 11H6.644l-.47-1.542H4.17z"/>'),te=d("BadgeCc",'<path d="M3.708 7.755c0-1.111.488-1.753 1.319-1.753.681 0 1.138.47 1.186 1.107H7.36V7c-.052-1.186-1.024-2-2.342-2C3.414 5 2.5 6.05 2.5 7.751v.747c0 1.7.905 2.73 2.518 2.73 1.314 0 2.285-.792 2.342-1.939v-.114H6.213c-.048.615-.496 1.05-1.186 1.05-.84 0-1.319-.62-1.319-1.727v-.743zm6.14 0c0-1.111.488-1.753 1.318-1.753.682 0 1.139.47 1.187 1.107H13.5V7c-.053-1.186-1.024-2-2.342-2C9.554 5 8.64 6.05 8.64 7.751v.747c0 1.7.905 2.73 2.518 2.73 1.314 0 2.285-.792 2.342-1.939v-.114h-1.147c-.048.615-.497 1.05-1.187 1.05-.839 0-1.318-.62-1.318-1.727v-.743z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>'),ee=d("BadgeCcFill",'<path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm3.027 4.002c-.83 0-1.319.642-1.319 1.753v.743c0 1.107.48 1.727 1.319 1.727.69 0 1.138-.435 1.186-1.05H7.36v.114c-.057 1.147-1.028 1.938-2.342 1.938-1.613 0-2.518-1.028-2.518-2.729v-.747C2.5 6.051 3.414 5 5.018 5c1.318 0 2.29.813 2.342 2v.11H6.213c-.048-.638-.505-1.108-1.186-1.108zm6.14 0c-.831 0-1.319.642-1.319 1.753v.743c0 1.107.48 1.727 1.318 1.727.69 0 1.139-.435 1.187-1.05H13.5v.114c-.057 1.147-1.028 1.938-2.342 1.938-1.613 0-2.518-1.028-2.518-2.729v-.747c0-1.7.914-2.751 2.518-2.751 1.318 0 2.29.813 2.342 2v.11h-1.147c-.048-.638-.505-1.108-1.187-1.108z"/>'),ne=d("BadgeHd",'<path d="M7.396 11V5.001H6.209v2.44H3.687V5H2.5v6h1.187V8.43h2.522V11h1.187zM8.5 5.001V11h2.188c1.811 0 2.685-1.107 2.685-3.015 0-1.894-.86-2.984-2.684-2.984H8.5zm1.187.967h.843c1.112 0 1.622.686 1.622 2.04 0 1.353-.505 2.02-1.622 2.02h-.843v-4.06z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>'),re=d("BadgeHdFill",'<path d="M10.53 5.968h-.843v4.06h.843c1.117 0 1.622-.667 1.622-2.02 0-1.354-.51-2.04-1.622-2.04z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm5.396 3.001V11H6.209V8.43H3.687V11H2.5V5.001h1.187v2.44h2.522V5h1.187zM8.5 11V5.001h2.188c1.824 0 2.685 1.09 2.685 2.984C13.373 9.893 12.5 11 10.69 11H8.5z"/>'),ie=d("BadgeTm",'<path d="M5.295 11V5.995H7V5H2.403v.994h1.701V11h1.19zm3.397 0V7.01h.058l1.428 3.239h.773l1.42-3.24h.057V11H13.5V5.001h-1.2l-1.71 3.894h-.039l-1.71-3.894H7.634V11h1.06z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>'),oe=d("BadgeTmFill",'<path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm3.295 3.995V11H4.104V5.995h-1.7V5H7v.994H5.295zM8.692 7.01V11H7.633V5.001h1.209l1.71 3.894h.039l1.71-3.894H13.5V11h-1.072V7.01h-.057l-1.42 3.239h-.773L8.75 7.008h-.058z"/>'),ae=d("BadgeVo",'<path d="M4.508 11h1.429l1.99-5.999H6.61L5.277 9.708H5.22L3.875 5.001H2.5L4.508 11zM13.5 8.39v-.77c0-1.696-.962-2.733-2.566-2.733-1.604 0-2.571 1.029-2.571 2.734v.769c0 1.691.967 2.724 2.57 2.724 1.605 0 2.567-1.033 2.567-2.724zm-1.204-.778v.782c0 1.156-.571 1.732-1.362 1.732-.796 0-1.363-.576-1.363-1.732v-.782c0-1.156.567-1.736 1.363-1.736.79 0 1.362.58 1.362 1.736z"/><path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/>'),se=d("BadgeVoFill",'<path d="M12.296 8.394v-.782c0-1.156-.571-1.736-1.362-1.736-.796 0-1.363.58-1.363 1.736v.782c0 1.156.567 1.732 1.363 1.732.79 0 1.362-.576 1.362-1.732z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm11.5 5.62v.77c0 1.691-.962 2.724-2.566 2.724-1.604 0-2.571-1.033-2.571-2.724v-.77c0-1.704.967-2.733 2.57-2.733 1.605 0 2.567 1.037 2.567 2.734zM5.937 11H4.508L2.5 5.001h1.375L5.22 9.708h.057L6.61 5.001h1.318L5.937 11z"/>'),ce=d("Bag",'<path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>'),le=d("BagCheck",'<path fill-rule="evenodd" d="M10.854 8.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L7.5 10.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>'),ue=d("BagCheckFill",'<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zm-.646 5.354a.5.5 0 0 0-.708-.708L7.5 10.793 6.354 9.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/>'),de=d("BagDash",'<path fill-rule="evenodd" d="M5.5 10a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>'),he=d("BagDashFill",'<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zM6 9.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H6z"/>'),fe=d("BagFill",'<path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5z"/>'),pe=d("BagPlus",'<path fill-rule="evenodd" d="M8 7.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V12a.5.5 0 0 1-1 0v-1.5H6a.5.5 0 0 1 0-1h1.5V8a.5.5 0 0 1 .5-.5z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>'),me=d("BagPlusFill",'<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zM8.5 8a.5.5 0 0 0-1 0v1.5H6a.5.5 0 0 0 0 1h1.5V12a.5.5 0 0 0 1 0v-1.5H10a.5.5 0 0 0 0-1H8.5V8z"/>'),be=d("BagX",'<path fill-rule="evenodd" d="M6.146 8.146a.5.5 0 0 1 .708 0L8 9.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 10l1.147 1.146a.5.5 0 0 1-.708.708L8 10.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 10 6.146 8.854a.5.5 0 0 1 0-.708z"/><path d="M8 1a2.5 2.5 0 0 1 2.5 2.5V4h-5v-.5A2.5 2.5 0 0 1 8 1zm3.5 3v-.5a3.5 3.5 0 1 0-7 0V4H1v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4h-3.5zM2 5h12v9a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V5z"/>'),ge=d("BagXFill",'<path fill-rule="evenodd" d="M10.5 3.5a2.5 2.5 0 0 0-5 0V4h5v-.5zm1 0V4H15v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V4h3.5v-.5a3.5 3.5 0 1 1 7 0zM6.854 8.146a.5.5 0 1 0-.708.708L7.293 10l-1.147 1.146a.5.5 0 0 0 .708.708L8 10.707l1.146 1.147a.5.5 0 0 0 .708-.708L8.707 10l1.147-1.146a.5.5 0 0 0-.708-.708L8 9.293 6.854 8.146z"/>'),ve=d("BarChart",'<path d="M4 11H2v3h2v-3zm5-4H7v7h2V7zm5-5v12h-2V2h2zm-2-1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2zM6 7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V7zm-5 4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-3z"/>'),we=d("BarChartFill",'<path d="M1 11a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-3zm5-4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V7zm5-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V2z"/>'),ye=d("BarChartLine",'<path d="M11 2a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1v-3a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3h1V7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7h1V2zm1 12h2V2h-2v12zm-3 0V7H7v7h2zm-5 0v-3H2v3h2z"/>'),ke=d("BarChartLineFill",'<path d="M11 2a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1v-3a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3h1V7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7h1V2z"/>'),_e=d("BarChartSteps",'<path d="M.5 0a.5.5 0 0 1 .5.5v15a.5.5 0 0 1-1 0V.5A.5.5 0 0 1 .5 0zM2 1.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-4a.5.5 0 0 1-.5-.5v-1zm2 4a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zm2 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-6a.5.5 0 0 1-.5-.5v-1zm2 4a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1z"/>'),Oe=d("Basket",'<path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1v4.5a2.5 2.5 0 0 1-2.5 2.5h-9A2.5 2.5 0 0 1 1 13.5V9a1 1 0 0 1-1-1V7a1 1 0 0 1 1-1h1.217L5.07 1.243a.5.5 0 0 1 .686-.172zM2 9v4.5A1.5 1.5 0 0 0 3.5 15h9a1.5 1.5 0 0 0 1.5-1.5V9H2zM1 7v1h14V7H1zm3 3a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3A.5.5 0 0 1 4 10zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3A.5.5 0 0 1 6 10zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3A.5.5 0 0 1 8 10zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 1 .5-.5zm2 0a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 1 .5-.5z"/>'),ze=d("Basket2",'<path d="M4 10a1 1 0 0 1 2 0v2a1 1 0 0 1-2 0v-2zm3 0a1 1 0 0 1 2 0v2a1 1 0 0 1-2 0v-2zm3 0a1 1 0 1 1 2 0v2a1 1 0 0 1-2 0v-2z"/><path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-.623l-1.844 6.456a.75.75 0 0 1-.722.544H3.69a.75.75 0 0 1-.722-.544L1.123 8H.5a.5.5 0 0 1-.5-.5v-1A.5.5 0 0 1 .5 6h1.717L5.07 1.243a.5.5 0 0 1 .686-.172zM2.163 8l1.714 6h8.246l1.714-6H2.163z"/>'),Ae=d("Basket2Fill",'<path d="M5.929 1.757a.5.5 0 1 0-.858-.514L2.217 6H.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h.623l1.844 6.456A.75.75 0 0 0 3.69 15h8.622a.75.75 0 0 0 .722-.544L14.877 8h.623a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1.717L10.93 1.243a.5.5 0 1 0-.858.514L12.617 6H3.383L5.93 1.757zM4 10a1 1 0 0 1 2 0v2a1 1 0 1 1-2 0v-2zm3 0a1 1 0 0 1 2 0v2a1 1 0 1 1-2 0v-2zm4-1a1 1 0 0 1 1 1v2a1 1 0 1 1-2 0v-2a1 1 0 0 1 1-1z"/>'),je=d("Basket3",'<path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-1A.5.5 0 0 1 .5 6h1.717L5.07 1.243a.5.5 0 0 1 .686-.172zM3.394 15l-1.48-6h-.97l1.525 6.426a.75.75 0 0 0 .729.574h9.606a.75.75 0 0 0 .73-.574L15.056 9h-.972l-1.479 6h-9.21z"/>'),Me=d("Basket3Fill",'<path d="M5.757 1.071a.5.5 0 0 1 .172.686L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-1A.5.5 0 0 1 .5 6h1.717L5.07 1.243a.5.5 0 0 1 .686-.172zM2.468 15.426L.943 9h14.114l-1.525 6.426a.75.75 0 0 1-.729.574H3.197a.75.75 0 0 1-.73-.574z"/>'),Ce=d("BasketFill",'<path d="M5.071 1.243a.5.5 0 0 1 .858.514L3.383 6h9.234L10.07 1.757a.5.5 0 1 1 .858-.514L13.783 6H15.5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5H15v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V9H.5a.5.5 0 0 1-.5-.5v-2A.5.5 0 0 1 .5 6h1.717L5.07 1.243zM3.5 10.5a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3zm2.5 0a.5.5 0 1 0-1 0v3a.5.5 0 0 0 1 0v-3z"/>'),Ve=d("Battery",'<path d="M0 6a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V6zm2-1a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1H2zm14 3a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>'),Se=d("BatteryCharging",'<path d="M9.585 2.568a.5.5 0 0 1 .226.58L8.677 6.832h1.99a.5.5 0 0 1 .364.843l-5.334 5.667a.5.5 0 0 1-.842-.49L5.99 9.167H4a.5.5 0 0 1-.364-.843l5.333-5.667a.5.5 0 0 1 .616-.09z"/><path d="M2 4h4.332l-.94 1H2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h2.38l-.308 1H2a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2z"/><path d="M2 6h2.45L2.908 7.639A1.5 1.5 0 0 0 3.313 10H2V6zm8.595-2l-.308 1H12a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H9.276l-.942 1H12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-1.405z"/><path d="M12 10h-1.783l1.542-1.639c.097-.103.178-.218.241-.34V10zm0-3.354V6h-.646a1.5 1.5 0 0 1 .646.646zM16 8a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>'),xe=d("BatteryFull",'<path d="M2 6h10v4H2V6z"/><path d="M2 4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H2zm10 1a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h10zm4 3a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>'),Te=d("BatteryHalf",'<path d="M2 6h5v4H2V6z"/><path d="M2 4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H2zm10 1a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h10zm4 3a1.5 1.5 0 0 1-1.5 1.5v-3A1.5 1.5 0 0 1 16 8z"/>'),Pe=d("Bell",'<path d="M8 16a2 2 0 0 0 2-2H6a2 2 0 0 0 2 2zM8 1.918l-.797.161A4.002 4.002 0 0 0 4 6c0 .628-.134 2.197-.459 3.742-.16.767-.376 1.566-.663 2.258h10.244c-.287-.692-.502-1.49-.663-2.258C12.134 8.197 12 6.628 12 6a4.002 4.002 0 0 0-3.203-3.92L8 1.917zM14.22 12c.223.447.481.801.78 1H1c.299-.199.557-.553.78-1C2.68 10.2 3 6.88 3 6c0-2.42 1.72-4.44 4.005-4.901a1 1 0 1 1 1.99 0A5.002 5.002 0 0 1 13 6c0 .88.32 4.2 1.22 6z"/>'),Ie=d("BellFill",'<path d="M8 16a2 2 0 0 0 2-2H6a2 2 0 0 0 2 2zm.995-14.901a1 1 0 1 0-1.99 0A5.002 5.002 0 0 0 3 6c0 1.098-.5 6-2 7h14c-1.5-1-2-5.902-2-7 0-2.42-1.72-4.44-4.005-4.901z"/>'),Ee=d("Bezier",'<path fill-rule="evenodd" d="M0 10.5A1.5 1.5 0 0 1 1.5 9h1A1.5 1.5 0 0 1 4 10.5v1A1.5 1.5 0 0 1 2.5 13h-1A1.5 1.5 0 0 1 0 11.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm10.5.5A1.5 1.5 0 0 1 13.5 9h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM6 4.5A1.5 1.5 0 0 1 7.5 3h1A1.5 1.5 0 0 1 10 4.5v1A1.5 1.5 0 0 1 8.5 7h-1A1.5 1.5 0 0 1 6 5.5v-1zM7.5 4a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/><path d="M6 4.5H1.866a1 1 0 1 0 0 1h2.668A6.517 6.517 0 0 0 1.814 9H2.5c.123 0 .244.015.358.043a5.517 5.517 0 0 1 3.185-3.185A1.503 1.503 0 0 1 6 5.5v-1zm3.957 1.358A1.5 1.5 0 0 0 10 5.5v-1h4.134a1 1 0 1 1 0 1h-2.668a6.517 6.517 0 0 1 2.72 3.5H13.5c-.123 0-.243.015-.358.043a5.517 5.517 0 0 0-3.185-3.185z"/>'),Le=d("Bezier2",'<path fill-rule="evenodd" d="M1 2.5A1.5 1.5 0 0 1 2.5 1h1A1.5 1.5 0 0 1 5 2.5h4.134a1 1 0 1 1 0 1h-2.01c.18.18.34.381.484.605.638.992.892 2.354.892 3.895 0 1.993.257 3.092.713 3.7.356.476.895.721 1.787.784A1.5 1.5 0 0 1 12.5 11h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5H6.866a1 1 0 1 1 0-1h1.711a2.839 2.839 0 0 1-.165-.2C7.743 11.407 7.5 10.007 7.5 8c0-1.46-.246-2.597-.733-3.355-.39-.605-.952-1-1.767-1.112A1.5 1.5 0 0 1 3.5 5h-1A1.5 1.5 0 0 1 1 3.5v-1zM2.5 2a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm10 10a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>'),Be=d("Bicycle",'<path d="M4 4.5a.5.5 0 0 1 .5-.5H6a.5.5 0 0 1 0 1v.5h4.14l.386-1.158A.5.5 0 0 1 11 4h1a.5.5 0 0 1 0 1h-.64l-.311.935.807 1.29a3 3 0 1 1-.848.53l-.508-.812-2.076 3.322A.5.5 0 0 1 8 10.5H5.959a3 3 0 1 1-1.815-3.274L5 5.856V5h-.5a.5.5 0 0 1-.5-.5zm1.5 2.443l-.508.814c.5.444.85 1.054.967 1.743h1.139L5.5 6.943zM8 9.057L9.598 6.5H6.402L8 9.057zM4.937 9.5a1.997 1.997 0 0 0-.487-.877l-.548.877h1.035zM3.603 8.092A2 2 0 1 0 4.937 10.5H3a.5.5 0 0 1-.424-.765l1.027-1.643zm7.947.53a2 2 0 1 0 .848-.53l1.026 1.643a.5.5 0 1 1-.848.53L11.55 8.623z"/>'),He=d("Binoculars",'<path d="M3 2.5A1.5 1.5 0 0 1 4.5 1h1A1.5 1.5 0 0 1 7 2.5V5h2V2.5A1.5 1.5 0 0 1 10.5 1h1A1.5 1.5 0 0 1 13 2.5v2.382a.5.5 0 0 0 .276.447l.895.447A1.5 1.5 0 0 1 15 7.118V14.5a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 14.5v-3a.5.5 0 0 1 .146-.354l.854-.853V9.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v.793l.854.853A.5.5 0 0 1 7 11.5v3A1.5 1.5 0 0 1 5.5 16h-3A1.5 1.5 0 0 1 1 14.5V7.118a1.5 1.5 0 0 1 .83-1.342l.894-.447A.5.5 0 0 0 3 4.882V2.5zM4.5 2a.5.5 0 0 0-.5.5V3h2v-.5a.5.5 0 0 0-.5-.5h-1zM6 4H4v.882a1.5 1.5 0 0 1-.83 1.342l-.894.447A.5.5 0 0 0 2 7.118V13h4v-1.293l-.854-.853A.5.5 0 0 1 5 10.5v-1A1.5 1.5 0 0 1 6.5 8h3A1.5 1.5 0 0 1 11 9.5v1a.5.5 0 0 1-.146.354l-.854.853V13h4V7.118a.5.5 0 0 0-.276-.447l-.895-.447A1.5 1.5 0 0 1 12 4.882V4h-2v1.5a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5V4zm4-1h2v-.5a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5V3zm4 11h-4v.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5V14zm-8 0H2v.5a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5V14z"/>'),Fe=d("BinocularsFill",'<path d="M4.5 1A1.5 1.5 0 0 0 3 2.5V3h4v-.5A1.5 1.5 0 0 0 5.5 1h-1zM7 4v1h2V4h4v.882a.5.5 0 0 0 .276.447l.895.447A1.5 1.5 0 0 1 15 7.118V13H9v-1.5a.5.5 0 0 1 .146-.354l.854-.853V9.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v.793l.854.853A.5.5 0 0 1 7 11.5V13H1V7.118a1.5 1.5 0 0 1 .83-1.342l.894-.447A.5.5 0 0 0 3 4.882V4h4zM1 14v.5A1.5 1.5 0 0 0 2.5 16h3A1.5 1.5 0 0 0 7 14.5V14H1zm8 0v.5a1.5 1.5 0 0 0 1.5 1.5h3a1.5 1.5 0 0 0 1.5-1.5V14H9zm4-11H9v-.5A1.5 1.5 0 0 1 10.5 1h1A1.5 1.5 0 0 1 13 2.5V3z"/>'),De=d("BlockquoteLeft",'<path d="M2.5 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm5 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm0 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm-5 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm.79-5.373c.112-.078.26-.17.444-.275L3.524 6c-.122.074-.272.17-.452.287-.18.117-.35.26-.51.428a2.425 2.425 0 0 0-.398.562c-.11.207-.164.438-.164.692 0 .36.072.65.217.873.144.219.385.328.72.328.215 0 .383-.07.504-.211a.697.697 0 0 0 .188-.463c0-.23-.07-.404-.211-.521-.137-.121-.326-.182-.568-.182h-.282c.024-.203.065-.37.123-.498a1.38 1.38 0 0 1 .252-.37 1.94 1.94 0 0 1 .346-.298zm2.167 0c.113-.078.262-.17.445-.275L5.692 6c-.122.074-.272.17-.452.287-.18.117-.35.26-.51.428a2.425 2.425 0 0 0-.398.562c-.11.207-.164.438-.164.692 0 .36.072.65.217.873.144.219.385.328.72.328.215 0 .383-.07.504-.211a.697.697 0 0 0 .188-.463c0-.23-.07-.404-.211-.521-.137-.121-.326-.182-.568-.182h-.282a1.75 1.75 0 0 1 .118-.492c.058-.13.144-.254.257-.375a1.94 1.94 0 0 1 .346-.3z"/>'),Re=d("BlockquoteRight",'<path d="M2.5 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm0 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm0 3a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-6zm0 3a.5.5 0 0 0 0 1h11a.5.5 0 0 0 0-1h-11zm10.113-5.373a6.59 6.59 0 0 0-.445-.275l.21-.352c.122.074.272.17.452.287.18.117.35.26.51.428.156.164.289.351.398.562.11.207.164.438.164.692 0 .36-.072.65-.216.873-.145.219-.385.328-.721.328-.215 0-.383-.07-.504-.211a.697.697 0 0 1-.188-.463c0-.23.07-.404.211-.521.137-.121.326-.182.569-.182h.281a1.686 1.686 0 0 0-.123-.498 1.379 1.379 0 0 0-.252-.37 1.94 1.94 0 0 0-.346-.298zm-2.168 0A6.59 6.59 0 0 0 10 6.352L10.21 6c.122.074.272.17.452.287.18.117.35.26.51.428.156.164.289.351.398.562.11.207.164.438.164.692 0 .36-.072.65-.216.873-.145.219-.385.328-.721.328-.215 0-.383-.07-.504-.211a.697.697 0 0 1-.188-.463c0-.23.07-.404.211-.521.137-.121.327-.182.569-.182h.281a1.749 1.749 0 0 0-.117-.492 1.402 1.402 0 0 0-.258-.375 1.94 1.94 0 0 0-.346-.3z"/>'),Ne=d("Book",'<path d="M1 2.828c.885-.37 2.154-.769 3.388-.893 1.33-.134 2.458.063 3.112.752v9.746c-.935-.53-2.12-.603-3.213-.493-1.18.12-2.37.461-3.287.811V2.828zm7.5-.141c.654-.689 1.782-.886 3.112-.752 1.234.124 2.503.523 3.388.893v9.923c-.918-.35-2.107-.692-3.287-.81-1.094-.111-2.278-.039-3.213.492V2.687zM8 1.783C7.015.936 5.587.81 4.287.94c-1.514.153-3.042.672-3.994 1.105A.5.5 0 0 0 0 2.5v11a.5.5 0 0 0 .707.455c.882-.4 2.303-.881 3.68-1.02 1.409-.142 2.59.087 3.223.877a.5.5 0 0 0 .78 0c.633-.79 1.814-1.019 3.222-.877 1.378.139 2.8.62 3.681 1.02A.5.5 0 0 0 16 13.5v-11a.5.5 0 0 0-.293-.455c-.952-.433-2.48-.952-3.994-1.105C10.413.809 8.985.936 8 1.783z"/>'),$e=d("BookFill",'<path d="M8 1.783C7.015.936 5.587.81 4.287.94c-1.514.153-3.042.672-3.994 1.105A.5.5 0 0 0 0 2.5v11a.5.5 0 0 0 .707.455c.882-.4 2.303-.881 3.68-1.02 1.409-.142 2.59.087 3.223.877a.5.5 0 0 0 .78 0c.633-.79 1.814-1.019 3.222-.877 1.378.139 2.8.62 3.681 1.02A.5.5 0 0 0 16 13.5v-11a.5.5 0 0 0-.293-.455c-.952-.433-2.48-.952-3.994-1.105C10.413.809 8.985.936 8 1.783z"/>'),Ue=d("BookHalf",'<path d="M8.5 2.687c.654-.689 1.782-.886 3.112-.752 1.234.124 2.503.523 3.388.893v9.923c-.918-.35-2.107-.692-3.287-.81-1.094-.111-2.278-.039-3.213.492V2.687zM8 1.783C7.015.936 5.587.81 4.287.94c-1.514.153-3.042.672-3.994 1.105A.5.5 0 0 0 0 2.5v11a.5.5 0 0 0 .707.455c.882-.4 2.303-.881 3.68-1.02 1.409-.142 2.59.087 3.223.877a.5.5 0 0 0 .78 0c.633-.79 1.814-1.019 3.222-.877 1.378.139 2.8.62 3.681 1.02A.5.5 0 0 0 16 13.5v-11a.5.5 0 0 0-.293-.455c-.952-.433-2.48-.952-3.994-1.105C10.413.809 8.985.936 8 1.783z"/>'),qe=d("Bookmark",'<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>'),We=d("BookmarkCheck",'<path fill-rule="evenodd" d="M10.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>'),Ge=d("BookmarkCheckFill",'<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zm8.854-9.646a.5.5 0 0 0-.708-.708L7.5 7.793 6.354 6.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/>'),Ye=d("BookmarkDash",'<path fill-rule="evenodd" d="M5.5 6.5A.5.5 0 0 1 6 6h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>'),Ke=d("BookmarkDashFill",'<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zM6 6a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H6z"/>'),Qe=d("BookmarkFill",'<path d="M2 2v13.5a.5.5 0 0 0 .74.439L8 13.069l5.26 2.87A.5.5 0 0 0 14 15.5V2a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2z"/>'),Xe=d("BookmarkHeart",'<path fill-rule="evenodd" d="M8 4.41c1.387-1.425 4.854 1.07 0 4.277C3.146 5.48 6.613 2.986 8 4.412z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>'),Je=d("BookmarkHeartFill",'<path d="M2 15.5a.5.5 0 0 0 .74.439L8 13.069l5.26 2.87A.5.5 0 0 0 14 15.5V2a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v13.5zM8 4.41c1.387-1.425 4.854 1.07 0 4.277C3.146 5.48 6.613 2.986 8 4.412z"/>'),Ze=d("BookmarkPlus",'<path fill-rule="evenodd" d="M8 4a.5.5 0 0 1 .5.5V6H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V7H6a.5.5 0 0 1 0-1h1.5V4.5A.5.5 0 0 1 8 4z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>'),tn=d("BookmarkPlusFill",'<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zm6.5-11a.5.5 0 0 0-1 0V6H6a.5.5 0 0 0 0 1h1.5v1.5a.5.5 0 0 0 1 0V7H10a.5.5 0 0 0 0-1H8.5V4.5z"/>'),en=d("BookmarkStar",'<path d="M7.84 4.1a.178.178 0 0 1 .32 0l.634 1.285a.178.178 0 0 0 .134.098l1.42.206c.145.021.204.2.098.303L9.42 6.993a.178.178 0 0 0-.051.158l.242 1.414a.178.178 0 0 1-.258.187l-1.27-.668a.178.178 0 0 0-.165 0l-1.27.668a.178.178 0 0 1-.257-.187l.242-1.414a.178.178 0 0 0-.05-.158l-1.03-1.001a.178.178 0 0 1 .098-.303l1.42-.206a.178.178 0 0 0 .134-.098L7.84 4.1z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>'),nn=d("BookmarkStarFill",'<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zM8.16 4.1a.178.178 0 0 0-.32 0l-.634 1.285a.178.178 0 0 1-.134.098l-1.42.206a.178.178 0 0 0-.098.303L6.58 6.993c.042.041.061.1.051.158L6.39 8.565a.178.178 0 0 0 .258.187l1.27-.668a.178.178 0 0 1 .165 0l1.27.668a.178.178 0 0 0 .257-.187L9.368 7.15a.178.178 0 0 1 .05-.158l1.028-1.001a.178.178 0 0 0-.098-.303l-1.42-.206a.178.178 0 0 1-.134-.098L8.16 4.1z"/>'),rn=d("BookmarkX",'<path fill-rule="evenodd" d="M6.146 5.146a.5.5 0 0 1 .708 0L8 6.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 7l1.147 1.146a.5.5 0 0 1-.708.708L8 7.707 6.854 8.854a.5.5 0 1 1-.708-.708L7.293 7 6.146 5.854a.5.5 0 0 1 0-.708z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.777.416L8 13.101l-5.223 2.815A.5.5 0 0 1 2 15.5V2zm2-1a1 1 0 0 0-1 1v12.566l4.723-2.482a.5.5 0 0 1 .554 0L13 14.566V2a1 1 0 0 0-1-1H4z"/>'),on=d("BookmarkXFill",'<path fill-rule="evenodd" d="M2 15.5V2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v13.5a.5.5 0 0 1-.74.439L8 13.069l-5.26 2.87A.5.5 0 0 1 2 15.5zM6.854 5.146a.5.5 0 1 0-.708.708L7.293 7 6.146 8.146a.5.5 0 1 0 .708.708L8 7.707l1.146 1.147a.5.5 0 1 0 .708-.708L8.707 7l1.147-1.146a.5.5 0 0 0-.708-.708L8 6.293 6.854 5.146z"/>'),an=d("Bookmarks",'<path d="M2 4a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v11.5a.5.5 0 0 1-.777.416L7 13.101l-4.223 2.815A.5.5 0 0 1 2 15.5V4zm2-1a1 1 0 0 0-1 1v10.566l3.723-2.482a.5.5 0 0 1 .554 0L11 14.566V4a1 1 0 0 0-1-1H4z"/><path d="M4.268 1H12a1 1 0 0 1 1 1v11.768l.223.148A.5.5 0 0 0 14 13.5V2a2 2 0 0 0-2-2H6a2 2 0 0 0-1.732 1z"/>'),sn=d("BookmarksFill",'<path d="M2 4a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v11.5a.5.5 0 0 1-.777.416L7 13.101l-4.223 2.815A.5.5 0 0 1 2 15.5V4z"/><path d="M4.268 1A2 2 0 0 1 6 0h6a2 2 0 0 1 2 2v11.5a.5.5 0 0 1-.777.416L13 13.768V2a1 1 0 0 0-1-1H4.268z"/>'),cn=d("Bookshelf",'<path d="M2.5 0a.5.5 0 0 1 .5.5V2h10V.5a.5.5 0 0 1 1 0v15a.5.5 0 0 1-1 0V15H3v.5a.5.5 0 0 1-1 0V.5a.5.5 0 0 1 .5-.5zM3 14h10v-3H3v3zm0-4h10V7H3v3zm0-4h10V3H3v3z"/>'),ln=d("Bootstrap",'<path d="M5.062 12h3.475c1.804 0 2.888-.908 2.888-2.396 0-1.102-.761-1.916-1.904-2.034v-.1c.832-.14 1.482-.93 1.482-1.816 0-1.3-.955-2.11-2.542-2.11H5.062V12zm1.313-4.875V4.658h1.78c.973 0 1.542.457 1.542 1.237 0 .802-.604 1.23-1.764 1.23H6.375zm0 3.762V8.162h1.822c1.236 0 1.887.463 1.887 1.348 0 .896-.627 1.377-1.811 1.377H6.375z"/><path d="M0 4a4 4 0 0 1 4-4h8a4 4 0 0 1 4 4v8a4 4 0 0 1-4 4H4a4 4 0 0 1-4-4V4zm4-3a3 3 0 0 0-3 3v8a3 3 0 0 0 3 3h8a3 3 0 0 0 3-3V4a3 3 0 0 0-3-3H4z"/>'),un=d("BootstrapFill",'<path d="M6.375 7.125V4.658h1.78c.973 0 1.542.457 1.542 1.237 0 .802-.604 1.23-1.764 1.23H6.375zm0 3.762h1.898c1.184 0 1.81-.48 1.81-1.377 0-.885-.65-1.348-1.886-1.348H6.375v2.725z"/><path d="M4.002 0a4 4 0 0 0-4 4v8a4 4 0 0 0 4 4h8a4 4 0 0 0 4-4V4a4 4 0 0 0-4-4h-8zm1.06 12V3.545h3.399c1.587 0 2.543.809 2.543 2.11 0 .884-.65 1.675-1.483 1.816v.1c1.143.117 1.904.931 1.904 2.033 0 1.488-1.084 2.396-2.888 2.396H5.062z"/>'),dn=d("BootstrapReboot",'<path d="M1.161 8a6.84 6.84 0 1 0 6.842-6.84.58.58 0 0 1 0-1.16 8 8 0 1 1-6.556 3.412l-.663-.577a.58.58 0 0 1 .227-.997l2.52-.69a.58.58 0 0 1 .728.633l-.332 2.592a.58.58 0 0 1-.956.364l-.643-.56A6.812 6.812 0 0 0 1.16 8z"/><path d="M6.641 11.671V8.843h1.57l1.498 2.828h1.314L9.377 8.665c.897-.3 1.427-1.106 1.427-2.1 0-1.37-.943-2.246-2.456-2.246H5.5v7.352h1.141zm0-3.75V5.277h1.57c.881 0 1.416.499 1.416 1.32 0 .84-.504 1.324-1.386 1.324h-1.6z"/>'),hn=d("BorderStyle",'<path d="M1 3.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-1zm0 4a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-1zm0 4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm8 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-4 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm8 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-4-4a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-1z"/>'),fn=d("BorderWidth",'<path d="M0 3.5A.5.5 0 0 1 .5 3h15a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-2zm0 5A.5.5 0 0 1 .5 8h15a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-1zm0 4a.5.5 0 0 1 .5-.5h15a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5z"/>'),pn=d("BoundingBox",'<path d="M5 2V0H0v5h2v6H0v5h5v-2h6v2h5v-5h-2V5h2V0h-5v2H5zm6 1v2h2v6h-2v2H5v-2H3V5h2V3h6zm1-2h3v3h-3V1zm3 11v3h-3v-3h3zM4 15H1v-3h3v3zM1 4V1h3v3H1z"/>'),mn=d("BoundingBoxCircles",'<path d="M2 1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zM0 2a2 2 0 0 1 3.937-.5h8.126A2 2 0 1 1 14.5 3.937v8.126a2 2 0 1 1-2.437 2.437H3.937A2 2 0 1 1 1.5 12.063V3.937A2 2 0 0 1 0 2zm2.5 1.937v8.126c.703.18 1.256.734 1.437 1.437h8.126a2.004 2.004 0 0 1 1.437-1.437V3.937A2.004 2.004 0 0 1 12.063 2.5H3.937A2.004 2.004 0 0 1 2.5 3.937zM14 1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zM2 13a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm12 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>'),bn=d("Box",'<path d="M8.186 1.113a.5.5 0 0 0-.372 0L1.846 3.5 8 5.961 14.154 3.5 8.186 1.113zM15 4.239l-6.5 2.6v7.922l6.5-2.6V4.24zM7.5 14.762V6.838L1 4.239v7.923l6.5 2.6zM7.443.184a1.5 1.5 0 0 1 1.114 0l7.129 2.852A.5.5 0 0 1 16 3.5v8.662a1 1 0 0 1-.629.928l-7.185 2.874a.5.5 0 0 1-.372 0L.63 13.09a1 1 0 0 1-.63-.928V3.5a.5.5 0 0 1 .314-.464L7.443.184z"/>'),gn=d("BoxArrowDown",'<path fill-rule="evenodd" d="M3.5 10a.5.5 0 0 1-.5-.5v-8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 0 0 1h2A1.5 1.5 0 0 0 14 9.5v-8A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v8A1.5 1.5 0 0 0 3.5 11h2a.5.5 0 0 0 0-1h-2z"/><path fill-rule="evenodd" d="M7.646 15.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 14.293V5.5a.5.5 0 0 0-1 0v8.793l-2.146-2.147a.5.5 0 0 0-.708.708l3 3z"/>'),vn=d("BoxArrowDownLeft",'<path fill-rule="evenodd" d="M7.364 12.5a.5.5 0 0 0 .5.5H14.5a1.5 1.5 0 0 0 1.5-1.5v-10A1.5 1.5 0 0 0 14.5 0h-10A1.5 1.5 0 0 0 3 1.5v6.636a.5.5 0 1 0 1 0V1.5a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v10a.5.5 0 0 1-.5.5H7.864a.5.5 0 0 0-.5.5z"/><path fill-rule="evenodd" d="M0 15.5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 0-1H1.707l8.147-8.146a.5.5 0 0 0-.708-.708L1 14.293V10.5a.5.5 0 0 0-1 0v5z"/>'),wn=d("BoxArrowDownRight",'<path fill-rule="evenodd" d="M8.636 12.5a.5.5 0 0 1-.5.5H1.5A1.5 1.5 0 0 1 0 11.5v-10A1.5 1.5 0 0 1 1.5 0h10A1.5 1.5 0 0 1 13 1.5v6.636a.5.5 0 0 1-1 0V1.5a.5.5 0 0 0-.5-.5h-10a.5.5 0 0 0-.5.5v10a.5.5 0 0 0 .5.5h6.636a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M16 15.5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1 0-1h3.793L6.146 6.854a.5.5 0 1 1 .708-.708L15 14.293V10.5a.5.5 0 0 1 1 0v5z"/>'),yn=d("BoxArrowInDown",'<path fill-rule="evenodd" d="M3.5 6a.5.5 0 0 0-.5.5v8a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5v-8a.5.5 0 0 0-.5-.5h-2a.5.5 0 0 1 0-1h2A1.5 1.5 0 0 1 14 6.5v8a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 14.5v-8A1.5 1.5 0 0 1 3.5 5h2a.5.5 0 0 1 0 1h-2z"/><path fill-rule="evenodd" d="M7.646 11.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V1.5a.5.5 0 0 0-1 0v8.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3z"/>'),kn=d("BoxArrowInDownLeft",'<path fill-rule="evenodd" d="M9.636 2.5a.5.5 0 0 0-.5-.5H2.5A1.5 1.5 0 0 0 1 3.5v10A1.5 1.5 0 0 0 2.5 15h10a1.5 1.5 0 0 0 1.5-1.5V6.864a.5.5 0 0 0-1 0V13.5a.5.5 0 0 1-.5.5h-10a.5.5 0 0 1-.5-.5v-10a.5.5 0 0 1 .5-.5h6.636a.5.5 0 0 0 .5-.5z"/><path fill-rule="evenodd" d="M5 10.5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 0-1H6.707l8.147-8.146a.5.5 0 0 0-.708-.708L6 9.293V5.5a.5.5 0 0 0-1 0v5z"/>'),_n=d("BoxArrowInDownRight",'<path fill-rule="evenodd" d="M6.364 2.5a.5.5 0 0 1 .5-.5H13.5A1.5 1.5 0 0 1 15 3.5v10a1.5 1.5 0 0 1-1.5 1.5h-10A1.5 1.5 0 0 1 2 13.5V6.864a.5.5 0 1 1 1 0V13.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5v-10a.5.5 0 0 0-.5-.5H6.864a.5.5 0 0 1-.5-.5z"/><path fill-rule="evenodd" d="M11 10.5a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1 0-1h3.793L1.146 1.854a.5.5 0 1 1 .708-.708L10 9.293V5.5a.5.5 0 0 1 1 0v5z"/>'),On=d("BoxArrowInLeft",'<path fill-rule="evenodd" d="M10 3.5a.5.5 0 0 0-.5-.5h-8a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 1 1 0v2A1.5 1.5 0 0 1 9.5 14h-8A1.5 1.5 0 0 1 0 12.5v-9A1.5 1.5 0 0 1 1.5 2h8A1.5 1.5 0 0 1 11 3.5v2a.5.5 0 0 1-1 0v-2z"/><path fill-rule="evenodd" d="M4.146 8.354a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H14.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3z"/>'),zn=d("BoxArrowInRight",'<path fill-rule="evenodd" d="M6 3.5a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-8a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 0-1 0v2A1.5 1.5 0 0 0 6.5 14h8a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-8A1.5 1.5 0 0 0 5 3.5v2a.5.5 0 0 0 1 0v-2z"/><path fill-rule="evenodd" d="M11.854 8.354a.5.5 0 0 0 0-.708l-3-3a.5.5 0 1 0-.708.708L10.293 7.5H1.5a.5.5 0 0 0 0 1h8.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3z"/>'),An=d("BoxArrowInUp",'<path fill-rule="evenodd" d="M3.5 10a.5.5 0 0 1-.5-.5v-8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 0 0 1h2A1.5 1.5 0 0 0 14 9.5v-8A1.5 1.5 0 0 0 12.5 0h-9A1.5 1.5 0 0 0 2 1.5v8A1.5 1.5 0 0 0 3.5 11h2a.5.5 0 0 0 0-1h-2z"/><path fill-rule="evenodd" d="M7.646 4.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V14.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3z"/>'),jn=d("BoxArrowInUpLeft",'<path fill-rule="evenodd" d="M9.636 13.5a.5.5 0 0 1-.5.5H2.5A1.5 1.5 0 0 1 1 12.5v-10A1.5 1.5 0 0 1 2.5 1h10A1.5 1.5 0 0 1 14 2.5v6.636a.5.5 0 0 1-1 0V2.5a.5.5 0 0 0-.5-.5h-10a.5.5 0 0 0-.5.5v10a.5.5 0 0 0 .5.5h6.636a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M5 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1H6.707l8.147 8.146a.5.5 0 0 1-.708.708L6 6.707V10.5a.5.5 0 0 1-1 0v-5z"/>'),Mn=d("BoxArrowInUpRight",'<path fill-rule="evenodd" d="M6.364 13.5a.5.5 0 0 0 .5.5H13.5a1.5 1.5 0 0 0 1.5-1.5v-10A1.5 1.5 0 0 0 13.5 1h-10A1.5 1.5 0 0 0 2 2.5v6.636a.5.5 0 1 0 1 0V2.5a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v10a.5.5 0 0 1-.5.5H6.864a.5.5 0 0 0-.5.5z"/><path fill-rule="evenodd" d="M11 5.5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h3.793l-8.147 8.146a.5.5 0 0 0 .708.708L10 6.707V10.5a.5.5 0 0 0 1 0v-5z"/>'),Cn=d("BoxArrowLeft",'<path fill-rule="evenodd" d="M6 12.5a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-8a.5.5 0 0 0-.5.5v2a.5.5 0 0 1-1 0v-2A1.5 1.5 0 0 1 6.5 2h8A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-8A1.5 1.5 0 0 1 5 12.5v-2a.5.5 0 0 1 1 0v2z"/><path fill-rule="evenodd" d="M.146 8.354a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L1.707 7.5H10.5a.5.5 0 0 1 0 1H1.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3z"/>'),Vn=d("BoxArrowRight",'<path fill-rule="evenodd" d="M10 12.5a.5.5 0 0 1-.5.5h-8a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 .5.5v2a.5.5 0 0 0 1 0v-2A1.5 1.5 0 0 0 9.5 2h-8A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h8a1.5 1.5 0 0 0 1.5-1.5v-2a.5.5 0 0 0-1 0v2z"/><path fill-rule="evenodd" d="M15.854 8.354a.5.5 0 0 0 0-.708l-3-3a.5.5 0 0 0-.708.708L14.293 7.5H5.5a.5.5 0 0 0 0 1h8.793l-2.147 2.146a.5.5 0 0 0 .708.708l3-3z"/>'),Sn=d("BoxArrowUp",'<path fill-rule="evenodd" d="M3.5 6a.5.5 0 0 0-.5.5v8a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5v-8a.5.5 0 0 0-.5-.5h-2a.5.5 0 0 1 0-1h2A1.5 1.5 0 0 1 14 6.5v8a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 14.5v-8A1.5 1.5 0 0 1 3.5 5h2a.5.5 0 0 1 0 1h-2z"/><path fill-rule="evenodd" d="M7.646.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 1.707V10.5a.5.5 0 0 1-1 0V1.707L5.354 3.854a.5.5 0 1 1-.708-.708l3-3z"/>'),xn=d("BoxArrowUpLeft",'<path fill-rule="evenodd" d="M7.364 3.5a.5.5 0 0 1 .5-.5H14.5A1.5 1.5 0 0 1 16 4.5v10a1.5 1.5 0 0 1-1.5 1.5h-10A1.5 1.5 0 0 1 3 14.5V7.864a.5.5 0 1 1 1 0V14.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5v-10a.5.5 0 0 0-.5-.5H7.864a.5.5 0 0 1-.5-.5z"/><path fill-rule="evenodd" d="M0 .5A.5.5 0 0 1 .5 0h5a.5.5 0 0 1 0 1H1.707l8.147 8.146a.5.5 0 0 1-.708.708L1 1.707V5.5a.5.5 0 0 1-1 0v-5z"/>'),Tn=d("BoxArrowUpRight",'<path fill-rule="evenodd" d="M8.636 3.5a.5.5 0 0 0-.5-.5H1.5A1.5 1.5 0 0 0 0 4.5v10A1.5 1.5 0 0 0 1.5 16h10a1.5 1.5 0 0 0 1.5-1.5V7.864a.5.5 0 0 0-1 0V14.5a.5.5 0 0 1-.5.5h-10a.5.5 0 0 1-.5-.5v-10a.5.5 0 0 1 .5-.5h6.636a.5.5 0 0 0 .5-.5z"/><path fill-rule="evenodd" d="M16 .5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h3.793L6.146 9.146a.5.5 0 1 0 .708.708L15 1.707V5.5a.5.5 0 0 0 1 0v-5z"/>'),Pn=d("BoxSeam",'<path d="M8.186 1.113a.5.5 0 0 0-.372 0L1.846 3.5l2.404.961L10.404 2l-2.218-.887zm3.564 1.426L5.596 5 8 5.961 14.154 3.5l-2.404-.961zm3.25 1.7l-6.5 2.6v7.922l6.5-2.6V4.24zM7.5 14.762V6.838L1 4.239v7.923l6.5 2.6zM7.443.184a1.5 1.5 0 0 1 1.114 0l7.129 2.852A.5.5 0 0 1 16 3.5v8.662a1 1 0 0 1-.629.928l-7.185 2.874a.5.5 0 0 1-.372 0L.63 13.09a1 1 0 0 1-.63-.928V3.5a.5.5 0 0 1 .314-.464L7.443.184z"/>'),In=d("Braces",'<path d="M2.114 8.063V7.9c1.005-.102 1.497-.615 1.497-1.6V4.503c0-1.094.39-1.538 1.354-1.538h.273V2h-.376C3.25 2 2.49 2.759 2.49 4.352v1.524c0 1.094-.376 1.456-1.49 1.456v1.299c1.114 0 1.49.362 1.49 1.456v1.524c0 1.593.759 2.352 2.372 2.352h.376v-.964h-.273c-.964 0-1.354-.444-1.354-1.538V9.663c0-.984-.492-1.497-1.497-1.6zM13.886 7.9v.163c-1.005.103-1.497.616-1.497 1.6v1.798c0 1.094-.39 1.538-1.354 1.538h-.273v.964h.376c1.613 0 2.372-.759 2.372-2.352v-1.524c0-1.094.376-1.456 1.49-1.456V7.332c-1.114 0-1.49-.362-1.49-1.456V4.352C13.51 2.759 12.75 2 11.138 2h-.376v.964h.273c.964 0 1.354.444 1.354 1.538V6.3c0 .984.492 1.497 1.497 1.6z"/>'),En=d("Bricks",'<path d="M0 .5A.5.5 0 0 1 .5 0h15a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5H14v2h1.5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5H14v2h1.5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5H.5a.5.5 0 0 1-.5-.5v-3a.5.5 0 0 1 .5-.5H2v-2H.5a.5.5 0 0 1-.5-.5v-3A.5.5 0 0 1 .5 6H2V4H.5a.5.5 0 0 1-.5-.5v-3zM3 4v2h4.5V4H3zm5.5 0v2H13V4H8.5zM3 10v2h4.5v-2H3zm5.5 0v2H13v-2H8.5zM1 1v2h3.5V1H1zm4.5 0v2h5V1h-5zm6 0v2H15V1h-3.5zM1 7v2h3.5V7H1zm4.5 0v2h5V7h-5zm6 0v2H15V7h-3.5zM1 13v2h3.5v-2H1zm4.5 0v2h5v-2h-5zm6 0v2H15v-2h-3.5z"/>'),Ln=d("Briefcase",'<path d="M6.5 1A1.5 1.5 0 0 0 5 2.5V3H1.5A1.5 1.5 0 0 0 0 4.5v8A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-8A1.5 1.5 0 0 0 14.5 3H11v-.5A1.5 1.5 0 0 0 9.5 1h-3zm0 1h3a.5.5 0 0 1 .5.5V3H6v-.5a.5.5 0 0 1 .5-.5zm1.886 6.914L15 7.151V12.5a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5V7.15l6.614 1.764a1.5 1.5 0 0 0 .772 0zM1.5 4h13a.5.5 0 0 1 .5.5v1.616L8.129 7.948a.5.5 0 0 1-.258 0L1 6.116V4.5a.5.5 0 0 1 .5-.5z"/>'),Bn=d("BriefcaseFill",'<path d="M6.5 1A1.5 1.5 0 0 0 5 2.5V3H1.5A1.5 1.5 0 0 0 0 4.5v1.384l7.614 2.03a1.5 1.5 0 0 0 .772 0L16 5.884V4.5A1.5 1.5 0 0 0 14.5 3H11v-.5A1.5 1.5 0 0 0 9.5 1h-3zm0 1h3a.5.5 0 0 1 .5.5V3H6v-.5a.5.5 0 0 1 .5-.5z"/><path d="M0 12.5A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5V6.85L8.129 8.947a.5.5 0 0 1-.258 0L0 6.85v5.65z"/>'),Hn=d("BrightnessAltHigh",'<path d="M8 3a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 3zm8 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zm-13.5.5a.5.5 0 0 0 0-1h-2a.5.5 0 0 0 0 1h2zm11.157-6.157a.5.5 0 0 1 0 .707l-1.414 1.414a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm-9.9 2.121a.5.5 0 0 0 .707-.707L3.05 5.343a.5.5 0 1 0-.707.707l1.414 1.414zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4zm0 1a3 3 0 0 1 2.959 2.5H5.04A3 3 0 0 1 8 8z"/>'),Fn=d("BrightnessAltHighFill",'<path d="M8 3a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 3zm8 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zm-13.5.5a.5.5 0 0 0 0-1h-2a.5.5 0 0 0 0 1h2zm11.157-6.157a.5.5 0 0 1 0 .707l-1.414 1.414a.5.5 0 1 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm-9.9 2.121a.5.5 0 0 0 .707-.707L3.05 5.343a.5.5 0 1 0-.707.707l1.414 1.414zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4z"/>'),Dn=d("BrightnessAltLow",'<path d="M8.5 5.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5 6a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM2 11a.5.5 0 1 0 1 0 .5.5 0 0 0-1 0zm10.243-3.536a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-8.486-.707a.5.5 0 1 0 .707.707.5.5 0 0 0-.707-.707zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4zm0 1a3 3 0 0 1 2.959 2.5H5.04A3 3 0 0 1 8 8z"/>'),Rn=d("BrightnessAltLowFill",'<path d="M8.5 5.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5 6a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM2 11a.5.5 0 1 0 1 0 .5.5 0 0 0-1 0zm10.243-3.536a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-8.486-.707a.5.5 0 1 0 .707.707.5.5 0 0 0-.707-.707zM8 7a4 4 0 0 0-4 4 .5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5 4 4 0 0 0-4-4z"/>'),Nn=d("BrightnessHigh",'<path d="M8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6zm0 1a4 4 0 1 0 0-8 4 4 0 0 0 0 8zM8 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 0zm0 13a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 13zm8-5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zM3 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2A.5.5 0 0 1 3 8zm10.657-5.657a.5.5 0 0 1 0 .707l-1.414 1.415a.5.5 0 1 1-.707-.708l1.414-1.414a.5.5 0 0 1 .707 0zm-9.193 9.193a.5.5 0 0 1 0 .707L3.05 13.657a.5.5 0 0 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm9.193 2.121a.5.5 0 0 1-.707 0l-1.414-1.414a.5.5 0 0 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .707zM4.464 4.465a.5.5 0 0 1-.707 0L2.343 3.05a.5.5 0 1 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .708z"/>'),$n=d("BrightnessHighFill",'<path d="M12 8a4 4 0 1 1-8 0 4 4 0 0 1 8 0zM8 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 0zm0 13a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 13zm8-5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zM3 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2A.5.5 0 0 1 3 8zm10.657-5.657a.5.5 0 0 1 0 .707l-1.414 1.415a.5.5 0 1 1-.707-.708l1.414-1.414a.5.5 0 0 1 .707 0zm-9.193 9.193a.5.5 0 0 1 0 .707L3.05 13.657a.5.5 0 0 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm9.193 2.121a.5.5 0 0 1-.707 0l-1.414-1.414a.5.5 0 0 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .707zM4.464 4.465a.5.5 0 0 1-.707 0L2.343 3.05a.5.5 0 1 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .708z"/>'),Un=d("BrightnessLow",'<path d="M8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6zm0 1a4 4 0 1 0 0-8 4 4 0 0 0 0 8zm.5-9.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm0 11a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5-5a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm-11 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm9.743-4.036a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-7.779 7.779a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm7.072 0a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707zM3.757 4.464a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707z"/>'),qn=d("BrightnessLowFill",'<path d="M12 8a4 4 0 1 1-8 0 4 4 0 0 1 8 0zM8.5 2.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm0 11a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm5-5a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm-11 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm9.743-4.036a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm-7.779 7.779a.5.5 0 1 1-.707-.707.5.5 0 0 1 .707.707zm7.072 0a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707zM3.757 4.464a.5.5 0 1 1 .707-.707.5.5 0 0 1-.707.707z"/>'),Wn=d("Broadcast",'<path d="M3.05 3.05a7 7 0 0 0 0 9.9.5.5 0 0 1-.707.707 8 8 0 0 1 0-11.314.5.5 0 0 1 .707.707zm2.122 2.122a4 4 0 0 0 0 5.656.5.5 0 0 1-.708.708 5 5 0 0 1 0-7.072.5.5 0 0 1 .708.708zm5.656-.708a.5.5 0 0 1 .708 0 5 5 0 0 1 0 7.072.5.5 0 1 1-.708-.708 4 4 0 0 0 0-5.656.5.5 0 0 1 0-.708zm2.122-2.12a.5.5 0 0 1 .707 0 8 8 0 0 1 0 11.313.5.5 0 0 1-.707-.707 7 7 0 0 0 0-9.9.5.5 0 0 1 0-.707zM10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>'),Gn=d("BroadcastPin",'<path d="M3.05 3.05a7 7 0 0 0 0 9.9.5.5 0 0 1-.707.707 8 8 0 0 1 0-11.314.5.5 0 0 1 .707.707zm2.122 2.122a4 4 0 0 0 0 5.656.5.5 0 0 1-.708.708 5 5 0 0 1 0-7.072.5.5 0 0 1 .708.708zm5.656-.708a.5.5 0 0 1 .708 0 5 5 0 0 1 0 7.072.5.5 0 1 1-.708-.708 4 4 0 0 0 0-5.656.5.5 0 0 1 0-.708zm2.122-2.12a.5.5 0 0 1 .707 0 8 8 0 0 1 0 11.313.5.5 0 0 1-.707-.707 7 7 0 0 0 0-9.9.5.5 0 0 1 0-.707zM6 8a2 2 0 1 1 2.5 1.937V15.5a.5.5 0 0 1-1 0V9.937A2 2 0 0 1 6 8z"/>'),Yn=d("Brush",'<path d="M15.825.12a.5.5 0 0 1 .132.584c-1.53 3.43-4.743 8.17-7.095 10.64a6.067 6.067 0 0 1-2.373 1.534c-.018.227-.06.538-.16.868-.201.659-.667 1.479-1.708 1.74a8.117 8.117 0 0 1-3.078.132 3.658 3.658 0 0 1-.563-.135 1.382 1.382 0 0 1-.465-.247.714.714 0 0 1-.204-.288.622.622 0 0 1 .004-.443c.095-.245.316-.38.461-.452.393-.197.625-.453.867-.826.094-.144.184-.297.287-.472l.117-.198c.151-.255.326-.54.546-.848.528-.739 1.2-.925 1.746-.896.126.007.243.025.348.048.062-.172.142-.38.238-.608.261-.619.658-1.419 1.187-2.069 2.175-2.67 6.18-6.206 9.117-8.104a.5.5 0 0 1 .596.04zM4.705 11.912a1.23 1.23 0 0 0-.419-.1c-.247-.013-.574.05-.88.479a11.01 11.01 0 0 0-.5.777l-.104.177c-.107.181-.213.362-.32.528-.206.317-.438.61-.76.861a7.127 7.127 0 0 0 2.657-.12c.559-.139.843-.569.993-1.06a3.121 3.121 0 0 0 .126-.75l-.793-.792zm1.44.026c.12-.04.277-.1.458-.183a5.068 5.068 0 0 0 1.535-1.1c1.9-1.996 4.412-5.57 6.052-8.631-2.591 1.927-5.566 4.66-7.302 6.792-.442.543-.796 1.243-1.042 1.826a11.507 11.507 0 0 0-.276.721l.575.575zm-4.973 3.04l.007-.005a.031.031 0 0 1-.007.004zm3.582-3.043l.002.001h-.002z"/>'),Kn=d("BrushFill",'<path d="M15.825.12a.5.5 0 0 1 .132.584c-1.53 3.43-4.743 8.17-7.095 10.64a6.067 6.067 0 0 1-2.373 1.534c-.018.227-.06.538-.16.868-.201.659-.667 1.479-1.708 1.74a8.117 8.117 0 0 1-3.078.132 3.658 3.658 0 0 1-.563-.135 1.382 1.382 0 0 1-.465-.247.714.714 0 0 1-.204-.288.622.622 0 0 1 .004-.443c.095-.245.316-.38.461-.452.393-.197.625-.453.867-.826.094-.144.184-.297.287-.472l.117-.198c.151-.255.326-.54.546-.848.528-.739 1.2-.925 1.746-.896.126.007.243.025.348.048.062-.172.142-.38.238-.608.261-.619.658-1.419 1.187-2.069 2.175-2.67 6.18-6.206 9.117-8.104a.5.5 0 0 1 .596.04z"/>'),Qn=d("Bucket",'<path d="M2.522 5H2a.5.5 0 0 0-.494.574l1.372 9.149A1.5 1.5 0 0 0 4.36 16h7.278a1.5 1.5 0 0 0 1.483-1.277l1.373-9.149A.5.5 0 0 0 14 5h-.522A5.5 5.5 0 0 0 2.522 5zm1.005 0a4.5 4.5 0 0 1 8.945 0H3.527zm9.892 1l-1.286 8.574a.5.5 0 0 1-.494.426H4.36a.5.5 0 0 1-.494-.426L2.58 6h10.838z"/>'),Xn=d("BucketFill",'<path d="M2.522 5H2a.5.5 0 0 0-.494.574l1.372 9.149A1.5 1.5 0 0 0 4.36 16h7.278a1.5 1.5 0 0 0 1.483-1.277l1.373-9.149A.5.5 0 0 0 14 5h-.522A5.5 5.5 0 0 0 2.522 5zm1.005 0a4.5 4.5 0 0 1 8.945 0H3.527z"/>'),Jn=d("Bug",'<path d="M4.355.522a.5.5 0 0 1 .623.333l.291.956A4.979 4.979 0 0 1 8 1c1.007 0 1.946.298 2.731.811l.29-.956a.5.5 0 1 1 .957.29l-.41 1.352A4.985 4.985 0 0 1 13 6h.5a.5.5 0 0 0 .5-.5V5a.5.5 0 0 1 1 0v.5A1.5 1.5 0 0 1 13.5 7H13v1h1.5a.5.5 0 0 1 0 1H13v1h.5a1.5 1.5 0 0 1 1.5 1.5v.5a.5.5 0 1 1-1 0v-.5a.5.5 0 0 0-.5-.5H13a5 5 0 0 1-10 0h-.5a.5.5 0 0 0-.5.5v.5a.5.5 0 1 1-1 0v-.5A1.5 1.5 0 0 1 2.5 10H3V9H1.5a.5.5 0 0 1 0-1H3V7h-.5A1.5 1.5 0 0 1 1 5.5V5a.5.5 0 0 1 1 0v.5a.5.5 0 0 0 .5.5H3c0-1.364.547-2.601 1.432-3.503l-.41-1.352a.5.5 0 0 1 .333-.623zM4 7v4a4 4 0 0 0 3.5 3.97V7H4zm4.5 0v7.97A4 4 0 0 0 12 11V7H8.5zM12 6a3.989 3.989 0 0 0-1.334-2.982A3.983 3.983 0 0 0 8 2a3.983 3.983 0 0 0-2.667 1.018A3.989 3.989 0 0 0 4 6h8z"/>'),Zn=d("BugFill",'<path d="M4.978.855a.5.5 0 1 0-.956.29l.41 1.352A4.985 4.985 0 0 0 3 6h10a4.985 4.985 0 0 0-1.432-3.503l.41-1.352a.5.5 0 1 0-.956-.29l-.291.956A4.978 4.978 0 0 0 8 1a4.979 4.979 0 0 0-2.731.811l-.29-.956z"/><path d="M13 6v1H8.5v8.975A5 5 0 0 0 13 11h.5a.5.5 0 0 1 .5.5v.5a.5.5 0 1 0 1 0v-.5a1.5 1.5 0 0 0-1.5-1.5H13V9h1.5a.5.5 0 0 0 0-1H13V7h.5A1.5 1.5 0 0 0 15 5.5V5a.5.5 0 0 0-1 0v.5a.5.5 0 0 1-.5.5H13zm-5.5 9.975V7H3V6h-.5a.5.5 0 0 1-.5-.5V5a.5.5 0 0 0-1 0v.5A1.5 1.5 0 0 0 2.5 7H3v1H1.5a.5.5 0 0 0 0 1H3v1h-.5A1.5 1.5 0 0 0 1 11.5v.5a.5.5 0 1 0 1 0v-.5a.5.5 0 0 1 .5-.5H3a5 5 0 0 0 4.5 4.975z"/>'),tr=d("Building",'<path fill-rule="evenodd" d="M14.763.075A.5.5 0 0 1 15 .5v15a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5V14h-1v1.5a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5V10a.5.5 0 0 1 .342-.474L6 7.64V4.5a.5.5 0 0 1 .276-.447l8-4a.5.5 0 0 1 .487.022zM6 8.694L1 10.36V15h5V8.694zM7 15h2v-1.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5V15h2V1.309l-7 3.5V15z"/><path d="M2 11h1v1H2v-1zm2 0h1v1H4v-1zm-2 2h1v1H2v-1zm2 0h1v1H4v-1zm4-4h1v1H8V9zm2 0h1v1h-1V9zm-2 2h1v1H8v-1zm2 0h1v1h-1v-1zm2-2h1v1h-1V9zm0 2h1v1h-1v-1zM8 7h1v1H8V7zm2 0h1v1h-1V7zm2 0h1v1h-1V7zM8 5h1v1H8V5zm2 0h1v1h-1V5zm2 0h1v1h-1V5zm0-2h1v1h-1V3z"/>'),er=d("Bullseye",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8 13A5 5 0 1 1 8 3a5 5 0 0 1 0 10zm0 1A6 6 0 1 0 8 2a6 6 0 0 0 0 12z"/><path d="M8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6zm0 1a4 4 0 1 0 0-8 4 4 0 0 0 0 8z"/><path d="M9.5 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),nr=d("Calculator",'<path d="M12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M4 2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-2zm0 4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-4z"/>'),rr=d("CalculatorFill",'<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2 .5v2a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-7a.5.5 0 0 0-.5.5zm0 4v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zM4.5 9a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM4 12.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zM7.5 6a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM7 9.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zm.5 2.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM10 6.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zm.5 2.5a.5.5 0 0 0-.5.5v4a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-.5-.5h-1z"/>'),ir=d("Calendar",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),or=d("Calendar2",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),ar=d("Calendar2Check",'<path d="M10.854 8.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L7.5 10.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),sr=d("Calendar2CheckFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-2.6 5.854a.5.5 0 0 0-.708-.708L7.5 10.793 6.354 9.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/>'),cr=d("Calendar2Date",'<path d="M6.445 12.688V7.354h-.633A12.6 12.6 0 0 0 4.5 8.16v.695c.375-.257.969-.62 1.258-.777h.012v4.61h.675zm1.188-1.305c.047.64.594 1.406 1.703 1.406 1.258 0 2-1.066 2-2.871 0-1.934-.781-2.668-1.953-2.668-.926 0-1.797.672-1.797 1.809 0 1.16.824 1.77 1.676 1.77.746 0 1.23-.376 1.383-.79h.027c-.004 1.316-.461 2.164-1.305 2.164-.664 0-1.008-.45-1.05-.82h-.684zm2.953-2.317c0 .696-.559 1.18-1.184 1.18-.601 0-1.144-.383-1.144-1.2 0-.823.582-1.21 1.168-1.21.633 0 1.16.398 1.16 1.23z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),lr=d("Calendar2DateFill",'<path d="M9.402 10.246c.625 0 1.184-.484 1.184-1.18 0-.832-.527-1.23-1.16-1.23-.586 0-1.168.387-1.168 1.21 0 .817.543 1.2 1.144 1.2z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-4.118 9.79c1.258 0 2-1.067 2-2.872 0-1.934-.781-2.668-1.953-2.668-.926 0-1.797.672-1.797 1.809 0 1.16.824 1.77 1.676 1.77.746 0 1.23-.376 1.383-.79h.027c-.004 1.316-.461 2.164-1.305 2.164-.664 0-1.008-.45-1.05-.82h-.684c.047.64.594 1.406 1.703 1.406zm-2.89-5.435h-.633A12.6 12.6 0 0 0 4.5 8.16v.695c.375-.257.969-.62 1.258-.777h.012v4.61h.675V7.354z"/>'),ur=d("Calendar2Day",'<path d="M4.684 12.523v-2.3h2.261v-.61H4.684V7.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V9.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105zm2.805-5.093c0 .238.192.425.43.425a.428.428 0 1 0 0-.855.426.426 0 0 0-.43.43zm.094 5.093h.672V8.418h-.672v4.105z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),dr=d("Calendar2DayFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-2.24 4.855a.428.428 0 1 0 0-.855.426.426 0 0 0-.429.43c0 .238.192.425.43.425zm.337.563h-.672v4.105h.672V8.418zm-6.867 4.105v-2.3h2.261v-.61H4.684V7.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V9.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105z"/>'),hr=d("Calendar2Event",'<path d="M11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),fr=d("Calendar2EventFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM11.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>'),pr=d("Calendar2Fill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM2.545 3h10.91c.3 0 .545.224.545.5v1c0 .276-.244.5-.546.5H2.545C2.245 5 2 4.776 2 4.5v-1c0-.276.244-.5.545-.5z"/>'),mr=d("Calendar2Minus",'<path d="M5.5 10.5A.5.5 0 0 1 6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),br=d("Calendar2MinusFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM6 10a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1H6z"/>'),gr=d("Calendar2Month",'<path d="M2.56 12.332l.54-1.602h1.984l.54 1.602h.718L4.444 7h-.696L1.85 12.332h.71zm1.544-4.527L4.9 10.18H3.284l.8-2.375h.02zm5.746.422h-.676v2.543c0 .652-.414 1.023-1.004 1.023-.539 0-.98-.246-.98-1.012V8.227h-.676v2.746c0 .941.606 1.425 1.453 1.425.656 0 1.043-.28 1.188-.605h.027v.539h.668V8.227zm2.258 5.046c-.563 0-.91-.304-.985-.636h-.687c.094.683.625 1.199 1.668 1.199.93 0 1.746-.527 1.746-1.578V8.227h-.649v.578h-.019c-.191-.348-.637-.64-1.195-.64-.965 0-1.64.679-1.64 1.886v.34c0 1.23.683 1.902 1.64 1.902.558 0 1.008-.293 1.172-.648h.02v.605c0 .645-.423 1.023-1.071 1.023zm.008-4.53c.648 0 1.062.527 1.062 1.359v.253c0 .848-.39 1.364-1.062 1.364-.692 0-1.098-.512-1.098-1.364v-.253c0-.868.406-1.36 1.098-1.36z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),vr=d("Calendar2MonthFill",'<path d="M4.104 7.805L4.9 10.18H3.284l.8-2.375h.02zm9.074 2.297c0-.832-.414-1.36-1.062-1.36-.692 0-1.098.492-1.098 1.36v.253c0 .852.406 1.364 1.098 1.364.671 0 1.062-.516 1.062-1.364v-.253z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM2.561 12.332L3.1 10.73h1.984l.54 1.602h.718L4.444 7h-.696L1.85 12.332h.71zM9.85 8.227h-.676v2.543c0 .652-.414 1.023-1.004 1.023-.539 0-.98-.246-.98-1.012V8.227h-.676v2.746c0 .941.606 1.425 1.453 1.425.656 0 1.043-.28 1.188-.605h.027v.539h.668V8.227zm1.273 4.41h-.687c.094.683.625 1.199 1.668 1.199.93 0 1.746-.527 1.746-1.578V8.227h-.649v.578h-.019c-.191-.348-.637-.64-1.195-.64-.965 0-1.64.679-1.64 1.886v.34c0 1.23.683 1.902 1.64 1.902.558 0 1.008-.293 1.172-.648h.02v.605c0 .645-.423 1.023-1.071 1.023-.563 0-.91-.304-.985-.636z"/>'),wr=d("Calendar2Plus",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4zM8 8a.5.5 0 0 1 .5.5V10H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V11H6a.5.5 0 0 1 0-1h1.5V8.5A.5.5 0 0 1 8 8z"/>'),yr=d("Calendar2PlusFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 3.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5H2.545c-.3 0-.545.224-.545.5zm6.5 5a.5.5 0 0 0-1 0V10H6a.5.5 0 0 0 0 1h1.5v1.5a.5.5 0 0 0 1 0V11H10a.5.5 0 0 0 0-1H8.5V8.5z"/>'),kr=d("Calendar2Range",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4zM9 8a1 1 0 0 1 1-1h5v2h-5a1 1 0 0 1-1-1zm-8 2h4a1 1 0 1 1 0 2H1v-2z"/>'),_r=d("Calendar2RangeFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM10 7a1 1 0 0 0 0 2h5V7h-5zm-4 4a1 1 0 0 0-1-1H1v2h4a1 1 0 0 0 1-1z"/>'),Or=d("Calendar2Week",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4zM11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-5 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/>'),zr=d("Calendar2WeekFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zM8.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm3 0a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM3 10.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5zm3.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>'),Ar=d("Calendar2X",'<path d="M6.146 8.146a.5.5 0 0 1 .708 0L8 9.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 10l1.147 1.146a.5.5 0 0 1-.708.708L8 10.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 10 6.146 8.854a.5.5 0 0 1 0-.708z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2z"/><path d="M2.5 4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H3a.5.5 0 0 1-.5-.5V4z"/>'),jr=d("Calendar2XFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zm9.954 3H2.545c-.3 0-.545.224-.545.5v1c0 .276.244.5.545.5h10.91c.3 0 .545-.224.545-.5v-1c0-.276-.244-.5-.546-.5zm-6.6 5.146a.5.5 0 1 0-.708.708L7.293 10l-1.147 1.146a.5.5 0 0 0 .708.708L8 10.707l1.146 1.147a.5.5 0 0 0 .708-.708L8.707 10l1.147-1.146a.5.5 0 0 0-.708-.708L8 9.293 6.854 8.146z"/>'),Mr=d("Calendar3",'<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M6.5 7a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-9 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-9 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm3 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),Cr=d("Calendar3Event",'<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M12 7a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),Vr=d("Calendar3EventFill",'<path fill-rule="evenodd" d="M2 0a2 2 0 0 0-2 2h16a2 2 0 0 0-2-2H2zM0 14V3h16v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm12-8a1 1 0 1 0 2 0 1 1 0 0 0-2 0z"/>'),Sr=d("Calendar3Fill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2H0zm0 1v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3H0z"/>'),xr=d("Calendar3Range",'<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M7 10a1 1 0 0 0 0-2H1v2h6zm2-3h6V5H9a1 1 0 0 0 0 2z"/>'),Tr=d("Calendar3RangeFill",'<path fill-rule="evenodd" d="M2 0a2 2 0 0 0-2 2h16a2 2 0 0 0-2-2H2zM0 8V3h16v2h-6a1 1 0 1 0 0 2h6v7a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-4h6a1 1 0 1 0 0-2H0z"/>'),Pr=d("Calendar3Week",'<path d="M14 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM1 3.857C1 3.384 1.448 3 2 3h12c.552 0 1 .384 1 .857v10.286c0 .473-.448.857-1 .857H2c-.552 0-1-.384-1-.857V3.857z"/><path d="M12 7a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-5 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm2-3a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm-5 3a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),Ir=d("Calendar3WeekFill",'<path fill-rule="evenodd" d="M2 0a2 2 0 0 0-2 2h16a2 2 0 0 0-2-2H2zM0 14V3h16v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm12-8a1 1 0 1 0 2 0 1 1 0 0 0-2 0zM5 9a1 1 0 1 0 2 0 1 1 0 0 0-2 0zm5-2a1 1 0 1 1 0-2 1 1 0 0 1 0 2zM2 9a1 1 0 1 0 2 0 1 1 0 0 0-2 0z"/>'),Er=d("Calendar4",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/>'),Lr=d("Calendar4Event",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/><path d="M11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/>'),Br=d("Calendar4Range",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/><path d="M9 7.5a.5.5 0 0 1 .5-.5H15v2H9.5a.5.5 0 0 1-.5-.5v-1zm-2 3v1a.5.5 0 0 1-.5.5H1v-2h5.5a.5.5 0 0 1 .5.5z"/>'),Hr=d("Calendar4Week",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"/><path d="M11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-2 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/>'),Fr=d("CalendarCheck",'<path d="M10.854 7.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 9.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),Dr=d("CalendarCheckFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zm-5.146-5.146l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L7.5 10.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>'),Rr=d("CalendarDate",'<path d="M6.445 11.688V6.354h-.633A12.6 12.6 0 0 0 4.5 7.16v.695c.375-.257.969-.62 1.258-.777h.012v4.61h.675zm1.188-1.305c.047.64.594 1.406 1.703 1.406 1.258 0 2-1.066 2-2.871 0-1.934-.781-2.668-1.953-2.668-.926 0-1.797.672-1.797 1.809 0 1.16.824 1.77 1.676 1.77.746 0 1.23-.376 1.383-.79h.027c-.004 1.316-.461 2.164-1.305 2.164-.664 0-1.008-.45-1.05-.82h-.684zm2.953-2.317c0 .696-.559 1.18-1.184 1.18-.601 0-1.144-.383-1.144-1.2 0-.823.582-1.21 1.168-1.21.633 0 1.16.398 1.16 1.23z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),Nr=d("CalendarDateFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zm5.402 9.746c.625 0 1.184-.484 1.184-1.18 0-.832-.527-1.23-1.16-1.23-.586 0-1.168.387-1.168 1.21 0 .817.543 1.2 1.144 1.2z"/><path d="M16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zm-6.664-1.21c-1.11 0-1.656-.767-1.703-1.407h.683c.043.37.387.82 1.051.82.844 0 1.301-.848 1.305-2.164h-.027c-.153.414-.637.79-1.383.79-.852 0-1.676-.61-1.676-1.77 0-1.137.871-1.809 1.797-1.809 1.172 0 1.953.734 1.953 2.668 0 1.805-.742 2.871-2 2.871zm-2.89-5.435v5.332H5.77V8.079h-.012c-.29.156-.883.52-1.258.777V8.16a12.6 12.6 0 0 1 1.313-.805h.632z"/>'),$r=d("CalendarDay",'<path d="M4.684 11.523v-2.3h2.261v-.61H4.684V6.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V8.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105zm2.805-5.093c0 .238.192.425.43.425a.428.428 0 1 0 0-.855.426.426 0 0 0-.43.43zm.094 5.093h.672V7.418h-.672v4.105z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),Ur=d("CalendarDayFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V5h16v9zm-4.785-6.145a.428.428 0 1 0 0-.855.426.426 0 0 0-.43.43c0 .238.192.425.43.425zm.336.563h-.672v4.105h.672V8.418zm-6.867 4.105v-2.3h2.261v-.61H4.684V7.801h2.464v-.61H4v5.332h.684zm3.296 0h.676V9.98c0-.554.227-1.007.953-1.007.125 0 .258.004.329.015v-.613a1.806 1.806 0 0 0-.254-.02c-.582 0-.891.32-1.012.567h-.02v-.504H7.98v4.105z"/>'),qr=d("CalendarEvent",'<path d="M11 6.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),Wr=d("CalendarEventFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zm-3.5-7h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5z"/>'),Gr=d("CalendarFill",'<path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V5h16V4H0V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5z"/>'),Yr=d("CalendarMinus",'<path d="M5.5 9.5A.5.5 0 0 1 6 9h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),Kr=d("CalendarMinusFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>'),Qr=d("CalendarMonth",'<path d="M2.56 11.332L3.1 9.73h1.984l.54 1.602h.718L4.444 6h-.696L1.85 11.332h.71zm1.544-4.527L4.9 9.18H3.284l.8-2.375h.02zm5.746.422h-.676V9.77c0 .652-.414 1.023-1.004 1.023-.539 0-.98-.246-.98-1.012V7.227h-.676v2.746c0 .941.606 1.425 1.453 1.425.656 0 1.043-.28 1.188-.605h.027v.539h.668V7.227zm2.258 5.046c-.563 0-.91-.304-.985-.636h-.687c.094.683.625 1.199 1.668 1.199.93 0 1.746-.527 1.746-1.578V7.227h-.649v.578h-.019c-.191-.348-.637-.64-1.195-.64-.965 0-1.64.679-1.64 1.886v.34c0 1.23.683 1.902 1.64 1.902.558 0 1.008-.293 1.172-.648h.02v.605c0 .645-.423 1.023-1.071 1.023zm.008-4.53c.648 0 1.062.527 1.062 1.359v.253c0 .848-.39 1.364-1.062 1.364-.692 0-1.098-.512-1.098-1.364v-.253c0-.868.406-1.36 1.098-1.36z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),Xr=d("CalendarMonthFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zm.104 7.305L4.9 10.18H3.284l.8-2.375h.02zm9.074 2.297c0-.832-.414-1.36-1.062-1.36-.692 0-1.098.492-1.098 1.36v.253c0 .852.406 1.364 1.098 1.364.671 0 1.062-.516 1.062-1.364v-.253z"/><path d="M16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM2.56 12.332h-.71L3.748 7h.696l1.898 5.332h-.719l-.539-1.602H3.1l-.54 1.602zm7.29-4.105v4.105h-.668v-.539h-.027c-.145.324-.532.605-1.188.605-.847 0-1.453-.484-1.453-1.425V8.227h.676v2.554c0 .766.441 1.012.98 1.012.59 0 1.004-.371 1.004-1.023V8.227h.676zm1.273 4.41c.075.332.422.636.985.636.648 0 1.07-.378 1.07-1.023v-.605h-.02c-.163.355-.613.648-1.171.648-.957 0-1.64-.672-1.64-1.902v-.34c0-1.207.675-1.887 1.64-1.887.558 0 1.004.293 1.195.64h.02v-.577h.648v4.03c0 1.052-.816 1.579-1.746 1.579-1.043 0-1.574-.516-1.668-1.2h.687z"/>'),Jr=d("CalendarPlus",'<path d="M8 7a.5.5 0 0 1 .5.5V9H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V10H6a.5.5 0 0 1 0-1h1.5V7.5A.5.5 0 0 1 8 7z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),Zr=d("CalendarPlusFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM8.5 8.5V10H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V11H6a.5.5 0 0 1 0-1h1.5V8.5a.5.5 0 0 1 1 0z"/>'),ti=d("CalendarRange",'<path d="M9 7a1 1 0 0 1 1-1h5v2h-5a1 1 0 0 1-1-1zM1 9h4a1 1 0 0 1 0 2H1V9z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),ei=d("CalendarRangeFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 7V5H0v5h5a1 1 0 1 1 0 2H0v2a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9h-6a1 1 0 1 1 0-2h6z"/>'),ni=d("CalendarWeek",'<path d="M11 6.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm-5 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),ri=d("CalendarWeekFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM9.5 7h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5zm3 0h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5zM2 10.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1zm3.5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5z"/>'),ii=d("CalendarX",'<path d="M6.146 7.146a.5.5 0 0 1 .708 0L8 8.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 9l1.147 1.146a.5.5 0 0 1-.708.708L8 9.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 9 6.146 7.854a.5.5 0 0 1 0-.708z"/><path d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM1 4v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4H1z"/>'),oi=d("CalendarXFill",'<path d="M4 .5a.5.5 0 0 0-1 0V1H2a2 2 0 0 0-2 2v1h16V3a2 2 0 0 0-2-2h-1V.5a.5.5 0 0 0-1 0V1H4V.5zM16 14V5H0v9a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2zM6.854 8.146L8 9.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 10l1.147 1.146a.5.5 0 0 1-.708.708L8 10.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 10 6.146 8.854a.5.5 0 1 1 .708-.708z"/>'),ai=d("Camera",'<path d="M15 12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h1.172a3 3 0 0 0 2.12-.879l.83-.828A1 1 0 0 1 6.827 3h2.344a1 1 0 0 1 .707.293l.828.828A3 3 0 0 0 12.828 5H14a1 1 0 0 1 1 1v6zM2 4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-1.172a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 9.172 2H6.828a2 2 0 0 0-1.414.586l-.828.828A2 2 0 0 1 3.172 4H2z"/><path d="M8 11a2.5 2.5 0 1 1 0-5 2.5 2.5 0 0 1 0 5zm0 1a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7zM3 6.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/>'),si=d("Camera2",'<path d="M5 8c0-1.657 2.343-3 4-3V4a4 4 0 0 0-4 4z"/><path d="M12.318 3h2.015C15.253 3 16 3.746 16 4.667v6.666c0 .92-.746 1.667-1.667 1.667h-2.015A5.97 5.97 0 0 1 9 14a5.972 5.972 0 0 1-3.318-1H1.667C.747 13 0 12.254 0 11.333V4.667C0 3.747.746 3 1.667 3H2a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1h.682A5.97 5.97 0 0 1 9 2c1.227 0 2.367.368 3.318 1zM2 4.5a.5.5 0 1 0-1 0 .5.5 0 0 0 1 0zM14 8A5 5 0 1 0 4 8a5 5 0 0 0 10 0z"/>'),ci=d("CameraFill",'<path d="M10.5 8.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0z"/><path d="M2 4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-1.172a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 9.172 2H6.828a2 2 0 0 0-1.414.586l-.828.828A2 2 0 0 1 3.172 4H2zm.5 2a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm9 2.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0z"/>'),li=d("CameraReels",'<path d="M6 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0zM1 3a2 2 0 1 0 4 0 2 2 0 0 0-4 0z"/><path d="M9 6h.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 7.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 16H2a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h7zm6 8.73V7.27l-3.5 1.555v4.35l3.5 1.556zM1 8v6a1 1 0 0 0 1 1h7.5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1z"/><path d="M9 6a3 3 0 1 0 0-6 3 3 0 0 0 0 6zM7 3a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/>'),ui=d("CameraReelsFill",'<path d="M6 3a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M9 6a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/><path d="M9 6h.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 7.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 16H2a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h7z"/>'),di=d("CameraVideo",'<path fill-rule="evenodd" d="M0 5a2 2 0 0 1 2-2h7.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 4.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 13H2a2 2 0 0 1-2-2V5zm11.5 5.175l3.5 1.556V4.269l-3.5 1.556v4.35zM2 4a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h7.5a1 1 0 0 0 1-1V5a1 1 0 0 0-1-1H2z"/>'),hi=d("CameraVideoFill",'<path fill-rule="evenodd" d="M0 5a2 2 0 0 1 2-2h7.5a2 2 0 0 1 1.983 1.738l3.11-1.382A1 1 0 0 1 16 4.269v7.462a1 1 0 0 1-1.406.913l-3.111-1.382A2 2 0 0 1 9.5 13H2a2 2 0 0 1-2-2V5z"/>'),fi=d("CameraVideoOff",'<path fill-rule="evenodd" d="M10.961 12.365a1.99 1.99 0 0 0 .522-1.103l3.11 1.382A1 1 0 0 0 16 11.731V4.269a1 1 0 0 0-1.406-.913l-3.111 1.382A2 2 0 0 0 9.5 3H4.272l.714 1H9.5a1 1 0 0 1 1 1v6a1 1 0 0 1-.144.518l.605.847zM1.428 4.18A.999.999 0 0 0 1 5v6a1 1 0 0 0 1 1h5.014l.714 1H2a2 2 0 0 1-2-2V5c0-.675.334-1.272.847-1.634l.58.814zM15 11.73l-3.5-1.555v-4.35L15 4.269v7.462zm-4.407 3.56l-10-14 .814-.58 10 14-.814.58z"/>'),pi=d("CameraVideoOffFill",'<path fill-rule="evenodd" d="M10.961 12.365a1.99 1.99 0 0 0 .522-1.103l3.11 1.382A1 1 0 0 0 16 11.731V4.269a1 1 0 0 0-1.406-.913l-3.111 1.382A2 2 0 0 0 9.5 3H4.272l6.69 9.365zm-10.114-9A2.001 2.001 0 0 0 0 5v6a2 2 0 0 0 2 2h5.728L.847 3.366zm9.746 11.925l-10-14 .814-.58 10 14-.814.58z"/>'),mi=d("Capslock",'<path fill-rule="evenodd" d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1H1.654C.78 9.5.326 8.455.924 7.816L7.27 1.047zM14.346 8.5L8 1.731 1.654 8.5H4.5a1 1 0 0 1 1 1v1h5v-1a1 1 0 0 1 1-1h2.846zm-9.846 5a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1zm6 0h-5v1h5v-1z"/>'),bi=d("CapslockFill",'<path d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1H1.654C.78 9.5.326 8.455.924 7.816L7.27 1.047zM4.5 13.5a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-1z"/>'),gi=d("CardChecklist",'<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M7 5.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm-1.496-.854a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 1 1 .708-.708l.146.147 1.146-1.147a.5.5 0 0 1 .708 0zM7 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm-1.496-.854a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 0 1 .708-.708l.146.147 1.146-1.147a.5.5 0 0 1 .708 0z"/>'),vi=d("CardHeading",'<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M3 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0-5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5v-1z"/>'),wi=d("CardImage",'<path d="M6.002 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M1.5 2A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13zm13 1a.5.5 0 0 1 .5.5v6l-3.775-1.947a.5.5 0 0 0-.577.093l-3.71 3.71-2.66-1.772a.5.5 0 0 0-.63.062L1.002 12v.54A.505.505 0 0 1 1 12.5v-9a.5.5 0 0 1 .5-.5h13z"/>'),yi=d("CardList",'<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M5 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 5 8zm0-2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0 5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-1-5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zM4 8a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm0 2.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/>'),ki=d("CardText",'<path d="M14.5 3a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h13zm-13-1A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M3 5.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 8a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 8zm0 2.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),_i=d("CaretDown",'<path d="M3.204 5h9.592L8 10.481 3.204 5zm-.753.659l4.796 5.48a1 1 0 0 0 1.506 0l4.796-5.48c.566-.647.106-1.659-.753-1.659H3.204a1 1 0 0 0-.753 1.659z"/>'),Oi=d("CaretDownFill",'<path d="M7.247 11.14L2.451 5.658C1.885 5.013 2.345 4 3.204 4h9.592a1 1 0 0 1 .753 1.659l-4.796 5.48a1 1 0 0 1-1.506 0z"/>'),zi=d("CaretDownSquare",'<path d="M3.626 6.832A.5.5 0 0 1 4 6h8a.5.5 0 0 1 .374.832l-4 4.5a.5.5 0 0 1-.748 0l-4-4.5z"/><path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V2z"/>'),Ai=d("CaretDownSquareFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm4 4a.5.5 0 0 0-.374.832l4 4.5a.5.5 0 0 0 .748 0l4-4.5A.5.5 0 0 0 12 6H4z"/>'),ji=d("CaretLeft",'<path d="M10 12.796V3.204L4.519 8 10 12.796zm-.659.753l-5.48-4.796a1 1 0 0 1 0-1.506l5.48-4.796A1 1 0 0 1 11 3.204v9.592a1 1 0 0 1-1.659.753z"/>'),Mi=d("CaretLeftFill",'<path d="M3.86 8.753l5.482 4.796c.646.566 1.658.106 1.658-.753V3.204a1 1 0 0 0-1.659-.753l-5.48 4.796a1 1 0 0 0 0 1.506z"/>'),Ci=d("CaretLeftSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M10.205 12.456A.5.5 0 0 0 10.5 12V4a.5.5 0 0 0-.832-.374l-4.5 4a.5.5 0 0 0 0 .748l4.5 4a.5.5 0 0 0 .537.082z"/>'),Vi=d("CaretLeftSquareFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm10.5 10V4a.5.5 0 0 0-.832-.374l-4.5 4a.5.5 0 0 0 0 .748l4.5 4A.5.5 0 0 0 10.5 12z"/>'),Si=d("CaretRight",'<path d="M6 12.796V3.204L11.481 8 6 12.796zm.659.753l5.48-4.796a1 1 0 0 0 0-1.506L6.66 2.451C6.011 1.885 5 2.345 5 3.204v9.592a1 1 0 0 0 1.659.753z"/>'),xi=d("CaretRightFill",'<path d="M12.14 8.753l-5.482 4.796c-.646.566-1.658.106-1.658-.753V3.204a1 1 0 0 1 1.659-.753l5.48 4.796a1 1 0 0 1 0 1.506z"/>'),Ti=d("CaretRightSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5.795 12.456A.5.5 0 0 1 5.5 12V4a.5.5 0 0 1 .832-.374l4.5 4a.5.5 0 0 1 0 .748l-4.5 4a.5.5 0 0 1-.537.082z"/>'),Pi=d("CaretRightSquareFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm5.5 10a.5.5 0 0 0 .832.374l4.5-4a.5.5 0 0 0 0-.748l-4.5-4A.5.5 0 0 0 5.5 4v8z"/>'),Ii=d("CaretUp",'<path d="M3.204 11h9.592L8 5.519 3.204 11zm-.753-.659l4.796-5.48a1 1 0 0 1 1.506 0l4.796 5.48c.566.647.106 1.659-.753 1.659H3.204a1 1 0 0 1-.753-1.659z"/>'),Ei=d("CaretUpFill",'<path d="M7.247 4.86l-4.796 5.481c-.566.647-.106 1.659.753 1.659h9.592a1 1 0 0 0 .753-1.659l-4.796-5.48a1 1 0 0 0-1.506 0z"/>'),Li=d("CaretUpSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M3.544 10.705A.5.5 0 0 0 4 11h8a.5.5 0 0 0 .374-.832l-4-4.5a.5.5 0 0 0-.748 0l-4 4.5a.5.5 0 0 0-.082.537z"/>'),Bi=d("CaretUpSquareFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm4 9h8a.5.5 0 0 0 .374-.832l-4-4.5a.5.5 0 0 0-.748 0l-4 4.5A.5.5 0 0 0 4 11z"/>'),Hi=d("Cart",'<path d="M0 1.5A.5.5 0 0 1 .5 1H2a.5.5 0 0 1 .485.379L2.89 3H14.5a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 13 12H4a.5.5 0 0 1-.491-.408L2.01 3.607 1.61 2H.5a.5.5 0 0 1-.5-.5zM3.102 4l1.313 7h8.17l1.313-7H3.102zM5 12a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm7 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm-7 1a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm7 0a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),Fi=d("Cart2",'<path d="M0 2.5A.5.5 0 0 1 .5 2H2a.5.5 0 0 1 .485.379L2.89 4H14.5a.5.5 0 0 1 .485.621l-1.5 6A.5.5 0 0 1 13 11H4a.5.5 0 0 1-.485-.379L1.61 3H.5a.5.5 0 0 1-.5-.5zM3.14 5l1.25 5h8.22l1.25-5H3.14zM5 13a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0zm9-1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/>'),Di=d("Cart3",'<path d="M0 1.5A.5.5 0 0 1 .5 1H2a.5.5 0 0 1 .485.379L2.89 3H14.5a.5.5 0 0 1 .49.598l-1 5a.5.5 0 0 1-.465.401l-9.397.472L4.415 11H13a.5.5 0 0 1 0 1H4a.5.5 0 0 1-.491-.408L2.01 3.607 1.61 2H.5a.5.5 0 0 1-.5-.5zM3.102 4l.84 4.479 9.144-.459L13.89 4H3.102zM5 12a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm7 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm-7 1a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm7 0a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),Ri=d("Cart4",'<path d="M0 2.5A.5.5 0 0 1 .5 2H2a.5.5 0 0 1 .485.379L2.89 4H14.5a.5.5 0 0 1 .485.621l-1.5 6A.5.5 0 0 1 13 11H4a.5.5 0 0 1-.485-.379L1.61 3H.5a.5.5 0 0 1-.5-.5zM3.14 5l.5 2H5V5H3.14zM6 5v2h2V5H6zm3 0v2h2V5H9zm3 0v2h1.36l.5-2H12zm1.11 3H12v2h.61l.5-2zM11 8H9v2h2V8zM8 8H6v2h2V8zM5 8H3.89l.5 2H5V8zm0 5a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0zm9-1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm-2 1a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/>'),Ni=d("CartCheck",'<path d="M11.354 6.354a.5.5 0 0 0-.708-.708L8 8.293 6.854 7.146a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),$i=d("CartCheckFill",'<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-1.646-7.646l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L8 8.293l2.646-2.647a.5.5 0 0 1 .708.708z"/>'),Ui=d("CartDash",'<path d="M6.5 7a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1h-4z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),qi=d("CartDashFill",'<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM6.5 7h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1 0-1z"/>'),Wi=d("CartFill",'<path d="M0 1.5A.5.5 0 0 1 .5 1H2a.5.5 0 0 1 .485.379L2.89 3H14.5a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 13 12H4a.5.5 0 0 1-.491-.408L2.01 3.607 1.61 2H.5a.5.5 0 0 1-.5-.5zM5 12a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm7 0a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm-7 1a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm7 0a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),Gi=d("CartPlus",'<path d="M9 5.5a.5.5 0 0 0-1 0V7H6.5a.5.5 0 0 0 0 1H8v1.5a.5.5 0 0 0 1 0V8h1.5a.5.5 0 0 0 0-1H9V5.5z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),Yi=d("CartPlusFill",'<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM9 5.5V7h1.5a.5.5 0 0 1 0 1H9v1.5a.5.5 0 0 1-1 0V8H6.5a.5.5 0 0 1 0-1H8V5.5a.5.5 0 0 1 1 0z"/>'),Ki=d("CartX",'<path d="M7.354 5.646a.5.5 0 1 0-.708.708L7.793 7.5 6.646 8.646a.5.5 0 1 0 .708.708L8.5 8.207l1.146 1.147a.5.5 0 0 0 .708-.708L9.207 7.5l1.147-1.146a.5.5 0 0 0-.708-.708L8.5 6.793 7.354 5.646z"/><path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zm3.915 10L3.102 4h10.796l-1.313 7h-8.17zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),Qi=d("CartXFill",'<path d="M.5 1a.5.5 0 0 0 0 1h1.11l.401 1.607 1.498 7.985A.5.5 0 0 0 4 12h1a2 2 0 1 0 0 4 2 2 0 0 0 0-4h7a2 2 0 1 0 0 4 2 2 0 0 0 0-4h1a.5.5 0 0 0 .491-.408l1.5-8A.5.5 0 0 0 14.5 3H2.89l-.405-1.621A.5.5 0 0 0 2 1H.5zM6 14a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm7 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM7.354 5.646L8.5 6.793l1.146-1.147a.5.5 0 0 1 .708.708L9.207 7.5l1.147 1.146a.5.5 0 0 1-.708.708L8.5 8.207 7.354 9.354a.5.5 0 1 1-.708-.708L7.793 7.5 6.646 6.354a.5.5 0 1 1 .708-.708z"/>'),Xi=d("Cash",'<path d="M8 10a2 2 0 1 0 0-4 2 2 0 0 0 0 4z"/><path d="M0 4a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V4zm3 0a2 2 0 0 1-2 2v4a2 2 0 0 1 2 2h10a2 2 0 0 1 2-2V6a2 2 0 0 1-2-2H3z"/>'),Ji=d("CashStack",'<path d="M1 3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1H1zm7 8a2 2 0 1 0 0-4 2 2 0 0 0 0 4z"/><path d="M0 5a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V5zm3 0a2 2 0 0 1-2 2v4a2 2 0 0 1 2 2h10a2 2 0 0 1 2-2V7a2 2 0 0 1-2-2H3z"/>'),Zi=d("Cast",'<path d="M7.646 9.354l-3.792 3.792a.5.5 0 0 0 .353.854h7.586a.5.5 0 0 0 .354-.854L8.354 9.354a.5.5 0 0 0-.708 0z"/><path d="M11.414 11H14.5a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5h-13a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .5.5h3.086l-1 1H1.5A1.5 1.5 0 0 1 0 10.5v-7A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v7a1.5 1.5 0 0 1-1.5 1.5h-2.086l-1-1z"/>'),to=d("Chat",'<path d="M2.678 11.894a1 1 0 0 1 .287.801 10.97 10.97 0 0 1-.398 2c1.395-.323 2.247-.697 2.634-.893a1 1 0 0 1 .71-.074A8.06 8.06 0 0 0 8 14c3.996 0 7-2.807 7-6 0-3.192-3.004-6-7-6S1 4.808 1 8c0 1.468.617 2.83 1.678 3.894zm-.493 3.905a21.682 21.682 0 0 1-.713.129c-.2.032-.352-.176-.273-.362a9.68 9.68 0 0 0 .244-.637l.003-.01c.248-.72.45-1.548.524-2.319C.743 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.52.263-1.639.742-3.468 1.105z"/>'),eo=d("ChatDots",'<path d="M5 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/><path d="M2.165 15.803l.02-.004c1.83-.363 2.948-.842 3.468-1.105A9.06 9.06 0 0 0 8 15c4.418 0 8-3.134 8-7s-3.582-7-8-7-8 3.134-8 7c0 1.76.743 3.37 1.97 4.6a10.437 10.437 0 0 1-.524 2.318l-.003.011a10.722 10.722 0 0 1-.244.637c-.079.186.074.394.273.362a21.673 21.673 0 0 0 .693-.125zm.8-3.108a1 1 0 0 0-.287-.801C1.618 10.83 1 9.468 1 8c0-3.192 3.004-6 7-6s7 2.808 7 6c0 3.193-3.004 6-7 6a8.06 8.06 0 0 1-2.088-.272 1 1 0 0 0-.711.074c-.387.196-1.24.57-2.634.893a10.97 10.97 0 0 0 .398-2z"/>'),no=d("ChatDotsFill",'<path d="M16 8c0 3.866-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.584.296-1.925.864-4.181 1.234-.2.032-.352-.176-.273-.362.354-.836.674-1.95.77-2.966C.744 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7zM5 8a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm4 0a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),ro=d("ChatFill",'<path d="M8 15c4.418 0 8-3.134 8-7s-3.582-7-8-7-8 3.134-8 7c0 1.76.743 3.37 1.97 4.6-.097 1.016-.417 2.13-.771 2.966-.079.186.074.394.273.362 2.256-.37 3.597-.938 4.18-1.234A9.06 9.06 0 0 0 8 15z"/>'),io=d("ChatLeft",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>'),oo=d("ChatLeftDots",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),ao=d("ChatLeftDotsFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H4.414a1 1 0 0 0-.707.293L.854 15.146A.5.5 0 0 1 0 14.793V2zm5 4a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm4 0a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),so=d("ChatLeftFill",'<path d="M2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>'),co=d("ChatLeftQuote",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M7.066 4.76A1.665 1.665 0 0 0 4 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>'),lo=d("ChatLeftQuoteFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H4.414a1 1 0 0 0-.707.293L.854 15.146A.5.5 0 0 1 0 14.793V2zm7.194 2.766a1.688 1.688 0 0 0-.227-.272 1.467 1.467 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 5.734 4C4.776 4 4 4.746 4 5.667c0 .92.776 1.666 1.734 1.666.343 0 .662-.095.931-.26-.137.389-.39.804-.81 1.22a.405.405 0 0 0 .011.59c.173.16.447.155.614-.01 1.334-1.329 1.37-2.758.941-3.706a2.461 2.461 0 0 0-.227-.4zM11 7.073c-.136.389-.39.804-.81 1.22a.405.405 0 0 0 .012.59c.172.16.446.155.613-.01 1.334-1.329 1.37-2.758.942-3.706a2.466 2.466 0 0 0-.228-.4 1.686 1.686 0 0 0-.227-.273 1.466 1.466 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 10.07 4c-.957 0-1.734.746-1.734 1.667 0 .92.777 1.666 1.734 1.666.343 0 .662-.095.931-.26z"/>'),uo=d("ChatLeftText",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4.414A2 2 0 0 0 3 11.586l-2 2V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12.793a.5.5 0 0 0 .854.353l2.853-2.853A1 1 0 0 1 4.414 12H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M3 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 6a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 6zm0 2.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>'),ho=d("ChatLeftTextFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H4.414a1 1 0 0 0-.707.293L.854 15.146A.5.5 0 0 1 0 14.793V2zm3.5 1a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/>'),fo=d("ChatQuote",'<path d="M2.678 11.894a1 1 0 0 1 .287.801 10.97 10.97 0 0 1-.398 2c1.395-.323 2.247-.697 2.634-.893a1 1 0 0 1 .71-.074A8.06 8.06 0 0 0 8 14c3.996 0 7-2.807 7-6 0-3.192-3.004-6-7-6S1 4.808 1 8c0 1.468.617 2.83 1.678 3.894zm-.493 3.905a21.682 21.682 0 0 1-.713.129c-.2.032-.352-.176-.273-.362a9.68 9.68 0 0 0 .244-.637l.003-.01c.248-.72.45-1.548.524-2.319C.743 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.52.263-1.639.742-3.468 1.105z"/><path d="M7.066 6.76A1.665 1.665 0 0 0 4 7.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 0 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 7.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 0 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>'),po=d("ChatQuoteFill",'<path d="M16 8c0 3.866-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.584.296-1.925.864-4.181 1.234-.2.032-.352-.176-.273-.362.354-.836.674-1.95.77-2.966C.744 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7zM7.194 6.766a1.688 1.688 0 0 0-.227-.272 1.467 1.467 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 5.734 6C4.776 6 4 6.746 4 7.667c0 .92.776 1.666 1.734 1.666.343 0 .662-.095.931-.26-.137.389-.39.804-.81 1.22a.405.405 0 0 0 .011.59c.173.16.447.155.614-.01 1.334-1.329 1.37-2.758.941-3.706a2.461 2.461 0 0 0-.227-.4zM11 9.073c-.136.389-.39.804-.81 1.22a.405.405 0 0 0 .012.59c.172.16.446.155.613-.01 1.334-1.329 1.37-2.758.942-3.706a2.466 2.466 0 0 0-.228-.4 1.686 1.686 0 0 0-.227-.273 1.466 1.466 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 10.07 6c-.957 0-1.734.746-1.734 1.667 0 .92.777 1.666 1.734 1.666.343 0 .662-.095.931-.26z"/>'),mo=d("ChatRight",'<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/>'),bo=d("ChatRightDots",'<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/><path d="M5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),go=d("ChatRightDotsFill",'<path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h9.586a1 1 0 0 1 .707.293l2.853 2.853a.5.5 0 0 0 .854-.353V2zM5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 1a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>'),vo=d("ChatRightFill",'<path d="M14 0a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/>'),wo=d("ChatRightQuote",'<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/><path d="M7.066 4.76A1.665 1.665 0 0 0 4 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>'),yo=d("ChatRightQuoteFill",'<path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h9.586a1 1 0 0 1 .707.293l2.853 2.853a.5.5 0 0 0 .854-.353V2zM7.194 4.766c.087.124.163.26.227.401.428.948.393 2.377-.942 3.706a.446.446 0 0 1-.612.01.405.405 0 0 1-.011-.59c.419-.416.672-.831.809-1.22-.269.165-.588.26-.93.26C4.775 7.333 4 6.587 4 5.667 4 4.747 4.776 4 5.734 4c.271 0 .528.06.756.166l.008.004c.169.07.327.182.469.324.085.083.161.174.227.272zM11 7.073c-.269.165-.588.26-.93.26-.958 0-1.735-.746-1.735-1.666 0-.92.777-1.667 1.734-1.667.271 0 .528.06.756.166l.008.004c.17.07.327.182.469.324.085.083.161.174.227.272.087.124.164.26.228.401.428.948.392 2.377-.942 3.706a.446.446 0 0 1-.613.01.405.405 0 0 1-.011-.59c.42-.416.672-.831.81-1.22z"/>'),ko=d("ChatRightText",'<path d="M2 1a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h9.586a2 2 0 0 1 1.414.586l2 2V2a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v12.793a.5.5 0 0 1-.854.353l-2.853-2.853a1 1 0 0 0-.707-.293H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12z"/><path d="M3 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 6a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 6zm0 2.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>'),_o=d("ChatRightTextFill",'<path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h9.586a1 1 0 0 1 .707.293l2.853 2.853a.5.5 0 0 0 .854-.353V2zM3.5 3h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1 0-1zm0 2.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1 0-1zm0 2.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1z"/>'),Oo=d("ChatSquare",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>'),zo=d("ChatSquareDots",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5 6a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),Ao=d("ChatSquareDotsFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.5a1 1 0 0 0-.8.4l-1.9 2.533a1 1 0 0 1-1.6 0L5.3 12.4a1 1 0 0 0-.8-.4H2a2 2 0 0 1-2-2V2zm5 4a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm4 0a1 1 0 1 0-2 0 1 1 0 0 0 2 0zm3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),jo=d("ChatSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>'),Mo=d("ChatSquareQuote",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M7.066 4.76A1.665 1.665 0 0 0 4 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112zm4 0A1.665 1.665 0 0 0 8 5.668a1.667 1.667 0 0 0 2.561 1.406c-.131.389-.375.804-.777 1.22a.417.417 0 1 0 .6.58c1.486-1.54 1.293-3.214.682-4.112z"/>'),Co=d("ChatSquareQuoteFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.5a1 1 0 0 0-.8.4l-1.9 2.533a1 1 0 0 1-1.6 0L5.3 12.4a1 1 0 0 0-.8-.4H2a2 2 0 0 1-2-2V2zm7.194 2.766a1.688 1.688 0 0 0-.227-.272 1.467 1.467 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 5.734 4C4.776 4 4 4.746 4 5.667c0 .92.776 1.666 1.734 1.666.343 0 .662-.095.931-.26-.137.389-.39.804-.81 1.22a.405.405 0 0 0 .011.59c.173.16.447.155.614-.01 1.334-1.329 1.37-2.758.941-3.706a2.461 2.461 0 0 0-.227-.4zM11 7.073c-.136.389-.39.804-.81 1.22a.405.405 0 0 0 .012.59c.172.16.446.155.613-.01 1.334-1.329 1.37-2.758.942-3.706a2.466 2.466 0 0 0-.228-.4 1.686 1.686 0 0 0-.227-.273 1.466 1.466 0 0 0-.469-.324l-.008-.004A1.785 1.785 0 0 0 10.07 4c-.957 0-1.734.746-1.734 1.667 0 .92.777 1.666 1.734 1.666.343 0 .662-.095.931-.26z"/>'),Vo=d("ChatSquareText",'<path d="M14 1a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1h-2.5a2 2 0 0 0-1.6.8L8 14.333 6.1 11.8a2 2 0 0 0-1.6-.8H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5a1 1 0 0 1 .8.4l1.9 2.533a1 1 0 0 0 1.6 0l1.9-2.533a1 1 0 0 1 .8-.4H14a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M3 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3 6a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9A.5.5 0 0 1 3 6zm0 2.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>'),So=d("ChatSquareTextFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.5a1 1 0 0 0-.8.4l-1.9 2.533a1 1 0 0 1-1.6 0L5.3 12.4a1 1 0 0 0-.8-.4H2a2 2 0 0 1-2-2V2zm3.5 1a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/>'),xo=d("ChatText",'<path d="M2.678 11.894a1 1 0 0 1 .287.801 10.97 10.97 0 0 1-.398 2c1.395-.323 2.247-.697 2.634-.893a1 1 0 0 1 .71-.074A8.06 8.06 0 0 0 8 14c3.996 0 7-2.807 7-6 0-3.192-3.004-6-7-6S1 4.808 1 8c0 1.468.617 2.83 1.678 3.894zm-.493 3.905a21.682 21.682 0 0 1-.713.129c-.2.032-.352-.176-.273-.362a9.68 9.68 0 0 0 .244-.637l.003-.01c.248-.72.45-1.548.524-2.319C.743 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.52.263-1.639.742-3.468 1.105z"/><path d="M4 5.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8zm0 2.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>'),To=d("ChatTextFill",'<path d="M16 8c0 3.866-3.582 7-8 7a9.06 9.06 0 0 1-2.347-.306c-.584.296-1.925.864-4.181 1.234-.2.032-.352-.176-.273-.362.354-.836.674-1.95.77-2.966C.744 11.37 0 9.76 0 8c0-3.866 3.582-7 8-7s8 3.134 8 7zM4.5 5a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-7zm0 2.5a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-7zm0 2.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1h-4z"/>'),Po=d("Check",'<path d="M10.97 4.97a.75.75 0 0 1 1.07 1.05l-3.99 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.267.267 0 0 1 .02-.022z"/>'),Io=d("Check2",'<path d="M13.854 3.646a.5.5 0 0 1 0 .708l-7 7a.5.5 0 0 1-.708 0l-3.5-3.5a.5.5 0 1 1 .708-.708L6.5 10.293l6.646-6.647a.5.5 0 0 1 .708 0z"/>'),Eo=d("Check2All",'<path d="M12.354 4.354a.5.5 0 0 0-.708-.708L5 10.293 1.854 7.146a.5.5 0 1 0-.708.708l3.5 3.5a.5.5 0 0 0 .708 0l7-7zm-4.208 7l-.896-.897.707-.707.543.543 6.646-6.647a.5.5 0 0 1 .708.708l-7 7a.5.5 0 0 1-.708 0z"/><path d="M5.354 7.146l.896.897-.707.707-.897-.896a.5.5 0 1 1 .708-.708z"/>'),Lo=d("Check2Circle",'<path d="M2.5 8a5.5 5.5 0 0 1 8.25-4.764.5.5 0 0 0 .5-.866A6.5 6.5 0 1 0 14.5 8a.5.5 0 0 0-1 0 5.5 5.5 0 1 1-11 0z"/><path d="M15.354 3.354a.5.5 0 0 0-.708-.708L8 9.293 5.354 6.646a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0l7-7z"/>'),Bo=d("Check2Square",'<path d="M3 14.5A1.5 1.5 0 0 1 1.5 13V3A1.5 1.5 0 0 1 3 1.5h8a.5.5 0 0 1 0 1H3a.5.5 0 0 0-.5.5v10a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5V8a.5.5 0 0 1 1 0v5a1.5 1.5 0 0 1-1.5 1.5H3z"/><path d="M8.354 10.354l7-7a.5.5 0 0 0-.708-.708L8 9.293 5.354 6.646a.5.5 0 1 0-.708.708l3 3a.5.5 0 0 0 .708 0z"/>'),Ho=d("CheckAll",'<path d="M8.97 4.97a.75.75 0 0 1 1.071 1.05l-3.992 4.99a.75.75 0 0 1-1.08.02L2.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093L8.95 4.992a.252.252 0 0 1 .02-.022zm-.92 5.14l.92.92a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 1 0-1.091-1.028L9.477 9.417l-.485-.486-.943 1.179z"/>'),Fo=d("CheckCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M10.97 4.97a.235.235 0 0 0-.02.022L7.477 9.417 5.384 7.323a.75.75 0 0 0-1.06 1.06L6.97 11.03a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 0 0-1.071-1.05z"/>'),Do=d("CheckCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-3.97-3.03a.75.75 0 0 0-1.08.022L7.477 9.417 5.384 7.323a.75.75 0 0 0-1.06 1.06L6.97 11.03a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 0 0-.01-1.05z"/>'),Ro=d("CheckSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M10.97 4.97a.75.75 0 0 1 1.071 1.05l-3.992 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.235.235 0 0 1 .02-.022z"/>'),No=d("CheckSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm10.03 4.97a.75.75 0 0 1 .011 1.05l-3.992 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.75.75 0 0 1 1.08-.022z"/>'),$o=d("ChevronBarContract",'<path fill-rule="evenodd" d="M3.646 14.854a.5.5 0 0 0 .708 0L8 11.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zm0-13.708a.5.5 0 0 1 .708 0L8 4.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zM1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8z"/>'),Uo=d("ChevronBarDown",'<path fill-rule="evenodd" d="M3.646 4.146a.5.5 0 0 1 .708 0L8 7.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zM1 11.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13a.5.5 0 0 1-.5-.5z"/>'),qo=d("ChevronBarExpand",'<path fill-rule="evenodd" d="M3.646 10.146a.5.5 0 0 1 .708 0L8 13.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zm0-4.292a.5.5 0 0 0 .708 0L8 2.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zM1 8a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 8z"/>'),Wo=d("ChevronBarLeft",'<path fill-rule="evenodd" d="M11.854 3.646a.5.5 0 0 1 0 .708L8.207 8l3.647 3.646a.5.5 0 0 1-.708.708l-4-4a.5.5 0 0 1 0-.708l4-4a.5.5 0 0 1 .708 0zM4.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5z"/>'),Go=d("ChevronBarRight",'<path fill-rule="evenodd" d="M4.146 3.646a.5.5 0 0 0 0 .708L7.793 8l-3.647 3.646a.5.5 0 0 0 .708.708l4-4a.5.5 0 0 0 0-.708l-4-4a.5.5 0 0 0-.708 0zM11.5 1a.5.5 0 0 1 .5.5v13a.5.5 0 0 1-1 0v-13a.5.5 0 0 1 .5-.5z"/>'),Yo=d("ChevronBarUp",'<path fill-rule="evenodd" d="M3.646 11.854a.5.5 0 0 0 .708 0L8 8.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zM2.4 5.2c0 .22.18.4.4.4h10.4a.4.4 0 0 0 0-.8H2.8a.4.4 0 0 0-.4.4z"/>'),Ko=d("ChevronCompactDown",'<path fill-rule="evenodd" d="M1.553 6.776a.5.5 0 0 1 .67-.223L8 9.44l5.776-2.888a.5.5 0 1 1 .448.894l-6 3a.5.5 0 0 1-.448 0l-6-3a.5.5 0 0 1-.223-.67z"/>'),Qo=d("ChevronCompactLeft",'<path fill-rule="evenodd" d="M9.224 1.553a.5.5 0 0 1 .223.67L6.56 8l2.888 5.776a.5.5 0 1 1-.894.448l-3-6a.5.5 0 0 1 0-.448l3-6a.5.5 0 0 1 .67-.223z"/>'),Xo=d("ChevronCompactRight",'<path fill-rule="evenodd" d="M6.776 1.553a.5.5 0 0 1 .671.223l3 6a.5.5 0 0 1 0 .448l-3 6a.5.5 0 1 1-.894-.448L9.44 8 6.553 2.224a.5.5 0 0 1 .223-.671z"/>'),Jo=d("ChevronCompactUp",'<path fill-rule="evenodd" d="M7.776 5.553a.5.5 0 0 1 .448 0l6 3a.5.5 0 1 1-.448.894L8 6.56 2.224 9.447a.5.5 0 1 1-.448-.894l6-3z"/>'),Zo=d("ChevronContract",'<path fill-rule="evenodd" d="M3.646 13.854a.5.5 0 0 0 .708 0L8 10.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708zm0-11.708a.5.5 0 0 1 .708 0L8 5.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708z"/>'),ta=d("ChevronDoubleDown",'<path fill-rule="evenodd" d="M1.646 6.646a.5.5 0 0 1 .708 0L8 12.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/><path fill-rule="evenodd" d="M1.646 2.646a.5.5 0 0 1 .708 0L8 8.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/>'),ea=d("ChevronDoubleLeft",'<path fill-rule="evenodd" d="M8.354 1.646a.5.5 0 0 1 0 .708L2.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/><path fill-rule="evenodd" d="M12.354 1.646a.5.5 0 0 1 0 .708L6.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/>'),na=d("ChevronDoubleRight",'<path fill-rule="evenodd" d="M3.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L9.293 8 3.646 2.354a.5.5 0 0 1 0-.708z"/><path fill-rule="evenodd" d="M7.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L13.293 8 7.646 2.354a.5.5 0 0 1 0-.708z"/>'),ra=d("ChevronDoubleUp",'<path fill-rule="evenodd" d="M7.646 2.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1-.708.708L8 3.707 2.354 9.354a.5.5 0 1 1-.708-.708l6-6z"/><path fill-rule="evenodd" d="M7.646 6.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1-.708.708L8 7.707l-5.646 5.647a.5.5 0 0 1-.708-.708l6-6z"/>'),ia=d("ChevronDown",'<path fill-rule="evenodd" d="M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/>'),oa=d("ChevronExpand",'<path fill-rule="evenodd" d="M3.646 9.146a.5.5 0 0 1 .708 0L8 12.793l3.646-3.647a.5.5 0 0 1 .708.708l-4 4a.5.5 0 0 1-.708 0l-4-4a.5.5 0 0 1 0-.708zm0-2.292a.5.5 0 0 0 .708 0L8 3.207l3.646 3.647a.5.5 0 0 0 .708-.708l-4-4a.5.5 0 0 0-.708 0l-4 4a.5.5 0 0 0 0 .708z"/>'),aa=d("ChevronLeft",'<path fill-rule="evenodd" d="M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/>'),sa=d("ChevronRight",'<path fill-rule="evenodd" d="M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708z"/>'),ca=d("ChevronUp",'<path fill-rule="evenodd" d="M7.646 4.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1-.708.708L8 5.707l-5.646 5.647a.5.5 0 0 1-.708-.708l6-6z"/>'),la=d("Circle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/>'),ua=d("CircleFill",'<circle cx="8" cy="8" r="8"/>'),da=d("CircleHalf",'<path d="M8 15A7 7 0 1 0 8 1v14zm0 1A8 8 0 1 1 8 0a8 8 0 0 1 0 16z"/>'),ha=d("CircleSquare",'<path d="M0 6a6 6 0 1 1 12 0A6 6 0 0 1 0 6z"/><path d="M12.93 5h1.57a.5.5 0 0 1 .5.5v9a.5.5 0 0 1-.5.5h-9a.5.5 0 0 1-.5-.5v-1.57a6.953 6.953 0 0 1-1-.22v1.79A1.5 1.5 0 0 0 5.5 16h9a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 4h-1.79c.097.324.17.658.22 1z"/>'),fa=d("Clipboard",'<path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>'),pa=d("ClipboardCheck",'<path fill-rule="evenodd" d="M10.854 7.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 9.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>'),ma=d("ClipboardData",'<path d="M4 11a1 1 0 1 1 2 0v1a1 1 0 1 1-2 0v-1zm6-4a1 1 0 1 1 2 0v5a1 1 0 1 1-2 0V7zM7 9a1 1 0 0 1 2 0v3a1 1 0 1 1-2 0V9z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>'),ba=d("ClipboardMinus",'<path fill-rule="evenodd" d="M5.5 9.5A.5.5 0 0 1 6 9h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>'),ga=d("ClipboardPlus",'<path fill-rule="evenodd" d="M8 7a.5.5 0 0 1 .5.5V9H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V10H6a.5.5 0 0 1 0-1h1.5V7.5A.5.5 0 0 1 8 7z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>'),va=d("ClipboardX",'<path fill-rule="evenodd" d="M6.146 7.146a.5.5 0 0 1 .708 0L8 8.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 9l1.147 1.146a.5.5 0 0 1-.708.708L8 9.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 9 6.146 7.854a.5.5 0 0 1 0-.708z"/><path d="M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"/><path d="M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"/>'),wa=d("Clock",'<path d="M8 3.5a.5.5 0 0 0-1 0V9a.5.5 0 0 0 .252.434l3.5 2a.5.5 0 0 0 .496-.868L8 8.71V3.5z"/><path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm7-8A7 7 0 1 1 1 8a7 7 0 0 1 14 0z"/>'),ya=d("ClockFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8 3.5a.5.5 0 0 0-1 0V9a.5.5 0 0 0 .252.434l3.5 2a.5.5 0 0 0 .496-.868L8 8.71V3.5z"/>'),ka=d("ClockHistory",'<path d="M8.515 1.019A7 7 0 0 0 8 1V0a8 8 0 0 1 .589.022l-.074.997zm2.004.45a7.003 7.003 0 0 0-.985-.299l.219-.976c.383.086.76.2 1.126.342l-.36.933zm1.37.71a7.01 7.01 0 0 0-.439-.27l.493-.87a8.025 8.025 0 0 1 .979.654l-.615.789a6.996 6.996 0 0 0-.418-.302zm1.834 1.79a6.99 6.99 0 0 0-.653-.796l.724-.69c.27.285.52.59.747.91l-.818.576zm.744 1.352a7.08 7.08 0 0 0-.214-.468l.893-.45a7.976 7.976 0 0 1 .45 1.088l-.95.313a7.023 7.023 0 0 0-.179-.483zm.53 2.507a6.991 6.991 0 0 0-.1-1.025l.985-.17c.067.386.106.778.116 1.17l-1 .025zm-.131 1.538c.033-.17.06-.339.081-.51l.993.123a7.957 7.957 0 0 1-.23 1.155l-.964-.267c.046-.165.086-.332.12-.501zm-.952 2.379c.184-.29.346-.594.486-.908l.914.405c-.16.36-.345.706-.555 1.038l-.845-.535zm-.964 1.205c.122-.122.239-.248.35-.378l.758.653a8.073 8.073 0 0 1-.401.432l-.707-.707z"/><path d="M8 1a7 7 0 1 0 4.95 11.95l.707.707A8.001 8.001 0 1 1 8 0v1z"/><path d="M7.5 3a.5.5 0 0 1 .5.5v5.21l3.248 1.856a.5.5 0 0 1-.496.868l-3.5-2A.5.5 0 0 1 7 9V3.5a.5.5 0 0 1 .5-.5z"/>'),_a=d("Cloud",'<path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>'),Oa=d("CloudArrowDown",'<path fill-rule="evenodd" d="M7.646 10.854a.5.5 0 0 0 .708 0l2-2a.5.5 0 0 0-.708-.708L8.5 9.293V5.5a.5.5 0 0 0-1 0v3.793L6.354 8.146a.5.5 0 1 0-.708.708l2 2z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>'),za=d("CloudArrowDownFill",'<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm2.354 6.854l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5a.5.5 0 0 1 1 0v3.793l1.146-1.147a.5.5 0 0 1 .708.708z"/>'),Aa=d("CloudArrowUp",'<path fill-rule="evenodd" d="M7.646 5.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 6.707V10.5a.5.5 0 0 1-1 0V6.707L6.354 7.854a.5.5 0 1 1-.708-.708l2-2z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>'),ja=d("CloudArrowUpFill",'<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm2.354 5.146a.5.5 0 0 1-.708.708L8.5 6.707V10.5a.5.5 0 0 1-1 0V6.707L6.354 7.854a.5.5 0 1 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2z"/>'),Ma=d("CloudCheck",'<path fill-rule="evenodd" d="M10.354 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>'),Ca=d("CloudCheckFill",'<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm2.354 4.854l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>'),Va=d("CloudDownload",'<path d="M4.406 1.342A5.53 5.53 0 0 1 8 0c2.69 0 4.923 2 5.166 4.579C14.758 4.804 16 6.137 16 7.773 16 9.569 14.502 11 12.687 11H10a.5.5 0 0 1 0-1h2.688C13.979 10 15 8.988 15 7.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 2.825 10.328 1 8 1a4.53 4.53 0 0 0-2.941 1.1c-.757.652-1.153 1.438-1.153 2.055v.448l-.445.049C2.064 4.805 1 5.952 1 7.318 1 8.785 2.23 10 3.781 10H6a.5.5 0 0 1 0 1H3.781C1.708 11 0 9.366 0 7.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383z"/><path d="M7.646 15.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 14.293V5.5a.5.5 0 0 0-1 0v8.793l-2.146-2.147a.5.5 0 0 0-.708.708l3 3z"/>'),Sa=d("CloudDownloadFill",'<path fill-rule="evenodd" d="M8 0a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 4.095 0 5.555 0 7.318 0 9.366 1.708 11 3.781 11H7.5V5.5a.5.5 0 0 1 1 0V11h4.188C14.502 11 16 9.57 16 7.773c0-1.636-1.242-2.969-2.834-3.194C12.923 1.999 10.69 0 8 0zm-.354 15.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 14.293V11h-1v3.293l-2.146-2.147a.5.5 0 0 0-.708.708l3 3z"/>'),xa=d("CloudFill",'<path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383z"/>'),Ta=d("CloudMinus",'<path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>'),Pa=d("CloudMinusFill",'<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zM6 7.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>'),Ia=d("CloudPlus",'<path fill-rule="evenodd" d="M8 5.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 .5-.5z"/><path d="M4.406 3.342A5.53 5.53 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773 16 11.569 14.502 13 12.687 13H3.781C1.708 13 0 11.366 0 9.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383zm.653.757c-.757.653-1.153 1.44-1.153 2.056v.448l-.445.049C2.064 6.805 1 7.952 1 9.318 1 10.785 2.23 12 3.781 12h8.906C13.98 12 15 10.988 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3a4.53 4.53 0 0 0-2.941 1.1z"/>'),Ea=d("CloudPlusFill",'<path d="M8 2a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13h8.906C14.502 13 16 11.57 16 9.773c0-1.636-1.242-2.969-2.834-3.194C12.923 3.999 10.69 2 8 2zm.5 4v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 1 0z"/>'),La=d("CloudSlash",'<path fill-rule="evenodd" d="M3.112 5.112a3.125 3.125 0 0 0-.17.613C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13H11l-1-1H3.781C2.231 12 1 10.785 1 9.318c0-1.365 1.064-2.513 2.46-2.666l.446-.05v-.447c0-.075.006-.152.018-.231l-.812-.812zm2.55-1.45l-.725-.725A5.512 5.512 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773a3.2 3.2 0 0 1-1.516 2.711l-.733-.733C14.498 11.378 15 10.626 15 9.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 4.825 10.328 3 8 3c-.875 0-1.678.26-2.339.661z"/><path d="M13.646 14.354l-12-12 .708-.708 12 12-.707.707z"/>'),Ba=d("CloudSlashFill",'<path fill-rule="evenodd" d="M3.112 5.112a3.125 3.125 0 0 0-.17.613C1.266 6.095 0 7.555 0 9.318 0 11.366 1.708 13 3.781 13H11L3.112 5.112zm11.372 7.372L4.937 2.937A5.512 5.512 0 0 1 8 2c2.69 0 4.923 2 5.166 4.579C14.758 6.804 16 8.137 16 9.773a3.2 3.2 0 0 1-1.516 2.711zm-.838 1.87l-12-12 .708-.708 12 12-.707.707z"/>'),Ha=d("CloudUpload",'<path fill-rule="evenodd" d="M4.406 1.342A5.53 5.53 0 0 1 8 0c2.69 0 4.923 2 5.166 4.579C14.758 4.804 16 6.137 16 7.773 16 9.569 14.502 11 12.687 11H10a.5.5 0 0 1 0-1h2.688C13.979 10 15 8.988 15 7.773c0-1.216-1.02-2.228-2.313-2.228h-.5v-.5C12.188 2.825 10.328 1 8 1a4.53 4.53 0 0 0-2.941 1.1c-.757.652-1.153 1.438-1.153 2.055v.448l-.445.049C2.064 4.805 1 5.952 1 7.318 1 8.785 2.23 10 3.781 10H6a.5.5 0 0 1 0 1H3.781C1.708 11 0 9.366 0 7.318c0-1.763 1.266-3.223 2.942-3.593.143-.863.698-1.723 1.464-2.383z"/><path fill-rule="evenodd" d="M7.646 4.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V14.5a.5.5 0 0 1-1 0V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3z"/>'),Fa=d("CloudUploadFill",'<path fill-rule="evenodd" d="M8 0a5.53 5.53 0 0 0-3.594 1.342c-.766.66-1.321 1.52-1.464 2.383C1.266 4.095 0 5.555 0 7.318 0 9.366 1.708 11 3.781 11H7.5V5.707L5.354 7.854a.5.5 0 1 1-.708-.708l3-3a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 5.707V11h4.188C14.502 11 16 9.57 16 7.773c0-1.636-1.242-2.969-2.834-3.194C12.923 1.999 10.69 0 8 0zm-.5 14.5V11h1v3.5a.5.5 0 0 1-1 0z"/>'),Da=d("Code",'<path d="M5.854 4.854a.5.5 0 1 0-.708-.708l-3.5 3.5a.5.5 0 0 0 0 .708l3.5 3.5a.5.5 0 0 0 .708-.708L2.707 8l3.147-3.146zm4.292 0a.5.5 0 0 1 .708-.708l3.5 3.5a.5.5 0 0 1 0 .708l-3.5 3.5a.5.5 0 0 1-.708-.708L13.293 8l-3.147-3.146z"/>'),Ra=d("CodeSlash",'<path d="M10.478 1.647a.5.5 0 1 0-.956-.294l-4 13a.5.5 0 0 0 .956.294l4-13zM4.854 4.146a.5.5 0 0 1 0 .708L1.707 8l3.147 3.146a.5.5 0 0 1-.708.708l-3.5-3.5a.5.5 0 0 1 0-.708l3.5-3.5a.5.5 0 0 1 .708 0zm6.292 0a.5.5 0 0 0 0 .708L14.293 8l-3.147 3.146a.5.5 0 0 0 .708.708l3.5-3.5a.5.5 0 0 0 0-.708l-3.5-3.5a.5.5 0 0 0-.708 0z"/>'),Na=d("CodeSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M6.854 4.646a.5.5 0 0 1 0 .708L4.207 8l2.647 2.646a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708l3-3a.5.5 0 0 1 .708 0zm2.292 0a.5.5 0 0 0 0 .708L11.793 8l-2.647 2.646a.5.5 0 0 0 .708.708l3-3a.5.5 0 0 0 0-.708l-3-3a.5.5 0 0 0-.708 0z"/>'),$a=d("Collection",'<path d="M2.5 3.5a.5.5 0 0 1 0-1h11a.5.5 0 0 1 0 1h-11zm2-2a.5.5 0 0 1 0-1h7a.5.5 0 0 1 0 1h-7zM0 13a1.5 1.5 0 0 0 1.5 1.5h13A1.5 1.5 0 0 0 16 13V6a1.5 1.5 0 0 0-1.5-1.5h-13A1.5 1.5 0 0 0 0 6v7zm1.5.5A.5.5 0 0 1 1 13V6a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-13z"/>'),Ua=d("CollectionFill",'<path d="M0 13a1.5 1.5 0 0 0 1.5 1.5h13A1.5 1.5 0 0 0 16 13V6a1.5 1.5 0 0 0-1.5-1.5h-13A1.5 1.5 0 0 0 0 6v7zM2 3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 0-1h-11A.5.5 0 0 0 2 3zm2-2a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7A.5.5 0 0 0 4 1z"/>'),qa=d("CollectionPlay",'<path d="M2 3a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 0-1h-11A.5.5 0 0 0 2 3zm2-2a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7A.5.5 0 0 0 4 1zm2.765 5.576A.5.5 0 0 0 6 7v5a.5.5 0 0 0 .765.424l4-2.5a.5.5 0 0 0 0-.848l-4-2.5z"/><path d="M1.5 14.5A1.5 1.5 0 0 1 0 13V6a1.5 1.5 0 0 1 1.5-1.5h13A1.5 1.5 0 0 1 16 6v7a1.5 1.5 0 0 1-1.5 1.5h-13zm13-1a.5.5 0 0 0 .5-.5V6a.5.5 0 0 0-.5-.5h-13A.5.5 0 0 0 1 6v7a.5.5 0 0 0 .5.5h13z"/>'),Wa=d("CollectionPlayFill",'<path d="M2.5 3.5a.5.5 0 0 1 0-1h11a.5.5 0 0 1 0 1h-11zm2-2a.5.5 0 0 1 0-1h7a.5.5 0 0 1 0 1h-7zM0 13a1.5 1.5 0 0 0 1.5 1.5h13A1.5 1.5 0 0 0 16 13V6a1.5 1.5 0 0 0-1.5-1.5h-13A1.5 1.5 0 0 0 0 6v7zm6.258-6.437a.5.5 0 0 1 .507.013l4 2.5a.5.5 0 0 1 0 .848l-4 2.5A.5.5 0 0 1 6 12V7a.5.5 0 0 1 .258-.437z"/>'),Ga=d("Columns",'<path d="M0 2a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V2zm8.5 0v8H15V2H8.5zm0 9v3H15v-3H8.5zm-1-9H1v3h6.5V2zM1 14h6.5V6H1v8z"/>'),Ya=d("ColumnsGap",'<path d="M6 1v3H1V1h5zM1 0a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1H1zm14 12v3h-5v-3h5zm-5-1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1h-5zM6 8v7H1V8h5zM1 7a1 1 0 0 0-1 1v7a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H1zm14-6v7h-5V1h5zm-5-1a1 1 0 0 0-1 1v7a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1h-5z"/>'),Ka=d("Command",'<path d="M3.5 2A1.5 1.5 0 0 1 5 3.5V5H3.5a1.5 1.5 0 1 1 0-3zM6 5V3.5A2.5 2.5 0 1 0 3.5 6H5v4H3.5A2.5 2.5 0 1 0 6 12.5V11h4v1.5a2.5 2.5 0 1 0 2.5-2.5H11V6h1.5A2.5 2.5 0 1 0 10 3.5V5H6zm4 1v4H6V6h4zm1-1V3.5A1.5 1.5 0 1 1 12.5 5H11zm0 6h1.5a1.5 1.5 0 1 1-1.5 1.5V11zm-6 0v1.5A1.5 1.5 0 1 1 3.5 11H5z"/>'),Qa=d("Compass",'<path d="M8 16.016a7.5 7.5 0 0 0 1.962-14.74A1 1 0 0 0 9 0H7a1 1 0 0 0-.962 1.276A7.5 7.5 0 0 0 8 16.016zm6.5-7.5a6.5 6.5 0 1 1-13 0 6.5 6.5 0 0 1 13 0z"/><path d="M6.94 7.44l4.95-2.83-2.83 4.95-4.949 2.83 2.828-4.95z"/>'),Xa=d("CompassFill",'<path d="M15.5 8.516a7.5 7.5 0 1 1-9.462-7.24A1 1 0 0 1 7 0h2a1 1 0 0 1 .962 1.276 7.503 7.503 0 0 1 5.538 7.24zm-3.61-3.905L6.94 7.439 4.11 12.39l4.95-2.828 2.828-4.95z"/>'),Ja=d("Cone",'<path d="M7.03 1.88c.252-1.01 1.688-1.01 1.94 0l2.905 11.62H14a.5.5 0 0 1 0 1H2a.5.5 0 0 1 0-1h2.125L7.03 1.88z"/>'),Za=d("ConeStriped",'<path d="M9.97 4.88l.953 3.811C10.158 8.878 9.14 9 8 9c-1.14 0-2.159-.122-2.923-.309L6.03 4.88C6.635 4.957 7.3 5 8 5s1.365-.043 1.97-.12zm-.245-.978L8.97.88C8.718-.13 7.282-.13 7.03.88L6.274 3.9C6.8 3.965 7.382 4 8 4c.618 0 1.2-.036 1.725-.098zm4.396 8.613a.5.5 0 0 1 .037.96l-6 2a.5.5 0 0 1-.316 0l-6-2a.5.5 0 0 1 .037-.96l2.391-.598.565-2.257c.862.212 1.964.339 3.165.339s2.303-.127 3.165-.339l.565 2.257 2.391.598z"/>'),ts=d("Controller",'<path d="M11.5 6.027a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-1.5 1.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm2.5-.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-1.5 1.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm-6.5-3h1v1h1v1h-1v1h-1v-1h-1v-1h1v-1z"/><path d="M3.051 3.26a.5.5 0 0 1 .354-.613l1.932-.518a.5.5 0 0 1 .62.39c.655-.079 1.35-.117 2.043-.117.72 0 1.443.041 2.12.126a.5.5 0 0 1 .622-.399l1.932.518a.5.5 0 0 1 .306.729c.14.09.266.19.373.297.408.408.78 1.05 1.095 1.772.32.733.599 1.591.805 2.466.206.875.34 1.78.364 2.606.024.816-.059 1.602-.328 2.21a1.42 1.42 0 0 1-1.445.83c-.636-.067-1.115-.394-1.513-.773-.245-.232-.496-.526-.739-.808-.126-.148-.25-.292-.368-.423-.728-.804-1.597-1.527-3.224-1.527-1.627 0-2.496.723-3.224 1.527-.119.131-.242.275-.368.423-.243.282-.494.575-.739.808-.398.38-.877.706-1.513.773a1.42 1.42 0 0 1-1.445-.83c-.27-.608-.352-1.395-.329-2.21.024-.826.16-1.73.365-2.606.206-.875.486-1.733.805-2.466.315-.722.687-1.364 1.094-1.772a2.34 2.34 0 0 1 .433-.335.504.504 0 0 1-.028-.079zm2.036.412c-.877.185-1.469.443-1.733.708-.276.276-.587.783-.885 1.465a13.748 13.748 0 0 0-.748 2.295 12.351 12.351 0 0 0-.339 2.406c-.022.755.062 1.368.243 1.776a.42.42 0 0 0 .426.24c.327-.034.61-.199.929-.502.212-.202.4-.423.615-.674.133-.156.276-.323.44-.504C4.861 9.969 5.978 9.027 8 9.027s3.139.942 3.965 1.855c.164.181.307.348.44.504.214.251.403.472.615.674.318.303.601.468.929.503a.42.42 0 0 0 .426-.241c.18-.408.265-1.02.243-1.776a12.354 12.354 0 0 0-.339-2.406 13.753 13.753 0 0 0-.748-2.295c-.298-.682-.61-1.19-.885-1.465-.264-.265-.856-.523-1.733-.708-.85-.179-1.877-.27-2.913-.27-1.036 0-2.063.091-2.913.27z"/>'),es=d("Cpu",'<path d="M5 0a.5.5 0 0 1 .5.5V2h1V.5a.5.5 0 0 1 1 0V2h1V.5a.5.5 0 0 1 1 0V2h1V.5a.5.5 0 0 1 1 0V2A2.5 2.5 0 0 1 14 4.5h1.5a.5.5 0 0 1 0 1H14v1h1.5a.5.5 0 0 1 0 1H14v1h1.5a.5.5 0 0 1 0 1H14v1h1.5a.5.5 0 0 1 0 1H14a2.5 2.5 0 0 1-2.5 2.5v1.5a.5.5 0 0 1-1 0V14h-1v1.5a.5.5 0 0 1-1 0V14h-1v1.5a.5.5 0 0 1-1 0V14h-1v1.5a.5.5 0 0 1-1 0V14A2.5 2.5 0 0 1 2 11.5H.5a.5.5 0 0 1 0-1H2v-1H.5a.5.5 0 0 1 0-1H2v-1H.5a.5.5 0 0 1 0-1H2v-1H.5a.5.5 0 0 1 0-1H2A2.5 2.5 0 0 1 4.5 2V.5A.5.5 0 0 1 5 0zm-.5 3A1.5 1.5 0 0 0 3 4.5v7A1.5 1.5 0 0 0 4.5 13h7a1.5 1.5 0 0 0 1.5-1.5v-7A1.5 1.5 0 0 0 11.5 3h-7zM5 6.5A1.5 1.5 0 0 1 6.5 5h3A1.5 1.5 0 0 1 11 6.5v3A1.5 1.5 0 0 1 9.5 11h-3A1.5 1.5 0 0 1 5 9.5v-3zM6.5 6a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3z"/>'),ns=d("CpuFill",'<path d="M6.5 6a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3z"/><path d="M5.5.5a.5.5 0 0 0-1 0V2A2.5 2.5 0 0 0 2 4.5H.5a.5.5 0 0 0 0 1H2v1H.5a.5.5 0 0 0 0 1H2v1H.5a.5.5 0 0 0 0 1H2v1H.5a.5.5 0 0 0 0 1H2A2.5 2.5 0 0 0 4.5 14v1.5a.5.5 0 0 0 1 0V14h1v1.5a.5.5 0 0 0 1 0V14h1v1.5a.5.5 0 0 0 1 0V14h1v1.5a.5.5 0 0 0 1 0V14a2.5 2.5 0 0 0 2.5-2.5h1.5a.5.5 0 0 0 0-1H14v-1h1.5a.5.5 0 0 0 0-1H14v-1h1.5a.5.5 0 0 0 0-1H14v-1h1.5a.5.5 0 0 0 0-1H14A2.5 2.5 0 0 0 11.5 2V.5a.5.5 0 0 0-1 0V2h-1V.5a.5.5 0 0 0-1 0V2h-1V.5a.5.5 0 0 0-1 0V2h-1V.5zm1 4.5h3A1.5 1.5 0 0 1 11 6.5v3A1.5 1.5 0 0 1 9.5 11h-3A1.5 1.5 0 0 1 5 9.5v-3A1.5 1.5 0 0 1 6.5 5z"/>'),rs=d("CreditCard",'<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm2-1a1 1 0 0 0-1 1v1h14V4a1 1 0 0 0-1-1H2zm13 4H1v5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V7z"/><path d="M2 10a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1v-1z"/>'),is=d("CreditCard2Back",'<path d="M11 5.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-1z"/><path d="M2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm13 2v5H1V4a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zm-1 9H2a1 1 0 0 1-1-1v-1h14v1a1 1 0 0 1-1 1z"/>'),os=d("CreditCard2BackFill",'<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5H0V4zm11.5 1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-2zM0 11v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1H0z"/>'),as=d("CreditCard2Front",'<path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/><path d="M2 5.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-1zm0 3a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm3 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5z"/>'),ss=d("CreditCard2FrontFill",'<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm2.5 1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-2zm0 3a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm3 0a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm3 0a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm3 0a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/>'),cs=d("CreditCardFill",'<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1H0V4zm0 3v5a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7H0zm3 2h1a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1v-1a1 1 0 0 1 1-1z"/>'),ls=d("Crop",'<path d="M3.5.5A.5.5 0 0 1 4 1v13h13a.5.5 0 0 1 0 1h-2v2a.5.5 0 0 1-1 0v-2H3.5a.5.5 0 0 1-.5-.5V4H1a.5.5 0 0 1 0-1h2V1a.5.5 0 0 1 .5-.5zm2.5 3a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4H6.5a.5.5 0 0 1-.5-.5z"/>'),us=d("Cup",'<path d="M1 2a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v1h.5A1.5 1.5 0 0 1 16 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-.55a2.5 2.5 0 0 1-2.45 2h-8A2.5 2.5 0 0 1 1 12.5V2zm13 10h.5a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5H14v8zM13 2H2v10.5A1.5 1.5 0 0 0 3.5 14h8a1.5 1.5 0 0 0 1.5-1.5V2z"/>'),ds=d("CupFill",'<path d="M1 2a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v1h.5A1.5 1.5 0 0 1 16 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-.55a2.5 2.5 0 0 1-2.45 2h-8A2.5 2.5 0 0 1 1 12.5V2zm13 10h.5a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.5-.5H14v8z"/>'),hs=d("CupStraw",'<path d="M13.964 1.18a.5.5 0 0 1-.278.65l-2.255.902-.462 2.08c.375.096.714.216.971.368.228.135.56.396.56.82 0 .046-.004.09-.011.132l-.955 9.068a1.28 1.28 0 0 1-.524.93c-.488.34-1.494.87-3.01.87-1.516 0-2.522-.53-3.01-.87a1.28 1.28 0 0 1-.524-.93L3.51 6.132A.78.78 0 0 1 3.5 6c0-.424.332-.685.56-.82.262-.154.607-.276.99-.372C5.824 4.614 6.867 4.5 8 4.5c.712 0 1.389.045 1.985.127l.527-2.37a.5.5 0 0 1 .302-.355l2.5-1a.5.5 0 0 1 .65.279zM9.768 5.608A13.991 13.991 0 0 0 8 5.5c-1.076 0-2.033.11-2.707.278A3.284 3.284 0 0 0 4.645 6c.146.073.362.15.648.222C5.967 6.39 6.924 6.5 8 6.5c.571 0 1.109-.03 1.588-.085l.18-.808zm.292 1.756C9.445 7.45 8.742 7.5 8 7.5c-1.133 0-2.176-.114-2.95-.308a5.51 5.51 0 0 1-.435-.127l.845 8.03c.013.121.06.186.102.215.357.249 1.167.69 2.438.69 1.27 0 2.08-.441 2.438-.69.041-.029.09-.094.102-.214l.845-8.03a5.513 5.513 0 0 1-.435.126 8.88 8.88 0 0 1-.89.17zm-5.593-1.48s.003.002.005.006l-.005-.006zm7.066 0l-.005.006a.026.026 0 0 1 .005-.006zM11.354 6a3.174 3.174 0 0 0-.604-.21l-.099.445.055-.013c.286-.072.502-.149.648-.222z"/>'),fs=d("Cursor",'<path d="M14.082 2.182a.5.5 0 0 1 .103.557L8.528 15.467a.5.5 0 0 1-.917-.007L5.57 10.694.803 8.652a.5.5 0 0 1-.006-.916l12.728-5.657a.5.5 0 0 1 .556.103zM2.25 8.184l3.897 1.67a.5.5 0 0 1 .262.263l1.67 3.897L12.743 3.52 2.25 8.184z"/>'),ps=d("CursorFill",'<path d="M14.082 2.182a.5.5 0 0 1 .103.557L8.528 15.467a.5.5 0 0 1-.917-.007L5.57 10.694.803 8.652a.5.5 0 0 1-.006-.916l12.728-5.657a.5.5 0 0 1 .556.103z"/>'),ms=d("CursorText",'<path d="M5 2a.5.5 0 0 1 .5-.5c.862 0 1.573.287 2.06.566.174.099.321.198.44.286.119-.088.266-.187.44-.286A4.165 4.165 0 0 1 10.5 1.5a.5.5 0 0 1 0 1c-.638 0-1.177.213-1.564.434a3.49 3.49 0 0 0-.436.294V7.5H9a.5.5 0 0 1 0 1h-.5v4.272c.1.08.248.187.436.294.387.221.926.434 1.564.434a.5.5 0 0 1 0 1 4.165 4.165 0 0 1-2.06-.566A4.561 4.561 0 0 1 8 13.65a4.561 4.561 0 0 1-.44.285 4.165 4.165 0 0 1-2.06.566.5.5 0 0 1 0-1c.638 0 1.177-.213 1.564-.434.188-.107.335-.214.436-.294V8.5H7a.5.5 0 0 1 0-1h.5V3.228a3.49 3.49 0 0 0-.436-.294A3.166 3.166 0 0 0 5.5 2.5.5.5 0 0 1 5 2zm3.352 1.355zm-.704 9.29z"/>'),bs=d("Dash",'<path d="M4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8z"/>'),gs=d("DashCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8z"/>'),vs=d("DashCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.5 7.5a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-7z"/>'),ws=d("DashSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M4 8a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7A.5.5 0 0 1 4 8z"/>'),ys=d("DashSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm2.5 7.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1z"/>'),ks=d("Diagram2",'<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H11a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 5 7h2.5V6A1.5 1.5 0 0 1 6 4.5v-1zM8.5 5a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1zM3 11.5A1.5 1.5 0 0 1 4.5 10h1A1.5 1.5 0 0 1 7 11.5v1A1.5 1.5 0 0 1 5.5 14h-1A1.5 1.5 0 0 1 3 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm4.5.5a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1A1.5 1.5 0 0 1 9 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>'),_s=d("Diagram2Fill",'<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H11a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 5 7h2.5V6A1.5 1.5 0 0 1 6 4.5v-1zm-3 8A1.5 1.5 0 0 1 4.5 10h1A1.5 1.5 0 0 1 7 11.5v1A1.5 1.5 0 0 1 5.5 14h-1A1.5 1.5 0 0 1 3 12.5v-1zm6 0a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1A1.5 1.5 0 0 1 9 12.5v-1z"/>'),Os=d("Diagram3",'<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H14a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 2 7h5.5V6A1.5 1.5 0 0 1 6 4.5v-1zM8.5 5a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1zM0 11.5A1.5 1.5 0 0 1 1.5 10h1A1.5 1.5 0 0 1 4 11.5v1A1.5 1.5 0 0 1 2.5 14h-1A1.5 1.5 0 0 1 0 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm4.5.5A1.5 1.5 0 0 1 7.5 10h1a1.5 1.5 0 0 1 1.5 1.5v1A1.5 1.5 0 0 1 8.5 14h-1A1.5 1.5 0 0 1 6 12.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zm4.5.5a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5v-1zm1.5-.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>'),zs=d("Diagram3Fill",'<path fill-rule="evenodd" d="M6 3.5A1.5 1.5 0 0 1 7.5 2h1A1.5 1.5 0 0 1 10 3.5v1A1.5 1.5 0 0 1 8.5 6v1H14a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0V8h-5v.5a.5.5 0 0 1-1 0v-1A.5.5 0 0 1 2 7h5.5V6A1.5 1.5 0 0 1 6 4.5v-1zm-6 8A1.5 1.5 0 0 1 1.5 10h1A1.5 1.5 0 0 1 4 11.5v1A1.5 1.5 0 0 1 2.5 14h-1A1.5 1.5 0 0 1 0 12.5v-1zm6 0A1.5 1.5 0 0 1 7.5 10h1a1.5 1.5 0 0 1 1.5 1.5v1A1.5 1.5 0 0 1 8.5 14h-1A1.5 1.5 0 0 1 6 12.5v-1zm6 0a1.5 1.5 0 0 1 1.5-1.5h1a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1-1.5 1.5h-1a1.5 1.5 0 0 1-1.5-1.5v-1z"/>'),As=d("Diamond",'<path d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435zm1.4.7a.495.495 0 0 0-.7 0L1.134 7.65a.495.495 0 0 0 0 .7l6.516 6.516a.495.495 0 0 0 .7 0l6.516-6.516a.495.495 0 0 0 0-.7L8.35 1.134z"/>'),js=d("DiamondFill",'<path fill-rule="evenodd" d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435z"/>'),Ms=d("DiamondHalf",'<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L.436 6.95c-.58.58-.58 1.519 0 2.098l6.516 6.516c.58.58 1.519.58 2.098 0l6.516-6.516c.58-.58.58-1.519 0-2.098L9.05.435zM8 .989c.127 0 .253.049.35.145l6.516 6.516a.495.495 0 0 1 0 .7L8.35 14.866a.493.493 0 0 1-.35.145V.989z"/>'),Cs=d("Dice1",'<circle cx="8" cy="8" r="1.5"/><path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/>'),Vs=d("Dice1Fill",'<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm5 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),Ss=d("Dice2",'<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),xs=d("Dice2Fill",'<path d="M0 3a3 3 0 0 1 3-3h10a3 3 0 0 1 3 3v10a3 3 0 0 1-3 3H3a3 3 0 0 1-3-3V3zm5.5 1a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0zm6.5 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/>'),Ts=d("Dice3",'<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-4-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),Ps=d("Dice3Fill",'<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm2.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM8 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),Is=d("Dice4",'<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),Es=d("Dice4Fill",'<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm1 5.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm8 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm1.5 6.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM4 13.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),Ls=d("Dice5",'<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm4-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),Bs=d("Dice5Fill",'<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm2.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM12 13.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zM5.5 12a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM8 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),Hs=d("Dice6",'<path d="M13 1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h10zM3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3z"/><path d="M5.5 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm8 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 8a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-8 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),Fs=d("Dice6Fill",'<path d="M3 0a3 3 0 0 0-3 3v10a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V3a3 3 0 0 0-3-3H3zm1 5.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm8 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm1.5 6.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM12 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zM5.5 12a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM4 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),Ds=d("Disc",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0zM8 4a4 4 0 0 0-4 4 .5.5 0 0 1-1 0 5 5 0 0 1 5-5 .5.5 0 0 1 0 1zm4.5 3.5a.5.5 0 0 1 .5.5 5 5 0 0 1-5 5 .5.5 0 0 1 0-1 4 4 0 0 0 4-4 .5.5 0 0 1 .5-.5z"/>'),Rs=d("DiscFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-6 0a2 2 0 1 0-4 0 2 2 0 0 0 4 0zM4 8a4 4 0 0 1 4-4 .5.5 0 0 0 0-1 5 5 0 0 0-5 5 .5.5 0 0 0 1 0zm9 0a.5.5 0 1 0-1 0 4 4 0 0 1-4 4 .5.5 0 0 0 0 1 5 5 0 0 0 5-5z"/>'),Ns=d("Discord",'<path d="M6.552 6.712c-.456 0-.816.4-.816.888s.368.888.816.888c.456 0 .816-.4.816-.888.008-.488-.36-.888-.816-.888zm2.92 0c-.456 0-.816.4-.816.888s.368.888.816.888c.456 0 .816-.4.816-.888s-.36-.888-.816-.888z"/><path d="M13.36 0H2.64C1.736 0 1 .736 1 1.648v10.816c0 .912.736 1.648 1.64 1.648h9.072l-.424-1.48 1.024.952.968.896L15 16V1.648C15 .736 14.264 0 13.36 0zm-3.088 10.448s-.288-.344-.528-.648c1.048-.296 1.448-.952 1.448-.952-.328.216-.64.368-.92.472-.4.168-.784.28-1.16.344a5.604 5.604 0 0 1-2.072-.008 6.716 6.716 0 0 1-1.176-.344 4.688 4.688 0 0 1-.584-.272c-.024-.016-.048-.024-.072-.04-.016-.008-.024-.016-.032-.024-.144-.08-.224-.136-.224-.136s.384.64 1.4.944c-.24.304-.536.664-.536.664-1.768-.056-2.44-1.216-2.44-1.216 0-2.576 1.152-4.664 1.152-4.664 1.152-.864 2.248-.84 2.248-.84l.08.096c-1.44.416-2.104 1.048-2.104 1.048s.176-.096.472-.232c.856-.376 1.536-.48 1.816-.504.048-.008.088-.016.136-.016a6.521 6.521 0 0 1 4.024.752s-.632-.6-1.992-1.016l.112-.128s1.096-.024 2.248.84c0 0 1.152 2.088 1.152 4.664 0 0-.68 1.16-2.448 1.216z"/>'),$s=d("Display",'<path d="M0 4s0-2 2-2h12s2 0 2 2v6s0 2-2 2h-4c0 .667.083 1.167.25 1.5H11a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1h.75c.167-.333.25-.833.25-1.5H2s-2 0-2-2V4zm1.398-.855a.758.758 0 0 0-.254.302A1.46 1.46 0 0 0 1 4.01V10c0 .325.078.502.145.602.07.105.17.188.302.254a1.464 1.464 0 0 0 .538.143L2.01 11H14c.325 0 .502-.078.602-.145a.758.758 0 0 0 .254-.302 1.464 1.464 0 0 0 .143-.538L15 9.99V4c0-.325-.078-.502-.145-.602a.757.757 0 0 0-.302-.254A1.46 1.46 0 0 0 13.99 3H2c-.325 0-.502.078-.602.145z"/>'),Us=d("DisplayFill",'<path d="M6 12c0 .667-.083 1.167-.25 1.5H5a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1h-.75c-.167-.333-.25-.833-.25-1.5h4c2 0 2-2 2-2V4c0-2-2-2-2-2H2C0 2 0 4 0 4v6c0 2 2 2 2 2h4z"/>'),qs=d("DistributeHorizontal",'<path fill-rule="evenodd" d="M14.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5zm-13 0a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 1 0v-13a.5.5 0 0 0-.5-.5z"/><path d="M6 13a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v10z"/>'),Ws=d("DistributeVertical",'<path fill-rule="evenodd" d="M1 1.5a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 0-1h-13a.5.5 0 0 0-.5.5zm0 13a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 0-1h-13a.5.5 0 0 0-.5.5z"/><path d="M2 7a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V7z"/>'),Gs=d("DoorClosed",'<path d="M3 2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v13h1.5a.5.5 0 0 1 0 1h-13a.5.5 0 0 1 0-1H3V2zm1 13h8V2H4v13z"/><path d="M9 9a1 1 0 1 0 2 0 1 1 0 0 0-2 0z"/>'),Ys=d("DoorClosedFill",'<path d="M12 1a1 1 0 0 1 1 1v13h1.5a.5.5 0 0 1 0 1h-13a.5.5 0 0 1 0-1H3V2a1 1 0 0 1 1-1h8zm-2 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),Ks=d("DoorOpen",'<path d="M8.5 10c-.276 0-.5-.448-.5-1s.224-1 .5-1 .5.448.5 1-.224 1-.5 1z"/><path d="M10.828.122A.5.5 0 0 1 11 .5V1h.5A1.5 1.5 0 0 1 13 2.5V15h1.5a.5.5 0 0 1 0 1h-13a.5.5 0 0 1 0-1H3V1.5a.5.5 0 0 1 .43-.495l7-1a.5.5 0 0 1 .398.117zM11.5 2H11v13h1V2.5a.5.5 0 0 0-.5-.5zM4 1.934V15h6V1.077l-6 .857z"/>'),Qs=d("DoorOpenFill",'<path d="M1.5 15a.5.5 0 0 0 0 1h13a.5.5 0 0 0 0-1H13V2.5A1.5 1.5 0 0 0 11.5 1H11V.5a.5.5 0 0 0-.57-.495l-7 1A.5.5 0 0 0 3 1.5V15H1.5zM11 2h.5a.5.5 0 0 1 .5.5V15h-1V2zm-2.5 8c-.276 0-.5-.448-.5-1s.224-1 .5-1 .5.448.5 1-.224 1-.5 1z"/>'),Xs=d("Dot",'<path d="M8 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/>'),Js=d("Download",'<path d="M.5 9.9a.5.5 0 0 1 .5.5v2.5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0v2.5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5z"/><path d="M7.646 11.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V1.5a.5.5 0 0 0-1 0v8.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3z"/>'),Zs=d("Droplet",'<path fill-rule="evenodd" d="M7.21.8C7.69.295 8 0 8 0c.109.363.234.708.371 1.038.812 1.946 2.073 3.35 3.197 4.6C12.878 7.096 14 8.345 14 10a6 6 0 0 1-12 0C2 6.668 5.58 2.517 7.21.8zm.413 1.021A31.25 31.25 0 0 0 5.794 3.99c-.726.95-1.436 2.008-1.96 3.07C3.304 8.133 3 9.138 3 10a5 5 0 0 0 10 0c0-1.201-.796-2.157-2.181-3.7l-.03-.032C9.75 5.11 8.5 3.72 7.623 1.82z"/><path fill-rule="evenodd" d="M4.553 7.776c.82-1.641 1.717-2.753 2.093-3.13l.708.708c-.29.29-1.128 1.311-1.907 2.87l-.894-.448z"/>'),tc=d("DropletFill",'<path fill-rule="evenodd" d="M8 16a6 6 0 0 0 6-6c0-1.655-1.122-2.904-2.432-4.362C10.254 4.176 8.75 2.503 8 0c0 0-6 5.686-6 10a6 6 0 0 0 6 6zM6.646 4.646c-.376.377-1.272 1.489-2.093 3.13l.894.448c.78-1.559 1.616-2.58 1.907-2.87l-.708-.708z"/>'),ec=d("DropletHalf",'<path fill-rule="evenodd" d="M7.21.8C7.69.295 8 0 8 0c.109.363.234.708.371 1.038.812 1.946 2.073 3.35 3.197 4.6C12.878 7.096 14 8.345 14 10a6 6 0 0 1-12 0C2 6.668 5.58 2.517 7.21.8zm.413 1.021A31.25 31.25 0 0 0 5.794 3.99c-.726.95-1.436 2.008-1.96 3.07C3.304 8.133 3 9.138 3 10c0 0 2.5 1.5 5 .5s5-.5 5-.5c0-1.201-.796-2.157-2.181-3.7l-.03-.032C9.75 5.11 8.5 3.72 7.623 1.82z"/><path fill-rule="evenodd" d="M4.553 7.776c.82-1.641 1.717-2.753 2.093-3.13l.708.708c-.29.29-1.128 1.311-1.907 2.87l-.894-.448z"/>'),nc=d("Earbuds",'<path fill-rule="evenodd" d="M6.825 4.138c.596 2.141-.36 3.593-2.389 4.117a4.432 4.432 0 0 1-2.018.054c-.048-.01.9 2.778 1.522 4.61l.41 1.205a.52.52 0 0 1-.346.659l-.593.19a.548.548 0 0 1-.69-.34L.184 6.99c-.696-2.137.662-4.309 2.564-4.8 2.029-.523 3.402 0 4.076 1.948zm-.868 2.221c.43-.112.561-.993.292-1.969-.269-.975-.836-1.675-1.266-1.563-.43.112-.561.994-.292 1.969.269.975.836 1.675 1.266 1.563zm3.218-2.221c-.596 2.141.36 3.593 2.389 4.117a4.434 4.434 0 0 0 2.018.054c.048-.01-.9 2.778-1.522 4.61l-.41 1.205a.52.52 0 0 0 .346.659l.593.19c.289.092.6-.06.69-.34l2.536-7.643c.696-2.137-.662-4.309-2.564-4.8-2.029-.523-3.402 0-4.076 1.948zm.868 2.221c-.43-.112-.561-.993-.292-1.969.269-.975.836-1.675 1.266-1.563.43.112.561.994.292 1.969-.269.975-.836 1.675-1.266 1.563z"/>'),rc=d("Easel",'<path d="M8 0a.5.5 0 0 1 .473.337L9.046 2H14a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1h-1.85l1.323 3.837a.5.5 0 1 1-.946.326L11.092 11H8.5v3a.5.5 0 0 1-1 0v-3H4.908l-1.435 4.163a.5.5 0 1 1-.946-.326L3.85 11H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h4.954L7.527.337A.5.5 0 0 1 8 0zM2 3v7h12V3H2z"/>'),ic=d("EaselFill",'<path d="M8.473.337a.5.5 0 0 0-.946 0L6.954 2H2a1 1 0 0 0-1 1v7a1 1 0 0 0 1 1h1.85l-1.323 3.837a.5.5 0 1 0 .946.326L4.908 11H7.5v2.5a.5.5 0 0 0 1 0V11h2.592l1.435 4.163a.5.5 0 0 0 .946-.326L12.15 11H14a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H9.046L8.473.337z"/>'),oc=d("Egg",'<path d="M8 15a5 5 0 0 1-5-5c0-1.956.69-4.286 1.742-6.12.524-.913 1.112-1.658 1.704-2.164C7.044 1.206 7.572 1 8 1c.428 0 .956.206 1.554.716.592.506 1.18 1.251 1.704 2.164C12.31 5.714 13 8.044 13 10a5 5 0 0 1-5 5zm0 1a6 6 0 0 0 6-6c0-4.314-3-10-6-10S2 5.686 2 10a6 6 0 0 0 6 6z"/>'),ac=d("EggFill",'<path d="M14 10a6 6 0 0 1-12 0C2 5.686 5 0 8 0s6 5.686 6 10z"/>'),sc=d("EggFried",'<path d="M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path d="M13.997 5.17a5 5 0 0 0-8.101-4.09A5 5 0 0 0 1.28 9.342a5 5 0 0 0 8.336 5.109 3.5 3.5 0 0 0 5.201-4.065 3.001 3.001 0 0 0-.822-5.216zm-1-.034a1 1 0 0 0 .668.977 2.001 2.001 0 0 1 .547 3.478 1 1 0 0 0-.341 1.113 2.5 2.5 0 0 1-3.715 2.905 1 1 0 0 0-1.262.152 4 4 0 0 1-6.67-4.087 1 1 0 0 0-.2-1 4 4 0 0 1 3.693-6.61 1 1 0 0 0 .8-.2 4 4 0 0 1 6.48 3.273z"/>'),cc=d("Eject",'<path d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H1.656C.78 9.5.326 8.455.926 7.816L7.27 1.047zM14.346 8.5L8 1.731 1.654 8.5h12.692zM.5 11.5a1 1 0 0 1 1-1h13a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-13a1 1 0 0 1-1-1v-1zm14 0h-13v1h13v-1z"/>'),lc=d("EjectFill",'<path d="M7.27 1.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H1.656C.78 9.5.326 8.455.926 7.816L7.27 1.047zM.5 11.5a1 1 0 0 1 1-1h13a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1h-13a1 1 0 0 1-1-1v-1z"/>'),uc=d("EmojiAngry",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 12.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 10.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 9.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zm6.991-8.38a.5.5 0 1 1 .448.894l-1.009.504c.176.27.285.64.285 1.049 0 .828-.448 1.5-1 1.5s-1-.672-1-1.5c0-.247.04-.48.11-.686a.502.502 0 0 1 .166-.761l2-1zm-6.552 0a.5.5 0 0 0-.448.894l1.009.504A1.94 1.94 0 0 0 5 6.5C5 7.328 5.448 8 6 8s1-.672 1-1.5c0-.247-.04-.48-.11-.686a.502.502 0 0 0-.166-.761l-2-1z"/>'),dc=d("EmojiAngryFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM4.053 4.276a.5.5 0 0 1 .67-.223l2 1a.5.5 0 0 1 .166.76c.071.206.111.44.111.687C7 7.328 6.552 8 6 8s-1-.672-1-1.5c0-.408.109-.778.285-1.049l-1.009-.504a.5.5 0 0 1-.223-.67zm.232 8.157a.5.5 0 0 1-.183-.683A4.498 4.498 0 0 1 8 9.5a4.5 4.5 0 0 1 3.898 2.25.5.5 0 1 1-.866.5A3.498 3.498 0 0 0 8 10.5a3.498 3.498 0 0 0-3.032 1.75.5.5 0 0 1-.683.183zM10 8c-.552 0-1-.672-1-1.5 0-.247.04-.48.11-.686a.502.502 0 0 1 .166-.761l2-1a.5.5 0 1 1 .448.894l-1.009.504c.176.27.285.64.285 1.049 0 .828-.448 1.5-1 1.5z"/>'),hc=d("EmojiDizzy",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M9.146 5.146a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708.708l-.647.646.647.646a.5.5 0 0 1-.708.708l-.646-.647-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zm-5 0a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 1 1 .708.708l-.647.646.647.646a.5.5 0 1 1-.708.708L5.5 7.207l-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zM10 11a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>'),fc=d("EmojiDizzyFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM4.146 5.146a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 1 1 .708.708l-.647.646.647.646a.5.5 0 1 1-.708.708L5.5 7.207l-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zm5 0a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708.708l-.647.646.647.646a.5.5 0 0 1-.708.708l-.646-.647-.646.647a.5.5 0 1 1-.708-.708l.647-.646-.647-.646a.5.5 0 0 1 0-.708zM8 13a2 2 0 1 1 0-4 2 2 0 0 1 0 4z"/>'),pc=d("EmojiExpressionless",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4 10.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm5 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>'),mc=d("EmojiExpressionlessFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM4.5 6h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1zm5 0h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1zm-5 4h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1z"/>'),bc=d("EmojiFrown",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 12.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 10.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 9.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm4 0c0 .828-.448 1.5-1 1.5s-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5z"/>'),gc=d("EmojiFrownFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm-2.715 5.933a.5.5 0 0 1-.183-.683A4.498 4.498 0 0 1 8 9.5a4.5 4.5 0 0 1 3.898 2.25.5.5 0 0 1-.866.5A3.498 3.498 0 0 0 8 10.5a3.498 3.498 0 0 0-3.032 1.75.5.5 0 0 1-.683.183zM10 8c-.552 0-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5S10.552 8 10 8z"/>'),vc=d("EmojiHeartEyes",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11.315 10.014a.5.5 0 0 1 .548.736A4.498 4.498 0 0 1 7.965 13a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .548-.736h.005l.017.005.067.015.252.055c.215.046.515.108.857.169.693.124 1.522.242 2.152.242.63 0 1.46-.118 2.152-.242a26.58 26.58 0 0 0 1.109-.224l.067-.015.017-.004.005-.002zM4.756 4.566c.763-1.424 4.02-.12.952 3.434-4.496-1.596-2.35-4.298-.952-3.434zm6.488 0c1.398-.864 3.544 1.838-.952 3.434-3.067-3.554.19-4.858.952-3.434z"/>'),wc=d("EmojiHeartEyesFill",'<path d="M8 0a8 8 0 1 0 0 16A8 8 0 0 0 8 0zM4.756 4.566c.763-1.424 4.02-.12.952 3.434-4.496-1.596-2.35-4.298-.952-3.434zm6.559 5.448a.5.5 0 0 1 .548.736A4.498 4.498 0 0 1 7.965 13a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .548-.736h.005l.017.005.067.015.252.055c.215.046.515.108.857.169.693.124 1.522.242 2.152.242.63 0 1.46-.118 2.152-.242a26.58 26.58 0 0 0 1.109-.224l.067-.015.017-.004.005-.002zm-.07-5.448c1.397-.864 3.543 1.838-.953 3.434-3.067-3.554.19-4.858.952-3.434z"/>'),yc=d("EmojiLaughing",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M12.331 9.5a1 1 0 0 1 0 1A4.998 4.998 0 0 1 8 13a4.998 4.998 0 0 1-4.33-2.5A1 1 0 0 1 4.535 9h6.93a1 1 0 0 1 .866.5zM7 6.5c0 .828-.448 0-1 0s-1 .828-1 0S5.448 5 6 5s1 .672 1 1.5zm4 0c0 .828-.448 0-1 0s-1 .828-1 0S9.448 5 10 5s1 .672 1 1.5z"/>'),kc=d("EmojiLaughingFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5c0 .501-.164.396-.415.235C6.42 6.629 6.218 6.5 6 6.5c-.218 0-.42.13-.585.235C5.164 6.896 5 7 5 6.5 5 5.672 5.448 5 6 5s1 .672 1 1.5zm5.331 3a1 1 0 0 1 0 1A4.998 4.998 0 0 1 8 13a4.998 4.998 0 0 1-4.33-2.5A1 1 0 0 1 4.535 9h6.93a1 1 0 0 1 .866.5zm-1.746-2.765C10.42 6.629 10.218 6.5 10 6.5c-.218 0-.42.13-.585.235C9.164 6.896 9 7 9 6.5c0-.828.448-1.5 1-1.5s1 .672 1 1.5c0 .501-.164.396-.415.235z"/>'),_c=d("EmojiNeutral",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4 10.5a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7a.5.5 0 0 0-.5.5zm3-4C7 5.672 6.552 5 6 5s-1 .672-1 1.5S5.448 8 6 8s1-.672 1-1.5zm4 0c0-.828-.448-1.5-1-1.5s-1 .672-1 1.5S9.448 8 10 8s1-.672 1-1.5z"/>'),Oc=d("EmojiNeutralFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm-3 4a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM10 8c-.552 0-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5S10.552 8 10 8z"/>'),zc=d("EmojiSmile",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 9.567a.5.5 0 0 1 .683.183A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .183-.683zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm4 0c0 .828-.448 1.5-1 1.5s-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5z"/>'),Ac=d("EmojiSmileFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zM4.285 9.567a.5.5 0 0 1 .683.183A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .183-.683zM10 8c-.552 0-1-.672-1-1.5S9.448 5 10 5s1 .672 1 1.5S10.552 8 10 8z"/>'),jc=d("EmojiSmileUpsideDown",'<path d="M8 1a7 7 0 1 0 0 14A7 7 0 0 0 8 1zm0-1a8 8 0 1 1 0 16A8 8 0 0 1 8 0z"/><path d="M4.285 6.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 4.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 3.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zM7 9.5C7 8.672 6.552 8 6 8s-1 .672-1 1.5.448 1.5 1 1.5 1-.672 1-1.5zm4 0c0-.828-.448-1.5-1-1.5s-1 .672-1 1.5.448 1.5 1 1.5 1-.672 1-1.5z"/>'),Mc=d("EmojiSmileUpsideDownFill",'<path d="M8 0a8 8 0 1 1 0 16A8 8 0 0 1 8 0zM7 9.5C7 8.672 6.552 8 6 8s-1 .672-1 1.5.448 1.5 1 1.5 1-.672 1-1.5zM4.285 6.433a.5.5 0 0 0 .683-.183A3.498 3.498 0 0 1 8 4.5c1.295 0 2.426.703 3.032 1.75a.5.5 0 0 0 .866-.5A4.498 4.498 0 0 0 8 3.5a4.5 4.5 0 0 0-3.898 2.25.5.5 0 0 0 .183.683zM10 8c-.552 0-1 .672-1 1.5s.448 1.5 1 1.5 1-.672 1-1.5S10.552 8 10 8z"/>'),Cc=d("EmojiSunglasses",'<path d="M4.968 9.75a.5.5 0 1 0-.866.5A4.498 4.498 0 0 0 8 12.5a4.5 4.5 0 0 0 3.898-2.25.5.5 0 1 0-.866-.5A3.498 3.498 0 0 1 8 11.5a3.498 3.498 0 0 1-3.032-1.75zM7 5.116V5a1 1 0 0 0-1-1H3.28a1 1 0 0 0-.97 1.243l.311 1.242A2 2 0 0 0 4.561 8H5a2 2 0 0 0 1.994-1.839A2.99 2.99 0 0 1 8 6c.393 0 .74.064 1.006.161A2 2 0 0 0 11 8h.438a2 2 0 0 0 1.94-1.515l.311-1.242A1 1 0 0 0 12.72 4H10a1 1 0 0 0-1 1v.116A4.22 4.22 0 0 0 8 5c-.35 0-.69.04-1 .116z"/><path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-1 0A7 7 0 1 0 1 8a7 7 0 0 0 14 0z"/>'),Vc=d("EmojiSunglassesFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM2.31 5.243A1 1 0 0 1 3.28 4H6a1 1 0 0 1 1 1v.116A4.22 4.22 0 0 1 8 5c.35 0 .69.04 1 .116V5a1 1 0 0 1 1-1h2.72a1 1 0 0 1 .97 1.243l-.311 1.242A2 2 0 0 1 11.439 8H11a2 2 0 0 1-1.994-1.839A2.99 2.99 0 0 0 8 6c-.393 0-.74.064-1.006.161A2 2 0 0 1 5 8h-.438a2 2 0 0 1-1.94-1.515L2.31 5.243zM4.969 9.75A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .866-.5z"/>'),Sc=d("EmojiWink",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.285 9.567a.5.5 0 0 1 .683.183A3.498 3.498 0 0 0 8 11.5a3.498 3.498 0 0 0 3.032-1.75.5.5 0 1 1 .866.5A4.498 4.498 0 0 1 8 12.5a4.498 4.498 0 0 1-3.898-2.25.5.5 0 0 1 .183-.683zM7 6.5C7 7.328 6.552 8 6 8s-1-.672-1-1.5S5.448 5 6 5s1 .672 1 1.5zm1.757-.437a.5.5 0 0 1 .68.194.934.934 0 0 0 .813.493c.339 0 .645-.19.813-.493a.5.5 0 1 1 .874.486A1.934 1.934 0 0 1 10.25 7.75c-.73 0-1.356-.412-1.687-1.007a.5.5 0 0 1 .194-.68z"/>'),xc=d("EmojiWinkFill",'<path d="M8 0a8 8 0 1 1 0 16A8 8 0 0 1 8 0zM7 6.5C7 5.672 6.552 5 6 5s-1 .672-1 1.5S5.448 8 6 8s1-.672 1-1.5zM4.285 9.567a.5.5 0 0 0-.183.683A4.498 4.498 0 0 0 8 12.5a4.5 4.5 0 0 0 3.898-2.25.5.5 0 1 0-.866-.5A3.498 3.498 0 0 1 8 11.5a3.498 3.498 0 0 1-3.032-1.75.5.5 0 0 0-.683-.183zm5.152-3.31a.5.5 0 0 0-.874.486c.33.595.958 1.007 1.687 1.007.73 0 1.356-.412 1.687-1.007a.5.5 0 0 0-.874-.486.934.934 0 0 1-.813.493.934.934 0 0 1-.813-.493z"/>'),Tc=d("Envelope",'<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm2-1a1 1 0 0 0-1 1v.217l7 4.2 7-4.2V4a1 1 0 0 0-1-1H2zm13 2.383l-4.758 2.855L15 11.114v-5.73zm-.034 6.878L9.271 8.82 8 9.583 6.728 8.82l-5.694 3.44A1 1 0 0 0 2 13h12a1 1 0 0 0 .966-.739zM1 11.114l4.758-2.876L1 5.383v5.73z"/>'),Pc=d("EnvelopeFill",'<path d="M.05 3.555A2 2 0 0 1 2 2h12a2 2 0 0 1 1.95 1.555L8 8.414.05 3.555zM0 4.697v7.104l5.803-3.558L0 4.697zM6.761 8.83l-6.57 4.027A2 2 0 0 0 2 14h12a2 2 0 0 0 1.808-1.144l-6.57-4.027L8 9.586l-1.239-.757zm3.436-.586L16 11.801V4.697l-5.803 3.546z"/>'),Ic=d("EnvelopeOpen",'<path d="M8.47 1.318a1 1 0 0 0-.94 0l-6 3.2A1 1 0 0 0 1 5.4v.818l5.724 3.465L8 8.917l1.276.766L15 6.218V5.4a1 1 0 0 0-.53-.882l-6-3.2zM15 7.388l-4.754 2.877L15 13.117v-5.73zm-.035 6.874L8 10.083l-6.965 4.18A1 1 0 0 0 2 15h12a1 1 0 0 0 .965-.738zM1 13.117l4.754-2.852L1 7.387v5.73zM7.059.435a2 2 0 0 1 1.882 0l6 3.2A2 2 0 0 1 16 5.4V14a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V5.4a2 2 0 0 1 1.059-1.765l6-3.2z"/>'),Ec=d("EnvelopeOpenFill",'<path d="M8.941.435a2 2 0 0 0-1.882 0l-6 3.2A2 2 0 0 0 0 5.4v.313l6.709 3.933L8 8.928l1.291.717L16 5.715V5.4a2 2 0 0 0-1.059-1.765l-6-3.2zM16 6.873l-5.693 3.337L16 13.372v-6.5zm-.059 7.611L8 10.072.059 14.484A2 2 0 0 0 2 16h12a2 2 0 0 0 1.941-1.516zM0 13.373l5.693-3.163L0 6.873v6.5z"/>'),Lc=d("Exclamation",'<path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.553.553 0 0 1-1.1 0L7.1 4.995z"/>'),Bc=d("ExclamationCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>'),Hc=d("ExclamationCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8 4a.905.905 0 0 0-.9.995l.35 3.507a.552.552 0 0 0 1.1 0l.35-3.507A.905.905 0 0 0 8 4zm.002 6a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>'),Fc=d("ExclamationDiamond",'<path d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435zm1.4.7a.495.495 0 0 0-.7 0L1.134 7.65a.495.495 0 0 0 0 .7l6.516 6.516a.495.495 0 0 0 .7 0l6.516-6.516a.495.495 0 0 0 0-.7L8.35 1.134z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>'),Dc=d("ExclamationDiamondFill",'<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L.436 6.95c-.58.58-.58 1.519 0 2.098l6.516 6.516c.58.58 1.519.58 2.098 0l6.516-6.516c.58-.58.58-1.519 0-2.098L9.05.435zM8 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),Rc=d("ExclamationOctagon",'<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>'),Nc=d("ExclamationOctagonFill",'<path d="M11.46.146A.5.5 0 0 0 11.107 0H4.893a.5.5 0 0 0-.353.146L.146 4.54A.5.5 0 0 0 0 4.893v6.214a.5.5 0 0 0 .146.353l4.394 4.394a.5.5 0 0 0 .353.146h6.214a.5.5 0 0 0 .353-.146l4.394-4.394a.5.5 0 0 0 .146-.353V4.893a.5.5 0 0 0-.146-.353L11.46.146zM8 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),$c=d("ExclamationSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>'),Uc=d("ExclamationSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm6 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),qc=d("ExclamationTriangle",'<path d="M7.938 2.016A.13.13 0 0 1 8.002 2a.13.13 0 0 1 .063.016.146.146 0 0 1 .054.057l6.857 11.667c.036.06.035.124.002.183a.163.163 0 0 1-.054.06.116.116 0 0 1-.066.017H1.146a.115.115 0 0 1-.066-.017.163.163 0 0 1-.054-.06.176.176 0 0 1 .002-.183L7.884 2.073a.147.147 0 0 1 .054-.057zm1.044-.45a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566z"/><path d="M7.002 12a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 5.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995z"/>'),Wc=d("ExclamationTriangleFill",'<path d="M8.982 1.566a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566zM8 5c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995A.905.905 0 0 1 8 5zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),Gc=d("Exclude",'<path d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm12 2H5a1 1 0 0 0-1 1v7h7a1 1 0 0 0 1-1V4z"/>'),Yc=d("Eye",'<path d="M16 8s-3-5.5-8-5.5S0 8 0 8s3 5.5 8 5.5S16 8 16 8zM1.173 8a13.133 13.133 0 0 1 1.66-2.043C4.12 4.668 5.88 3.5 8 3.5c2.12 0 3.879 1.168 5.168 2.457A13.133 13.133 0 0 1 14.828 8c-.058.087-.122.183-.195.288-.335.48-.83 1.12-1.465 1.755C11.879 11.332 10.119 12.5 8 12.5c-2.12 0-3.879-1.168-5.168-2.457A13.134 13.134 0 0 1 1.172 8z"/><path d="M8 5.5a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5zM4.5 8a3.5 3.5 0 1 1 7 0 3.5 3.5 0 0 1-7 0z"/>'),Kc=d("EyeFill",'<path d="M10.5 8a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0z"/><path d="M0 8s3-5.5 8-5.5S16 8 16 8s-3 5.5-8 5.5S0 8 0 8zm8 3.5a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7z"/>'),Qc=d("EyeSlash",'<path d="M13.359 11.238C15.06 9.72 16 8 16 8s-3-5.5-8-5.5a7.028 7.028 0 0 0-2.79.588l.77.771A5.944 5.944 0 0 1 8 3.5c2.12 0 3.879 1.168 5.168 2.457A13.134 13.134 0 0 1 14.828 8c-.058.087-.122.183-.195.288-.335.48-.83 1.12-1.465 1.755-.165.165-.337.328-.517.486l.708.709z"/><path d="M11.297 9.176a3.5 3.5 0 0 0-4.474-4.474l.823.823a2.5 2.5 0 0 1 2.829 2.829l.822.822zm-2.943 1.299l.822.822a3.5 3.5 0 0 1-4.474-4.474l.823.823a2.5 2.5 0 0 0 2.829 2.829z"/><path d="M3.35 5.47c-.18.16-.353.322-.518.487A13.134 13.134 0 0 0 1.172 8l.195.288c.335.48.83 1.12 1.465 1.755C4.121 11.332 5.881 12.5 8 12.5c.716 0 1.39-.133 2.02-.36l.77.772A7.029 7.029 0 0 1 8 13.5C3 13.5 0 8 0 8s.939-1.721 2.641-3.238l.708.709zm10.296 8.884l-12-12 .708-.708 12 12-.708.708z"/>'),Xc=d("EyeSlashFill",'<path d="M10.79 12.912l-1.614-1.615a3.5 3.5 0 0 1-4.474-4.474l-2.06-2.06C.938 6.278 0 8 0 8s3 5.5 8 5.5a7.027 7.027 0 0 0 2.79-.588zM5.21 3.088A7.028 7.028 0 0 1 8 2.5c5 0 8 5.5 8 5.5s-.939 1.721-2.641 3.238l-2.062-2.062a3.5 3.5 0 0 0-4.474-4.474L5.21 3.088z"/><path d="M5.525 7.646a2.5 2.5 0 0 0 2.829 2.829l-2.83-2.829zm4.95.708l-2.829-2.83a2.5 2.5 0 0 1 2.829 2.829zm3.171 6l-12-12 .708-.708 12 12-.708.707z"/>'),Jc=d("Eyeglasses",'<path d="M4 6a2 2 0 1 1 0 4 2 2 0 0 1 0-4zm2.625.547a3 3 0 0 0-5.584.953H.5a.5.5 0 0 0 0 1h.541A3 3 0 0 0 7 8a1 1 0 0 1 2 0 3 3 0 0 0 5.959.5h.541a.5.5 0 0 0 0-1h-.541a3 3 0 0 0-5.584-.953A1.993 1.993 0 0 0 8 6c-.532 0-1.016.208-1.375.547zM14 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>'),Zc=d("Facebook",'<path d="M16 8.049c0-4.446-3.582-8.05-8-8.05C3.58 0-.002 3.603-.002 8.05c0 4.017 2.926 7.347 6.75 7.951v-5.625h-2.03V8.05H6.75V6.275c0-2.017 1.195-3.131 3.022-3.131.876 0 1.791.157 1.791.157v1.98h-1.009c-.993 0-1.303.621-1.303 1.258v1.51h2.218l-.354 2.326H9.25V16c3.824-.604 6.75-3.934 6.75-7.951z"/>'),tl=d("File",'<path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),el=d("FileArrowDown",'<path d="M8 5a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5A.5.5 0 0 1 8 5z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),nl=d("FileArrowDownFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8 5a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5A.5.5 0 0 1 8 5z"/>'),rl=d("FileArrowUp",'<path d="M8 11a.5.5 0 0 0 .5-.5V6.707l1.146 1.147a.5.5 0 0 0 .708-.708l-2-2a.5.5 0 0 0-.708 0l-2 2a.5.5 0 1 0 .708.708L7.5 6.707V10.5a.5.5 0 0 0 .5.5z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),il=d("FileArrowUpFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM7.5 6.707L6.354 7.854a.5.5 0 1 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 6.707V10.5a.5.5 0 0 1-1 0V6.707z"/>'),ol=d("FileBarGraph",'<path d="M4.5 12a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1zm3 0a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm3 0a.5.5 0 0 1-.5-.5v-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-.5.5h-1z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),al=d("FileBarGraphFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-2 11.5v-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5zm-2.5.5a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm-3 0a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1z"/>'),sl=d("FileBinary",'<path d="M5.526 13.09c.976 0 1.524-.79 1.524-2.205 0-1.412-.548-2.203-1.524-2.203-.978 0-1.526.79-1.526 2.203 0 1.415.548 2.206 1.526 2.206zm-.832-2.205c0-1.05.29-1.612.832-1.612.358 0 .607.247.733.721L4.7 11.137a6.749 6.749 0 0 1-.006-.252zm.832 1.614c-.36 0-.606-.246-.732-.718l1.556-1.145c.003.079.005.164.005.249 0 1.052-.29 1.614-.829 1.614zm5.329.501v-.595H9.73V8.772h-.69l-1.19.786v.688L8.986 9.5h.05v2.906h-1.18V13h3z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),cl=d("FileBinaryFill",'<path d="M5.526 9.273c-.542 0-.832.563-.832 1.612 0 .088.003.173.006.252l1.56-1.143c-.126-.474-.375-.72-.733-.72zm-.732 2.508c.126.472.372.718.732.718.54 0 .83-.563.83-1.614 0-.085-.003-.17-.006-.25l-1.556 1.146z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM7.05 10.885c0 1.415-.548 2.206-1.524 2.206C4.548 13.09 4 12.3 4 10.885c0-1.412.548-2.203 1.526-2.203.976 0 1.524.79 1.524 2.203zm3.805 1.52V13h-3v-.595h1.181V9.5h-.05l-1.136.747v-.688l1.19-.786h.69v3.633h1.125z"/>'),ll=d("FileBreak",'<path d="M0 10.5a.5.5 0 0 1 .5-.5h15a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5zM12 0H4a2 2 0 0 0-2 2v7h1V2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v7h1V2a2 2 0 0 0-2-2zm2 12h-1v2a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-2H2v2a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2v-2z"/>'),ul=d("FileBreakFill",'<path d="M4 0h8a2 2 0 0 1 2 2v7H2V2a2 2 0 0 1 2-2zM2 12h12v2a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-2zM.5 10a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>'),dl=d("FileCheck",'<path d="M10.854 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),hl=d("FileCheckFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-1.146 6.854l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 8.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>'),fl=d("FileCode",'<path d="M6.646 5.646a.5.5 0 1 1 .708.708L5.707 8l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zm2.708 0a.5.5 0 1 0-.708.708L10.293 8 8.646 9.646a.5.5 0 0 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),pl=d("FileCodeFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6.646 5.646a.5.5 0 1 1 .708.708L5.707 8l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zm2.708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 8 8.646 6.354a.5.5 0 1 1 .708-.708z"/>'),ml=d("FileDiff",'<path d="M8 4a.5.5 0 0 1 .5.5V6H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V7H6a.5.5 0 0 1 0-1h1.5V4.5A.5.5 0 0 1 8 4zm-2.5 6.5A.5.5 0 0 1 6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),bl=d("FileDiffFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 4.5V6H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V7H6a.5.5 0 0 1 0-1h1.5V4.5a.5.5 0 0 1 1 0zM6 10h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>'),gl=d("FileEarmark",'<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>'),vl=d("FileEarmarkArrowDown",'<path d="M8.5 6.5a.5.5 0 0 0-1 0v3.793L6.354 9.146a.5.5 0 1 0-.708.708l2 2a.5.5 0 0 0 .708 0l2-2a.5.5 0 0 0-.708-.708L8.5 10.293V6.5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),wl=d("FileEarmarkArrowDownFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-1 4v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 .708-.708L7.5 11.293V7.5a.5.5 0 0 1 1 0z"/>'),yl=d("FileEarmarkArrowUp",'<path d="M8.5 11.5a.5.5 0 0 1-1 0V7.707L6.354 8.854a.5.5 0 1 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 7.707V11.5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),kl=d("FileEarmarkArrowUpFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.354 9.854a.5.5 0 0 1-.708-.708l2-2a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1-.708.708L8.5 8.707V12.5a.5.5 0 0 1-1 0V8.707L6.354 9.854z"/>'),_l=d("FileEarmarkBarGraph",'<path d="M10 13.5a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-6a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v6zm-2.5.5a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm-3 0a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Ol=d("FileEarmarkBarGraphFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm.5 10v-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5zm-2.5.5a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-.5.5h-1zm-3 0a.5.5 0 0 1-.5-.5v-2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-1z"/>'),zl=d("FileEarmarkBinary",'<path d="M7.05 11.885c0 1.415-.548 2.206-1.524 2.206C4.548 14.09 4 13.3 4 11.885c0-1.412.548-2.203 1.526-2.203.976 0 1.524.79 1.524 2.203zm-1.524-1.612c-.542 0-.832.563-.832 1.612 0 .088.003.173.006.252l1.559-1.143c-.126-.474-.375-.72-.733-.72zm-.732 2.508c.126.472.372.718.732.718.54 0 .83-.563.83-1.614 0-.085-.003-.17-.006-.25l-1.556 1.146zm6.061.624V14h-3v-.595h1.181V10.5h-.05l-1.136.747v-.688l1.19-.786h.69v3.633h1.125z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Al=d("FileEarmarkBinaryFill",'<path d="M5.526 10.273c-.542 0-.832.563-.832 1.612 0 .088.003.173.006.252l1.559-1.143c-.126-.474-.375-.72-.733-.72zm-.732 2.508c.126.472.372.718.732.718.54 0 .83-.563.83-1.614 0-.085-.003-.17-.006-.25l-1.556 1.146z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-2.45 8.385c0 1.415-.548 2.206-1.524 2.206C4.548 14.09 4 13.3 4 11.885c0-1.412.548-2.203 1.526-2.203.976 0 1.524.79 1.524 2.203zm3.805 1.52V14h-3v-.595h1.181V10.5h-.05l-1.136.747v-.688l1.19-.786h.69v3.633h1.125z"/>'),jl=d("FileEarmarkBreak",'<path d="M14 4.5V9h-1V4.5h-2A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v7H2V2a2 2 0 0 1 2-2h5.5L14 4.5zM13 12h1v2a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-2h1v2a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1v-2zM.5 10a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>'),Ml=d("FileEarmarkBreakFill",'<path d="M4 0h5.293A1 1 0 0 1 10 .293L13.707 4a1 1 0 0 1 .293.707V9H2V2a2 2 0 0 1 2-2zm5.5 1.5v2a1 1 0 0 0 1 1h2l-3-3zM2 12h12v2a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-2zM.5 10a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>'),Cl=d("FileEarmarkCheck",'<path d="M10.854 7.854a.5.5 0 0 0-.708-.708L7.5 9.793 6.354 8.646a.5.5 0 1 0-.708.708l1.5 1.5a.5.5 0 0 0 .708 0l3-3z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Vl=d("FileEarmarkCheckFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm1.354 4.354l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 9.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>'),Sl=d("FileEarmarkCode",'<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/><path d="M8.646 6.646a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 9 8.646 7.354a.5.5 0 0 1 0-.708zm-1.292 0a.5.5 0 0 0-.708 0l-2 2a.5.5 0 0 0 0 .708l2 2a.5.5 0 0 0 .708-.708L5.707 9l1.647-1.646a.5.5 0 0 0 0-.708z"/>'),xl=d("FileEarmarkCodeFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.646 7.646a.5.5 0 1 1 .708.708L5.707 10l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zm2.708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 10 8.646 8.354a.5.5 0 1 1 .708-.708z"/>'),Tl=d("FileEarmarkDiff",'<path d="M8 5a.5.5 0 0 1 .5.5V7H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V8H6a.5.5 0 0 1 0-1h1.5V5.5A.5.5 0 0 1 8 5zm-2.5 6.5A.5.5 0 0 1 6 11h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Pl=d("FileEarmarkDiffFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM8 6a.5.5 0 0 1 .5.5V8H10a.5.5 0 0 1 0 1H8.5v1.5a.5.5 0 0 1-1 0V9H6a.5.5 0 0 1 0-1h1.5V6.5A.5.5 0 0 1 8 6zm-2.5 6.5A.5.5 0 0 1 6 12h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/>'),Il=d("FileEarmarkEasel",'<path d="M8.5 6a.5.5 0 1 0-1 0h-2A1.5 1.5 0 0 0 4 7.5v2A1.5 1.5 0 0 0 5.5 11h.473l-.447 1.342a.5.5 0 1 0 .948.316L7.027 11H7.5v1a.5.5 0 0 0 1 0v-1h.473l.553 1.658a.5.5 0 1 0 .948-.316L10.027 11h.473A1.5 1.5 0 0 0 12 9.5v-2A1.5 1.5 0 0 0 10.5 6h-2zM5 7.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),El=d("FileEarmarkEaselFill",'<path d="M5 7.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM8.5 6h2A1.5 1.5 0 0 1 12 7.5v2a1.5 1.5 0 0 1-1.5 1.5h-.473l.447 1.342a.5.5 0 0 1-.948.316L8.973 11H8.5v1a.5.5 0 0 1-1 0v-1h-.473l-.553 1.658a.5.5 0 1 1-.948-.316L5.973 11H5.5A1.5 1.5 0 0 1 4 9.5v-2A1.5 1.5 0 0 1 5.5 6h2a.5.5 0 0 1 1 0z"/>'),Ll=d("FileEarmarkExcel",'<path d="M5.884 6.68a.5.5 0 1 0-.768.64L7.349 10l-2.233 2.68a.5.5 0 0 0 .768.64L8 10.781l2.116 2.54a.5.5 0 0 0 .768-.641L8.651 10l2.233-2.68a.5.5 0 0 0-.768-.64L8 9.219l-2.116-2.54z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Bl=d("FileEarmarkExcelFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5.884 6.68L8 9.219l2.116-2.54a.5.5 0 1 1 .768.641L8.651 10l2.233 2.68a.5.5 0 0 1-.768.64L8 10.781l-2.116 2.54a.5.5 0 0 1-.768-.641L7.349 10 5.116 7.32a.5.5 0 1 1 .768-.64z"/>'),Hl=d("FileEarmarkFill",'<path d="M4 0h5.293A1 1 0 0 1 10 .293L13.707 4a1 1 0 0 1 .293.707V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2zm5.5 1.5v2a1 1 0 0 0 1 1h2l-3-3z"/>'),Fl=d("FileEarmarkFont",'<path d="M10.943 6H5.057L5 8h.5c.18-1.096.356-1.192 1.694-1.235l.293-.01v5.09c0 .47-.1.582-.898.655v.5H9.41v-.5c-.803-.073-.903-.184-.903-.654V6.755l.298.01c1.338.043 1.514.14 1.694 1.235h.5l-.057-2z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>'),Dl=d("FileEarmarkFontFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5.057 6h5.886L11 8h-.5c-.18-1.096-.356-1.192-1.694-1.235l-.298-.01v5.09c0 .47.1.582.903.655v.5H6.59v-.5c.799-.073.898-.184.898-.654V6.755l-.293.01C5.856 6.808 5.68 6.905 5.5 8H5l.057-2z"/>'),Rl=d("FileEarmarkImage",'<path d="M6.502 7a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/><path d="M14 14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5V14zM4 1a1 1 0 0 0-1 1v10l2.224-2.224a.5.5 0 0 1 .61-.075L8 11l2.157-3.02a.5.5 0 0 1 .76-.063L13 10V4.5h-2A1.5 1.5 0 0 1 9.5 3V1H4z"/>'),Nl=d("FileEarmarkImageFill",'<path d="M4 0h5.293A1 1 0 0 1 10 .293L13.707 4a1 1 0 0 1 .293.707v5.586l-2.73-2.73a1 1 0 0 0-1.52.127l-1.889 2.644-1.769-1.062a1 1 0 0 0-1.222.15L2 12.292V2a2 2 0 0 1 2-2zm5.5 1.5v2a1 1 0 0 0 1 1h2l-3-3zm-1.498 4a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/><path d="M10.564 8.27L14 11.708V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-.293l3.578-3.577 2.56 1.536 2.426-3.395z"/>'),$l=d("FileEarmarkLock",'<path d="M10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0zM7 7v1h2V7a1 1 0 0 0-2 0zM6 9.3v2.4c0 .042.02.107.105.175A.637.637 0 0 0 6.5 12h3a.64.64 0 0 0 .395-.125c.085-.068.105-.133.105-.175V9.3c0-.042-.02-.107-.105-.175A.637.637 0 0 0 9.5 9h-3a.637.637 0 0 0-.395.125C6.02 9.193 6 9.258 6 9.3z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Ul=d("FileEarmarkLock2",'<path d="M10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0zM7 7v1h2V7a1 1 0 0 0-2 0z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),ql=d("FileEarmarkLock2Fill",'<path d="M7 7a1 1 0 0 1 2 0v1H7V7z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0z"/>'),Wl=d("FileEarmarkLockFill",'<path d="M7 7a1 1 0 0 1 2 0v1H7V7zM6 9.3c0-.042.02-.107.105-.175A.637.637 0 0 1 6.5 9h3a.64.64 0 0 1 .395.125c.085.068.105.133.105.175v2.4c0 .042-.02.107-.105.175A.637.637 0 0 1 9.5 12h-3a.637.637 0 0 1-.395-.125C6.02 11.807 6 11.742 6 11.7V9.3z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM10 7v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V9.3c0-.627.46-1.058 1-1.224V7a2 2 0 1 1 4 0z"/>'),Gl=d("FileEarmarkMedical",'<path d="M7.5 5.5a.5.5 0 0 0-1 0v.634l-.549-.317a.5.5 0 1 0-.5.866L6 7l-.549.317a.5.5 0 1 0 .5.866l.549-.317V8.5a.5.5 0 1 0 1 0v-.634l.549.317a.5.5 0 1 0 .5-.866L8 7l.549-.317a.5.5 0 1 0-.5-.866l-.549.317V5.5zm-2 4.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Yl=d("FileEarmarkMedicalFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-3 2v.634l.549-.317a.5.5 0 1 1 .5.866L7 7l.549.317a.5.5 0 1 1-.5.866L6.5 7.866V8.5a.5.5 0 0 1-1 0v-.634l-.549.317a.5.5 0 1 1-.5-.866L5 7l-.549-.317a.5.5 0 0 1 .5-.866l.549.317V5.5a.5.5 0 1 1 1 0zm-2 4.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zm0 2h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1z"/>'),Kl=d("FileEarmarkMinus",'<path d="M5.5 9a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>'),Ql=d("FileEarmarkMinusFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6 8.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>'),Xl=d("FileEarmarkMusic",'<path d="M11 6.64a1 1 0 0 0-1.243-.97l-1 .25A1 1 0 0 0 8 6.89v4.306A2.572 2.572 0 0 0 7 11c-.5 0-.974.134-1.338.377-.36.24-.662.628-.662 1.123s.301.883.662 1.123c.364.243.839.377 1.338.377.5 0 .974-.134 1.338-.377.36-.24.662-.628.662-1.123V8.89l2-.5V6.64z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Jl=d("FileEarmarkMusicFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM11 6.64v1.75l-2 .5v3.61c0 .495-.301.883-.662 1.123C7.974 13.866 7.499 14 7 14c-.5 0-.974-.134-1.338-.377-.36-.24-.662-.628-.662-1.123s.301-.883.662-1.123C6.026 11.134 6.501 11 7 11c.356 0 .7.068 1 .196V6.89a1 1 0 0 1 .757-.97l1-.25A1 1 0 0 1 11 6.64z"/>'),Zl=d("FileEarmarkPerson",'<path d="M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2v9.255S12 12 8 12s-5 1.755-5 1.755V2a1 1 0 0 1 1-1h5.5v2z"/>'),tu=d("FileEarmarkPersonFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0zm2 5.755V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-.245S4 12 8 12s5 1.755 5 1.755z"/>'),eu=d("FileEarmarkPlay",'<path d="M6 6.883v4.234a.5.5 0 0 0 .757.429l3.528-2.117a.5.5 0 0 0 0-.858L6.757 6.454a.5.5 0 0 0-.757.43z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),nu=d("FileEarmarkPlayFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6 6.883a.5.5 0 0 1 .757-.429l3.528 2.117a.5.5 0 0 1 0 .858l-3.528 2.117a.5.5 0 0 1-.757-.43V6.884z"/>'),ru=d("FileEarmarkPlus",'<path d="M8 6.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V9.5H6a.5.5 0 0 1 0-1h1.5V7a.5.5 0 0 1 .5-.5z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>'),iu=d("FileEarmarkPlusFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM8.5 7v1.5H10a.5.5 0 0 1 0 1H8.5V11a.5.5 0 0 1-1 0V9.5H6a.5.5 0 0 1 0-1h1.5V7a.5.5 0 0 1 1 0z"/>'),ou=d("FileEarmarkPost",'<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/><path d="M4 6.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-7zm0-3a.5.5 0 0 1 .5-.5H7a.5.5 0 0 1 0 1H4.5a.5.5 0 0 1-.5-.5z"/>'),au=d("FileEarmarkPostFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-5-.5H7a.5.5 0 0 1 0 1H4.5a.5.5 0 0 1 0-1zm0 3h7a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-7a.5.5 0 0 1 .5-.5z"/>'),su=d("FileEarmarkPpt",'<path d="M5 6a.5.5 0 0 0-.496.438l-.5 4A.5.5 0 0 0 4.5 11h3v2.016c-.863.055-1.5.251-1.5.484 0 .276.895.5 2 .5s2-.224 2-.5c0-.233-.637-.429-1.5-.484V11h3a.5.5 0 0 0 .496-.562l-.5-4A.5.5 0 0 0 11 6H5zm2 3.78V7.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 9.778z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),cu=d("FileEarmarkPptFill",'<path d="M6.5 8.5a2 2 0 1 0 4 0 2 2 0 0 0-4 0z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.5 6v.264a3 3 0 1 1 0 4.472V13.5a.5.5 0 0 1-1 0V6a.5.5 0 0 1 1 0z"/>'),lu=d("FileEarmarkRichtext",'<path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/><path d="M4.5 12.5A.5.5 0 0 1 5 12h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zm0-2A.5.5 0 0 1 5 10h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zm1.639-3.708l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V8.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V8s1.54-1.274 1.639-1.208zM6.25 6a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5z"/>'),uu=d("FileEarmarkRichtextFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM7 6.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V9.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V9s1.54-1.274 1.639-1.208zM5 11h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm0 2h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1z"/>'),du=d("FileEarmarkRuled",'<path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V9H3V2a1 1 0 0 1 1-1h5.5v2zM3 12v-2h2v2H3zm0 1h2v2H4a1 1 0 0 1-1-1v-1zm3 2v-2h7v1a1 1 0 0 1-1 1H6zm7-3H6v-2h7v2z"/>'),hu=d("FileEarmarkRuledFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM3 9h10v1H6v2h7v1H6v2H5v-2H3v-1h2v-2H3V9z"/>'),fu=d("FileEarmarkSlides",'<path d="M4 0h5.5v1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h1V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2z"/><path d="M9.5 3V0L14 4.5h-3A1.5 1.5 0 0 1 9.5 3zm.5 10.5c0 .276-.895.5-2 .5s-2-.224-2-.5.895-.5 2-.5 2 .224 2 .5z"/><path fill-rule="evenodd" d="M4.504 6.438A.5.5 0 0 1 5 6h6a.5.5 0 0 1 .496.438l.5 4A.5.5 0 0 1 11.5 11h-3v2.016a7.795 7.795 0 0 0-1 0V11h-3a.5.5 0 0 1-.496-.562l.5-4zM7 7.221v2.558c0 .097.106.157.19.107l2.13-1.279a.125.125 0 0 0 0-.214l-2.13-1.28a.125.125 0 0 0-.19.109z"/>'),pu=d("FileEarmarkSlidesFill",'<path d="M7 9.78V7.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 9.778z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5 6h6a.5.5 0 0 1 .496.438l.5 4A.5.5 0 0 1 11.5 11h-3v2.016c.863.055 1.5.251 1.5.484 0 .276-.895.5-2 .5s-2-.224-2-.5c0-.233.637-.429 1.5-.484V11h-3a.5.5 0 0 1-.496-.562l.5-4A.5.5 0 0 1 5 6z"/>'),mu=d("FileEarmarkSpreadsheet",'<path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V9H3V2a1 1 0 0 1 1-1h5.5v2zM3 12v-2h2v2H3zm0 1h2v2H4a1 1 0 0 1-1-1v-1zm3 2v-2h3v2H6zm4 0v-2h3v1a1 1 0 0 1-1 1h-2zm3-3h-3v-2h3v2zm-7 0v-2h3v2H6z"/>'),bu=d("FileEarmarkSpreadsheetFill",'<path d="M6 12v-2h3v2H6z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM3 9h10v1h-3v2h3v1h-3v2H9v-2H6v2H5v-2H3v-1h2v-2H3V9z"/>'),gu=d("FileEarmarkText",'<path d="M5.5 7a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zM5 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/><path d="M9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.5L9.5 0zm0 1v2A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5z"/>'),vu=d("FileEarmarkTextFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM4.5 9a.5.5 0 0 1 0-1h7a.5.5 0 0 1 0 1h-7zM4 10.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 1 0-1h4a.5.5 0 0 1 0 1h-4z"/>'),wu=d("FileEarmarkWord",'<path d="M5.485 6.879a.5.5 0 1 0-.97.242l1.5 6a.5.5 0 0 0 .967.01L8 9.402l1.018 3.73a.5.5 0 0 0 .967-.01l1.5-6a.5.5 0 0 0-.97-.242l-1.036 4.144-.997-3.655a.5.5 0 0 0-.964 0l-.997 3.655L5.485 6.88z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),yu=d("FileEarmarkWordFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM5.485 6.879l1.036 4.144.997-3.655a.5.5 0 0 1 .964 0l.997 3.655 1.036-4.144a.5.5 0 0 1 .97.242l-1.5 6a.5.5 0 0 1-.967.01L8 9.402l-1.018 3.73a.5.5 0 0 1-.967-.01l-1.5-6a.5.5 0 1 1 .97-.242z"/>'),ku=d("FileEarmarkX",'<path d="M6.854 7.146a.5.5 0 1 0-.708.708L7.293 9l-1.147 1.146a.5.5 0 0 0 .708.708L8 9.707l1.146 1.147a.5.5 0 0 0 .708-.708L8.707 9l1.147-1.146a.5.5 0 0 0-.708-.708L8 8.293 6.854 7.146z"/><path d="M14 14V4.5L9.5 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM9.5 3A1.5 1.5 0 0 0 11 4.5h2V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),_u=d("FileEarmarkXFill",'<path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zM6.854 7.146L8 8.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 9l1.147 1.146a.5.5 0 0 1-.708.708L8 9.707l-1.146 1.147a.5.5 0 0 1-.708-.708L7.293 9 6.146 7.854a.5.5 0 1 1 .708-.708z"/>'),Ou=d("FileEarmarkZip",'<path d="M5 7.5a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v.938l.4 1.599a1 1 0 0 1-.416 1.074l-.93.62a1 1 0 0 1-1.11 0l-.929-.62a1 1 0 0 1-.415-1.074L5 8.438V7.5zm2 0H6v.938a1 1 0 0 1-.03.243l-.4 1.598.93.62.929-.62-.4-1.598A1 1 0 0 1 7 8.438V7.5z"/><path d="M14 4.5V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h5.5L14 4.5zm-3 0A1.5 1.5 0 0 1 9.5 3V1h-2v1h-1v1h1v1h-1v1h1v1H6V5H5V4h1V3H5V2h1V1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4.5h-2z"/>'),zu=d("FileEarmarkZipFill",'<path d="M5.5 9.438V8.5h1v.938a1 1 0 0 0 .03.243l.4 1.598-.93.62-.93-.62.4-1.598a1 1 0 0 0 .03-.243z"/><path d="M9.293 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V4.707A1 1 0 0 0 13.707 4L10 .293A1 1 0 0 0 9.293 0zM9.5 3.5v-2l3 3h-2a1 1 0 0 1-1-1zm-4-.5V2h-1V1H6v1h1v1H6v1h1v1H6v1h1v1H5.5V6h-1V5h1V4h-1V3h1zm0 4.5h1a1 1 0 0 1 1 1v.938l.4 1.599a1 1 0 0 1-.416 1.074l-.93.62a1 1 0 0 1-1.109 0l-.93-.62a1 1 0 0 1-.415-1.074l.4-1.599V8.5a1 1 0 0 1 1-1z"/>'),Au=d("FileEasel",'<path d="M8.5 5a.5.5 0 1 0-1 0h-2A1.5 1.5 0 0 0 4 6.5v2A1.5 1.5 0 0 0 5.5 10h.473l-.447 1.342a.5.5 0 1 0 .948.316L7.027 10H7.5v1a.5.5 0 0 0 1 0v-1h.473l.553 1.658a.5.5 0 1 0 .948-.316L10.027 10h.473A1.5 1.5 0 0 0 12 8.5v-2A1.5 1.5 0 0 0 10.5 5h-2zM5 6.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),ju=d("FileEaselFill",'<path d="M5 6.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-2z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 5h2A1.5 1.5 0 0 1 12 6.5v2a1.5 1.5 0 0 1-1.5 1.5h-.473l.447 1.342a.5.5 0 0 1-.948.316L8.973 10H8.5v1a.5.5 0 0 1-1 0v-1h-.473l-.553 1.658a.5.5 0 1 1-.948-.316L5.973 10H5.5A1.5 1.5 0 0 1 4 8.5v-2A1.5 1.5 0 0 1 5.5 5h2a.5.5 0 0 1 1 0z"/>'),Mu=d("FileExcel",'<path d="M5.18 4.616a.5.5 0 0 1 .704.064L8 7.219l2.116-2.54a.5.5 0 1 1 .768.641L8.651 8l2.233 2.68a.5.5 0 0 1-.768.64L8 8.781l-2.116 2.54a.5.5 0 0 1-.768-.641L7.349 8 5.116 5.32a.5.5 0 0 1 .064-.704z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),Cu=d("FileExcelFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5.884 4.68L8 7.219l2.116-2.54a.5.5 0 1 1 .768.641L8.651 8l2.233 2.68a.5.5 0 0 1-.768.64L8 8.781l-2.116 2.54a.5.5 0 0 1-.768-.641L7.349 8 5.116 5.32a.5.5 0 1 1 .768-.64z"/>'),Vu=d("FileFill",'<path fill-rule="evenodd" d="M4 0h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2z"/>'),Su=d("FileFont",'<path d="M10.943 4H5.057L5 6h.5c.18-1.096.356-1.192 1.694-1.235l.293-.01v6.09c0 .47-.1.582-.898.655v.5H9.41v-.5c-.803-.073-.903-.184-.903-.654V4.755l.298.01c1.338.043 1.514.14 1.694 1.235h.5l-.057-2z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),xu=d("FileFontFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5.057 4h5.886L11 6h-.5c-.18-1.096-.356-1.192-1.694-1.235l-.298-.01v6.09c0 .47.1.582.903.655v.5H6.59v-.5c.799-.073.898-.184.898-.654V4.755l-.293.01C5.856 4.808 5.68 4.905 5.5 6H5l.057-2z"/>'),Tu=d("FileImage",'<path d="M8.002 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM3 2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v8l-2.083-2.083a.5.5 0 0 0-.76.063L8 11 5.835 9.7a.5.5 0 0 0-.611.076L3 12V2z"/>'),Pu=d("FileImageFill",'<path d="M4 0h8a2 2 0 0 1 2 2v8.293l-2.73-2.73a1 1 0 0 0-1.52.127l-1.889 2.644-1.769-1.062a1 1 0 0 0-1.222.15L2 12.292V2a2 2 0 0 1 2-2zm4.002 5.5a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/><path d="M10.564 8.27L14 11.708V14a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-.293l3.578-3.577 2.56 1.536 2.426-3.395z"/>'),Iu=d("FileLock",'<path d="M8 5a1 1 0 0 1 1 1v1H7V6a1 1 0 0 1 1-1zm2 2.076V6a2 2 0 1 0-4 0v1.076c-.54.166-1 .597-1 1.224v2.4c0 .816.781 1.3 1.5 1.3h3c.719 0 1.5-.484 1.5-1.3V8.3c0-.627-.46-1.058-1-1.224zM6.105 8.125A.637.637 0 0 1 6.5 8h3a.64.64 0 0 1 .395.125c.085.068.105.133.105.175v2.4c0 .042-.02.107-.105.175A.637.637 0 0 1 9.5 11h-3a.637.637 0 0 1-.395-.125C6.02 10.807 6 10.742 6 10.7V8.3c0-.042.02-.107.105-.175z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),Eu=d("FileLock2",'<path d="M8 5a1 1 0 0 1 1 1v1H7V6a1 1 0 0 1 1-1zm2 2.076V6a2 2 0 1 0-4 0v1.076c-.54.166-1 .597-1 1.224v2.4c0 .816.781 1.3 1.5 1.3h3c.719 0 1.5-.484 1.5-1.3V8.3c0-.627-.46-1.058-1-1.224z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),Lu=d("FileLock2Fill",'<path d="M7 6a1 1 0 0 1 2 0v1H7V6z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-2 6v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V8.3c0-.627.46-1.058 1-1.224V6a2 2 0 1 1 4 0z"/>'),Bu=d("FileLockFill",'<path d="M7 6a1 1 0 0 1 2 0v1H7V6zM6 8.3c0-.042.02-.107.105-.175A.637.637 0 0 1 6.5 8h3a.64.64 0 0 1 .395.125c.085.068.105.133.105.175v2.4c0 .042-.02.107-.105.175A.637.637 0 0 1 9.5 11h-3a.637.637 0 0 1-.395-.125C6.02 10.807 6 10.742 6 10.7V8.3z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-2 6v1.076c.54.166 1 .597 1 1.224v2.4c0 .816-.781 1.3-1.5 1.3h-3c-.719 0-1.5-.484-1.5-1.3V8.3c0-.627.46-1.058 1-1.224V6a2 2 0 1 1 4 0z"/>'),Hu=d("FileMedical",'<path d="M8.5 4.5a.5.5 0 0 0-1 0v.634l-.549-.317a.5.5 0 1 0-.5.866L7 6l-.549.317a.5.5 0 1 0 .5.866l.549-.317V7.5a.5.5 0 1 0 1 0v-.634l.549.317a.5.5 0 1 0 .5-.866L9 6l.549-.317a.5.5 0 1 0-.5-.866l-.549.317V4.5zM5.5 9a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 2a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),Fu=d("FileMedicalFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 4.5v.634l.549-.317a.5.5 0 1 1 .5.866L9 6l.549.317a.5.5 0 1 1-.5.866L8.5 6.866V7.5a.5.5 0 0 1-1 0v-.634l-.549.317a.5.5 0 1 1-.5-.866L7 6l-.549-.317a.5.5 0 0 1 .5-.866l.549.317V4.5a.5.5 0 1 1 1 0zM5.5 9h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zm0 2h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1z"/>'),Du=d("FileMinus",'<path d="M5.5 8a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),Ru=d("FileMinusFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6 7.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>'),Nu=d("FileMusic",'<path d="M10.304 3.13a1 1 0 0 1 1.196.98v1.8l-2.5.5v5.09c0 .495-.301.883-.662 1.123C7.974 12.866 7.499 13 7 13c-.5 0-.974-.134-1.338-.377-.36-.24-.662-.628-.662-1.123s.301-.883.662-1.123C6.026 10.134 6.501 10 7 10c.356 0 .7.068 1 .196V4.41a1 1 0 0 1 .804-.98l1.5-.3z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),$u=d("FileMusicFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-.5 4.11v1.8l-2.5.5v5.09c0 .495-.301.883-.662 1.123C7.974 12.866 7.499 13 7 13c-.5 0-.974-.134-1.338-.377-.36-.24-.662-.628-.662-1.123s.301-.883.662-1.123C6.026 10.134 6.501 10 7 10c.356 0 .7.068 1 .196V4.41a1 1 0 0 1 .804-.98l1.5-.3a1 1 0 0 1 1.196.98z"/>'),Uu=d("FilePerson",'<path d="M12 1a1 1 0 0 1 1 1v10.755S12 11 8 11s-5 1.755-5 1.755V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M8 10a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>'),qu=d("FilePersonFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm-1 7a3 3 0 1 1-6 0 3 3 0 0 1 6 0zm-3 4c2.623 0 4.146.826 5 1.755V14a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-1.245C3.854 11.825 5.377 11 8 11z"/>'),Wu=d("FilePlay",'<path d="M6 10.117V5.883a.5.5 0 0 1 .757-.429l3.528 2.117a.5.5 0 0 1 0 .858l-3.528 2.117a.5.5 0 0 1-.757-.43z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),Gu=d("FilePlayFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6 5.883a.5.5 0 0 1 .757-.429l3.528 2.117a.5.5 0 0 1 0 .858l-3.528 2.117a.5.5 0 0 1-.757-.43V5.884z"/>'),Yu=d("FilePlus",'<path d="M8.5 6a.5.5 0 0 0-1 0v1.5H6a.5.5 0 0 0 0 1h1.5V10a.5.5 0 0 0 1 0V8.5H10a.5.5 0 0 0 0-1H8.5V6z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),Ku=d("FilePlusFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM8.5 6v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 1 0z"/>'),Qu=d("FilePost",'<path d="M4 3.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-8z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),Xu=d("FilePostFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM4.5 3h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1zm0 2h7a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-8a.5.5 0 0 1 .5-.5z"/>'),Ju=d("FilePpt",'<path d="M6.5 4.5a.5.5 0 0 0-1 0V12a.5.5 0 0 0 1 0V9.236a3 3 0 1 0 0-4.472V4.5zm0 2.5a2 2 0 1 1 4 0 2 2 0 0 1-4 0z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),Zu=d("FilePptFill",'<path d="M6.5 7a2 2 0 1 0 4 0 2 2 0 0 0-4 0z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6.5 4.5v.264a3 3 0 1 1 0 4.472V12a.5.5 0 0 1-1 0V4.5a.5.5 0 0 1 1 0z"/>'),td=d("FileRichtext",'<path d="M7 4.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V7.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V7s1.54-1.274 1.639-1.208zM5 9a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1H5zm0 2a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1H5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),ed=d("FileRichtextFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM7 4.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047l1.888.974V7.5a.5.5 0 0 1-.5.5H5a.5.5 0 0 1-.5-.5V7s1.54-1.274 1.639-1.208zM5 9h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm0 2h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1z"/>'),nd=d("FileRuled",'<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v4h10V2a1 1 0 0 0-1-1H4zm9 6H6v2h7V7zm0 3H6v2h7v-2zm0 3H6v2h6a1 1 0 0 0 1-1v-1zm-8 2v-2H3v1a1 1 0 0 0 1 1h1zm-2-3h2v-2H3v2zm0-3h2V7H3v2z"/>'),rd=d("FileRuledFill",'<path d="M12 0H4a2 2 0 0 0-2 2v4h12V2a2 2 0 0 0-2-2zm2 7H6v2h8V7zm0 3H6v2h8v-2zm0 3H6v3h6a2 2 0 0 0 2-2v-1zm-9 3v-3H2v1a2 2 0 0 0 2 2h1zm-3-4h3v-2H2v2zm0-3h3V7H2v2z"/>'),id=d("FileSlides",'<path d="M5 4a.5.5 0 0 0-.496.438l-.5 4A.5.5 0 0 0 4.5 9h3v2.016c-.863.055-1.5.251-1.5.484 0 .276.895.5 2 .5s2-.224 2-.5c0-.233-.637-.429-1.5-.484V9h3a.5.5 0 0 0 .496-.562l-.5-4A.5.5 0 0 0 11 4H5zm2 3.78V5.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 7.778z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),od=d("FileSlidesFill",'<path d="M7 7.78V5.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 7 7.778z"/><path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5 4h6a.5.5 0 0 1 .496.438l.5 4A.5.5 0 0 1 11.5 9h-3v2.016c.863.055 1.5.251 1.5.484 0 .276-.895.5-2 .5s-2-.224-2-.5c0-.233.637-.429 1.5-.484V9h-3a.5.5 0 0 1-.496-.562l.5-4A.5.5 0 0 1 5 4z"/>'),ad=d("FileSpreadsheet",'<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v4h10V2a1 1 0 0 0-1-1H4zm9 6h-3v2h3V7zm0 3h-3v2h3v-2zm0 3h-3v2h2a1 1 0 0 0 1-1v-1zm-4 2v-2H6v2h3zm-4 0v-2H3v1a1 1 0 0 0 1 1h1zm-2-3h2v-2H3v2zm0-3h2V7H3v2zm3-2v2h3V7H6zm3 3H6v2h3v-2z"/>'),sd=d("FileSpreadsheetFill",'<path d="M12 0H4a2 2 0 0 0-2 2v4h12V2a2 2 0 0 0-2-2zm2 7h-4v2h4V7zm0 3h-4v2h4v-2zm0 3h-4v3h2a2 2 0 0 0 2-2v-1zm-5 3v-3H6v3h3zm-4 0v-3H2v1a2 2 0 0 0 2 2h1zm-3-4h3v-2H2v2zm0-3h3V7H2v2zm4 0V7h3v2H6zm0 1h3v2H6v-2z"/>'),cd=d("FileText",'<path d="M5 4a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1H5zm-.5 2.5A.5.5 0 0 1 5 6h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zM5 8a.5.5 0 0 0 0 1h6a.5.5 0 0 0 0-1H5zm0 2a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1H5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm10-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1z"/>'),ld=d("FileTextFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5 4h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm-.5 2.5A.5.5 0 0 1 5 6h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zM5 8h6a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1zm0 2h3a.5.5 0 0 1 0 1H5a.5.5 0 0 1 0-1z"/>'),ud=d("FileWord",'<path d="M4.879 4.515a.5.5 0 0 1 .606.364l1.036 4.144.997-3.655a.5.5 0 0 1 .964 0l.997 3.655 1.036-4.144a.5.5 0 0 1 .97.242l-1.5 6a.5.5 0 0 1-.967.01L8 7.402l-1.018 3.73a.5.5 0 0 1-.967-.01l-1.5-6a.5.5 0 0 1 .364-.606z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),dd=d("FileWordFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM5.485 4.879l1.036 4.144.997-3.655a.5.5 0 0 1 .964 0l.997 3.655 1.036-4.144a.5.5 0 0 1 .97.242l-1.5 6a.5.5 0 0 1-.967.01L8 7.402l-1.018 3.73a.5.5 0 0 1-.967-.01l-1.5-6a.5.5 0 1 1 .97-.242z"/>'),hd=d("FileX",'<path d="M6.146 6.146a.5.5 0 0 1 .708 0L8 7.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 8l1.147 1.146a.5.5 0 0 1-.708.708L8 8.707 6.854 9.854a.5.5 0 0 1-.708-.708L7.293 8 6.146 6.854a.5.5 0 0 1 0-.708z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm0 1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1z"/>'),fd=d("FileXFill",'<path d="M12 0H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zM6.854 6.146L8 7.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 8l1.147 1.146a.5.5 0 0 1-.708.708L8 8.707 6.854 9.854a.5.5 0 0 1-.708-.708L7.293 8 6.146 6.854a.5.5 0 1 1 .708-.708z"/>'),pd=d("FileZip",'<path d="M6.5 7.5a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v.938l.4 1.599a1 1 0 0 1-.416 1.074l-.93.62a1 1 0 0 1-1.109 0l-.93-.62a1 1 0 0 1-.415-1.074l.4-1.599V7.5zm2 0h-1v.938a1 1 0 0 1-.03.243l-.4 1.598.93.62.93-.62-.4-1.598a1 1 0 0 1-.03-.243V7.5z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm5.5-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H9v1H8v1h1v1H8v1h1v1H7.5V5h-1V4h1V3h-1V2h1V1z"/>'),md=d("FileZipFill",'<path d="M8.5 9.438V8.5h-1v.938a1 1 0 0 1-.03.243l-.4 1.598.93.62.93-.62-.4-1.598a1 1 0 0 1-.03-.243z"/><path d="M4 0h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2zm2.5 8.5v.938l-.4 1.599a1 1 0 0 0 .416 1.074l.93.62a1 1 0 0 0 1.109 0l.93-.62a1 1 0 0 0 .415-1.074l-.4-1.599V8.5a1 1 0 0 0-1-1h-1a1 1 0 0 0-1 1zm1-5.5h-1v1h1v1h-1v1h1v1H9V6H8V5h1V4H8V3h1V2H8V1H6.5v1h1v1z"/>'),bd=d("Files",'<path d="M13 0H6a2 2 0 0 0-2 2 2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h7a2 2 0 0 0 2-2 2 2 0 0 0 2-2V2a2 2 0 0 0-2-2zm0 13V4a2 2 0 0 0-2-2H5a1 1 0 0 1 1-1h7a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1zM3 4a1 1 0 0 1 1-1h7a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V4z"/>'),gd=d("FilesAlt",'<path d="M11 0H3a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2 2 2 0 0 0 2-2V4a2 2 0 0 0-2-2 2 2 0 0 0-2-2zm2 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1V3zM2 2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V2z"/>'),vd=d("Film",'<path d="M0 1a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v14a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V1zm4 0v6h8V1H4zm8 8H4v6h8V9zM1 1v2h2V1H1zm2 3H1v2h2V4zM1 7v2h2V7H1zm2 3H1v2h2v-2zm-2 3v2h2v-2H1zM15 1h-2v2h2V1zm-2 3v2h2V4h-2zm2 3h-2v2h2V7zm-2 3v2h2v-2h-2zm2 3h-2v2h2v-2z"/>'),wd=d("Filter",'<path d="M6 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),yd=d("FilterCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M7 11.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5z"/>'),kd=d("FilterCircleFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zM3.5 5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1 0-1zM5 8.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm2 3a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5z"/>'),_d=d("FilterLeft",'<path d="M2 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Od=d("FilterRight",'<path d="M14 10.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 .5-.5zm0-3a.5.5 0 0 0-.5-.5h-7a.5.5 0 0 0 0 1h7a.5.5 0 0 0 .5-.5zm0-3a.5.5 0 0 0-.5-.5h-11a.5.5 0 0 0 0 1h11a.5.5 0 0 0 .5-.5z"/>'),zd=d("FilterSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M6 11.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Ad=d("FilterSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm.5 5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1 0-1zM4 8.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm2 3a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5z"/>'),jd=d("Flag",'<path d="M14.778.085A.5.5 0 0 1 15 .5V8a.5.5 0 0 1-.314.464L14.5 8l.186.464-.003.001-.006.003-.023.009a12.435 12.435 0 0 1-.397.15c-.264.095-.631.223-1.047.35-.816.252-1.879.523-2.71.523-.847 0-1.548-.28-2.158-.525l-.028-.01C7.68 8.71 7.14 8.5 6.5 8.5c-.7 0-1.638.23-2.437.477A19.626 19.626 0 0 0 3 9.342V15.5a.5.5 0 0 1-1 0V.5a.5.5 0 0 1 1 0v.282c.226-.079.496-.17.79-.26C4.606.272 5.67 0 6.5 0c.84 0 1.524.277 2.121.519l.043.018C9.286.788 9.828 1 10.5 1c.7 0 1.638-.23 2.437-.477a19.587 19.587 0 0 0 1.349-.476l.019-.007.004-.002h.001M14 1.221c-.22.078-.48.167-.766.255-.81.252-1.872.523-2.734.523-.886 0-1.592-.286-2.203-.534l-.008-.003C7.662 1.21 7.139 1 6.5 1c-.669 0-1.606.229-2.415.478A21.294 21.294 0 0 0 3 1.845v6.433c.22-.078.48-.167.766-.255C4.576 7.77 5.638 7.5 6.5 7.5c.847 0 1.548.28 2.158.525l.028.01C9.32 8.29 9.86 8.5 10.5 8.5c.668 0 1.606-.229 2.415-.478A21.317 21.317 0 0 0 14 7.655V1.222z"/>'),Md=d("FlagFill",'<path d="M14.778.085A.5.5 0 0 1 15 .5V8a.5.5 0 0 1-.314.464L14.5 8l.186.464-.003.001-.006.003-.023.009a12.435 12.435 0 0 1-.397.15c-.264.095-.631.223-1.047.35-.816.252-1.879.523-2.71.523-.847 0-1.548-.28-2.158-.525l-.028-.01C7.68 8.71 7.14 8.5 6.5 8.5c-.7 0-1.638.23-2.437.477A19.626 19.626 0 0 0 3 9.342V15.5a.5.5 0 0 1-1 0V.5a.5.5 0 0 1 1 0v.282c.226-.079.496-.17.79-.26C4.606.272 5.67 0 6.5 0c.84 0 1.524.277 2.121.519l.043.018C9.286.788 9.828 1 10.5 1c.7 0 1.638-.23 2.437-.477a19.587 19.587 0 0 0 1.349-.476l.019-.007.004-.002h.001"/>'),Cd=d("Flower1",'<path d="M6.174 1.184a2 2 0 0 1 3.652 0A2 2 0 0 1 12.99 3.01a2 2 0 0 1 1.826 3.164 2 2 0 0 1 0 3.652 2 2 0 0 1-1.826 3.164 2 2 0 0 1-3.164 1.826 2 2 0 0 1-3.652 0A2 2 0 0 1 3.01 12.99a2 2 0 0 1-1.826-3.164 2 2 0 0 1 0-3.652A2 2 0 0 1 3.01 3.01a2 2 0 0 1 3.164-1.826zM8 1a1 1 0 0 0-.998 1.03l.01.091c.012.077.029.176.054.296.049.241.122.542.213.887.182.688.428 1.513.676 2.314L8 5.762l.045-.144c.248-.8.494-1.626.676-2.314.091-.345.164-.646.213-.887a4.997 4.997 0 0 0 .064-.386L9 2a1 1 0 0 0-1-1zM2 9l.03-.002.091-.01a4.99 4.99 0 0 0 .296-.054c.241-.049.542-.122.887-.213a60.59 60.59 0 0 0 2.314-.676L5.762 8l-.144-.045a60.59 60.59 0 0 0-2.314-.676 16.705 16.705 0 0 0-.887-.213 4.99 4.99 0 0 0-.386-.064L2 7a1 1 0 1 0 0 2zm7 5l-.002-.03a5.005 5.005 0 0 0-.064-.386 16.398 16.398 0 0 0-.213-.888 60.582 60.582 0 0 0-.676-2.314L8 10.238l-.045.144c-.248.8-.494 1.626-.676 2.314-.091.345-.164.646-.213.887a4.996 4.996 0 0 0-.064.386L7 14a1 1 0 1 0 2 0zm-5.696-2.134l.025-.017a5.001 5.001 0 0 0 .303-.248c.184-.164.408-.377.661-.629A60.614 60.614 0 0 0 5.96 9.23l.103-.111-.147.033a60.88 60.88 0 0 0-2.343.572c-.344.093-.64.18-.874.258a5.063 5.063 0 0 0-.367.138l-.027.014a1 1 0 1 0 1 1.732zM4.5 14.062a1 1 0 0 0 1.366-.366l.014-.027c.01-.02.021-.048.036-.084a5.09 5.09 0 0 0 .102-.283c.078-.233.165-.53.258-.874a60.6 60.6 0 0 0 .572-2.343l.033-.147-.11.102a60.848 60.848 0 0 0-1.743 1.667 17.07 17.07 0 0 0-.629.66 5.06 5.06 0 0 0-.248.304l-.017.025a1 1 0 0 0 .366 1.366zm9.196-8.196a1 1 0 0 0-1-1.732l-.025.017a4.951 4.951 0 0 0-.303.248 16.69 16.69 0 0 0-.661.629A60.72 60.72 0 0 0 10.04 6.77l-.102.111.147-.033a60.6 60.6 0 0 0 2.342-.572c.345-.093.642-.18.875-.258a4.993 4.993 0 0 0 .367-.138.53.53 0 0 0 .027-.014zM11.5 1.938a1 1 0 0 0-1.366.366l-.014.027c-.01.02-.021.048-.036.084a5.09 5.09 0 0 0-.102.283c-.078.233-.165.53-.258.875a60.62 60.62 0 0 0-.572 2.342l-.033.147.11-.102a60.848 60.848 0 0 0 1.743-1.667c.252-.253.465-.477.629-.66a5.001 5.001 0 0 0 .248-.304l.017-.025a1 1 0 0 0-.366-1.366zM14 9a1 1 0 0 0 0-2l-.03.002a4.996 4.996 0 0 0-.386.064c-.242.049-.543.122-.888.213-.688.182-1.513.428-2.314.676L10.238 8l.144.045c.8.248 1.626.494 2.314.676.345.091.646.164.887.213a4.996 4.996 0 0 0 .386.064L14 9zM1.938 4.5a1 1 0 0 0 .393 1.38l.084.035c.072.03.166.064.283.103.233.078.53.165.874.258a60.88 60.88 0 0 0 2.343.572l.147.033-.103-.111a60.584 60.584 0 0 0-1.666-1.742 16.705 16.705 0 0 0-.66-.629 4.996 4.996 0 0 0-.304-.248l-.025-.017a1 1 0 0 0-1.366.366zm2.196-1.196l.017.025a4.996 4.996 0 0 0 .248.303c.164.184.377.408.629.661A60.597 60.597 0 0 0 6.77 5.96l.111.102-.033-.147a60.602 60.602 0 0 0-.572-2.342c-.093-.345-.18-.642-.258-.875a5.006 5.006 0 0 0-.138-.367l-.014-.027a1 1 0 1 0-1.732 1zm9.928 8.196a1 1 0 0 0-.366-1.366l-.027-.014a5 5 0 0 0-.367-.138c-.233-.078-.53-.165-.875-.258a60.619 60.619 0 0 0-2.342-.572l-.147-.033.102.111a60.73 60.73 0 0 0 1.667 1.742c.253.252.477.465.66.629a4.946 4.946 0 0 0 .304.248l.025.017a1 1 0 0 0 1.366-.366zm-3.928 2.196a1 1 0 0 0 1.732-1l-.017-.025a5.065 5.065 0 0 0-.248-.303 16.705 16.705 0 0 0-.629-.661A60.462 60.462 0 0 0 9.23 10.04l-.111-.102.033.147a60.6 60.6 0 0 0 .572 2.342c.093.345.18.642.258.875a4.985 4.985 0 0 0 .138.367.575.575 0 0 0 .014.027zM8 9.5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/>'),Vd=d("Flower2",'<path d="M8 16a4 4 0 0 0 4-4 4 4 0 0 0 0-8 4 4 0 0 0-8 0 4 4 0 1 0 0 8 4 4 0 0 0 4 4zm3-12c0 .073-.01.155-.03.247-.544.241-1.091.638-1.598 1.084A2.987 2.987 0 0 0 8 5c-.494 0-.96.12-1.372.331-.507-.446-1.054-.843-1.597-1.084A1.117 1.117 0 0 1 5 4a3 3 0 0 1 6 0zm-.812 6.052A2.99 2.99 0 0 0 11 8a2.99 2.99 0 0 0-.812-2.052c.215-.18.432-.346.647-.487C11.34 5.131 11.732 5 12 5a3 3 0 1 1 0 6c-.268 0-.66-.13-1.165-.461a6.833 6.833 0 0 1-.647-.487zm-3.56.617a3.001 3.001 0 0 0 2.744 0c.507.446 1.054.842 1.598 1.084.02.091.03.174.03.247a3 3 0 1 1-6 0c0-.073.01-.155.03-.247.544-.242 1.091-.638 1.598-1.084zm-.816-4.721A2.99 2.99 0 0 0 5 8c0 .794.308 1.516.812 2.052a6.83 6.83 0 0 1-.647.487C4.66 10.869 4.268 11 4 11a3 3 0 0 1 0-6c.268 0 .66.13 1.165.461.215.141.432.306.647.487zM8 9a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>'),Sd=d("Flower3",'<path d="M11.424 8c.437-.052.811-.136 1.04-.268a2 2 0 0 0-2-3.464c-.229.132-.489.414-.752.767C9.886 4.63 10 4.264 10 4a2 2 0 1 0-4 0c0 .264.114.63.288 1.035-.263-.353-.523-.635-.752-.767a2 2 0 0 0-2 3.464c.229.132.603.216 1.04.268-.437.052-.811.136-1.04.268a2 2 0 1 0 2 3.464c.229-.132.489-.414.752-.767C6.114 11.37 6 11.736 6 12a2 2 0 1 0 4 0c0-.264-.114-.63-.288-1.035.263.353.523.635.752.767a2 2 0 1 0 2-3.464c-.229-.132-.603-.216-1.04-.268zM9 4a1.468 1.468 0 0 1-.045.205c-.039.132-.1.295-.183.484a12.88 12.88 0 0 1-.637 1.223L8 6.142a21.73 21.73 0 0 1-.135-.23 12.88 12.88 0 0 1-.637-1.223 4.216 4.216 0 0 1-.183-.484A1.473 1.473 0 0 1 7 4a1 1 0 1 1 2 0zM3.67 5.5a1 1 0 0 1 1.366-.366 1.472 1.472 0 0 1 .156.142c.094.1.204.233.326.4.245.333.502.747.742 1.163l.13.232a21.86 21.86 0 0 1-.265.002 12.88 12.88 0 0 1-1.379-.06 4.214 4.214 0 0 1-.51-.083 1.47 1.47 0 0 1-.2-.064A1 1 0 0 1 3.67 5.5zm1.366 5.366a1 1 0 0 1-1-1.732c.001 0 .016-.008.047-.02.037-.013.087-.028.153-.044.134-.032.305-.06.51-.083a12.88 12.88 0 0 1 1.379-.06c.09 0 .178 0 .266.002a21.82 21.82 0 0 1-.131.232c-.24.416-.497.83-.742 1.163a4.1 4.1 0 0 1-.327.4 1.483 1.483 0 0 1-.155.142zM9 12a1 1 0 0 1-2 0 1.476 1.476 0 0 1 .045-.206c.039-.131.1-.294.183-.483.166-.378.396-.808.637-1.223L8 9.858l.135.23c.241.415.47.845.637 1.223.083.19.144.352.183.484A1.338 1.338 0 0 1 9 12zm3.33-6.5a1 1 0 0 1-.366 1.366 1.478 1.478 0 0 1-.2.064c-.134.032-.305.06-.51.083-.412.045-.898.061-1.379.06-.09 0-.178 0-.266-.002l.131-.232c.24-.416.497-.83.742-1.163a4.1 4.1 0 0 1 .327-.4c.046-.05.085-.086.114-.11.026-.022.04-.03.041-.032a1 1 0 0 1 1.366.366zm-1.366 5.366a1.494 1.494 0 0 1-.155-.141 4.225 4.225 0 0 1-.327-.4A12.88 12.88 0 0 1 9.74 9.16a22 22 0 0 1-.13-.232l.265-.002c.48-.001.967.015 1.379.06.205.023.376.051.51.083.066.016.116.031.153.044l.048.02a1 1 0 1 1-1 1.732zM8 9a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>'),xd=d("Folder",'<path d="M.54 3.87L.5 3a2 2 0 0 1 2-2h3.672a2 2 0 0 1 1.414.586l.828.828A2 2 0 0 0 9.828 3h3.982a2 2 0 0 1 1.992 2.181l-.637 7A2 2 0 0 1 13.174 14H2.826a2 2 0 0 1-1.991-1.819l-.637-7a1.99 1.99 0 0 1 .342-1.31zM2.19 4a1 1 0 0 0-.996 1.09l.637 7a1 1 0 0 0 .995.91h10.348a1 1 0 0 0 .995-.91l.637-7A1 1 0 0 0 13.81 4H2.19zm4.69-1.707A1 1 0 0 0 6.172 2H2.5a1 1 0 0 0-1 .981l.006.139C1.72 3.042 1.95 3 2.19 3h5.396l-.707-.707z"/>'),Td=d("Folder2",'<path d="M1 3.5A1.5 1.5 0 0 1 2.5 2h2.764c.958 0 1.76.56 2.311 1.184C7.985 3.648 8.48 4 9 4h4.5A1.5 1.5 0 0 1 15 5.5v7a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 12.5v-9zM2.5 3a.5.5 0 0 0-.5.5V6h12v-.5a.5.5 0 0 0-.5-.5H9c-.964 0-1.71-.629-2.174-1.154C6.374 3.334 5.82 3 5.264 3H2.5zM14 7H2v5.5a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 .5-.5V7z"/>'),Pd=d("Folder2Open",'<path d="M1 3.5A1.5 1.5 0 0 1 2.5 2h2.764c.958 0 1.76.56 2.311 1.184C7.985 3.648 8.48 4 9 4h4.5A1.5 1.5 0 0 1 15 5.5v.64c.57.265.94.876.856 1.546l-.64 5.124A2.5 2.5 0 0 1 12.733 15H3.266a2.5 2.5 0 0 1-2.481-2.19l-.64-5.124A1.5 1.5 0 0 1 1 6.14V3.5zM2 6h12v-.5a.5.5 0 0 0-.5-.5H9c-.964 0-1.71-.629-2.174-1.154C6.374 3.334 5.82 3 5.264 3H2.5a.5.5 0 0 0-.5.5V6zm-.367 1a.5.5 0 0 0-.496.562l.64 5.124A1.5 1.5 0 0 0 3.266 14h9.468a1.5 1.5 0 0 0 1.489-1.314l.64-5.124A.5.5 0 0 0 14.367 7H1.633z"/>'),Id=d("FolderCheck",'<path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14H9v-1H2.826a1 1 0 0 1-.995-.91l-.637-7A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09L14.54 8h1.005l.256-2.819A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm5.672-1a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/><path d="M15.854 10.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708l1.146 1.147 2.646-2.647a.5.5 0 0 1 .708 0z"/>'),Ed=d("FolderFill",'<path d="M9.828 3h3.982a2 2 0 0 1 1.992 2.181l-.637 7A2 2 0 0 1 13.174 14H2.826a2 2 0 0 1-1.991-1.819l-.637-7a1.99 1.99 0 0 1 .342-1.31L.5 3a2 2 0 0 1 2-2h3.672a2 2 0 0 1 1.414.586l.828.828A2 2 0 0 0 9.828 3zm-8.322.12C1.72 3.042 1.95 3 2.19 3h5.396l-.707-.707A1 1 0 0 0 6.172 2H2.5a1 1 0 0 0-1 .981l.006.139z"/>'),Ld=d("FolderMinus",'<path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14H9v-1H2.826a1 1 0 0 1-.995-.91l-.637-7A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09L14.54 8h1.005l.256-2.819A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm5.672-1a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/><path d="M11 11.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>'),Bd=d("FolderPlus",'<path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14H9v-1H2.826a1 1 0 0 1-.995-.91l-.637-7A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09L14.54 8h1.005l.256-2.819A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm5.672-1a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/><path d="M13.5 10a.5.5 0 0 1 .5.5V12h1.5a.5.5 0 0 1 0 1H14v1.5a.5.5 0 0 1-1 0V13h-1.5a.5.5 0 0 1 0-1H13v-1.5a.5.5 0 0 1 .5-.5z"/>'),Hd=d("FolderSymlink",'<path d="M11.798 8.271l-3.182 1.97c-.27.166-.616-.036-.616-.372V9.1s-2.571-.3-4 2.4c.571-4.8 3.143-4.8 4-4.8v-.769c0-.336.346-.538.616-.371l3.182 1.969c.27.166.27.576 0 .742z"/><path d="M.5 3l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14h10.348a2 2 0 0 0 1.991-1.819l.637-7A2 2 0 0 0 13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2zm.694 2.09A1 1 0 0 1 2.19 4h11.62a1 1 0 0 1 .996 1.09l-.636 7a1 1 0 0 1-.996.91H2.826a1 1 0 0 1-.995-.91l-.637-7zM6.172 2a1 1 0 0 1 .707.293L7.586 3H2.19c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672z"/>'),Fd=d("FolderSymlinkFill",'<path d="M13.81 3H9.828a2 2 0 0 1-1.414-.586l-.828-.828A2 2 0 0 0 6.172 1H2.5a2 2 0 0 0-2 2l.04.87a1.99 1.99 0 0 0-.342 1.311l.637 7A2 2 0 0 0 2.826 14h10.348a2 2 0 0 0 1.991-1.819l.637-7A2 2 0 0 0 13.81 3zM2.19 3c-.24 0-.47.042-.684.12L1.5 2.98a1 1 0 0 1 1-.98h3.672a1 1 0 0 1 .707.293L7.586 3H2.19zm9.608 5.271l-3.182 1.97c-.27.166-.616-.036-.616-.372V9.1s-2.571-.3-4 2.4c.571-4.8 3.143-4.8 4-4.8v-.769c0-.336.346-.538.616-.371l3.182 1.969c.27.166.27.576 0 .742z"/>'),Dd=d("FolderX",'<path d="M.54 3.87L.5 3a2 2 0 0 1 2-2h3.672a2 2 0 0 1 1.414.586l.828.828A2 2 0 0 0 9.828 3h3.982a2 2 0 0 1 1.992 2.181L15.546 8H14.54l.265-2.91A1 1 0 0 0 13.81 4H2.19a1 1 0 0 0-.996 1.09l.637 7a1 1 0 0 0 .995.91H9v1H2.826a2 2 0 0 1-1.991-1.819l-.637-7a1.99 1.99 0 0 1 .342-1.31zm6.339-1.577A1 1 0 0 0 6.172 2H2.5a1 1 0 0 0-1 .981l.006.139C1.72 3.042 1.95 3 2.19 3h5.396l-.707-.707z"/><path d="M11.854 10.146a.5.5 0 0 0-.708.708L12.293 12l-1.147 1.146a.5.5 0 0 0 .708.708L13 12.707l1.146 1.147a.5.5 0 0 0 .708-.708L13.707 12l1.147-1.146a.5.5 0 0 0-.708-.708L13 11.293l-1.146-1.147z"/>'),Rd=d("Fonts",'<path d="M12.258 3H3.747l-.082 2.46h.478c.26-1.544.76-1.783 2.694-1.845l.424-.013v7.827c0 .663-.144.82-1.3.923v.52h4.082v-.52c-1.162-.103-1.306-.26-1.306-.923V3.602l.43.013c1.935.062 2.434.301 2.694 1.846h.479L12.258 3z"/>'),Nd=d("Forward",'<path d="M9.502 5.513a.144.144 0 0 0-.202.134V6.65a.5.5 0 0 1-.5.5H2.5v2.9h6.3a.5.5 0 0 1 .5.5v1.003c0 .108.11.176.202.134l3.984-2.933a.51.51 0 0 1 .042-.028.147.147 0 0 0 0-.252.51.51 0 0 1-.042-.028L9.502 5.513zM8.3 5.647a1.144 1.144 0 0 1 1.767-.96l3.994 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a1.144 1.144 0 0 1-1.767-.96v-.503H2a.5.5 0 0 1-.5-.5v-3.9a.5.5 0 0 1 .5-.5h6.3v-.503z"/>'),$d=d("ForwardFill",'<path d="M9.77 12.11l4.012-2.953a.647.647 0 0 0 0-1.114L9.771 5.09a.644.644 0 0 0-.971.557V6.65H2v3.9h6.8v1.003c0 .505.545.808.97.557z"/>'),Ud=d("Front",'<path fill-rule="evenodd" d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm5 10v2a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1h-2v5a2 2 0 0 1-2 2H5z"/>'),qd=d("Fullscreen",'<path d="M1.5 1a.5.5 0 0 0-.5.5v4a.5.5 0 0 1-1 0v-4A1.5 1.5 0 0 1 1.5 0h4a.5.5 0 0 1 0 1h-4zM10 .5a.5.5 0 0 1 .5-.5h4A1.5 1.5 0 0 1 16 1.5v4a.5.5 0 0 1-1 0v-4a.5.5 0 0 0-.5-.5h-4a.5.5 0 0 1-.5-.5zM.5 10a.5.5 0 0 1 .5.5v4a.5.5 0 0 0 .5.5h4a.5.5 0 0 1 0 1h-4A1.5 1.5 0 0 1 0 14.5v-4a.5.5 0 0 1 .5-.5zm15 0a.5.5 0 0 1 .5.5v4a1.5 1.5 0 0 1-1.5 1.5h-4a.5.5 0 0 1 0-1h4a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 1 .5-.5z"/>'),Wd=d("FullscreenExit",'<path d="M5.5 0a.5.5 0 0 1 .5.5v4A1.5 1.5 0 0 1 4.5 6h-4a.5.5 0 0 1 0-1h4a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 1 .5-.5zm5 0a.5.5 0 0 1 .5.5v4a.5.5 0 0 0 .5.5h4a.5.5 0 0 1 0 1h-4A1.5 1.5 0 0 1 10 4.5v-4a.5.5 0 0 1 .5-.5zM0 10.5a.5.5 0 0 1 .5-.5h4A1.5 1.5 0 0 1 6 11.5v4a.5.5 0 0 1-1 0v-4a.5.5 0 0 0-.5-.5h-4a.5.5 0 0 1-.5-.5zm10 1a1.5 1.5 0 0 1 1.5-1.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 0-.5.5v4a.5.5 0 0 1-1 0v-4z"/>'),Gd=d("Funnel",'<path d="M1.5 1.5A.5.5 0 0 1 2 1h12a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.128.334L10 8.692V13.5a.5.5 0 0 1-.342.474l-3 1A.5.5 0 0 1 6 14.5V8.692L1.628 3.834A.5.5 0 0 1 1.5 3.5v-2zm1 .5v1.308l4.372 4.858A.5.5 0 0 1 7 8.5v5.306l2-.666V8.5a.5.5 0 0 1 .128-.334L13.5 3.308V2h-11z"/>'),Yd=d("FunnelFill",'<path d="M1.5 1.5A.5.5 0 0 1 2 1h12a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.128.334L10 8.692V13.5a.5.5 0 0 1-.342.474l-3 1A.5.5 0 0 1 6 14.5V8.692L1.628 3.834A.5.5 0 0 1 1.5 3.5v-2z"/>'),Kd=d("Gear",'<path d="M8 4.754a3.246 3.246 0 1 0 0 6.492 3.246 3.246 0 0 0 0-6.492zM5.754 8a2.246 2.246 0 1 1 4.492 0 2.246 2.246 0 0 1-4.492 0z"/><path d="M9.796 1.343c-.527-1.79-3.065-1.79-3.592 0l-.094.319a.873.873 0 0 1-1.255.52l-.292-.16c-1.64-.892-3.433.902-2.54 2.541l.159.292a.873.873 0 0 1-.52 1.255l-.319.094c-1.79.527-1.79 3.065 0 3.592l.319.094a.873.873 0 0 1 .52 1.255l-.16.292c-.892 1.64.901 3.434 2.541 2.54l.292-.159a.873.873 0 0 1 1.255.52l.094.319c.527 1.79 3.065 1.79 3.592 0l.094-.319a.873.873 0 0 1 1.255-.52l.292.16c1.64.893 3.434-.902 2.54-2.541l-.159-.292a.873.873 0 0 1 .52-1.255l.319-.094c1.79-.527 1.79-3.065 0-3.592l-.319-.094a.873.873 0 0 1-.52-1.255l.16-.292c.893-1.64-.902-3.433-2.541-2.54l-.292.159a.873.873 0 0 1-1.255-.52l-.094-.319zm-2.633.283c.246-.835 1.428-.835 1.674 0l.094.319a1.873 1.873 0 0 0 2.693 1.115l.291-.16c.764-.415 1.6.42 1.184 1.185l-.159.292a1.873 1.873 0 0 0 1.116 2.692l.318.094c.835.246.835 1.428 0 1.674l-.319.094a1.873 1.873 0 0 0-1.115 2.693l.16.291c.415.764-.42 1.6-1.185 1.184l-.291-.159a1.873 1.873 0 0 0-2.693 1.116l-.094.318c-.246.835-1.428.835-1.674 0l-.094-.319a1.873 1.873 0 0 0-2.692-1.115l-.292.16c-.764.415-1.6-.42-1.184-1.185l.159-.291A1.873 1.873 0 0 0 1.945 8.93l-.319-.094c-.835-.246-.835-1.428 0-1.674l.319-.094A1.873 1.873 0 0 0 3.06 4.377l-.16-.292c-.415-.764.42-1.6 1.185-1.184l.292.159a1.873 1.873 0 0 0 2.692-1.115l.094-.319z"/>'),Qd=d("GearFill",'<path d="M9.405 1.05c-.413-1.4-2.397-1.4-2.81 0l-.1.34a1.464 1.464 0 0 1-2.105.872l-.31-.17c-1.283-.698-2.686.705-1.987 1.987l.169.311c.446.82.023 1.841-.872 2.105l-.34.1c-1.4.413-1.4 2.397 0 2.81l.34.1a1.464 1.464 0 0 1 .872 2.105l-.17.31c-.698 1.283.705 2.686 1.987 1.987l.311-.169a1.464 1.464 0 0 1 2.105.872l.1.34c.413 1.4 2.397 1.4 2.81 0l.1-.34a1.464 1.464 0 0 1 2.105-.872l.31.17c1.283.698 2.686-.705 1.987-1.987l-.169-.311a1.464 1.464 0 0 1 .872-2.105l.34-.1c1.4-.413 1.4-2.397 0-2.81l-.34-.1a1.464 1.464 0 0 1-.872-2.105l.17-.31c.698-1.283-.705-2.686-1.987-1.987l-.311.169a1.464 1.464 0 0 1-2.105-.872l-.1-.34zM8 10.93a2.929 2.929 0 1 1 0-5.86 2.929 2.929 0 0 1 0 5.858z"/>'),Xd=d("GearWide",'<path d="M8.932.727c-.243-.97-1.62-.97-1.864 0l-.071.286a.96.96 0 0 1-1.622.434l-.205-.211c-.695-.719-1.888-.03-1.613.931l.08.284a.96.96 0 0 1-1.186 1.187l-.284-.081c-.96-.275-1.65.918-.931 1.613l.211.205a.96.96 0 0 1-.434 1.622l-.286.071c-.97.243-.97 1.62 0 1.864l.286.071a.96.96 0 0 1 .434 1.622l-.211.205c-.719.695-.03 1.888.931 1.613l.284-.08a.96.96 0 0 1 1.187 1.187l-.081.283c-.275.96.918 1.65 1.613.931l.205-.211a.96.96 0 0 1 1.622.434l.071.286c.243.97 1.62.97 1.864 0l.071-.286a.96.96 0 0 1 1.622-.434l.205.211c.695.719 1.888.03 1.613-.931l-.08-.284a.96.96 0 0 1 1.187-1.187l.283.081c.96.275 1.65-.918.931-1.613l-.211-.205a.96.96 0 0 1 .434-1.622l.286-.071c.97-.243.97-1.62 0-1.864l-.286-.071a.96.96 0 0 1-.434-1.622l.211-.205c.719-.695.03-1.888-.931-1.613l-.284.08a.96.96 0 0 1-1.187-1.186l.081-.284c.275-.96-.918-1.65-1.613-.931l-.205.211a.96.96 0 0 1-1.622-.434L8.932.727zM8 12.997a4.998 4.998 0 1 1 0-9.995 4.998 4.998 0 0 1 0 9.996z"/>'),Jd=d("GearWideConnected",'<path d="M7.068.727c.243-.97 1.62-.97 1.864 0l.071.286a.96.96 0 0 0 1.622.434l.205-.211c.695-.719 1.888-.03 1.613.931l-.08.284a.96.96 0 0 0 1.187 1.187l.283-.081c.96-.275 1.65.918.931 1.613l-.211.205a.96.96 0 0 0 .434 1.622l.286.071c.97.243.97 1.62 0 1.864l-.286.071a.96.96 0 0 0-.434 1.622l.211.205c.719.695.03 1.888-.931 1.613l-.284-.08a.96.96 0 0 0-1.187 1.187l.081.283c.275.96-.918 1.65-1.613.931l-.205-.211a.96.96 0 0 0-1.622.434l-.071.286c-.243.97-1.62.97-1.864 0l-.071-.286a.96.96 0 0 0-1.622-.434l-.205.211c-.695.719-1.888.03-1.613-.931l.08-.284a.96.96 0 0 0-1.186-1.187l-.284.081c-.96.275-1.65-.918-.931-1.613l.211-.205a.96.96 0 0 0-.434-1.622l-.286-.071c-.97-.243-.97-1.62 0-1.864l.286-.071a.96.96 0 0 0 .434-1.622l-.211-.205c-.719-.695-.03-1.888.931-1.613l.284.08a.96.96 0 0 0 1.187-1.186l-.081-.284c-.275-.96.918-1.65 1.613-.931l.205.211a.96.96 0 0 0 1.622-.434l.071-.286zM12.973 8.5H8.25l-2.834 3.779A4.998 4.998 0 0 0 12.973 8.5zm0-1a4.998 4.998 0 0 0-7.557-3.779l2.834 3.78h4.723zM5.048 3.967c-.03.021-.058.043-.087.065l.087-.065zm-.431.355A4.984 4.984 0 0 0 3.002 8c0 1.455.622 2.765 1.615 3.678L7.375 8 4.617 4.322zm.344 7.646l.087.065-.087-.065z"/>'),Zd=d("Gem",'<path d="M3.1.7a.5.5 0 0 1 .4-.2h9a.5.5 0 0 1 .4.2l2.976 3.974c.149.185.156.45.01.644L8.4 15.3a.5.5 0 0 1-.8 0L.1 5.3a.5.5 0 0 1 0-.6l3-4zm11.386 3.785l-1.806-2.41-.776 2.413 2.582-.003zm-3.633.004l.961-2.989H4.186l.963 2.995 5.704-.006zM5.47 5.495L8 13.366l2.532-7.876-5.062.005zm-1.371-.999l-.78-2.422-1.818 2.425 2.598-.003zM1.499 5.5l5.113 6.817-2.192-6.82L1.5 5.5zm7.889 6.817l5.123-6.83-2.928.002-2.195 6.828z"/>'),th=d("Geo",'<path fill-rule="evenodd" d="M8 1a3 3 0 1 0 0 6 3 3 0 0 0 0-6zM4 4a4 4 0 1 1 4.5 3.969V13.5a.5.5 0 0 1-1 0V7.97A4 4 0 0 1 4 3.999zm2.493 8.574a.5.5 0 0 1-.411.575c-.712.118-1.28.295-1.655.493a1.319 1.319 0 0 0-.37.265.301.301 0 0 0-.057.09V14l.002.008a.147.147 0 0 0 .016.033.617.617 0 0 0 .145.15c.165.13.435.27.813.395.751.25 1.82.414 3.024.414s2.273-.163 3.024-.414c.378-.126.648-.265.813-.395a.619.619 0 0 0 .146-.15.148.148 0 0 0 .015-.033L12 14v-.004a.301.301 0 0 0-.057-.09 1.318 1.318 0 0 0-.37-.264c-.376-.198-.943-.375-1.655-.493a.5.5 0 1 1 .164-.986c.77.127 1.452.328 1.957.594C12.5 13 13 13.4 13 14c0 .426-.26.752-.544.977-.29.228-.68.413-1.116.558-.878.293-2.059.465-3.34.465-1.281 0-2.462-.172-3.34-.465-.436-.145-.826-.33-1.116-.558C3.26 14.752 3 14.426 3 14c0-.599.5-1 .961-1.243.505-.266 1.187-.467 1.957-.594a.5.5 0 0 1 .575.411z"/>'),eh=d("GeoAlt",'<path d="M12.166 8.94c-.524 1.062-1.234 2.12-1.96 3.07A31.493 31.493 0 0 1 8 14.58a31.481 31.481 0 0 1-2.206-2.57c-.726-.95-1.436-2.008-1.96-3.07C3.304 7.867 3 6.862 3 6a5 5 0 0 1 10 0c0 .862-.305 1.867-.834 2.94zM8 16s6-5.686 6-10A6 6 0 0 0 2 6c0 4.314 6 10 6 10z"/><path d="M8 8a2 2 0 1 1 0-4 2 2 0 0 1 0 4zm0 1a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>'),nh=d("GeoAltFill",'<path d="M8 16s6-5.686 6-10A6 6 0 0 0 2 6c0 4.314 6 10 6 10zm0-7a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>'),rh=d("GeoFill",'<path fill-rule="evenodd" d="M4 4a4 4 0 1 1 4.5 3.969V13.5a.5.5 0 0 1-1 0V7.97A4 4 0 0 1 4 3.999zm2.493 8.574a.5.5 0 0 1-.411.575c-.712.118-1.28.295-1.655.493a1.319 1.319 0 0 0-.37.265.301.301 0 0 0-.057.09V14l.002.008a.147.147 0 0 0 .016.033.617.617 0 0 0 .145.15c.165.13.435.27.813.395.751.25 1.82.414 3.024.414s2.273-.163 3.024-.414c.378-.126.648-.265.813-.395a.619.619 0 0 0 .146-.15.148.148 0 0 0 .015-.033L12 14v-.004a.301.301 0 0 0-.057-.09 1.318 1.318 0 0 0-.37-.264c-.376-.198-.943-.375-1.655-.493a.5.5 0 1 1 .164-.986c.77.127 1.452.328 1.957.594C12.5 13 13 13.4 13 14c0 .426-.26.752-.544.977-.29.228-.68.413-1.116.558-.878.293-2.059.465-3.34.465-1.281 0-2.462-.172-3.34-.465-.436-.145-.826-.33-1.116-.558C3.26 14.752 3 14.426 3 14c0-.599.5-1 .961-1.243.505-.266 1.187-.467 1.957-.594a.5.5 0 0 1 .575.411z"/>'),ih=d("Gift",'<path d="M3 2.5a2.5 2.5 0 0 1 5 0 2.5 2.5 0 0 1 5 0v.006c0 .07 0 .27-.038.494H15a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1v7.5a1.5 1.5 0 0 1-1.5 1.5h-11A1.5 1.5 0 0 1 1 14.5V7a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h2.038A2.968 2.968 0 0 1 3 2.506V2.5zm1.068.5H7v-.5a1.5 1.5 0 1 0-3 0c0 .085.002.274.045.43a.522.522 0 0 0 .023.07zM9 3h2.932a.56.56 0 0 0 .023-.07c.043-.156.045-.345.045-.43a1.5 1.5 0 0 0-3 0V3zM1 4v2h6V4H1zm8 0v2h6V4H9zm5 3H9v8h4.5a.5.5 0 0 0 .5-.5V7zm-7 8V7H2v7.5a.5.5 0 0 0 .5.5H7z"/>'),oh=d("GiftFill",'<path d="M3 2.5a2.5 2.5 0 0 1 5 0 2.5 2.5 0 0 1 5 0v.006c0 .07 0 .27-.038.494H15a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h2.038A2.968 2.968 0 0 1 3 2.506V2.5zm1.068.5H7v-.5a1.5 1.5 0 1 0-3 0c0 .085.002.274.045.43a.522.522 0 0 0 .023.07zM9 3h2.932a.56.56 0 0 0 .023-.07c.043-.156.045-.345.045-.43a1.5 1.5 0 0 0-3 0V3zm6 4v7.5a1.5 1.5 0 0 1-1.5 1.5H9V7h6zM2.5 16A1.5 1.5 0 0 1 1 14.5V7h6v9H2.5z"/>'),ah=d("Github",'<path d="M8 0C3.58 0 0 3.58 0 8c0 3.54 2.29 6.53 5.47 7.59.4.07.55-.17.55-.38 0-.19-.01-.82-.01-1.49-2.01.37-2.53-.49-2.69-.94-.09-.23-.48-.94-.82-1.13-.28-.15-.68-.52-.01-.53.63-.01 1.08.58 1.23.82.72 1.21 1.87.87 2.33.66.07-.52.28-.87.51-1.07-1.78-.2-3.64-.89-3.64-3.95 0-.87.31-1.59.82-2.15-.08-.2-.36-1.02.08-2.12 0 0 .67-.21 2.2.82.64-.18 1.32-.27 2-.27.68 0 1.36.09 2 .27 1.53-1.04 2.2-.82 2.2-.82.44 1.1.16 1.92.08 2.12.51.56.82 1.27.82 2.15 0 3.07-1.87 3.75-3.65 3.95.29.25.54.73.54 1.48 0 1.07-.01 1.93-.01 2.2 0 .21.15.46.55.38A8.012 8.012 0 0 0 16 8c0-4.42-3.58-8-8-8z"/>'),sh=d("Globe",'<path d="M0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8zm7.5-6.923c-.67.204-1.335.82-1.887 1.855A7.97 7.97 0 0 0 5.145 4H7.5V1.077zM4.09 4a9.267 9.267 0 0 1 .64-1.539 6.7 6.7 0 0 1 .597-.933A7.025 7.025 0 0 0 2.255 4H4.09zm-.582 3.5c.03-.877.138-1.718.312-2.5H1.674a6.958 6.958 0 0 0-.656 2.5h2.49zM4.847 5a12.5 12.5 0 0 0-.338 2.5H7.5V5H4.847zM8.5 5v2.5h2.99a12.495 12.495 0 0 0-.337-2.5H8.5zM4.51 8.5a12.5 12.5 0 0 0 .337 2.5H7.5V8.5H4.51zm3.99 0V11h2.653c.187-.765.306-1.608.338-2.5H8.5zM5.145 12c.138.386.295.744.468 1.068.552 1.035 1.218 1.65 1.887 1.855V12H5.145zm.182 2.472a6.696 6.696 0 0 1-.597-.933A9.268 9.268 0 0 1 4.09 12H2.255a7.024 7.024 0 0 0 3.072 2.472zM3.82 11a13.652 13.652 0 0 1-.312-2.5h-2.49c.062.89.291 1.733.656 2.5H3.82zm6.853 3.472A7.024 7.024 0 0 0 13.745 12H11.91a9.27 9.27 0 0 1-.64 1.539 6.688 6.688 0 0 1-.597.933zM8.5 12v2.923c.67-.204 1.335-.82 1.887-1.855.173-.324.33-.682.468-1.068H8.5zm3.68-1h2.146c.365-.767.594-1.61.656-2.5h-2.49a13.65 13.65 0 0 1-.312 2.5zm2.802-3.5a6.959 6.959 0 0 0-.656-2.5H12.18c.174.782.282 1.623.312 2.5h2.49zM11.27 2.461c.247.464.462.98.64 1.539h1.835a7.024 7.024 0 0 0-3.072-2.472c.218.284.418.598.597.933zM10.855 4a7.966 7.966 0 0 0-.468-1.068C9.835 1.897 9.17 1.282 8.5 1.077V4h2.355z"/>'),ch=d("Globe2",'<path d="M0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8zm7.5-6.923c-.67.204-1.335.82-1.887 1.855-.143.268-.276.56-.395.872.705.157 1.472.257 2.282.287V1.077zM4.249 3.539c.142-.384.304-.744.481-1.078a6.7 6.7 0 0 1 .597-.933A7.01 7.01 0 0 0 3.051 3.05c.362.184.763.349 1.198.49zM3.509 7.5c.036-1.07.188-2.087.436-3.008a9.124 9.124 0 0 1-1.565-.667A6.964 6.964 0 0 0 1.018 7.5h2.49zm1.4-2.741a12.344 12.344 0 0 0-.4 2.741H7.5V5.091c-.91-.03-1.783-.145-2.591-.332zM8.5 5.09V7.5h2.99a12.342 12.342 0 0 0-.399-2.741c-.808.187-1.681.301-2.591.332zM4.51 8.5c.035.987.176 1.914.399 2.741A13.612 13.612 0 0 1 7.5 10.91V8.5H4.51zm3.99 0v2.409c.91.03 1.783.145 2.591.332.223-.827.364-1.754.4-2.741H8.5zm-3.282 3.696c.12.312.252.604.395.872.552 1.035 1.218 1.65 1.887 1.855V11.91c-.81.03-1.577.13-2.282.287zm.11 2.276a6.696 6.696 0 0 1-.598-.933 8.853 8.853 0 0 1-.481-1.079 8.38 8.38 0 0 0-1.198.49 7.01 7.01 0 0 0 2.276 1.522zm-1.383-2.964A13.36 13.36 0 0 1 3.508 8.5h-2.49a6.963 6.963 0 0 0 1.362 3.675c.47-.258.995-.482 1.565-.667zm6.728 2.964a7.009 7.009 0 0 0 2.275-1.521 8.376 8.376 0 0 0-1.197-.49 8.853 8.853 0 0 1-.481 1.078 6.688 6.688 0 0 1-.597.933zM8.5 11.909v3.014c.67-.204 1.335-.82 1.887-1.855.143-.268.276-.56.395-.872A12.63 12.63 0 0 0 8.5 11.91zm3.555-.401c.57.185 1.095.409 1.565.667A6.963 6.963 0 0 0 14.982 8.5h-2.49a13.36 13.36 0 0 1-.437 3.008zM14.982 7.5a6.963 6.963 0 0 0-1.362-3.675c-.47.258-.995.482-1.565.667.248.92.4 1.938.437 3.008h2.49zM11.27 2.461c.177.334.339.694.482 1.078a8.368 8.368 0 0 0 1.196-.49 7.01 7.01 0 0 0-2.275-1.52c.218.283.418.597.597.932zm-.488 1.343a7.765 7.765 0 0 0-.395-.872C9.835 1.897 9.17 1.282 8.5 1.077V4.09c.81-.03 1.577-.13 2.282-.287z"/>'),lh=d("Google",'<path d="M15.545 6.558a9.42 9.42 0 0 1 .139 1.626c0 2.434-.87 4.492-2.384 5.885h.002C11.978 15.292 10.158 16 8 16A8 8 0 1 1 8 0a7.689 7.689 0 0 1 5.352 2.082l-2.284 2.284A4.347 4.347 0 0 0 8 3.166c-2.087 0-3.86 1.408-4.492 3.304a4.792 4.792 0 0 0 0 3.063h.003c.635 1.893 2.405 3.301 4.492 3.301 1.078 0 2.004-.276 2.722-.764h-.003a3.702 3.702 0 0 0 1.599-2.431H8v-3.08h7.545z"/>'),uh=d("GraphDown",'<path fill-rule="evenodd" d="M0 0h1v15h15v1H0V0zm10 11.5a.5.5 0 0 0 .5.5h4a.5.5 0 0 0 .5-.5v-4a.5.5 0 0 0-1 0v2.6l-3.613-4.417a.5.5 0 0 0-.74-.037L7.06 8.233 3.404 3.206a.5.5 0 0 0-.808.588l4 5.5a.5.5 0 0 0 .758.06l2.609-2.61L13.445 11H10.5a.5.5 0 0 0-.5.5z"/>'),dh=d("GraphUp",'<path fill-rule="evenodd" d="M0 0h1v15h15v1H0V0zm10 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V4.9l-3.613 4.417a.5.5 0 0 1-.74.037L7.06 6.767l-3.656 5.027a.5.5 0 0 1-.808-.588l4-5.5a.5.5 0 0 1 .758-.06l2.609 2.61L13.445 4H10.5a.5.5 0 0 1-.5-.5z"/>'),hh=d("Grid",'<path d="M1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5v-3zM2.5 2a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3zm6.5.5A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5v-3zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3zM1 10.5A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5v-3zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3zm6.5.5A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5v-3zm1.5-.5a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 0-.5-.5h-3z"/>'),fh=d("Grid1x2",'<path d="M6 1H1v14h5V1zm9 0h-5v5h5V1zm0 9v5h-5v-5h5zM0 1a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v14a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V1zm9 0a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1V1zm1 8a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1h-5z"/>'),ph=d("Grid1x2Fill",'<path d="M0 1a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v14a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V1zm9 0a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1V1zm0 9a1 1 0 0 1 1-1h5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-5z"/>'),mh=d("Grid3x2",'<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v8a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 11.5v-8zM1.5 3a.5.5 0 0 0-.5.5V7h4V3H1.5zM5 8H1v3.5a.5.5 0 0 0 .5.5H5V8zm1 0v4h4V8H6zm4-1V3H6v4h4zm1 1v4h3.5a.5.5 0 0 0 .5-.5V8h-4zm0-1h4V3.5a.5.5 0 0 0-.5-.5H11v4z"/>'),bh=d("Grid3x2Gap",'<path d="M4 4v2H2V4h2zm1 7V9a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V4a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm5 5V9a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V4a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zM9 4v2H7V4h2zm5 0h-2v2h2V4zM4 9v2H2V9h2zm5 0v2H7V9h2zm5 0v2h-2V9h2zm-3-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V4zm1 4a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1h-2z"/>'),gh=d("Grid3x2GapFill",'<path d="M1 4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V4zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V4zM1 9a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V9zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V9zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V9z"/>'),vh=d("Grid3x3",'<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h13A1.5 1.5 0 0 1 16 1.5v13a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 14.5v-13zM1.5 1a.5.5 0 0 0-.5.5V5h4V1H1.5zM5 6H1v4h4V6zm1 4h4V6H6v4zm-1 1H1v3.5a.5.5 0 0 0 .5.5H5v-4zm1 0v4h4v-4H6zm5 0v4h3.5a.5.5 0 0 0 .5-.5V11h-4zm0-1h4V6h-4v4zm0-5h4V1.5a.5.5 0 0 0-.5-.5H11v4zm-1 0V1H6v4h4z"/>'),wh=d("Grid3x3Gap",'<path d="M4 2v2H2V2h2zm1 12v-2a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V7a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V2a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm5 10v-2a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V7a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zm0-5V2a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1zM9 2v2H7V2h2zm5 0v2h-2V2h2zM4 7v2H2V7h2zm5 0v2H7V7h2zm5 0h-2v2h2V7zM4 12v2H2v-2h2zm5 0v2H7v-2h2zm5 0v2h-2v-2h2zM12 1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2zm-1 6a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V7zm1 4a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1h-2z"/>'),yh=d("Grid3x3GapFill",'<path d="M1 2a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V2zM1 7a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V7zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V7zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1V7zM1 12a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1v-2zm5 0a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1v-2z"/>'),kh=d("GridFill",'<path d="M1 2.5A1.5 1.5 0 0 1 2.5 1h3A1.5 1.5 0 0 1 7 2.5v3A1.5 1.5 0 0 1 5.5 7h-3A1.5 1.5 0 0 1 1 5.5v-3zm8 0A1.5 1.5 0 0 1 10.5 1h3A1.5 1.5 0 0 1 15 2.5v3A1.5 1.5 0 0 1 13.5 7h-3A1.5 1.5 0 0 1 9 5.5v-3zm-8 8A1.5 1.5 0 0 1 2.5 9h3A1.5 1.5 0 0 1 7 10.5v3A1.5 1.5 0 0 1 5.5 15h-3A1.5 1.5 0 0 1 1 13.5v-3zm8 0A1.5 1.5 0 0 1 10.5 9h3a1.5 1.5 0 0 1 1.5 1.5v3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 9 13.5v-3z"/>'),_h=d("GripHorizontal",'<path d="M2 8a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm3 3a1 1 0 1 1 0 2 1 1 0 0 1 0-2zm0-3a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),Oh=d("GripVertical",'<path d="M7 2a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM7 5a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zM7 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-3 3a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-3 3a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),zh=d("Hammer",'<path d="M9.972 2.508a.5.5 0 0 0-.16-.556l-.178-.129a5.009 5.009 0 0 0-2.076-.783C6.215.862 4.504 1.229 2.84 3.133H1.786a.5.5 0 0 0-.354.147L.146 4.567a.5.5 0 0 0 0 .706l2.571 2.579a.5.5 0 0 0 .708 0l1.286-1.29a.5.5 0 0 0 .146-.353V5.57l8.387 8.873A.5.5 0 0 0 14 14.5l1.5-1.5a.5.5 0 0 0 .017-.689l-9.129-8.63c.747-.456 1.772-.839 3.112-.839a.5.5 0 0 0 .472-.334z"/>'),Ah=d("HandIndex",'<path d="M6.75 1a.75.75 0 0 1 .75.75V8a.5.5 0 0 0 1 0V5.467l.086-.004c.317-.012.637-.008.816.027.134.027.294.096.448.182.077.042.15.147.15.314V8a.5.5 0 1 0 1 0V6.435a4.9 4.9 0 0 1 .106-.01c.316-.024.584-.01.708.04.118.046.3.207.486.43.081.096.15.19.2.259V8.5a.5.5 0 0 0 1 0v-1h.342a1 1 0 0 1 .995 1.1l-.271 2.715a2.5 2.5 0 0 1-.317.991l-1.395 2.442a.5.5 0 0 1-.434.252H6.035a.5.5 0 0 1-.416-.223l-1.433-2.15a1.5 1.5 0 0 1-.243-.666l-.345-3.105a.5.5 0 0 1 .399-.546L5 8.11V9a.5.5 0 0 0 1 0V1.75A.75.75 0 0 1 6.75 1zM8.5 4.466V1.75a1.75 1.75 0 1 0-3.5 0v5.34l-1.2.24a1.5 1.5 0 0 0-1.196 1.636l.345 3.106a2.5 2.5 0 0 0 .405 1.11l1.433 2.15A1.5 1.5 0 0 0 6.035 16h6.385a1.5 1.5 0 0 0 1.302-.756l1.395-2.441a3.5 3.5 0 0 0 .444-1.389l.271-2.715a2 2 0 0 0-1.99-2.199h-.581a5.114 5.114 0 0 0-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 0 0-.56-.642 2.632 2.632 0 0 0-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"/>'),jh=d("HandIndexThumb",'<path d="M6.75 1a.75.75 0 0 1 .75.75V8a.5.5 0 0 0 1 0V5.467l.086-.004c.317-.012.637-.008.816.027.134.027.294.096.448.182.077.042.15.147.15.314V8a.5.5 0 0 0 1 0V6.435l.106-.01c.316-.024.584-.01.708.04.118.046.3.207.486.43.081.096.15.19.2.259V8.5a.5.5 0 1 0 1 0v-1h.342a1 1 0 0 1 .995 1.1l-.271 2.715a2.5 2.5 0 0 1-.317.991l-1.395 2.442a.5.5 0 0 1-.434.252H6.118a.5.5 0 0 1-.447-.276l-1.232-2.465-2.512-4.185a.517.517 0 0 1 .809-.631l2.41 2.41A.5.5 0 0 0 6 9.5V1.75A.75.75 0 0 1 6.75 1zM8.5 4.466V1.75a1.75 1.75 0 1 0-3.5 0v6.543L3.443 6.736A1.517 1.517 0 0 0 1.07 8.588l2.491 4.153 1.215 2.43A1.5 1.5 0 0 0 6.118 16h6.302a1.5 1.5 0 0 0 1.302-.756l1.395-2.441a3.5 3.5 0 0 0 .444-1.389l.271-2.715a2 2 0 0 0-1.99-2.199h-.581a5.114 5.114 0 0 0-.195-.248c-.191-.229-.51-.568-.88-.716-.364-.146-.846-.132-1.158-.108l-.132.012a1.26 1.26 0 0 0-.56-.642 2.632 2.632 0 0 0-.738-.288c-.31-.062-.739-.058-1.05-.046l-.048.002zm2.094 2.025z"/>'),Mh=d("HandThumbsDown",'<path d="M8.864 15.674c-.956.24-1.843-.484-1.908-1.42-.072-1.05-.23-2.015-.428-2.59-.125-.36-.479-1.012-1.04-1.638-.557-.624-1.282-1.179-2.131-1.41C2.685 8.432 2 7.85 2 7V3c0-.845.682-1.464 1.448-1.546 1.07-.113 1.564-.415 2.068-.723l.048-.029c.272-.166.578-.349.97-.484C6.931.08 7.395 0 8 0h3.5c.937 0 1.599.478 1.934 1.064.164.287.254.607.254.913 0 .152-.023.312-.077.464.201.262.38.577.488.9.11.33.172.762.004 1.15.069.13.12.268.159.403.077.27.113.567.113.856 0 .289-.036.586-.113.856-.035.12-.08.244-.138.363.394.571.418 1.2.234 1.733-.206.592-.682 1.1-1.2 1.272-.847.283-1.803.276-2.516.211a9.877 9.877 0 0 1-.443-.05 9.364 9.364 0 0 1-.062 4.51c-.138.508-.55.848-1.012.964l-.261.065zM11.5 1H8c-.51 0-.863.068-1.14.163-.281.097-.506.229-.776.393l-.04.025c-.555.338-1.198.73-2.49.868-.333.035-.554.29-.554.55V7c0 .255.226.543.62.65 1.095.3 1.977.997 2.614 1.709.635.71 1.064 1.475 1.238 1.977.243.7.407 1.768.482 2.85.025.362.36.595.667.518l.262-.065c.16-.04.258-.144.288-.255a8.34 8.34 0 0 0-.145-4.726.5.5 0 0 1 .595-.643h.003l.014.004.058.013a8.912 8.912 0 0 0 1.036.157c.663.06 1.457.054 2.11-.163.175-.059.45-.301.57-.651.107-.308.087-.67-.266-1.021L12.793 7l.353-.354c.043-.042.105-.14.154-.315.048-.167.075-.37.075-.581 0-.211-.027-.414-.075-.581-.05-.174-.111-.273-.154-.315l-.353-.354.353-.354c.047-.047.109-.176.005-.488a2.224 2.224 0 0 0-.505-.804l-.353-.354.353-.354c.006-.005.041-.05.041-.17a.866.866 0 0 0-.121-.415C12.4 1.272 12.063 1 11.5 1z"/>'),Ch=d("HandThumbsUp",'<path d="M8.864.046C7.908-.193 7.02.53 6.956 1.466c-.072 1.051-.23 2.016-.428 2.59-.125.36-.479 1.013-1.04 1.639-.557.623-1.282 1.178-2.131 1.41C2.685 7.288 2 7.87 2 8.72v4.001c0 .845.682 1.464 1.448 1.545 1.07.114 1.564.415 2.068.723l.048.03c.272.165.578.348.97.484.397.136.861.217 1.466.217h3.5c.937 0 1.599-.477 1.934-1.064a1.86 1.86 0 0 0 .254-.912c0-.152-.023-.312-.077-.464.201-.263.38-.578.488-.901.11-.33.172-.762.004-1.149.069-.13.12-.269.159-.403.077-.27.113-.568.113-.857 0-.288-.036-.585-.113-.856a2.144 2.144 0 0 0-.138-.362 1.9 1.9 0 0 0 .234-1.734c-.206-.592-.682-1.1-1.2-1.272-.847-.282-1.803-.276-2.516-.211a9.84 9.84 0 0 0-.443.05 9.365 9.365 0 0 0-.062-4.509A1.38 1.38 0 0 0 9.125.111L8.864.046zM11.5 14.721H8c-.51 0-.863-.069-1.14-.164-.281-.097-.506-.228-.776-.393l-.04-.024c-.555-.339-1.198-.731-2.49-.868-.333-.036-.554-.29-.554-.55V8.72c0-.254.226-.543.62-.65 1.095-.3 1.977-.996 2.614-1.708.635-.71 1.064-1.475 1.238-1.978.243-.7.407-1.768.482-2.85.025-.362.36-.594.667-.518l.262.066c.16.04.258.143.288.255a8.34 8.34 0 0 1-.145 4.725.5.5 0 0 0 .595.644l.003-.001.014-.003.058-.014a8.908 8.908 0 0 1 1.036-.157c.663-.06 1.457-.054 2.11.164.175.058.45.3.57.65.107.308.087.67-.266 1.022l-.353.353.353.354c.043.043.105.141.154.315.048.167.075.37.075.581 0 .212-.027.414-.075.582-.05.174-.111.272-.154.315l-.353.353.353.354c.047.047.109.177.005.488a2.224 2.224 0 0 1-.505.805l-.353.353.353.354c.006.005.041.05.041.17a.866.866 0 0 1-.121.416c-.165.288-.503.56-1.066.56z"/>'),Vh=d("Handbag",'<path d="M8 1a2 2 0 0 1 2 2v2H6V3a2 2 0 0 1 2-2zm3 4V3a3 3 0 1 0-6 0v2H3.361a1.5 1.5 0 0 0-1.483 1.277L.85 13.13A2.5 2.5 0 0 0 3.322 16h9.356a2.5 2.5 0 0 0 2.472-2.87l-1.028-6.853A1.5 1.5 0 0 0 12.64 5H11zm-1 1v1.5a.5.5 0 0 0 1 0V6h1.639a.5.5 0 0 1 .494.426l1.028 6.851A1.5 1.5 0 0 1 12.678 15H3.322a1.5 1.5 0 0 1-1.483-1.723l1.028-6.851A.5.5 0 0 1 3.36 6H5v1.5a.5.5 0 0 0 1 0V6h4z"/>'),Sh=d("HandbagFill",'<path d="M8 1a2 2 0 0 0-2 2v2H5V3a3 3 0 0 1 6 0v2h-1V3a2 2 0 0 0-2-2zM5 5H3.361a1.5 1.5 0 0 0-1.483 1.277L.85 13.13A2.5 2.5 0 0 0 3.322 16h9.356a2.5 2.5 0 0 0 2.472-2.87l-1.028-6.853A1.5 1.5 0 0 0 12.64 5H11v1.5a.5.5 0 0 1-1 0V5H6v1.5a.5.5 0 0 1-1 0V5z"/>'),xh=d("Hash",'<path d="M8.39 12.648a1.32 1.32 0 0 0-.015.18c0 .305.21.508.5.508.266 0 .492-.172.555-.477l.554-2.703h1.204c.421 0 .617-.234.617-.547 0-.312-.188-.53-.617-.53h-.985l.516-2.524h1.265c.43 0 .618-.227.618-.547 0-.313-.188-.524-.618-.524h-1.046l.476-2.304a1.06 1.06 0 0 0 .016-.164.51.51 0 0 0-.516-.516.54.54 0 0 0-.539.43l-.523 2.554H7.617l.477-2.304c.008-.04.015-.118.015-.164a.512.512 0 0 0-.523-.516.539.539 0 0 0-.531.43L6.53 5.484H5.414c-.43 0-.617.22-.617.532 0 .312.187.539.617.539h.906l-.515 2.523H4.609c-.421 0-.609.219-.609.531 0 .313.188.547.61.547h.976l-.516 2.492c-.008.04-.015.125-.015.18 0 .305.21.508.5.508.265 0 .492-.172.554-.477l.555-2.703h2.242l-.515 2.492zm-1-6.109h2.266l-.515 2.563H6.859l.532-2.563z"/>'),Th=d("Hdd",'<path d="M4.5 11a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM3 10.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/><path d="M16 11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V9.51c0-.418.105-.83.305-1.197l2.472-4.531A1.5 1.5 0 0 1 4.094 3h7.812a1.5 1.5 0 0 1 1.317.782l2.472 4.53c.2.368.305.78.305 1.198V11zM3.655 4.26L1.592 8.043C1.724 8.014 1.86 8 2 8h12c.14 0 .276.014.408.042L12.345 4.26a.5.5 0 0 0-.439-.26H4.094a.5.5 0 0 0-.44.26zM1 10v1a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-1a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1z"/>'),Ph=d("HddFill",'<path d="M0 10a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-1zm2.5 1a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm2 0a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM.91 7.204A2.993 2.993 0 0 1 2 7h12c.384 0 .752.072 1.09.204l-1.867-3.422A1.5 1.5 0 0 0 11.906 3H4.094a1.5 1.5 0 0 0-1.317.782L.91 7.204z"/>'),Ih=d("HddNetwork",'<path d="M4.5 5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM3 4.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v1a2 2 0 0 1-2 2H8.5v3a1.5 1.5 0 0 1 1.5 1.5h5.5a.5.5 0 0 1 0 1H10A1.5 1.5 0 0 1 8.5 14h-1A1.5 1.5 0 0 1 6 12.5H.5a.5.5 0 0 1 0-1H6A1.5 1.5 0 0 1 7.5 10V7H2a2 2 0 0 1-2-2V4zm1 0v1a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1zm6 7.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5z"/>'),Eh=d("HddNetworkFill",'<path d="M2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h5.5v3A1.5 1.5 0 0 0 6 11.5H.5a.5.5 0 0 0 0 1H6A1.5 1.5 0 0 0 7.5 14h1a1.5 1.5 0 0 0 1.5-1.5h5.5a.5.5 0 0 0 0-1H10A1.5 1.5 0 0 0 8.5 10V7H14a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1z"/>'),Lh=d("HddRack",'<path d="M4.5 5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zM3 4.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm2 7a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-2.5.5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/><path d="M2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h1v2H2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2h-1V7h1a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm13 2v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zm0 7v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-1a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zm-3-4v2H4V7h8z"/>'),Bh=d("HddRackFill",'<path d="M2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h1v2H2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2h-1V7h1a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm-2 7a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM12 7v2H4V7h8z"/>'),Hh=d("HddStack",'<path d="M14 10a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-1a1 1 0 0 1 1-1h12zM2 9a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2H2z"/><path d="M5 11.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-2 0a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zM14 3a1 1 0 0 1 1 1v1a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/><path d="M5 4.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm-2 0a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0z"/>'),Fh=d("HddStackFill",'<path d="M2 9a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-1a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zM2 2a2 2 0 0 0-2 2v1a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2zm.5 3a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm2 0a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1z"/>'),Dh=d("Headphones",'<path d="M8 3a5 5 0 0 0-5 5v1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V8a6 6 0 1 1 12 0v5a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1v-3a1 1 0 0 1 1-1h1V8a5 5 0 0 0-5-5z"/>'),Rh=d("Headset",'<path d="M8 1a5 5 0 0 0-5 5v1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V6a6 6 0 1 1 12 0v6a2.5 2.5 0 0 1-2.5 2.5H9.366a1 1 0 0 1-.866.5h-1a1 1 0 1 1 0-2h1a1 1 0 0 1 .866.5H11.5A1.5 1.5 0 0 0 13 12h-1a1 1 0 0 1-1-1V8a1 1 0 0 1 1-1h1V6a5 5 0 0 0-5-5z"/>'),Nh=d("Heart",'<path d="M8 2.748l-.717-.737C5.6.281 2.514.878 1.4 3.053c-.523 1.023-.641 2.5.314 4.385.92 1.815 2.834 3.989 6.286 6.357 3.452-2.368 5.365-4.542 6.286-6.357.955-1.886.838-3.362.314-4.385C13.486.878 10.4.28 8.717 2.01L8 2.748zM8 15C-7.333 4.868 3.279-3.04 7.824 1.143c.06.055.119.112.176.171a3.12 3.12 0 0 1 .176-.17C12.72-3.042 23.333 4.867 8 15z"/>'),$h=d("HeartFill",'<path fill-rule="evenodd" d="M8 1.314C12.438-3.248 23.534 4.735 8 15-7.534 4.736 3.562-3.248 8 1.314z"/>'),Uh=d("HeartHalf",'<path d="M8 2.748v11.047c3.452-2.368 5.365-4.542 6.286-6.357.955-1.886.838-3.362.314-4.385C13.486.878 10.4.28 8.717 2.01L8 2.748zM8 15C-7.333 4.868 3.279-3.04 7.824 1.143c.06.055.119.112.176.171a3.12 3.12 0 0 1 .176-.17C12.72-3.042 23.333 4.867 8 15z"/>'),qh=d("Heptagon",'<path d="M7.779.052a.5.5 0 0 1 .442 0l6.015 2.97a.5.5 0 0 1 .267.34l1.485 6.676a.5.5 0 0 1-.093.415l-4.162 5.354a.5.5 0 0 1-.395.193H4.662a.5.5 0 0 1-.395-.193L.105 10.453a.5.5 0 0 1-.093-.415l1.485-6.676a.5.5 0 0 1 .267-.34L7.779.053zM2.422 3.813l-1.383 6.212L4.907 15h6.186l3.868-4.975-1.383-6.212L8 1.058 2.422 3.813z"/>'),Wh=d("HeptagonFill",'<path fill-rule="evenodd" d="M7.779.052a.5.5 0 0 1 .442 0l6.015 2.97a.5.5 0 0 1 .267.34l1.485 6.676a.5.5 0 0 1-.093.415l-4.162 5.354a.5.5 0 0 1-.395.193H4.662a.5.5 0 0 1-.395-.193L.105 10.453a.5.5 0 0 1-.093-.415l1.485-6.676a.5.5 0 0 1 .267-.34L7.779.053z"/>'),Gh=d("HeptagonHalf",'<path d="M7.779.052a.5.5 0 0 1 .442 0l6.015 2.97a.5.5 0 0 1 .267.34l1.485 6.676a.5.5 0 0 1-.093.415l-4.162 5.354a.5.5 0 0 1-.395.193H4.662a.5.5 0 0 1-.395-.193L.105 10.453a.5.5 0 0 1-.093-.415l1.485-6.676a.5.5 0 0 1 .267-.34L7.779.053zM8 15h3.093l3.868-4.975-1.383-6.212L8 1.058V15z"/>'),Yh=d("Hexagon",'<path d="M14 4.577v6.846L8 15l-6-3.577V4.577L8 1l6 3.577zM8.5.134a1 1 0 0 0-1 0l-6 3.577a1 1 0 0 0-.5.866v6.846a1 1 0 0 0 .5.866l6 3.577a1 1 0 0 0 1 0l6-3.577a1 1 0 0 0 .5-.866V4.577a1 1 0 0 0-.5-.866L8.5.134z"/>'),Kh=d("HexagonFill",'<path fill-rule="evenodd" d="M8.5.134a1 1 0 0 0-1 0l-6 3.577a1 1 0 0 0-.5.866v6.846a1 1 0 0 0 .5.866l6 3.577a1 1 0 0 0 1 0l6-3.577a1 1 0 0 0 .5-.866V4.577a1 1 0 0 0-.5-.866L8.5.134z"/>'),Qh=d("HexagonHalf",'<path d="M14 4.577v6.846L8 15V1l6 3.577zM8.5.134a1 1 0 0 0-1 0l-6 3.577a1 1 0 0 0-.5.866v6.846a1 1 0 0 0 .5.866l6 3.577a1 1 0 0 0 1 0l6-3.577a1 1 0 0 0 .5-.866V4.577a1 1 0 0 0-.5-.866L8.5.134z"/>'),Xh=d("Hourglass",'<path d="M2 1.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-1v1a4.5 4.5 0 0 1-2.557 4.06c-.29.139-.443.377-.443.59v.7c0 .213.154.451.443.59A4.5 4.5 0 0 1 12.5 13v1h1a.5.5 0 0 1 0 1h-11a.5.5 0 1 1 0-1h1v-1a4.5 4.5 0 0 1 2.557-4.06c.29-.139.443-.377.443-.59v-.7c0-.213-.154-.451-.443-.59A4.5 4.5 0 0 1 3.5 3V2h-1a.5.5 0 0 1-.5-.5zm2.5.5v1a3.5 3.5 0 0 0 1.989 3.158c.533.256 1.011.791 1.011 1.491v.702c0 .7-.478 1.235-1.011 1.491A3.5 3.5 0 0 0 4.5 13v1h7v-1a3.5 3.5 0 0 0-1.989-3.158C8.978 9.586 8.5 9.052 8.5 8.351v-.702c0-.7.478-1.235 1.011-1.491A3.5 3.5 0 0 0 11.5 3V2h-7z"/>'),Jh=d("HourglassBottom",'<path d="M2 1.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-1v1a4.5 4.5 0 0 1-2.557 4.06c-.29.139-.443.377-.443.59v.7c0 .213.154.451.443.59A4.5 4.5 0 0 1 12.5 13v1h1a.5.5 0 0 1 0 1h-11a.5.5 0 1 1 0-1h1v-1a4.5 4.5 0 0 1 2.557-4.06c.29-.139.443-.377.443-.59v-.7c0-.213-.154-.451-.443-.59A4.5 4.5 0 0 1 3.5 3V2h-1a.5.5 0 0 1-.5-.5zm2.5.5v1a3.5 3.5 0 0 0 1.989 3.158c.533.256 1.011.791 1.011 1.491v.702s.18.149.5.149.5-.15.5-.15v-.7c0-.701.478-1.236 1.011-1.492A3.5 3.5 0 0 0 11.5 3V2h-7z"/>'),Zh=d("HourglassSplit",'<path d="M2.5 15a.5.5 0 1 1 0-1h1v-1a4.5 4.5 0 0 1 2.557-4.06c.29-.139.443-.377.443-.59v-.7c0-.213-.154-.451-.443-.59A4.5 4.5 0 0 1 3.5 3V2h-1a.5.5 0 0 1 0-1h11a.5.5 0 0 1 0 1h-1v1a4.5 4.5 0 0 1-2.557 4.06c-.29.139-.443.377-.443.59v.7c0 .213.154.451.443.59A4.5 4.5 0 0 1 12.5 13v1h1a.5.5 0 0 1 0 1h-11zm2-13v1c0 .537.12 1.045.337 1.5h6.326c.216-.455.337-.963.337-1.5V2h-7zm3 6.35c0 .701-.478 1.236-1.011 1.492A3.5 3.5 0 0 0 4.5 13s.866-1.299 3-1.48V8.35zm1 0v3.17c2.134.181 3 1.48 3 1.48a3.5 3.5 0 0 0-1.989-3.158C8.978 9.586 8.5 9.052 8.5 8.351z"/>'),tf=d("HourglassTop",'<path d="M2 14.5a.5.5 0 0 0 .5.5h11a.5.5 0 1 0 0-1h-1v-1a4.5 4.5 0 0 0-2.557-4.06c-.29-.139-.443-.377-.443-.59v-.7c0-.213.154-.451.443-.59A4.5 4.5 0 0 0 12.5 3V2h1a.5.5 0 0 0 0-1h-11a.5.5 0 0 0 0 1h1v1a4.5 4.5 0 0 0 2.557 4.06c.29.139.443.377.443.59v.7c0 .213-.154.451-.443.59A4.5 4.5 0 0 0 3.5 13v1h-1a.5.5 0 0 0-.5.5zm2.5-.5v-1a3.5 3.5 0 0 1 1.989-3.158c.533-.256 1.011-.79 1.011-1.491v-.702s.18.101.5.101.5-.1.5-.1v.7c0 .701.478 1.236 1.011 1.492A3.5 3.5 0 0 1 11.5 13v1h-7z"/>'),ef=d("House",'<path fill-rule="evenodd" d="M2 13.5V7h1v6.5a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5V7h1v6.5a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 13.5zm11-11V6l-2-2V2.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M7.293 1.5a1 1 0 0 1 1.414 0l6.647 6.646a.5.5 0 0 1-.708.708L8 2.207 1.354 8.854a.5.5 0 1 1-.708-.708L7.293 1.5z"/>'),nf=d("HouseDoor",'<path d="M8.354 1.146a.5.5 0 0 0-.708 0l-6 6A.5.5 0 0 0 1.5 7.5v7a.5.5 0 0 0 .5.5h4.5a.5.5 0 0 0 .5-.5v-4h2v4a.5.5 0 0 0 .5.5H14a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.146-.354L13 5.793V2.5a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1.293L8.354 1.146zM2.5 14V7.707l5.5-5.5 5.5 5.5V14H10v-4a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v4H2.5z"/>'),rf=d("HouseDoorFill",'<path d="M6.5 14.5v-3.505c0-.245.25-.495.5-.495h2c.25 0 .5.25.5.5v3.5a.5.5 0 0 0 .5.5h4a.5.5 0 0 0 .5-.5v-7a.5.5 0 0 0-.146-.354L13 5.793V2.5a.5.5 0 0 0-.5-.5h-1a.5.5 0 0 0-.5.5v1.293L8.354 1.146a.5.5 0 0 0-.708 0l-6 6A.5.5 0 0 0 1.5 7.5v7a.5.5 0 0 0 .5.5h4a.5.5 0 0 0 .5-.5z"/>'),of=d("HouseFill",'<path fill-rule="evenodd" d="M8 3.293l6 6V13.5a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 13.5V9.293l6-6zm5-.793V6l-2-2V2.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5z"/><path fill-rule="evenodd" d="M7.293 1.5a1 1 0 0 1 1.414 0l6.647 6.646a.5.5 0 0 1-.708.708L8 2.207 1.354 8.854a.5.5 0 1 1-.708-.708L7.293 1.5z"/>'),af=d("Hr",'<path d="M12 3H4a1 1 0 0 0-1 1v2.5H2V4a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2.5h-1V4a1 1 0 0 0-1-1zM2 9.5h1V12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V9.5h1V12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V9.5zm-1.5-2a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H.5z"/>'),sf=d("Image",'<path d="M6.002 5.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M2.002 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2h-12zm12 1a1 1 0 0 1 1 1v6.5l-3.777-1.947a.5.5 0 0 0-.577.093l-3.71 3.71-2.66-1.772a.5.5 0 0 0-.63.062L1.002 12V3a1 1 0 0 1 1-1h12z"/>'),cf=d("ImageAlt",'<path d="M7 2.5a2.5 2.5 0 1 1-5 0 2.5 2.5 0 0 1 5 0zm4.225 4.053a.5.5 0 0 0-.577.093l-3.71 4.71-2.66-2.772a.5.5 0 0 0-.63.062L.002 13v2a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1v-4.5l-4.777-3.947z"/>'),lf=d("ImageFill",'<path d="M.002 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-12a2 2 0 0 1-2-2V3zm1 9v1a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V9.5l-3.777-1.947a.5.5 0 0 0-.577.093l-3.71 3.71-2.66-1.772a.5.5 0 0 0-.63.062L1.002 12zm5-6.5a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/>'),uf=d("Images",'<path d="M4.502 9a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/><path d="M14.002 13a2 2 0 0 1-2 2h-10a2 2 0 0 1-2-2V5A2 2 0 0 1 2 3a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v8a2 2 0 0 1-1.998 2zM14 2H4a1 1 0 0 0-1 1h9.002a2 2 0 0 1 2 2v7A1 1 0 0 0 15 11V3a1 1 0 0 0-1-1zM2.002 4a1 1 0 0 0-1 1v8l2.646-2.354a.5.5 0 0 1 .63-.062l2.66 1.773 3.71-3.71a.5.5 0 0 1 .577-.094l1.777 1.947V5a1 1 0 0 0-1-1h-10z"/>'),df=d("Inbox",'<path d="M4.98 4a.5.5 0 0 0-.39.188L1.54 8H6a.5.5 0 0 1 .5.5 1.5 1.5 0 1 0 3 0A.5.5 0 0 1 10 8h4.46l-3.05-3.812A.5.5 0 0 0 11.02 4H4.98zm9.954 5H10.45a2.5 2.5 0 0 1-4.9 0H1.066l.32 2.562a.5.5 0 0 0 .497.438h12.234a.5.5 0 0 0 .496-.438L14.933 9zM3.809 3.563A1.5 1.5 0 0 1 4.981 3h6.038a1.5 1.5 0 0 1 1.172.563l3.7 4.625a.5.5 0 0 1 .105.374l-.39 3.124A1.5 1.5 0 0 1 14.117 13H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .106-.374l3.7-4.625z"/>'),hf=d("InboxFill",'<path d="M4.98 4a.5.5 0 0 0-.39.188L1.54 8H6a.5.5 0 0 1 .5.5 1.5 1.5 0 1 0 3 0A.5.5 0 0 1 10 8h4.46l-3.05-3.812A.5.5 0 0 0 11.02 4H4.98zm-1.17-.437A1.5 1.5 0 0 1 4.98 3h6.04a1.5 1.5 0 0 1 1.17.563l3.7 4.625a.5.5 0 0 1 .106.374l-.39 3.124A1.5 1.5 0 0 1 14.117 13H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .106-.374l3.7-4.625z"/>'),ff=d("Inboxes",'<path d="M4.98 1a.5.5 0 0 0-.39.188L1.54 5H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0A.5.5 0 0 1 10 5h4.46l-3.05-3.812A.5.5 0 0 0 11.02 1H4.98zm9.954 5H10.45a2.5 2.5 0 0 1-4.9 0H1.066l.32 2.562A.5.5 0 0 0 1.884 9h12.234a.5.5 0 0 0 .496-.438L14.933 6zM3.809.563A1.5 1.5 0 0 1 4.981 0h6.038a1.5 1.5 0 0 1 1.172.563l3.7 4.625a.5.5 0 0 1 .105.374l-.39 3.124A1.5 1.5 0 0 1 14.117 10H1.883A1.5 1.5 0 0 1 .394 8.686l-.39-3.124a.5.5 0 0 1 .106-.374L3.81.563zM.125 11.17A.5.5 0 0 1 .5 11H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0 .5.5 0 0 1 .5-.5h5.5a.5.5 0 0 1 .496.562l-.39 3.124A1.5 1.5 0 0 1 14.117 16H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .121-.393zm.941.83l.32 2.562a.5.5 0 0 0 .497.438h12.234a.5.5 0 0 0 .496-.438l.32-2.562H10.45a2.5 2.5 0 0 1-4.9 0H1.066z"/>'),pf=d("InboxesFill",'<path d="M4.98 1a.5.5 0 0 0-.39.188L1.54 5H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0A.5.5 0 0 1 10 5h4.46l-3.05-3.812A.5.5 0 0 0 11.02 1H4.98zM3.81.563A1.5 1.5 0 0 1 4.98 0h6.04a1.5 1.5 0 0 1 1.17.563l3.7 4.625a.5.5 0 0 1 .106.374l-.39 3.124A1.5 1.5 0 0 1 14.117 10H1.883A1.5 1.5 0 0 1 .394 8.686l-.39-3.124a.5.5 0 0 1 .106-.374L3.81.563zM.125 11.17A.5.5 0 0 1 .5 11H6a.5.5 0 0 1 .5.5 1.5 1.5 0 0 0 3 0 .5.5 0 0 1 .5-.5h5.5a.5.5 0 0 1 .496.562l-.39 3.124A1.5 1.5 0 0 1 14.117 16H1.883a1.5 1.5 0 0 1-1.489-1.314l-.39-3.124a.5.5 0 0 1 .121-.393z"/>'),mf=d("Info",'<path d="M8.93 6.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM9 4.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),bf=d("InfoCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8.93 6.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM9 4.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),gf=d("InfoCircleFill",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm.93-9.412l-1 4.705c-.07.34.029.533.304.533.194 0 .487-.07.686-.246l-.088.416c-.287.346-.92.598-1.465.598-.703 0-1.002-.422-.808-1.319l.738-3.468c.064-.293.006-.399-.287-.47l-.451-.081.082-.381 2.29-.287zM8 5.5a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>'),vf=d("InfoSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M8.93 6.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM9 4.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),wf=d("InfoSquareFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm8.93 4.588l-2.29.287-.082.38.45.083c.294.07.352.176.288.469l-.738 3.468c-.194.897.105 1.319.808 1.319.545 0 1.178-.252 1.465-.598l.088-.416c-.2.176-.492.246-.686.246-.275 0-.375-.193-.304-.533L8.93 6.588zM8 5.5a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),yf=d("InputCursor",'<path d="M10 5h4a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1h-4v1h4a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-4v1zM6 5V4H2a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h4v-1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h4z"/><path fill-rule="evenodd" d="M8 1a.5.5 0 0 1 .5.5v13a.5.5 0 0 1-1 0v-13A.5.5 0 0 1 8 1z"/>'),kf=d("InputCursorText",'<path fill-rule="evenodd" d="M5 2a.5.5 0 0 1 .5-.5c.862 0 1.573.287 2.06.566.174.099.321.198.44.286.119-.088.266-.187.44-.286A4.165 4.165 0 0 1 10.5 1.5a.5.5 0 0 1 0 1c-.638 0-1.177.213-1.564.434a3.49 3.49 0 0 0-.436.294V7.5H9a.5.5 0 0 1 0 1h-.5v4.272c.1.08.248.187.436.294.387.221.926.434 1.564.434a.5.5 0 0 1 0 1 4.165 4.165 0 0 1-2.06-.566A4.561 4.561 0 0 1 8 13.65a4.561 4.561 0 0 1-.44.285 4.165 4.165 0 0 1-2.06.566.5.5 0 0 1 0-1c.638 0 1.177-.213 1.564-.434.188-.107.335-.214.436-.294V8.5H7a.5.5 0 0 1 0-1h.5V3.228a3.49 3.49 0 0 0-.436-.294A3.166 3.166 0 0 0 5.5 2.5.5.5 0 0 1 5 2z"/><path d="M10 5h4a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1h-4v1h4a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-4v1zM6 5V4H2a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h4v-1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h4z"/>'),_f=d("Instagram",'<path d="M8 0C5.829 0 5.556.01 4.703.048 3.85.088 3.269.222 2.76.42a3.917 3.917 0 0 0-1.417.923A3.927 3.927 0 0 0 .42 2.76C.222 3.268.087 3.85.048 4.7.01 5.555 0 5.827 0 8.001c0 2.172.01 2.444.048 3.297.04.852.174 1.433.372 1.942.205.526.478.972.923 1.417.444.445.89.719 1.416.923.51.198 1.09.333 1.942.372C5.555 15.99 5.827 16 8 16s2.444-.01 3.298-.048c.851-.04 1.434-.174 1.943-.372a3.916 3.916 0 0 0 1.416-.923c.445-.445.718-.891.923-1.417.197-.509.332-1.09.372-1.942C15.99 10.445 16 10.173 16 8s-.01-2.445-.048-3.299c-.04-.851-.175-1.433-.372-1.941a3.926 3.926 0 0 0-.923-1.417A3.911 3.911 0 0 0 13.24.42c-.51-.198-1.092-.333-1.943-.372C10.443.01 10.172 0 7.998 0h.003zm-.717 1.442h.718c2.136 0 2.389.007 3.232.046.78.035 1.204.166 1.486.275.373.145.64.319.92.599.28.28.453.546.598.92.11.281.24.705.275 1.485.039.843.047 1.096.047 3.231s-.008 2.389-.047 3.232c-.035.78-.166 1.203-.275 1.485a2.47 2.47 0 0 1-.599.919c-.28.28-.546.453-.92.598-.28.11-.704.24-1.485.276-.843.038-1.096.047-3.232.047s-2.39-.009-3.233-.047c-.78-.036-1.203-.166-1.485-.276a2.478 2.478 0 0 1-.92-.598 2.48 2.48 0 0 1-.6-.92c-.109-.281-.24-.705-.275-1.485-.038-.843-.046-1.096-.046-3.233 0-2.136.008-2.388.046-3.231.036-.78.166-1.204.276-1.486.145-.373.319-.64.599-.92.28-.28.546-.453.92-.598.282-.11.705-.24 1.485-.276.738-.034 1.024-.044 2.515-.045v.002zm4.988 1.328a.96.96 0 1 0 0 1.92.96.96 0 0 0 0-1.92zm-4.27 1.122a4.109 4.109 0 1 0 0 8.217 4.109 4.109 0 0 0 0-8.217zm0 1.441a2.667 2.667 0 1 1 0 5.334 2.667 2.667 0 0 1 0-5.334z"/>'),Of=d("Intersect",'<path fill-rule="evenodd" d="M0 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v2h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-2H2a2 2 0 0 1-2-2V2zm5 10v2a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1h-2v5a2 2 0 0 1-2 2H5zm6-8H6a2 2 0 0 0-2 2v5H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v2z"/>'),zf=d("Journal",'<path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Af=d("JournalAlbum",'<path d="M5.5 4a.5.5 0 0 0-.5.5v5a.5.5 0 0 0 .5.5h5a.5.5 0 0 0 .5-.5v-5a.5.5 0 0 0-.5-.5h-5zm1 7a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),jf=d("JournalArrowDown",'<path fill-rule="evenodd" d="M8 5a.5.5 0 0 1 .5.5v3.793l1.146-1.147a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 1 1 .708-.708L7.5 9.293V5.5A.5.5 0 0 1 8 5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Mf=d("JournalArrowUp",'<path fill-rule="evenodd" d="M8 11a.5.5 0 0 0 .5-.5V6.707l1.146 1.147a.5.5 0 0 0 .708-.708l-2-2a.5.5 0 0 0-.708 0l-2 2a.5.5 0 1 0 .708.708L7.5 6.707V10.5a.5.5 0 0 0 .5.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Cf=d("JournalBookmark",'<path fill-rule="evenodd" d="M6 8V1h1v6.117L8.743 6.07a.5.5 0 0 1 .514 0L11 7.117V1h1v7a.5.5 0 0 1-.757.429L9 7.083 6.757 8.43A.5.5 0 0 1 6 8z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Vf=d("JournalBookmarkFill",'<path fill-rule="evenodd" d="M6 1h6v7a.5.5 0 0 1-.757.429L9 7.083 6.757 8.43A.5.5 0 0 1 6 8V1z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Sf=d("JournalCheck",'<path fill-rule="evenodd" d="M10.854 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),xf=d("JournalCode",'<path fill-rule="evenodd" d="M8.646 5.646a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L10.293 8 8.646 6.354a.5.5 0 0 1 0-.708zm-1.292 0a.5.5 0 0 0-.708 0l-2 2a.5.5 0 0 0 0 .708l2 2a.5.5 0 0 0 .708-.708L5.707 8l1.647-1.646a.5.5 0 0 0 0-.708z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Tf=d("JournalMedical",'<path fill-rule="evenodd" d="M8 4a.5.5 0 0 1 .5.5v.634l.549-.317a.5.5 0 1 1 .5.866L9 6l.549.317a.5.5 0 1 1-.5.866L8.5 6.866V7.5a.5.5 0 0 1-1 0v-.634l-.549.317a.5.5 0 1 1-.5-.866L7 6l-.549-.317a.5.5 0 0 1 .5-.866l.549.317V4.5A.5.5 0 0 1 8 4zM5 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Pf=d("JournalMinus",'<path fill-rule="evenodd" d="M5.5 8a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),If=d("JournalPlus",'<path fill-rule="evenodd" d="M8 5.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 .5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Ef=d("JournalRichtext",'<path d="M7.5 3.75a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm-.861 1.542l1.33.886 1.854-1.855a.25.25 0 0 1 .289-.047L11 4.75V7a.5.5 0 0 1-.5.5h-5A.5.5 0 0 1 5 7v-.5s1.54-1.274 1.639-1.208zM5 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Lf=d("JournalText",'<path d="M5 10.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm0-2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0-2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0-2a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Bf=d("JournalX",'<path fill-rule="evenodd" d="M6.146 6.146a.5.5 0 0 1 .708 0L8 7.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 8l1.147 1.146a.5.5 0 0 1-.708.708L8 8.707 6.854 9.854a.5.5 0 0 1-.708-.708L7.293 8 6.146 6.854a.5.5 0 0 1 0-.708z"/><path d="M3 0h10a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-1h1v1a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v1H1V2a2 2 0 0 1 2-2z"/><path d="M1 5v-.5a.5.5 0 0 1 1 0V5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V8h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0v.5h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1z"/>'),Hf=d("Journals",'<path d="M5 0h8a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2 2 2 0 0 1-2 2H3a2 2 0 0 1-2-2h1a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1H1a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v9a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H5a1 1 0 0 0-1 1H3a2 2 0 0 1 2-2z"/><path d="M1 6v-.5a.5.5 0 0 1 1 0V6h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 3v-.5a.5.5 0 0 1 1 0V9h.5a.5.5 0 0 1 0 1h-2a.5.5 0 0 1 0-1H1zm0 2.5v.5H.5a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1H2v-.5a.5.5 0 0 0-1 0z"/>'),Ff=d("Joystick",'<path d="M10 2a2 2 0 0 1-1.5 1.937v5.087c.863.083 1.5.377 1.5.726 0 .414-.895.75-2 .75s-2-.336-2-.75c0-.35.637-.643 1.5-.726V3.937A2 2 0 1 1 10 2z"/><path d="M0 9.665v1.717a1 1 0 0 0 .553.894l6.553 3.277a2 2 0 0 0 1.788 0l6.553-3.277a1 1 0 0 0 .553-.894V9.665c0-.1-.06-.19-.152-.23L9.5 6.715v.993l5.227 2.178a.125.125 0 0 1 .001.23l-5.94 2.546a2 2 0 0 1-1.576 0l-5.94-2.546a.125.125 0 0 1 .001-.23L6.5 7.708l-.013-.988L.152 9.435a.25.25 0 0 0-.152.23z"/>'),Df=d("Justify",'<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Rf=d("JustifyLeft",'<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Nf=d("JustifyRight",'<path fill-rule="evenodd" d="M6 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-4-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),$f=d("Kanban",'<path d="M13.5 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1h-11a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h11zm-11-1a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2h-11z"/><path d="M6.5 3a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3zm-4 0a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3zm8 0a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3z"/>'),Uf=d("KanbanFill",'<path d="M2.5 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2h-11zm5 2h1a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1zm-5 1a1 1 0 0 1 1-1h1a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3zm9-1h1a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1h-1a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1z"/>'),qf=d("Key",'<path d="M0 8a4 4 0 0 1 7.465-2H14a.5.5 0 0 1 .354.146l1.5 1.5a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0L13 9.207l-.646.647a.5.5 0 0 1-.708 0L11 9.207l-.646.647a.5.5 0 0 1-.708 0L9 9.207l-.646.647A.5.5 0 0 1 8 10h-.535A4 4 0 0 1 0 8zm4-3a3 3 0 1 0 2.712 4.285A.5.5 0 0 1 7.163 9h.63l.853-.854a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708 0l.646.647.793-.793-1-1h-6.63a.5.5 0 0 1-.451-.285A3 3 0 0 0 4 5z"/><path d="M4 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),Wf=d("KeyFill",'<path d="M3.5 11.5a3.5 3.5 0 1 1 3.163-5H14L15.5 8 14 9.5l-1-1-1 1-1-1-1 1-1-1-1 1H6.663a3.5 3.5 0 0 1-3.163 2zM2.5 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),Gf=d("Keyboard",'<path d="M14 5a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h12zM2 4a2 2 0 0 0-2 2v5a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H2z"/><path d="M13 10.25a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm0-2a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-5 0A.25.25 0 0 1 8.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 8 8.75v-.5zm2 0a.25.25 0 0 1 .25-.25h1.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-1.5a.25.25 0 0 1-.25-.25v-.5zm1 2a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-5-2A.25.25 0 0 1 6.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 6 8.75v-.5zm-2 0A.25.25 0 0 1 4.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 4 8.75v-.5zm-2 0A.25.25 0 0 1 2.25 8h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 2 8.75v-.5zm11-2a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-2 0a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm-2 0A.25.25 0 0 1 9.25 6h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 9 6.75v-.5zm-2 0A.25.25 0 0 1 7.25 6h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 7 6.75v-.5zm-2 0A.25.25 0 0 1 5.25 6h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5A.25.25 0 0 1 5 6.75v-.5zm-3 0A.25.25 0 0 1 2.25 6h1.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-1.5A.25.25 0 0 1 2 6.75v-.5zm0 4a.25.25 0 0 1 .25-.25h.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-.5a.25.25 0 0 1-.25-.25v-.5zm2 0a.25.25 0 0 1 .25-.25h5.5a.25.25 0 0 1 .25.25v.5a.25.25 0 0 1-.25.25h-5.5a.25.25 0 0 1-.25-.25v-.5z"/>'),Yf=d("KeyboardFill",'<path d="M0 6a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V6zm13 .25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5a.25.25 0 0 0-.25.25zM2.25 8a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 3 8.75v-.5A.25.25 0 0 0 2.75 8h-.5zM4 8.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 5 8.75v-.5A.25.25 0 0 0 4.75 8h-.5a.25.25 0 0 0-.25.25zM6.25 8a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 7 8.75v-.5A.25.25 0 0 0 6.75 8h-.5zM8 8.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 9 8.75v-.5A.25.25 0 0 0 8.75 8h-.5a.25.25 0 0 0-.25.25zM13.25 8a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5zm0 2a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5zm-3-2a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h1.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-1.5zm.75 2.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5a.25.25 0 0 0-.25.25zM11.25 6a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5zM9 6.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5A.25.25 0 0 0 9.75 6h-.5a.25.25 0 0 0-.25.25zM7.25 6a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 8 6.75v-.5A.25.25 0 0 0 7.75 6h-.5zM5 6.25v.5c0 .138.112.25.25.25h.5A.25.25 0 0 0 6 6.75v-.5A.25.25 0 0 0 5.75 6h-.5a.25.25 0 0 0-.25.25zM2.25 6a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h1.5A.25.25 0 0 0 4 6.75v-.5A.25.25 0 0 0 3.75 6h-1.5zM2 10.25v.5c0 .138.112.25.25.25h.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-.5a.25.25 0 0 0-.25.25zM4.25 10a.25.25 0 0 0-.25.25v.5c0 .138.112.25.25.25h5.5a.25.25 0 0 0 .25-.25v-.5a.25.25 0 0 0-.25-.25h-5.5z"/>'),Kf=d("Ladder",'<path d="M4.5 1a.5.5 0 0 1 .5.5V2h6v-.5a.5.5 0 0 1 1 0v14a.5.5 0 0 1-1 0V15H5v.5a.5.5 0 0 1-1 0v-14a.5.5 0 0 1 .5-.5zM5 14h6v-2H5v2zm0-3h6V9H5v2zm0-3h6V6H5v2zm0-3h6V3H5v2z"/>'),Qf=d("Lamp",'<path d="M13 3v4H3V3h10zM3 2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H3zm4.5-1l.276-.553a.25.25 0 0 1 .448 0L8.5 1h-1zm-.012 9h1.024c.337.646.677 1.33.95 1.949.176.396.318.75.413 1.042.048.146.081.266.102.36A1.347 1.347 0 0 1 10 13.5c0 .665-.717 1.5-2 1.5s-2-.835-2-1.5c0 0 0-.013.004-.039.003-.027.01-.063.02-.11.02-.094.053-.214.1-.36.096-.291.238-.646.413-1.042.274-.62.614-1.303.95-1.949zm1.627-1h-2.23C6.032 10.595 5 12.69 5 13.5 5 14.88 6.343 16 8 16s3-1.12 3-2.5c0-.81-1.032-2.905-1.885-4.5z"/>'),Xf=d("LampFill",'<path d="M2 3a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v4a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3zm5.5-2l.276-.553a.25.25 0 0 1 .448 0L8.5 1h-1zm-.615 8h2.23C9.968 10.595 11 12.69 11 13.5c0 1.38-1.343 2.5-3 2.5s-3-1.12-3-2.5c0-.81 1.032-2.905 1.885-4.5z"/>'),Jf=d("Laptop",'<path d="M13.5 3a.5.5 0 0 1 .5.5V11H2V3.5a.5.5 0 0 1 .5-.5h11zm-11-1A1.5 1.5 0 0 0 1 3.5V12h14V3.5A1.5 1.5 0 0 0 13.5 2h-11zM0 12.5h16a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5z"/>'),Zf=d("LaptopFill",'<path d="M2.5 2A1.5 1.5 0 0 0 1 3.5V12h14V3.5A1.5 1.5 0 0 0 13.5 2h-11zM0 12.5h16a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5z"/>'),tp=d("Layers",'<path d="M8.235 1.559a.5.5 0 0 0-.47 0l-7.5 4a.5.5 0 0 0 0 .882L3.188 8 .264 9.559a.5.5 0 0 0 0 .882l7.5 4a.5.5 0 0 0 .47 0l7.5-4a.5.5 0 0 0 0-.882L12.813 8l2.922-1.559a.5.5 0 0 0 0-.882l-7.5-4zm3.515 7.008L14.438 10 8 13.433 1.562 10 4.25 8.567l3.515 1.874a.5.5 0 0 0 .47 0l3.515-1.874zM8 9.433L1.562 6 8 2.567 14.438 6 8 9.433z"/>'),ep=d("LayersFill",'<path d="M7.765 1.559a.5.5 0 0 1 .47 0l7.5 4a.5.5 0 0 1 0 .882l-7.5 4a.5.5 0 0 1-.47 0l-7.5-4a.5.5 0 0 1 0-.882l7.5-4z"/><path d="M2.125 8.567l-1.86.992a.5.5 0 0 0 0 .882l7.5 4a.5.5 0 0 0 .47 0l7.5-4a.5.5 0 0 0 0-.882l-1.86-.992-5.17 2.756a1.5 1.5 0 0 1-1.41 0l-5.17-2.756z"/>'),np=d("LayersHalf",'<path d="M8.235 1.559a.5.5 0 0 0-.47 0l-7.5 4a.5.5 0 0 0 0 .882L3.188 8 .264 9.559a.5.5 0 0 0 0 .882l7.5 4a.5.5 0 0 0 .47 0l7.5-4a.5.5 0 0 0 0-.882L12.813 8l2.922-1.559a.5.5 0 0 0 0-.882l-7.5-4zM8 9.433L1.562 6 8 2.567 14.438 6 8 9.433z"/>'),rp=d("LayoutSidebar",'<path d="M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3zm5-1v12h9a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H5zM4 2H2a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h2V2z"/>'),ip=d("LayoutSidebarInset",'<path d="M14 2a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h12zM2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2z"/><path d="M3 4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V4z"/>'),op=d("LayoutSidebarInsetReverse",'<path d="M2 2a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H2zm12-1a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h12z"/><path d="M13 4a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1V4z"/>'),ap=d("LayoutSidebarReverse",'<path d="M16 3a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3zm-5-1v12H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h9zm1 0h2a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1h-2V2z"/>'),sp=d("LayoutSplit",'<path d="M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3zm8.5-1v12H14a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1H8.5zm-1 0H2a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h5.5V2z"/>'),cp=d("LayoutTextSidebar",'<path d="M3.5 3a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 3a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zM3 9.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm12-1v14h2a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1h-2zm-1 0H2a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h9V1z"/>'),lp=d("LayoutTextSidebarReverse",'<path d="M12.5 3a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5zm0 3a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5zm.5 3.5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 .5-.5zm-.5 2.5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5z"/><path d="M16 2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2zM4 1v14H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h2zm1 0h9a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H5V1z"/>'),up=d("LayoutTextWindow",'<path d="M3 6.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5z"/><path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm12 1a1 1 0 0 1 1 1v1H1V2a1 1 0 0 1 1-1h12zm1 3v10a1 1 0 0 1-1 1h-2V4h3zm-4 0v11H2a1 1 0 0 1-1-1V4h10z"/>'),dp=d("LayoutTextWindowReverse",'<path d="M13 6.5a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 .5-.5zm0 3a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5a.5.5 0 0 0 .5-.5zm-.5 2.5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1 0-1h5z"/><path d="M14 0a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2h12zM2 1a1 1 0 0 0-1 1v1h14V2a1 1 0 0 0-1-1H2zM1 4v10a1 1 0 0 0 1 1h2V4H1zm4 0v11h9a1 1 0 0 0 1-1V4H5z"/>'),hp=d("LayoutThreeColumns",'<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h13A1.5 1.5 0 0 1 16 1.5v13a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 14.5v-13zM1.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 .5.5H5V1H1.5zM10 15V1H6v14h4zm1 0h3.5a.5.5 0 0 0 .5-.5v-13a.5.5 0 0 0-.5-.5H11v14z"/>'),fp=d("LayoutWtf",'<path d="M5 1v8H1V1h4zM1 0a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V1a1 1 0 0 0-1-1H1zm13 2v5H9V2h5zM9 1a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H9zM5 13v2H3v-2h2zm-2-1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1H3zm12-1v2H9v-2h6zm-6-1a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1H9z"/>'),pp=d("LifePreserver",'<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm6.43-5.228a7.025 7.025 0 0 1-3.658 3.658l-1.115-2.788a4.015 4.015 0 0 0 1.985-1.985l2.788 1.115zM5.228 14.43a7.025 7.025 0 0 1-3.658-3.658l2.788-1.115a4.015 4.015 0 0 0 1.985 1.985L5.228 14.43zm9.202-9.202l-2.788 1.115a4.015 4.015 0 0 0-1.985-1.985l1.115-2.788a7.025 7.025 0 0 1 3.658 3.658zm-8.087-.87a4.015 4.015 0 0 0-1.985 1.985L1.57 5.228A7.025 7.025 0 0 1 5.228 1.57l1.115 2.788zM8 11a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>'),mp=d("Lightning",'<path d="M11.251.068a.5.5 0 0 1 .227.58L9.677 6.5H13a.5.5 0 0 1 .364.843l-8 8.5a.5.5 0 0 1-.842-.49L6.323 9.5H3a.5.5 0 0 1-.364-.843l8-8.5a.5.5 0 0 1 .615-.09zM4.157 8.5H7a.5.5 0 0 1 .478.647L6.11 13.59l5.732-6.09H9a.5.5 0 0 1-.478-.647L9.89 2.41 4.157 8.5z"/>'),bp=d("LightningFill",'<path d="M11.251.068a.5.5 0 0 1 .227.58L9.677 6.5H13a.5.5 0 0 1 .364.843l-8 8.5a.5.5 0 0 1-.842-.49L6.323 9.5H3a.5.5 0 0 1-.364-.843l8-8.5a.5.5 0 0 1 .615-.09z"/>'),gp=d("Link",'<path d="M6.354 5.5H4a3 3 0 0 0 0 6h3a3 3 0 0 0 2.83-4H9c-.086 0-.17.01-.25.031A2 2 0 0 1 7 10.5H4a2 2 0 1 1 0-4h1.535c.218-.376.495-.714.82-1z"/><path d="M9 5.5a3 3 0 0 0-2.83 4h1.098A2 2 0 0 1 9 6.5h3a2 2 0 1 1 0 4h-1.535a4.02 4.02 0 0 1-.82 1H12a3 3 0 1 0 0-6H9z"/>'),vp=d("Link45deg",'<path d="M4.715 6.542L3.343 7.914a3 3 0 1 0 4.243 4.243l1.828-1.829A3 3 0 0 0 8.586 5.5L8 6.086a1.001 1.001 0 0 0-.154.199 2 2 0 0 1 .861 3.337L6.88 11.45a2 2 0 1 1-2.83-2.83l.793-.792a4.018 4.018 0 0 1-.128-1.287z"/><path d="M6.586 4.672A3 3 0 0 0 7.414 9.5l.775-.776a2 2 0 0 1-.896-3.346L9.12 3.55a2 2 0 0 1 2.83 2.83l-.793.792c.112.42.155.855.128 1.287l1.372-1.372a3 3 0 0 0-4.243-4.243L6.586 4.672z"/>'),wp=d("Linkedin",'<path d="M0 1.146C0 .513.526 0 1.175 0h13.65C15.474 0 16 .513 16 1.146v13.708c0 .633-.526 1.146-1.175 1.146H1.175C.526 16 0 15.487 0 14.854V1.146zm4.943 12.248V6.169H2.542v7.225h2.401zm-1.2-8.212c.837 0 1.358-.554 1.358-1.248-.015-.709-.52-1.248-1.342-1.248-.822 0-1.359.54-1.359 1.248 0 .694.521 1.248 1.327 1.248h.016zm4.908 8.212V9.359c0-.216.016-.432.08-.586.173-.431.568-.878 1.232-.878.869 0 1.216.662 1.216 1.634v3.865h2.401V9.25c0-2.22-1.184-3.252-2.764-3.252-1.274 0-1.845.7-2.165 1.193v.025h-.016a5.54 5.54 0 0 1 .016-.025V6.169h-2.4c.03.678 0 7.225 0 7.225h2.4z"/>'),yp=d("List",'<path fill-rule="evenodd" d="M2.5 11.5A.5.5 0 0 1 3 11h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 3 7h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 3 3h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5z"/>'),kp=d("ListCheck",'<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM3.854 2.146a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 1 1 .708-.708L2 3.293l1.146-1.147a.5.5 0 0 1 .708 0zm0 4a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 1 1 .708-.708L2 7.293l1.146-1.147a.5.5 0 0 1 .708 0zm0 4a.5.5 0 0 1 0 .708l-1.5 1.5a.5.5 0 0 1-.708 0l-.5-.5a.5.5 0 0 1 .708-.708l.146.147 1.146-1.147a.5.5 0 0 1 .708 0z"/>'),_p=d("ListNested",'<path fill-rule="evenodd" d="M4.5 11.5A.5.5 0 0 1 5 11h10a.5.5 0 0 1 0 1H5a.5.5 0 0 1-.5-.5zm-2-4A.5.5 0 0 1 3 7h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm-2-4A.5.5 0 0 1 1 3h10a.5.5 0 0 1 0 1H1a.5.5 0 0 1-.5-.5z"/>'),Op=d("ListOl",'<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5z"/><path d="M1.713 11.865v-.474H2c.217 0 .363-.137.363-.317 0-.185-.158-.31-.361-.31-.223 0-.367.152-.373.31h-.59c.016-.467.373-.787.986-.787.588-.002.954.291.957.703a.595.595 0 0 1-.492.594v.033a.615.615 0 0 1 .569.631c.003.533-.502.8-1.051.8-.656 0-1-.37-1.008-.794h.582c.008.178.186.306.422.309.254 0 .424-.145.422-.35-.002-.195-.155-.348-.414-.348h-.3zm-.004-4.699h-.604v-.035c0-.408.295-.844.958-.844.583 0 .96.326.96.756 0 .389-.257.617-.476.848l-.537.572v.03h1.054V9H1.143v-.395l.957-.99c.138-.142.293-.304.293-.508 0-.18-.147-.32-.342-.32a.33.33 0 0 0-.342.338v.041zM2.564 5h-.635V2.924h-.031l-.598.42v-.567l.629-.443h.635V5z"/>'),zp=d("ListStars",'<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5z"/><path d="M2.242 2.194a.27.27 0 0 1 .516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 0 0-.094.3l.173.569c.078.256-.213.462-.423.3l-.417-.324a.267.267 0 0 0-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 0 0-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 0 0 .259-.194l.162-.53zm0 4a.27.27 0 0 1 .516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 0 0-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 0 0-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 0 0-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 0 0 .259-.194l.162-.53zm0 4a.27.27 0 0 1 .516 0l.162.53c.035.115.14.194.258.194h.551c.259 0 .37.333.164.493l-.468.363a.277.277 0 0 0-.094.3l.173.569c.078.255-.213.462-.423.3l-.417-.324a.267.267 0 0 0-.328 0l-.417.323c-.21.163-.5-.043-.423-.299l.173-.57a.277.277 0 0 0-.094-.299l-.468-.363c-.206-.16-.095-.493.164-.493h.55a.271.271 0 0 0 .259-.194l.162-.53z"/>'),Ap=d("ListTask",'<path fill-rule="evenodd" d="M2 2.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5V3a.5.5 0 0 0-.5-.5H2zM3 3H2v1h1V3z"/><path d="M5 3.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zM5.5 7a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9zm0 4a.5.5 0 0 0 0 1h9a.5.5 0 0 0 0-1h-9z"/><path fill-rule="evenodd" d="M1.5 7a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5H2a.5.5 0 0 1-.5-.5V7zM2 7h1v1H2V7zm0 3.5a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5H2zm1 .5H2v1h1v-1z"/>'),jp=d("ListUl",'<path fill-rule="evenodd" d="M5 11.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm-3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm0 4a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm0 4a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),Mp=d("Lock",'<path d="M8 1a2 2 0 0 1 2 2v4H6V3a2 2 0 0 1 2-2zm3 6V3a3 3 0 0 0-6 0v4a2 2 0 0 0-2 2v5a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2zM5 8h6a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V9a1 1 0 0 1 1-1z"/>'),Cp=d("LockFill",'<path d="M8 1a2 2 0 0 1 2 2v4H6V3a2 2 0 0 1 2-2zm3 6V3a3 3 0 0 0-6 0v4a2 2 0 0 0-2 2v5a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2z"/>'),Vp=d("Mailbox",'<path d="M4 4a3 3 0 0 0-3 3v6h6V7a3 3 0 0 0-3-3zm0-1h8a4 4 0 0 1 4 4v6a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V7a4 4 0 0 1 4-4zm2.646 1A3.99 3.99 0 0 1 8 7v6h7V7a3 3 0 0 0-3-3H6.646z"/><path d="M11.793 8.5H9v-1h5a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.354-.146l-.853-.854zM5 7c0 .552-.448 0-1 0s-1 .552-1 0a1 1 0 0 1 2 0z"/>'),Sp=d("Mailbox2",'<path d="M9 8.5h2.793l.853.854A.5.5 0 0 0 13 9.5h1a.5.5 0 0 0 .5-.5V8a.5.5 0 0 0-.5-.5H9v1z"/><path d="M12 3H4a4 4 0 0 0-4 4v6a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1V7a4 4 0 0 0-4-4zM8 7a3.99 3.99 0 0 0-1.354-3H12a3 3 0 0 1 3 3v6H8V7zm-3.415.157C4.42 7.087 4.218 7 4 7c-.218 0-.42.086-.585.157C3.164 7.264 3 7.334 3 7a1 1 0 0 1 2 0c0 .334-.164.264-.415.157z"/>'),xp=d("Map",'<path fill-rule="evenodd" d="M15.817.113A.5.5 0 0 1 16 .5v14a.5.5 0 0 1-.402.49l-5 1a.502.502 0 0 1-.196 0L5.5 15.01l-4.902.98A.5.5 0 0 1 0 15.5v-14a.5.5 0 0 1 .402-.49l5-1a.5.5 0 0 1 .196 0L10.5.99l4.902-.98a.5.5 0 0 1 .415.103zM10 1.91l-4-.8v12.98l4 .8V1.91zm1 12.98l4-.8V1.11l-4 .8v12.98zm-6-.8V1.11l-4 .8v12.98l4-.8z"/>'),Tp=d("MapFill",'<path fill-rule="evenodd" d="M16 .5a.5.5 0 0 0-.598-.49L10.5.99 5.598.01a.5.5 0 0 0-.196 0l-5 1A.5.5 0 0 0 0 1.5v14a.5.5 0 0 0 .598.49l4.902-.98 4.902.98a.502.502 0 0 0 .196 0l5-1A.5.5 0 0 0 16 14.5V.5zM5 14.09V1.11l.5-.1.5.1v12.98l-.402-.08a.498.498 0 0 0-.196 0L5 14.09zm5 .8V1.91l.402.08a.5.5 0 0 0 .196 0L11 1.91v12.98l-.5.1-.5-.1z"/>'),Pp=d("Markdown",'<path d="M14 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h12zM2 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2z"/><path fill-rule="evenodd" d="M9.146 8.146a.5.5 0 0 1 .708 0L11.5 9.793l1.646-1.647a.5.5 0 0 1 .708.708l-2 2a.5.5 0 0 1-.708 0l-2-2a.5.5 0 0 1 0-.708z"/><path fill-rule="evenodd" d="M11.5 5a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0v-4a.5.5 0 0 1 .5-.5z"/><path d="M3.56 11V7.01h.056l1.428 3.239h.774l1.42-3.24h.056V11h1.073V5.001h-1.2l-1.71 3.894h-.039l-1.71-3.894H2.5V11h1.06z"/>'),Ip=d("MarkdownFill",'<path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm11.5 1a.5.5 0 0 0-.5.5v3.793L9.854 8.146a.5.5 0 1 0-.708.708l2 2a.5.5 0 0 0 .708 0l2-2a.5.5 0 0 0-.708-.708L12 9.293V5.5a.5.5 0 0 0-.5-.5zM3.56 7.01h.056l1.428 3.239h.774l1.42-3.24h.056V11h1.073V5.001h-1.2l-1.71 3.894h-.039l-1.71-3.894H2.5V11h1.06V7.01z"/>'),Ep=d("MenuApp",'<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h2A1.5 1.5 0 0 1 5 1.5v2A1.5 1.5 0 0 1 3.5 5h-2A1.5 1.5 0 0 1 0 3.5v-2zM1.5 1a.5.5 0 0 0-.5.5v2a.5.5 0 0 0 .5.5h2a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-2zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),Lp=d("MenuAppFill",'<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h2A1.5 1.5 0 0 1 5 1.5v2A1.5 1.5 0 0 1 3.5 5h-2A1.5 1.5 0 0 1 0 3.5v-2zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),Bp=d("MenuButton",'<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h8A1.5 1.5 0 0 1 11 1.5v2A1.5 1.5 0 0 1 9.5 5h-8A1.5 1.5 0 0 1 0 3.5v-2zM1.5 1a.5.5 0 0 0-.5.5v2a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-8z"/><path d="M7.823 2.823l-.396-.396A.25.25 0 0 1 7.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),Hp=d("MenuButtonFill",'<path d="M1.5 0A1.5 1.5 0 0 0 0 1.5v2A1.5 1.5 0 0 0 1.5 5h8A1.5 1.5 0 0 0 11 3.5v-2A1.5 1.5 0 0 0 9.5 0h-8zm5.927 2.427A.25.25 0 0 1 7.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0l-.396-.396zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),Fp=d("MenuButtonWide",'<path d="M0 1.5A1.5 1.5 0 0 1 1.5 0h13A1.5 1.5 0 0 1 16 1.5v2A1.5 1.5 0 0 1 14.5 5h-13A1.5 1.5 0 0 1 0 3.5v-2zM1.5 1a.5.5 0 0 0-.5.5v2a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5h-13z"/><path d="M2 2.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm10.823.323l-.396-.396A.25.25 0 0 1 12.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),Dp=d("MenuButtonWideFill",'<path d="M1.5 0A1.5 1.5 0 0 0 0 1.5v2A1.5 1.5 0 0 0 1.5 5h13A1.5 1.5 0 0 0 16 3.5v-2A1.5 1.5 0 0 0 14.5 0h-13zm1 2h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1 0-1zm9.927.427A.25.25 0 0 1 12.604 2h.792a.25.25 0 0 1 .177.427l-.396.396a.25.25 0 0 1-.354 0l-.396-.396zM0 8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V8zm1 3v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2H1zm14-1V8a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v2h14zM2 8.5a.5.5 0 0 1 .5-.5h9a.5.5 0 0 1 0 1h-9a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),Rp=d("MenuDown",'<path d="M7.646.146a.5.5 0 0 1 .708 0L10.207 2H14a2 2 0 0 1 2 2v9a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h3.793L7.646.146zM1 7v3h14V7H1zm14-1V4a1 1 0 0 0-1-1h-3.793a1 1 0 0 1-.707-.293L8 1.207l-1.5 1.5A1 1 0 0 1 5.793 3H2a1 1 0 0 0-1 1v2h14zm0 5H1v2a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2zM2 4.5a.5.5 0 0 1 .5-.5h8a.5.5 0 0 1 0 1h-8a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0 4a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>'),Np=d("MenuUp",'<path d="M7.646 15.854a.5.5 0 0 0 .708 0L10.207 14H14a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2h3.793l1.853 1.854zM1 9V6h14v3H1zm14 1v2a1 1 0 0 1-1 1h-3.793a1 1 0 0 0-.707.293l-1.5 1.5-1.5-1.5A1 1 0 0 0 5.793 13H2a1 1 0 0 1-1-1v-2h14zm0-5H1V3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v2zM2 11.5a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 0-1h-8a.5.5 0 0 0-.5.5zm0-4a.5.5 0 0 0 .5.5h11a.5.5 0 0 0 0-1h-11a.5.5 0 0 0-.5.5zm0-4a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 0-1h-6a.5.5 0 0 0-.5.5z"/>'),$p=d("Mic",'<path fill-rule="evenodd" d="M3.5 6.5A.5.5 0 0 1 4 7v1a4 4 0 0 0 8 0V7a.5.5 0 0 1 1 0v1a5 5 0 0 1-4.5 4.975V15h3a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1h3v-2.025A5 5 0 0 1 3 8V7a.5.5 0 0 1 .5-.5z"/><path fill-rule="evenodd" d="M10 8V3a2 2 0 1 0-4 0v5a2 2 0 1 0 4 0zM8 0a3 3 0 0 0-3 3v5a3 3 0 0 0 6 0V3a3 3 0 0 0-3-3z"/>'),Up=d("MicFill",'<path d="M5 3a3 3 0 0 1 6 0v5a3 3 0 0 1-6 0V3z"/><path fill-rule="evenodd" d="M3.5 6.5A.5.5 0 0 1 4 7v1a4 4 0 0 0 8 0V7a.5.5 0 0 1 1 0v1a5 5 0 0 1-4.5 4.975V15h3a.5.5 0 0 1 0 1h-7a.5.5 0 0 1 0-1h3v-2.025A5 5 0 0 1 3 8V7a.5.5 0 0 1 .5-.5z"/>'),qp=d("MicMute",'<path fill-rule="evenodd" d="M12.734 9.613A4.995 4.995 0 0 0 13 8V7a.5.5 0 0 0-1 0v1c0 .274-.027.54-.08.799l.814.814zm-2.522 1.72A4 4 0 0 1 4 8V7a.5.5 0 0 0-1 0v1a5 5 0 0 0 4.5 4.975V15h-3a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-3v-2.025a4.973 4.973 0 0 0 2.43-.923l-.718-.719zM11 7.88V3a3 3 0 0 0-5.842-.963l.845.845A2 2 0 0 1 10 3v3.879l1 1zM8.738 9.86l.748.748A3 3 0 0 1 5 8V6.121l1 1V8a2 2 0 0 0 2.738 1.86zm4.908 3.494l-12-12 .708-.708 12 12-.708.707z"/>'),Wp=d("MicMuteFill",'<path fill-rule="evenodd" d="M12.734 9.613A4.995 4.995 0 0 0 13 8V7a.5.5 0 0 0-1 0v1c0 .274-.027.54-.08.799l.814.814zm-2.522 1.72A4 4 0 0 1 4 8V7a.5.5 0 0 0-1 0v1a5 5 0 0 0 4.5 4.975V15h-3a.5.5 0 0 0 0 1h7a.5.5 0 0 0 0-1h-3v-2.025a4.973 4.973 0 0 0 2.43-.923l-.718-.719zM11 7.88V3a3 3 0 0 0-5.842-.963L11 7.879zM5 6.12l4.486 4.486A3 3 0 0 1 5 8V6.121zm8.646 7.234l-12-12 .708-.708 12 12-.708.707z"/>'),Gp=d("Minecart",'<path d="M4 15a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm8-1a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zM.115 3.18A.5.5 0 0 1 .5 3h15a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 14 12H2a.5.5 0 0 1-.491-.408l-1.5-8a.5.5 0 0 1 .106-.411zm.987.82l1.313 7h11.17l1.313-7H1.102z"/>'),Yp=d("MinecartLoaded",'<path d="M4 15a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm8-1a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm0 1a2 2 0 1 0 0-4 2 2 0 0 0 0 4zM.115 3.18A.5.5 0 0 1 .5 3h15a.5.5 0 0 1 .491.592l-1.5 8A.5.5 0 0 1 14 12H2a.5.5 0 0 1-.491-.408l-1.5-8a.5.5 0 0 1 .106-.411zm.987.82l1.313 7h11.17l1.313-7H1.102z"/><path fill-rule="evenodd" d="M6 1a2.498 2.498 0 0 1 4 0c.818 0 1.545.394 2 1 .67 0 1.552.57 2 1h-2c-.314 0-.611-.15-.8-.4-.274-.365-.71-.6-1.2-.6-.314 0-.611-.15-.8-.4a1.497 1.497 0 0 0-2.4 0c-.189.25-.486.4-.8.4-.507 0-.955.251-1.228.638-.09.13-.194.25-.308.362H3c.13-.147.401-.432.562-.545a1.63 1.63 0 0 0 .393-.393A2.498 2.498 0 0 1 6 1z"/>'),Kp=d("Moon",'<path fill-rule="evenodd" d="M14.53 10.53a7 7 0 0 1-9.058-9.058A7.003 7.003 0 0 0 8 15a7.002 7.002 0 0 0 6.53-4.47z"/>'),Qp=d("Mouse",'<path d="M8 3a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 3zm4 8a4 4 0 0 1-8 0V5a4 4 0 1 1 8 0v6zM8 0a5 5 0 0 0-5 5v6a5 5 0 0 0 10 0V5a5 5 0 0 0-5-5z"/>'),Xp=d("Mouse2",'<path d="M3 5.188C3 2.341 5.22 0 8 0s5 2.342 5 5.188v5.625C13 13.658 10.78 16 8 16s-5-2.342-5-5.188V5.189zm4.5-4.155C5.541 1.289 4 3.035 4 5.188V5.5h3.5V1.033zm1 0V5.5H12v-.313c0-2.152-1.541-3.898-3.5-4.154zM12 6.5H4v4.313C4 13.145 5.81 15 8 15s4-1.855 4-4.188V6.5z"/>'),Jp=d("Mouse3",'<path d="M7 0c-.593 0-1.104.157-1.527.463-.418.302-.717.726-.93 1.208C4.123 2.619 4 3.879 4 5.187v.504L3.382 6A2.5 2.5 0 0 0 2 8.236v2.576C2 13.659 4.22 16 7 16h2c2.78 0 5-2.342 5-5.188V7.51a.71.71 0 0 0 0-.02V5.186c0-1.13-.272-2.044-.748-2.772-.474-.726-1.13-1.235-1.849-1.59C9.981.123 8.26 0 7 0zm2.5 6.099V1.232c.51.11 1.008.267 1.46.49.596.293 1.099.694 1.455 1.24.355.543.585 1.262.585 2.225v1.69l-3.5-.778zm-1-5.025v4.803L5 5.099c.006-1.242.134-2.293.457-3.024.162-.366.363-.63.602-.801C6.292 1.105 6.593 1 7 1c.468 0 .98.018 1.5.074zM5 6.124L13 7.9v2.912C13 13.145 11.19 15 9 15H7c-2.19 0-4-1.855-4-4.188V8.236a1.5 1.5 0 0 1 .83-1.342l.187-.093c.01.265.024.58.047.92.062.938.19 2.12.462 2.937a.5.5 0 1 0 .948-.316c-.227-.683-.35-1.75-.413-2.688a29.17 29.17 0 0 1-.06-1.528v-.002z"/>'),Zp=d("MusicNote",'<path d="M9 13c0 1.105-1.12 2-2.5 2S4 14.105 4 13s1.12-2 2.5-2 2.5.895 2.5 2z"/><path fill-rule="evenodd" d="M9 3v10H8V3h1z"/><path d="M8 2.82a1 1 0 0 1 .804-.98l3-.6A1 1 0 0 1 13 2.22V4L8 5V2.82z"/>'),tm=d("MusicNoteBeamed",'<path d="M6 13c0 1.105-1.12 2-2.5 2S1 14.105 1 13c0-1.104 1.12-2 2.5-2s2.5.896 2.5 2zm9-2c0 1.105-1.12 2-2.5 2s-2.5-.895-2.5-2 1.12-2 2.5-2 2.5.895 2.5 2z"/><path fill-rule="evenodd" d="M14 11V2h1v9h-1zM6 3v10H5V3h1z"/><path d="M5 2.905a1 1 0 0 1 .9-.995l8-.8a1 1 0 0 1 1.1.995V3L5 4V2.905z"/>'),em=d("MusicNoteList",'<path d="M12 13c0 1.105-1.12 2-2.5 2S7 14.105 7 13s1.12-2 2.5-2 2.5.895 2.5 2z"/><path fill-rule="evenodd" d="M12 3v10h-1V3h1z"/><path d="M11 2.82a1 1 0 0 1 .804-.98l3-.6A1 1 0 0 1 16 2.22V4l-5 1V2.82z"/><path fill-rule="evenodd" d="M0 11.5a.5.5 0 0 1 .5-.5H4a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 .5 7H8a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5zm0-4A.5.5 0 0 1 .5 3H8a.5.5 0 0 1 0 1H.5a.5.5 0 0 1-.5-.5z"/>'),nm=d("MusicPlayer",'<path d="M4 3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V3zm1 0v3h6V3H5zm3 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/><path d="M11 11a3 3 0 1 1-6 0 3 3 0 0 1 6 0zm-3 2a2 2 0 1 0 0-4 2 2 0 0 0 0 4z"/><path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm2-1a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H4z"/>'),rm=d("MusicPlayerFill",'<path d="M8 12a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm1 2h6a1 1 0 0 1 1 1v2.5a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1zm3 12a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>'),im=d("Newspaper",'<path d="M0 2.5A1.5 1.5 0 0 1 1.5 1h11A1.5 1.5 0 0 1 14 2.5v10.528c0 .3-.05.654-.238.972h.738a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 1 1 0v9a1.5 1.5 0 0 1-1.5 1.5H1.497A1.497 1.497 0 0 1 0 13.5v-11zM12 14c.37 0 .654-.211.853-.441.092-.106.147-.279.147-.531V2.5a.5.5 0 0 0-.5-.5h-11a.5.5 0 0 0-.5.5v11c0 .278.223.5.497.5H12z"/><path d="M2 3h10v2H2V3zm0 3h4v3H2V6zm0 4h4v1H2v-1zm0 2h4v1H2v-1zm5-6h2v1H7V6zm3 0h2v1h-2V6zM7 8h2v1H7V8zm3 0h2v1h-2V8zm-3 2h2v1H7v-1zm3 0h2v1h-2v-1zm-3 2h2v1H7v-1zm3 0h2v1h-2v-1z"/>'),om=d("NodeMinus",'<path fill-rule="evenodd" d="M11 4a4 4 0 1 0 0 8 4 4 0 0 0 0-8zM6.025 7.5a5 5 0 1 1 0 1H4A1.5 1.5 0 0 1 2.5 10h-1A1.5 1.5 0 0 1 0 8.5v-1A1.5 1.5 0 0 1 1.5 6h1A1.5 1.5 0 0 1 4 7.5h2.025zM1.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1zM8 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5A.5.5 0 0 1 8 8z"/>'),am=d("NodeMinusFill",'<path fill-rule="evenodd" d="M16 8a5 5 0 0 1-9.975.5H4A1.5 1.5 0 0 1 2.5 10h-1A1.5 1.5 0 0 1 0 8.5v-1A1.5 1.5 0 0 1 1.5 6h1A1.5 1.5 0 0 1 4 7.5h2.025A5 5 0 0 1 16 8zm-2 0a.5.5 0 0 0-.5-.5h-5a.5.5 0 0 0 0 1h5A.5.5 0 0 0 14 8z"/>'),sm=d("NodePlus",'<path fill-rule="evenodd" d="M11 4a4 4 0 1 0 0 8 4 4 0 0 0 0-8zM6.025 7.5a5 5 0 1 1 0 1H4A1.5 1.5 0 0 1 2.5 10h-1A1.5 1.5 0 0 1 0 8.5v-1A1.5 1.5 0 0 1 1.5 6h1A1.5 1.5 0 0 1 4 7.5h2.025zM11 5a.5.5 0 0 1 .5.5v2h2a.5.5 0 0 1 0 1h-2v2a.5.5 0 0 1-1 0v-2h-2a.5.5 0 0 1 0-1h2v-2A.5.5 0 0 1 11 5zM1.5 7a.5.5 0 0 0-.5.5v1a.5.5 0 0 0 .5.5h1a.5.5 0 0 0 .5-.5v-1a.5.5 0 0 0-.5-.5h-1z"/>'),cm=d("NodePlusFill",'<path d="M11 13a5 5 0 1 0-4.975-5.5H4A1.5 1.5 0 0 0 2.5 6h-1A1.5 1.5 0 0 0 0 7.5v1A1.5 1.5 0 0 0 1.5 10h1A1.5 1.5 0 0 0 4 8.5h2.025A5 5 0 0 0 11 13zm.5-7.5v2h2a.5.5 0 0 1 0 1h-2v2a.5.5 0 0 1-1 0v-2h-2a.5.5 0 0 1 0-1h2v-2a.5.5 0 0 1 1 0z"/>'),lm=d("Nut",'<path d="M11.42 2l3.428 6-3.428 6H4.58L1.152 8 4.58 2h6.84zM4.58 1a1 1 0 0 0-.868.504l-3.429 6a1 1 0 0 0 0 .992l3.429 6A1 1 0 0 0 4.58 15h6.84a1 1 0 0 0 .868-.504l3.428-6a1 1 0 0 0 0-.992l-3.428-6A1 1 0 0 0 11.42 1H4.58z"/><path d="M6.848 5.933a2.5 2.5 0 1 0 2.5 4.33 2.5 2.5 0 0 0-2.5-4.33zM5.067 9.848a3.5 3.5 0 1 1 6.062-3.5 3.5 3.5 0 0 1-6.062 3.5z"/>'),um=d("NutFill",'<path d="M4.58 1a1 1 0 0 0-.868.504l-3.429 6a1 1 0 0 0 0 .992l3.429 6A1 1 0 0 0 4.58 15h6.84a1 1 0 0 0 .868-.504l3.428-6a1 1 0 0 0 0-.992l-3.428-6A1 1 0 0 0 11.42 1H4.58zm5.018 9.696a3 3 0 1 1-3-5.196 3 3 0 0 1 3 5.196z"/>'),dm=d("Octagon",'<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/>'),hm=d("OctagonFill",'<path d="M11.107 0a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146A.5.5 0 0 1 4.893 0h6.214z"/>'),fm=d("OctagonHalf",'<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM8 15h2.9l4.1-4.1V5.1L10.9 1H8v14z"/>'),pm=d("Option",'<path d="M1 2.5a.5.5 0 0 1 .5-.5h3.797a.5.5 0 0 1 .439.26L11 13h3.5a.5.5 0 0 1 0 1h-3.797a.5.5 0 0 1-.439-.26L5 3H1.5a.5.5 0 0 1-.5-.5zm10 0a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5z"/>'),mm=d("Outlet",'<path d="M3.34 2.994c.275-.338.68-.494 1.074-.494h7.172c.393 0 .798.156 1.074.494.578.708 1.84 2.534 1.84 5.006 0 2.472-1.262 4.297-1.84 5.006-.276.338-.68.494-1.074.494H4.414c-.394 0-.799-.156-1.074-.494C2.762 12.297 1.5 10.472 1.5 8c0-2.472 1.262-4.297 1.84-5.006zm1.074.506a.376.376 0 0 0-.299.126C3.599 4.259 2.5 5.863 2.5 8c0 2.137 1.099 3.74 1.615 4.374.06.073.163.126.3.126h7.17c.137 0 .24-.053.3-.126.516-.633 1.615-2.237 1.615-4.374 0-2.137-1.099-3.74-1.615-4.374a.376.376 0 0 0-.3-.126h-7.17z"/><path d="M6 5.5a.5.5 0 0 1 .5.5v1.5a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm4 0a.5.5 0 0 1 .5.5v1.5a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zM7 10v1h2v-1a1 1 0 0 0-2 0z"/>'),bm=d("Paperclip",'<path d="M4.5 3a2.5 2.5 0 0 1 5 0v9a1.5 1.5 0 0 1-3 0V5a.5.5 0 0 1 1 0v7a.5.5 0 0 0 1 0V3a1.5 1.5 0 1 0-3 0v9a2.5 2.5 0 0 0 5 0V5a.5.5 0 0 1 1 0v7a3.5 3.5 0 1 1-7 0V3z"/>'),gm=d("Paragraph",'<path d="M10.5 15a.5.5 0 0 1-.5-.5V2H9v12.5a.5.5 0 0 1-1 0V9H7a4 4 0 1 1 0-8h5.5a.5.5 0 0 1 0 1H11v12.5a.5.5 0 0 1-.5.5z"/>'),vm=d("PatchCheck",'<path fill-rule="evenodd" d="M10.354 6.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>'),wm=d("PatchCheckFill",'<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zm.287 5.984l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7 8.793l2.646-2.647a.5.5 0 0 1 .708.708z"/>'),ym=d("PatchExclamation",'<path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>'),km=d("PatchExclamationFill",'<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zM8 4c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995A.905.905 0 0 1 8 4zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>'),_m=d("PatchMinus",'<path fill-rule="evenodd" d="M5.5 8a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>'),Om=d("PatchMinusFill",'<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zM6 7.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1 0-1z"/>'),zm=d("PatchPlus",'<path fill-rule="evenodd" d="M8 5.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 .5-.5z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/>'),Am=d("PatchPlusFill",'<path d="M10.067.87a2.89 2.89 0 0 0-4.134 0l-.622.638-.89-.011a2.89 2.89 0 0 0-2.924 2.924l.01.89-.636.622a2.89 2.89 0 0 0 0 4.134l.637.622-.011.89a2.89 2.89 0 0 0 2.924 2.924l.89-.01.622.636a2.89 2.89 0 0 0 4.134 0l.622-.637.89.011a2.89 2.89 0 0 0 2.924-2.924l-.01-.89.636-.622a2.89 2.89 0 0 0 0-4.134l-.637-.622.011-.89a2.89 2.89 0 0 0-2.924-2.924l-.89.01-.622-.636zM8.5 6v1.5H10a.5.5 0 0 1 0 1H8.5V10a.5.5 0 0 1-1 0V8.5H6a.5.5 0 0 1 0-1h1.5V6a.5.5 0 0 1 1 0z"/>'),jm=d("PatchQuestion",'<path d="M8.05 9.6c.336 0 .504-.24.554-.627.04-.534.198-.815.847-1.26.673-.475 1.049-1.09 1.049-1.986 0-1.325-.92-2.227-2.262-2.227-1.02 0-1.792.492-2.1 1.29A1.71 1.71 0 0 0 6 5.48c0 .393.203.64.545.64.272 0 .455-.147.564-.51.158-.592.525-.915 1.074-.915.61 0 1.03.446 1.03 1.084 0 .563-.208.885-.822 1.325-.619.433-.926.914-.926 1.64v.111c0 .428.208.745.585.745z"/><path d="M10.273 2.513l-.921-.944.715-.698.622.637.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636a2.89 2.89 0 0 1 4.134 0l-.715.698a1.89 1.89 0 0 0-2.704 0l-.92.944-1.32-.016a1.89 1.89 0 0 0-1.911 1.912l.016 1.318-.944.921a1.89 1.89 0 0 0 0 2.704l.944.92-.016 1.32a1.89 1.89 0 0 0 1.912 1.911l1.318-.016.921.944a1.89 1.89 0 0 0 2.704 0l.92-.944 1.32.016a1.89 1.89 0 0 0 1.911-1.912l-.016-1.318.944-.921a1.89 1.89 0 0 0 0-2.704l-.944-.92.016-1.32a1.89 1.89 0 0 0-1.912-1.911l-1.318.016z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0z"/>'),Mm=d("PatchQuestionFill",'<path d="M5.933.87a2.89 2.89 0 0 1 4.134 0l.622.638.89-.011a2.89 2.89 0 0 1 2.924 2.924l-.01.89.636.622a2.89 2.89 0 0 1 0 4.134l-.637.622.011.89a2.89 2.89 0 0 1-2.924 2.924l-.89-.01-.622.636a2.89 2.89 0 0 1-4.134 0l-.622-.637-.89.011a2.89 2.89 0 0 1-2.924-2.924l.01-.89-.636-.622a2.89 2.89 0 0 1 0-4.134l.637-.622-.011-.89a2.89 2.89 0 0 1 2.924-2.924l.89.01.622-.636zM7.002 11a1 1 0 1 0 2 0 1 1 0 0 0-2 0zm1.602-2.027c.04-.534.198-.815.846-1.26.674-.475 1.05-1.09 1.05-1.986 0-1.325-.92-2.227-2.262-2.227-1.02 0-1.792.492-2.1 1.29A1.71 1.71 0 0 0 6 5.48c0 .393.203.64.545.64.272 0 .455-.147.564-.51.158-.592.525-.915 1.074-.915.61 0 1.03.446 1.03 1.084 0 .563-.208.885-.822 1.325-.619.433-.926.914-.926 1.64v.111c0 .428.208.745.585.745.336 0 .504-.24.554-.627z"/>'),Cm=d("Pause",'<path d="M6 3.5a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5zm4 0a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5z"/>'),Vm=d("PauseBtn",'<path d="M6.25 5C5.56 5 5 5.56 5 6.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C7.5 5.56 6.94 5 6.25 5zm3.5 0c-.69 0-1.25.56-1.25 1.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C11 5.56 10.44 5 9.75 5z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),Sm=d("PauseBtnFill",'<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.25-7C5.56 5 5 5.56 5 6.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C7.5 5.56 6.94 5 6.25 5zm3.5 0c-.69 0-1.25.56-1.25 1.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C11 5.56 10.44 5 9.75 5z"/>'),xm=d("PauseCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M5 6.25a1.25 1.25 0 1 1 2.5 0v3.5a1.25 1.25 0 1 1-2.5 0v-3.5zm3.5 0a1.25 1.25 0 1 1 2.5 0v3.5a1.25 1.25 0 1 1-2.5 0v-3.5z"/>'),Tm=d("PauseCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.25 5C5.56 5 5 5.56 5 6.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C7.5 5.56 6.94 5 6.25 5zm3.5 0c-.69 0-1.25.56-1.25 1.25v3.5a1.25 1.25 0 1 0 2.5 0v-3.5C11 5.56 10.44 5 9.75 5z"/>'),Pm=d("PauseFill",'<path d="M5.5 3.5A1.5 1.5 0 0 1 7 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5zm5 0A1.5 1.5 0 0 1 12 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5z"/>'),Im=d("Peace",'<path d="M7.5 1.018a7 7 0 0 0-4.79 11.566L7.5 7.793V1.018zm1 0v6.775l4.79 4.79A7 7 0 0 0 8.5 1.018zm4.084 12.273L8.5 9.207v5.775a6.97 6.97 0 0 0 4.084-1.691zM7.5 14.982V9.207l-4.084 4.084A6.97 6.97 0 0 0 7.5 14.982zM0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8z"/>'),Em=d("PeaceFill",'<path d="M14 13.292A8 8 0 0 0 8.5.015v7.778l5.5 5.5zm-.708.708L8.5 9.206v6.778a7.967 7.967 0 0 0 4.792-1.986zM7.5 15.985V9.207L2.708 14A7.967 7.967 0 0 0 7.5 15.985zM2 13.292A8 8 0 0 1 7.5.015v7.778l-5.5 5.5z"/>'),Lm=d("Pen",'<path d="M13.498.795l.149-.149a1.207 1.207 0 1 1 1.707 1.708l-.149.148a1.5 1.5 0 0 1-.059 2.059L4.854 14.854a.5.5 0 0 1-.233.131l-4 1a.5.5 0 0 1-.606-.606l1-4a.5.5 0 0 1 .131-.232l9.642-9.642a.5.5 0 0 0-.642.056L6.854 4.854a.5.5 0 1 1-.708-.708L9.44.854A1.5 1.5 0 0 1 11.5.796a1.5 1.5 0 0 1 1.998-.001zm-.644.766a.5.5 0 0 0-.707 0L1.95 11.756l-.764 3.057 3.057-.764L14.44 3.854a.5.5 0 0 0 0-.708l-1.585-1.585z"/>'),Bm=d("PenFill",'<path d="M13.498.795l.149-.149a1.207 1.207 0 1 1 1.707 1.708l-.149.148a1.5 1.5 0 0 1-.059 2.059L4.854 14.854a.5.5 0 0 1-.233.131l-4 1a.5.5 0 0 1-.606-.606l1-4a.5.5 0 0 1 .131-.232l9.642-9.642a.5.5 0 0 0-.642.056L6.854 4.854a.5.5 0 1 1-.708-.708L9.44.854A1.5 1.5 0 0 1 11.5.796a1.5 1.5 0 0 1 1.998-.001z"/>'),Hm=d("Pencil",'<path d="M12.146.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708l-10 10a.5.5 0 0 1-.168.11l-5 2a.5.5 0 0 1-.65-.65l2-5a.5.5 0 0 1 .11-.168l10-10zM11.207 2.5L13.5 4.793 14.793 3.5 12.5 1.207 11.207 2.5zm1.586 3L10.5 3.207 4 9.707V10h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.293l6.5-6.5zm-9.761 5.175l-.106.106-1.528 3.821 3.821-1.528.106-.106A.5.5 0 0 1 5 12.5V12h-.5a.5.5 0 0 1-.5-.5V11h-.5a.5.5 0 0 1-.468-.325z"/>'),Fm=d("PencilFill",'<path d="M12.854.146a.5.5 0 0 0-.707 0L10.5 1.793 14.207 5.5l1.647-1.646a.5.5 0 0 0 0-.708l-3-3zm.646 6.061L9.793 2.5 3.293 9H3.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.5h.5a.5.5 0 0 1 .5.5v.207l6.5-6.5zm-7.468 7.468A.5.5 0 0 1 6 13.5V13h-.5a.5.5 0 0 1-.5-.5V12h-.5a.5.5 0 0 1-.5-.5V11h-.5a.5.5 0 0 1-.5-.5V10h-.5a.499.499 0 0 1-.175-.032l-.179.178a.5.5 0 0 0-.11.168l-2 5a.5.5 0 0 0 .65.65l5-2a.5.5 0 0 0 .168-.11l.178-.178z"/>'),Dm=d("PencilSquare",'<path d="M15.502 1.94a.5.5 0 0 1 0 .706L14.459 3.69l-2-2L13.502.646a.5.5 0 0 1 .707 0l1.293 1.293zm-1.75 2.456l-2-2L4.939 9.21a.5.5 0 0 0-.121.196l-.805 2.414a.25.25 0 0 0 .316.316l2.414-.805a.5.5 0 0 0 .196-.12l6.813-6.814z"/><path fill-rule="evenodd" d="M1 13.5A1.5 1.5 0 0 0 2.5 15h11a1.5 1.5 0 0 0 1.5-1.5v-6a.5.5 0 0 0-1 0v6a.5.5 0 0 1-.5.5h-11a.5.5 0 0 1-.5-.5v-11a.5.5 0 0 1 .5-.5H9a.5.5 0 0 0 0-1H2.5A1.5 1.5 0 0 0 1 2.5v11z"/>'),Rm=d("Pentagon",'<path d="M8 1.288l6.842 5.56L12.267 15H3.733L1.158 6.847 8 1.288zM16 6.5L8 0 0 6.5 3 16h10l3-9.5z"/>'),Nm=d("PentagonFill",'<path d="M8 0l8 6.5-3 9.5H3L0 6.5 8 0z"/>'),$m=d("PentagonHalf",'<path d="M8 1.288l6.842 5.56L12.267 15H8V1.288zM16 6.5L8 0 0 6.5 3 16h10l3-9.5z"/>'),Um=d("People",'<path d="M15 14s1 0 1-1-1-4-5-4-5 3-5 4 1 1 1 1h8zm-7.978-1A.261.261 0 0 1 7 12.996c.001-.264.167-1.03.76-1.72C8.312 10.629 9.282 10 11 10c1.717 0 2.687.63 3.24 1.276.593.69.758 1.457.76 1.72l-.008.002a.274.274 0 0 1-.014.002H7.022zM11 7a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm3-2a3 3 0 1 1-6 0 3 3 0 0 1 6 0zM6.936 9.28a5.88 5.88 0 0 0-1.23-.247A7.35 7.35 0 0 0 5 9c-4 0-5 3-5 4 0 .667.333 1 1 1h4.216A2.238 2.238 0 0 1 5 13c0-1.01.377-2.042 1.09-2.904.243-.294.526-.569.846-.816zM4.92 10A5.493 5.493 0 0 0 4 13H1c0-.26.164-1.03.76-1.724.545-.636 1.492-1.256 3.16-1.275zM1.5 5.5a3 3 0 1 1 6 0 3 3 0 0 1-6 0zm3-2a2 2 0 1 0 0 4 2 2 0 0 0 0-4z"/>'),qm=d("PeopleFill",'<path d="M7 14s-1 0-1-1 1-4 5-4 5 3 5 4-1 1-1 1H7zm4-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path fill-rule="evenodd" d="M5.216 14A2.238 2.238 0 0 1 5 13c0-1.355.68-2.75 1.936-3.72A6.325 6.325 0 0 0 5 9c-4 0-5 3-5 4s1 1 1 1h4.216z"/><path d="M4.5 8a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5z"/>'),Wm=d("Percent",'<path d="M13.442 2.558a.625.625 0 0 1 0 .884l-10 10a.625.625 0 1 1-.884-.884l10-10a.625.625 0 0 1 .884 0zM4.5 6a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm0 1a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5zm7 6a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm0 1a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5z"/>'),Gm=d("Person",'<path d="M8 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H3s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C11.516 10.68 10.289 10 8 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/>'),Ym=d("PersonBadge",'<path d="M6.5 2a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zM11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M4.5 0A2.5 2.5 0 0 0 2 2.5V14a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2.5A2.5 2.5 0 0 0 11.5 0h-7zM3 2.5A1.5 1.5 0 0 1 4.5 1h7A1.5 1.5 0 0 1 13 2.5v10.795a4.2 4.2 0 0 0-.776-.492C11.392 12.387 10.063 12 8 12s-3.392.387-4.224.803a4.2 4.2 0 0 0-.776.492V2.5z"/>'),Km=d("PersonBadgeFill",'<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm4.5 0a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zM8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm5 2.755C12.146 12.825 10.623 12 8 12s-4.146.826-5 1.755V14a1 1 0 0 0 1 1h8a1 1 0 0 0 1-1v-.245z"/>'),Qm=d("PersonBoundingBox",'<path d="M1.5 1a.5.5 0 0 0-.5.5v3a.5.5 0 0 1-1 0v-3A1.5 1.5 0 0 1 1.5 0h3a.5.5 0 0 1 0 1h-3zM11 .5a.5.5 0 0 1 .5-.5h3A1.5 1.5 0 0 1 16 1.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 1-.5-.5zM.5 11a.5.5 0 0 1 .5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 1 0 1h-3A1.5 1.5 0 0 1 0 14.5v-3a.5.5 0 0 1 .5-.5zm15 0a.5.5 0 0 1 .5.5v3a1.5 1.5 0 0 1-1.5 1.5h-3a.5.5 0 0 1 0-1h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 1 .5-.5z"/><path d="M3 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H3zm8-9a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/>'),Xm=d("PersonCheck",'<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M15.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L12.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/>'),Jm=d("PersonCheckFill",'<path fill-rule="evenodd" d="M15.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 0 1 .708-.708L12.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/><path d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>'),Zm=d("PersonCircle",'<path d="M13.468 12.37C12.758 11.226 11.195 10 8 10s-4.757 1.225-5.468 2.37A6.987 6.987 0 0 0 8 15a6.987 6.987 0 0 0 5.468-2.63z"/><path fill-rule="evenodd" d="M8 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path fill-rule="evenodd" d="M8 1a7 7 0 1 0 0 14A7 7 0 0 0 8 1zM0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8z"/>'),tb=d("PersonDash",'<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M11 7.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>'),eb=d("PersonDashFill",'<path fill-rule="evenodd" d="M11 7.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/><path d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>'),nb=d("PersonFill",'<path d="M3 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H3zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>'),rb=d("PersonLinesFill",'<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm-5 6s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zM11 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5zm.5 2.5a.5.5 0 0 0 0 1h4a.5.5 0 0 0 0-1h-4zm2 3a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1h-2zm0 3a.5.5 0 0 0 0 1h2a.5.5 0 0 0 0-1h-2z"/>'),ib=d("PersonPlus",'<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M13.5 5a.5.5 0 0 1 .5.5V7h1.5a.5.5 0 0 1 0 1H14v1.5a.5.5 0 0 1-1 0V8h-1.5a.5.5 0 0 1 0-1H13V5.5a.5.5 0 0 1 .5-.5z"/>'),ob=d("PersonPlusFill",'<path d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path fill-rule="evenodd" d="M13.5 5a.5.5 0 0 1 .5.5V7h1.5a.5.5 0 0 1 0 1H14v1.5a.5.5 0 0 1-1 0V8h-1.5a.5.5 0 0 1 0-1H13V5.5a.5.5 0 0 1 .5-.5z"/>'),ab=d("PersonSquare",'<path d="M11 6a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/><path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1v-1c0-1-1-4-6-4s-6 3-6 4v1a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12z"/>'),sb=d("PersonX",'<path d="M6 8a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm2-3a2 2 0 1 1-4 0 2 2 0 0 1 4 0zm4 8c0 1-1 1-1 1H1s-1 0-1-1 1-4 6-4 6 3 6 4zm-1-.004c-.001-.246-.154-.986-.832-1.664C9.516 10.68 8.289 10 6 10c-2.29 0-3.516.68-4.168 1.332-.678.678-.83 1.418-.832 1.664h10z"/><path fill-rule="evenodd" d="M12.146 5.146a.5.5 0 0 1 .708 0L14 6.293l1.146-1.147a.5.5 0 0 1 .708.708L14.707 7l1.147 1.146a.5.5 0 0 1-.708.708L14 7.707l-1.146 1.147a.5.5 0 0 1-.708-.708L13.293 7l-1.147-1.146a.5.5 0 0 1 0-.708z"/>'),cb=d("PersonXFill",'<path fill-rule="evenodd" d="M1 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm6.146-2.854a.5.5 0 0 1 .708 0L14 6.293l1.146-1.147a.5.5 0 0 1 .708.708L14.707 7l1.147 1.146a.5.5 0 0 1-.708.708L14 7.707l-1.146 1.147a.5.5 0 0 1-.708-.708L13.293 7l-1.147-1.146a.5.5 0 0 1 0-.708z"/>'),lb=d("Phone",'<path d="M11 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h6zM5 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H5z"/><path d="M8 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),ub=d("PhoneFill",'<path d="M3 2a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V2zm6 11a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>'),db=d("PhoneLandscape",'<path d="M1 4.5a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v6a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-6zm-1 6a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-6a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v6z"/><path d="M14 7.5a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>'),hb=d("PhoneLandscapeFill",'<path d="M2 12.5a2 2 0 0 1-2-2v-6a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H2zm11-6a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>'),fb=d("PhoneVibrate",'<path d="M10 3a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h4zM6 2a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H6z"/><path d="M8 12a1 1 0 1 0 0-2 1 1 0 0 0 0 2zM1.599 4.058a.5.5 0 0 1 .208.676A6.967 6.967 0 0 0 1 8c0 1.18.292 2.292.807 3.266a.5.5 0 0 1-.884.468A7.968 7.968 0 0 1 0 8c0-1.347.334-2.619.923-3.734a.5.5 0 0 1 .676-.208zm12.802 0a.5.5 0 0 1 .676.208A7.967 7.967 0 0 1 16 8a7.967 7.967 0 0 1-.923 3.734.5.5 0 0 1-.884-.468A6.967 6.967 0 0 0 15 8c0-1.18-.292-2.292-.807-3.266a.5.5 0 0 1 .208-.676zM3.057 5.534a.5.5 0 0 1 .284.648A4.986 4.986 0 0 0 3 8c0 .642.12 1.255.34 1.818a.5.5 0 1 1-.93.364A5.986 5.986 0 0 1 2 8c0-.769.145-1.505.41-2.182a.5.5 0 0 1 .647-.284zm9.886 0a.5.5 0 0 1 .648.284C13.855 6.495 14 7.231 14 8c0 .769-.145 1.505-.41 2.182a.5.5 0 0 1-.93-.364C12.88 9.255 13 8.642 13 8c0-.642-.12-1.255-.34-1.818a.5.5 0 0 1 .283-.648z"/>'),pb=d("PieChart",'<path d="M7.5 1.018a7 7 0 0 0-4.79 11.566L7.5 7.793V1.018zm1 0V7.5h6.482A7.001 7.001 0 0 0 8.5 1.018zM14.982 8.5H8.207l-4.79 4.79A7 7 0 0 0 14.982 8.5zM0 8a8 8 0 1 1 16 0A8 8 0 0 1 0 8z"/>'),mb=d("PieChartFill",'<path d="M15.985 8.5H8.207l-5.5 5.5a8 8 0 0 0 13.277-5.5zM2 13.292A8 8 0 0 1 7.5.015v7.778l-5.5 5.5zM8.5.015V7.5h7.485A8.001 8.001 0 0 0 8.5.015z"/>'),bb=d("Pip",'<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h13A1.5 1.5 0 0 1 16 3.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5v-9zM1.5 3a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-13z"/><path d="M8 8.5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-3z"/>'),gb=d("PipFill",'<path d="M1.5 2A1.5 1.5 0 0 0 0 3.5v9A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-9A1.5 1.5 0 0 0 14.5 2h-13zm7 6h5a.5.5 0 0 1 .5.5v3a.5.5 0 0 1-.5.5h-5a.5.5 0 0 1-.5-.5v-3a.5.5 0 0 1 .5-.5z"/>'),vb=d("Play",'<path d="M10.804 8L5 4.633v6.734L10.804 8zm.792-.696a.802.802 0 0 1 0 1.392l-6.363 3.692C4.713 12.69 4 12.345 4 11.692V4.308c0-.653.713-.998 1.233-.696l6.363 3.692z"/>'),wb=d("PlayBtn",'<path d="M6.79 5.093A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407l3.5-2.5a.5.5 0 0 0 0-.814l-3.5-2.5z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),yb=d("PlayBtnFill",'<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.79-6.907A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407l3.5-2.5a.5.5 0 0 0 0-.814l-3.5-2.5z"/>'),kb=d("PlayCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M6.271 5.055a.5.5 0 0 1 .52.038l3.5 2.5a.5.5 0 0 1 0 .814l-3.5 2.5A.5.5 0 0 1 6 10.5v-5a.5.5 0 0 1 .271-.445z"/>'),_b=d("PlayCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.79 5.093A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407l3.5-2.5a.5.5 0 0 0 0-.814l-3.5-2.5z"/>'),Ob=d("PlayFill",'<path d="M11.596 8.697l-6.363 3.692c-.54.313-1.233-.066-1.233-.697V4.308c0-.63.692-1.01 1.233-.696l6.363 3.692a.802.802 0 0 1 0 1.393z"/>'),zb=d("Plug",'<path d="M6 0a.5.5 0 0 1 .5.5V3h3V.5a.5.5 0 0 1 1 0V3h1a.5.5 0 0 1 .5.5v3A3.5 3.5 0 0 1 8.5 10c-.002.434-.01.845-.04 1.22-.041.514-.126 1.003-.317 1.424a2.083 2.083 0 0 1-.97 1.028C6.725 13.9 6.169 14 5.5 14c-.998 0-1.61.33-1.974.718A1.922 1.922 0 0 0 3 16H2c0-.616.232-1.367.797-1.968C3.374 13.42 4.261 13 5.5 13c.581 0 .962-.088 1.218-.219.241-.123.4-.3.514-.55.121-.266.193-.621.23-1.09.027-.34.035-.718.037-1.141A3.5 3.5 0 0 1 4 6.5v-3a.5.5 0 0 1 .5-.5h1V.5A.5.5 0 0 1 6 0zM5 4v2.5A2.5 2.5 0 0 0 7.5 9h1A2.5 2.5 0 0 0 11 6.5V4H5z"/>'),Ab=d("PlugFill",'<path d="M6 0a.5.5 0 0 1 .5.5V3h3V.5a.5.5 0 0 1 1 0V3h1a.5.5 0 0 1 .5.5v3A3.5 3.5 0 0 1 8.5 10c-.002.434-.01.845-.04 1.22-.041.514-.126 1.003-.317 1.424a2.083 2.083 0 0 1-.97 1.028C6.725 13.9 6.169 14 5.5 14c-.998 0-1.61.33-1.974.718A1.922 1.922 0 0 0 3 16H2c0-.616.232-1.367.797-1.968C3.374 13.42 4.261 13 5.5 13c.581 0 .962-.088 1.218-.219.241-.123.4-.3.514-.55.121-.266.193-.621.23-1.09.027-.34.035-.718.037-1.141A3.5 3.5 0 0 1 4 6.5v-3a.5.5 0 0 1 .5-.5h1V.5A.5.5 0 0 1 6 0z"/>'),jb=d("Plus",'<path d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"/>'),Mb=d("PlusCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"/>'),Cb=d("PlusCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM8.5 4.5a.5.5 0 0 0-1 0v3h-3a.5.5 0 0 0 0 1h3v3a.5.5 0 0 0 1 0v-3h3a.5.5 0 0 0 0-1h-3v-3z"/>'),Vb=d("PlusSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M8 4a.5.5 0 0 1 .5.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3A.5.5 0 0 1 8 4z"/>'),Sb=d("PlusSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm6.5 4.5v3h3a.5.5 0 0 1 0 1h-3v3a.5.5 0 0 1-1 0v-3h-3a.5.5 0 0 1 0-1h3v-3a.5.5 0 0 1 1 0z"/>'),xb=d("Power",'<path d="M7.5 1v7h1V1h-1z"/><path d="M3 8.812a4.999 4.999 0 0 1 2.578-4.375l-.485-.874A6 6 0 1 0 11 3.616l-.501.865A5 5 0 1 1 3 8.812z"/>'),Tb=d("Printer",'<path d="M2.5 8a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/><path d="M5 1a2 2 0 0 0-2 2v2H2a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h1v1a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-1h1a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-1V3a2 2 0 0 0-2-2H5zM4 3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1v2H4V3zm1 5a2 2 0 0 0-2 2v1H2a1 1 0 0 1-1-1V7a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-1v-1a2 2 0 0 0-2-2H5zm7 2v3a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1v-3a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1z"/>'),Pb=d("PrinterFill",'<path d="M5 1a2 2 0 0 0-2 2v1h10V3a2 2 0 0 0-2-2H5zm6 8H5a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1z"/><path d="M0 7a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2h-1v-2a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2H2a2 2 0 0 1-2-2V7zm2.5 1a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/>'),Ib=d("Puzzle",'<path d="M3.112 3.645A1.5 1.5 0 0 1 4.605 2H7a.5.5 0 0 1 .5.5v.382c0 .696-.497 1.182-.872 1.469a.459.459 0 0 0-.115.118.113.113 0 0 0-.012.025L6.5 4.5v.003l.003.01c.004.01.014.028.036.053a.86.86 0 0 0 .27.194C7.09 4.9 7.51 5 8 5c.492 0 .912-.1 1.19-.24a.86.86 0 0 0 .271-.194.213.213 0 0 0 .039-.063v-.009a.112.112 0 0 0-.012-.025.459.459 0 0 0-.115-.118c-.375-.287-.872-.773-.872-1.469V2.5A.5.5 0 0 1 9 2h2.395a1.5 1.5 0 0 1 1.493 1.645L12.645 6.5h.237c.195 0 .42-.147.675-.48.21-.274.528-.52.943-.52.568 0 .947.447 1.154.862C15.877 6.807 16 7.387 16 8s-.123 1.193-.346 1.638c-.207.415-.586.862-1.154.862-.415 0-.733-.246-.943-.52-.255-.333-.48-.48-.675-.48h-.237l.243 2.855A1.5 1.5 0 0 1 11.395 14H9a.5.5 0 0 1-.5-.5v-.382c0-.696.497-1.182.872-1.469a.459.459 0 0 0 .115-.118.113.113 0 0 0 .012-.025L9.5 11.5v-.003a.214.214 0 0 0-.039-.064.859.859 0 0 0-.27-.193C8.91 11.1 8.49 11 8 11c-.491 0-.912.1-1.19.24a.859.859 0 0 0-.271.194.214.214 0 0 0-.039.063v.003l.001.006a.113.113 0 0 0 .012.025c.016.027.05.068.115.118.375.287.872.773.872 1.469v.382a.5.5 0 0 1-.5.5H4.605a1.5 1.5 0 0 1-1.493-1.645L3.356 9.5h-.238c-.195 0-.42.147-.675.48-.21.274-.528.52-.943.52-.568 0-.947-.447-1.154-.862C.123 9.193 0 8.613 0 8s.123-1.193.346-1.638C.553 5.947.932 5.5 1.5 5.5c.415 0 .733.246.943.52.255.333.48.48.675.48h.238l-.244-2.855zM4.605 3a.5.5 0 0 0-.498.55l.001.007.29 3.4A.5.5 0 0 1 3.9 7.5h-.782c-.696 0-1.182-.497-1.469-.872a.459.459 0 0 0-.118-.115.112.112 0 0 0-.025-.012L1.5 6.5h-.003a.213.213 0 0 0-.064.039.86.86 0 0 0-.193.27C1.1 7.09 1 7.51 1 8c0 .491.1.912.24 1.19.07.14.14.225.194.271a.213.213 0 0 0 .063.039H1.5l.006-.001a.112.112 0 0 0 .025-.012.459.459 0 0 0 .118-.115c.287-.375.773-.872 1.469-.872H3.9a.5.5 0 0 1 .498.542l-.29 3.408a.5.5 0 0 0 .497.55h1.878c-.048-.166-.195-.352-.463-.557-.274-.21-.52-.528-.52-.943 0-.568.447-.947.862-1.154C6.807 10.123 7.387 10 8 10s1.193.123 1.638.346c.415.207.862.586.862 1.154 0 .415-.246.733-.52.943-.268.205-.415.39-.463.557h1.878a.5.5 0 0 0 .498-.55l-.001-.007-.29-3.4A.5.5 0 0 1 12.1 8.5h.782c.696 0 1.182.497 1.469.872.05.065.091.099.118.115.013.008.021.01.025.012a.02.02 0 0 0 .006.001h.003a.214.214 0 0 0 .064-.039.86.86 0 0 0 .193-.27c.14-.28.24-.7.24-1.191 0-.492-.1-.912-.24-1.19a.86.86 0 0 0-.194-.271.215.215 0 0 0-.063-.039H14.5l-.006.001a.113.113 0 0 0-.025.012.459.459 0 0 0-.118.115c-.287.375-.773.872-1.469.872H12.1a.5.5 0 0 1-.498-.543l.29-3.407a.5.5 0 0 0-.497-.55H9.517c.048.166.195.352.463.557.274.21.52.528.52.943 0 .568-.447.947-.862 1.154C9.193 5.877 8.613 6 8 6s-1.193-.123-1.638-.346C5.947 5.447 5.5 5.068 5.5 4.5c0-.415.246-.733.52-.943.268-.205.415-.39.463-.557H4.605z"/>'),Eb=d("PuzzleFill",'<path d="M3.112 3.645A1.5 1.5 0 0 1 4.605 2H7a.5.5 0 0 1 .5.5v.382c0 .696-.497 1.182-.872 1.469a.459.459 0 0 0-.115.118.113.113 0 0 0-.012.025L6.5 4.5v.003l.003.01c.004.01.014.028.036.053a.86.86 0 0 0 .27.194C7.09 4.9 7.51 5 8 5c.492 0 .912-.1 1.19-.24a.86.86 0 0 0 .271-.194.213.213 0 0 0 .036-.054l.003-.01v-.008a.112.112 0 0 0-.012-.025.459.459 0 0 0-.115-.118c-.375-.287-.872-.773-.872-1.469V2.5A.5.5 0 0 1 9 2h2.395a1.5 1.5 0 0 1 1.493 1.645L12.645 6.5h.237c.195 0 .42-.147.675-.48.21-.274.528-.52.943-.52.568 0 .947.447 1.154.862C15.877 6.807 16 7.387 16 8s-.123 1.193-.346 1.638c-.207.415-.586.862-1.154.862-.415 0-.733-.246-.943-.52-.255-.333-.48-.48-.675-.48h-.237l.243 2.855A1.5 1.5 0 0 1 11.395 14H9a.5.5 0 0 1-.5-.5v-.382c0-.696.497-1.182.872-1.469a.459.459 0 0 0 .115-.118.113.113 0 0 0 .012-.025L9.5 11.5v-.003l-.003-.01a.214.214 0 0 0-.036-.053.859.859 0 0 0-.27-.194C8.91 11.1 8.49 11 8 11c-.491 0-.912.1-1.19.24a.859.859 0 0 0-.271.194.214.214 0 0 0-.036.054l-.003.01v.002l.001.006a.113.113 0 0 0 .012.025c.016.027.05.068.115.118.375.287.872.773.872 1.469v.382a.5.5 0 0 1-.5.5H4.605a1.5 1.5 0 0 1-1.493-1.645L3.356 9.5h-.238c-.195 0-.42.147-.675.48-.21.274-.528.52-.943.52-.568 0-.947-.447-1.154-.862C.123 9.193 0 8.613 0 8s.123-1.193.346-1.638C.553 5.947.932 5.5 1.5 5.5c.415 0 .733.246.943.52.255.333.48.48.675.48h.238l-.244-2.855z"/>'),Lb=d("Question",'<path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>'),Bb=d("QuestionCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>'),Hb=d("QuestionCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.496 6.033h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286a.237.237 0 0 0 .241.247zm2.325 6.443c.61 0 1.029-.394 1.029-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94 0 .533.425.927 1.01.927z"/>'),Fb=d("QuestionDiamond",'<path d="M6.95.435c.58-.58 1.52-.58 2.1 0l6.515 6.516c.58.58.58 1.519 0 2.098L9.05 15.565c-.58.58-1.519.58-2.098 0L.435 9.05a1.482 1.482 0 0 1 0-2.098L6.95.435zm1.4.7a.495.495 0 0 0-.7 0L1.134 7.65a.495.495 0 0 0 0 .7l6.516 6.516a.495.495 0 0 0 .7 0l6.516-6.516a.495.495 0 0 0 0-.7L8.35 1.134z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>'),Db=d("QuestionDiamondFill",'<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L.436 6.95c-.58.58-.58 1.519 0 2.098l6.516 6.516c.58.58 1.519.58 2.098 0l6.516-6.516c.58-.58.58-1.519 0-2.098L9.05.435zM5.495 6.033a.237.237 0 0 1-.24-.247C5.35 4.091 6.737 3.5 8.005 3.5c1.396 0 2.672.73 2.672 2.24 0 1.08-.635 1.594-1.244 2.057-.737.559-1.01.768-1.01 1.486v.105a.25.25 0 0 1-.25.25h-.81a.25.25 0 0 1-.25-.246l-.004-.217c-.038-.927.495-1.498 1.168-1.987.59-.444.965-.736.965-1.371 0-.825-.628-1.168-1.314-1.168-.803 0-1.253.478-1.342 1.134-.018.137-.128.25-.266.25h-.825zm2.325 6.443c-.584 0-1.009-.394-1.009-.927 0-.552.425-.94 1.01-.94.609 0 1.028.388 1.028.94 0 .533-.42.927-1.029.927z"/>'),Rb=d("QuestionOctagon",'<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>'),Nb=d("QuestionOctagonFill",'<path d="M11.46.146A.5.5 0 0 0 11.107 0H4.893a.5.5 0 0 0-.353.146L.146 4.54A.5.5 0 0 0 0 4.893v6.214a.5.5 0 0 0 .146.353l4.394 4.394a.5.5 0 0 0 .353.146h6.214a.5.5 0 0 0 .353-.146l4.394-4.394a.5.5 0 0 0 .146-.353V4.893a.5.5 0 0 0-.146-.353L11.46.146zM5.496 6.033a.237.237 0 0 1-.24-.247C5.35 4.091 6.737 3.5 8.005 3.5c1.396 0 2.672.73 2.672 2.24 0 1.08-.635 1.594-1.244 2.057-.737.559-1.01.768-1.01 1.486v.105a.25.25 0 0 1-.25.25h-.81a.25.25 0 0 1-.25-.246l-.004-.217c-.038-.927.495-1.498 1.168-1.987.59-.444.965-.736.965-1.371 0-.825-.628-1.168-1.314-1.168-.803 0-1.253.478-1.342 1.134-.018.137-.128.25-.266.25h-.825zm2.325 6.443c-.584 0-1.009-.394-1.009-.927 0-.552.425-.94 1.01-.94.609 0 1.028.388 1.028.94 0 .533-.42.927-1.029.927z"/>'),$b=d("QuestionSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5.255 5.786a.237.237 0 0 0 .241.247h.825c.138 0 .248-.113.266-.25.09-.656.54-1.134 1.342-1.134.686 0 1.314.343 1.314 1.168 0 .635-.374.927-.965 1.371-.673.489-1.206 1.06-1.168 1.987l.003.217a.25.25 0 0 0 .25.246h.811a.25.25 0 0 0 .25-.25v-.105c0-.718.273-.927 1.01-1.486.609-.463 1.244-.977 1.244-2.056 0-1.511-1.276-2.241-2.673-2.241-1.267 0-2.655.59-2.75 2.286zm1.557 5.763c0 .533.425.927 1.01.927.609 0 1.028-.394 1.028-.927 0-.552-.42-.94-1.029-.94-.584 0-1.009.388-1.009.94z"/>'),Ub=d("QuestionSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm3.496 6.033a.237.237 0 0 1-.24-.247C5.35 4.091 6.737 3.5 8.005 3.5c1.396 0 2.672.73 2.672 2.24 0 1.08-.635 1.594-1.244 2.057-.737.559-1.01.768-1.01 1.486v.105a.25.25 0 0 1-.25.25h-.81a.25.25 0 0 1-.25-.246l-.004-.217c-.038-.927.495-1.498 1.168-1.987.59-.444.965-.736.965-1.371 0-.825-.628-1.168-1.314-1.168-.803 0-1.253.478-1.342 1.134-.018.137-.128.25-.266.25h-.825zm2.325 6.443c-.584 0-1.009-.394-1.009-.927 0-.552.425-.94 1.01-.94.609 0 1.028.388 1.028.94 0 .533-.42.927-1.029.927z"/>'),qb=d("Receipt",'<path d="M1.92.506a.5.5 0 0 1 .434.14L3 1.293l.646-.647a.5.5 0 0 1 .708 0L5 1.293l.646-.647a.5.5 0 0 1 .708 0L7 1.293l.646-.647a.5.5 0 0 1 .708 0L9 1.293l.646-.647a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .708 0l.646.647.646-.647a.5.5 0 0 1 .801.13l.5 1A.5.5 0 0 1 15 2v12a.5.5 0 0 1-.053.224l-.5 1a.5.5 0 0 1-.8.13L13 14.707l-.646.647a.5.5 0 0 1-.708 0L11 14.707l-.646.647a.5.5 0 0 1-.708 0L9 14.707l-.646.647a.5.5 0 0 1-.708 0L7 14.707l-.646.647a.5.5 0 0 1-.708 0L5 14.707l-.646.647a.5.5 0 0 1-.708 0L3 14.707l-.646.647a.5.5 0 0 1-.801-.13l-.5-1A.5.5 0 0 1 1 14V2a.5.5 0 0 1 .053-.224l.5-1a.5.5 0 0 1 .367-.27zm.217 1.338L2 2.118v11.764l.137.274.51-.51a.5.5 0 0 1 .707 0l.646.647.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.646.646.646-.646a.5.5 0 0 1 .708 0l.509.509.137-.274V2.118l-.137-.274-.51.51a.5.5 0 0 1-.707 0L12 1.707l-.646.647a.5.5 0 0 1-.708 0L10 1.707l-.646.647a.5.5 0 0 1-.708 0L8 1.707l-.646.647a.5.5 0 0 1-.708 0L6 1.707l-.646.647a.5.5 0 0 1-.708 0L4 1.707l-.646.647a.5.5 0 0 1-.708 0l-.509-.51z"/><path d="M3 4.5a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm8-6a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 0 1h-1a.5.5 0 0 1-.5-.5z"/>'),Wb=d("ReceiptCutoff",'<path d="M3 4.5a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 1 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 2a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zM11.5 4a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1zm0 2a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/><path d="M2.354.646a.5.5 0 0 0-.801.13l-.5 1A.5.5 0 0 0 1 2v13H.5a.5.5 0 0 0 0 1h15a.5.5 0 0 0 0-1H15V2a.5.5 0 0 0-.053-.224l-.5-1a.5.5 0 0 0-.8-.13L13 1.293l-.646-.647a.5.5 0 0 0-.708 0L11 1.293l-.646-.647a.5.5 0 0 0-.708 0L9 1.293 8.354.646a.5.5 0 0 0-.708 0L7 1.293 6.354.646a.5.5 0 0 0-.708 0L5 1.293 4.354.646a.5.5 0 0 0-.708 0L3 1.293 2.354.646zm-.217 1.198l.51.51a.5.5 0 0 0 .707 0L4 1.707l.646.647a.5.5 0 0 0 .708 0L6 1.707l.646.647a.5.5 0 0 0 .708 0L8 1.707l.646.647a.5.5 0 0 0 .708 0L10 1.707l.646.647a.5.5 0 0 0 .708 0L12 1.707l.646.647a.5.5 0 0 0 .708 0l.509-.51.137.274V15H2V2.118l.137-.274z"/>'),Gb=d("Reception0",'<path d="M0 13.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>'),Yb=d("Reception1",'<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4 2a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>'),Kb=d("Reception2",'<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-5zm4 5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5zm4 0a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>'),Qb=d("Reception3",'<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-5zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-8zm4 8a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 0 1h-2a.5.5 0 0 1-.5-.5z"/>'),Xb=d("Reception4",'<path d="M0 11.5a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-2zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-5zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-8zm4-3a.5.5 0 0 1 .5-.5h2a.5.5 0 0 1 .5.5v11a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1-.5-.5v-11z"/>'),Jb=d("Record",'<path fill-rule="evenodd" d="M8 12a4 4 0 1 0 0-8 4 4 0 0 0 0 8zm0 1A5 5 0 1 0 8 3a5 5 0 0 0 0 10z"/>'),Zb=d("Record2",'<path d="M8 12a4 4 0 1 1 0-8 4 4 0 0 1 0 8zm0 1A5 5 0 1 0 8 3a5 5 0 0 0 0 10z"/><path d="M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/>'),tg=d("Record2Fill",'<path d="M10 8a2 2 0 1 1-4 0 2 2 0 0 1 4 0z"/><path d="M8 13A5 5 0 1 0 8 3a5 5 0 0 0 0 10zm0-2a3 3 0 1 1 0-6 3 3 0 0 1 0 6z"/>'),eg=d("RecordBtn",'<path d="M8 11a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),ng=d("RecordBtnFill",'<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm8-1a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>'),rg=d("RecordCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11 8a3 3 0 1 1-6 0 3 3 0 0 1 6 0z"/>'),ig=d("RecordCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-8 3a3 3 0 1 0 0-6 3 3 0 0 0 0 6z"/>'),og=d("RecordFill",'<path fill-rule="evenodd" d="M8 13A5 5 0 1 0 8 3a5 5 0 0 0 0 10z"/>'),ag=d("Reply",'<path d="M9.502 5.013a.144.144 0 0 0-.202.134V6.3a.5.5 0 0 1-.5.5c-.667 0-2.013.005-3.3.822-.984.624-1.99 1.76-2.595 3.876C3.925 10.515 5.09 9.982 6.11 9.7a8.741 8.741 0 0 1 1.921-.306 7.403 7.403 0 0 1 .798.008h.013l.005.001h.001L8.8 9.9l.05-.498a.5.5 0 0 1 .45.498v1.153c0 .108.11.176.202.134l3.984-2.933a.494.494 0 0 1 .042-.028.147.147 0 0 0 0-.252.494.494 0 0 1-.042-.028L9.502 5.013zM8.3 10.386a7.745 7.745 0 0 0-1.923.277c-1.326.368-2.896 1.201-3.94 3.08a.5.5 0 0 1-.933-.305c.464-3.71 1.886-5.662 3.46-6.66 1.245-.79 2.527-.942 3.336-.971v-.66a1.144 1.144 0 0 1 1.767-.96l3.994 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a1.144 1.144 0 0 1-1.767-.96v-.667z"/>'),sg=d("ReplyAll",'<path d="M8.002 5.013a.144.144 0 0 0-.202.134V6.3a.5.5 0 0 1-.5.5c-.667 0-2.013.005-3.3.822-.984.624-1.99 1.76-2.595 3.876C2.425 10.515 3.59 9.982 4.61 9.7a8.741 8.741 0 0 1 1.921-.306 7.403 7.403 0 0 1 .798.008h.013l.005.001h.001L7.3 9.9l.05-.498a.5.5 0 0 1 .45.498v1.153c0 .108.11.176.202.134l3.984-2.933a.494.494 0 0 1 .042-.028.147.147 0 0 0 0-.252.494.494 0 0 1-.042-.028L8.002 5.013zM6.8 10.386a7.745 7.745 0 0 0-1.923.277c-1.326.368-2.896 1.201-3.94 3.08a.5.5 0 0 1-.933-.305c.464-3.71 1.886-5.662 3.46-6.66 1.245-.79 2.527-.942 3.336-.971v-.66a1.144 1.144 0 0 1 1.767-.96l3.994 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a1.144 1.144 0 0 1-1.767-.96v-.667z"/><path d="M10.868 4.293a.5.5 0 0 1 .7-.106l3.993 2.94a1.147 1.147 0 0 1 0 1.946l-3.994 2.94a.5.5 0 1 1-.593-.805l4.012-2.954a.508.508 0 0 1 .042-.028.147.147 0 0 0 0-.252.508.508 0 0 1-.042-.028l-4.012-2.954a.5.5 0 0 1-.106-.699z"/>'),cg=d("ReplyAllFill",'<path d="M8.079 11.9l4.568-3.281a.719.719 0 0 0 0-1.238L8.079 4.1A.716.716 0 0 0 7 4.719V6c-1.5 0-6 0-7 8 2.5-4.5 7-4 7-4v1.281c0 .56.606.898 1.079.62z"/><path d="M10.868 4.293a.5.5 0 0 0 .106.7l4.012 2.953a.51.51 0 0 0 .042.028.147.147 0 0 1 0 .252.512.512 0 0 0-.042.028l-4.012 2.954a.5.5 0 1 0 .593.805l3.994-2.94a1.147 1.147 0 0 0 0-1.946l-3.994-2.94a.5.5 0 0 0-.699.106z"/>'),lg=d("ReplyFill",'<path d="M9.079 11.9l4.568-3.281a.719.719 0 0 0 0-1.238L9.079 4.1A.716.716 0 0 0 8 4.719V6c-1.5 0-6 0-7 8 2.5-4.5 7-4 7-4v1.281c0 .56.606.898 1.079.62z"/>'),ug=d("Rss",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M5.5 12a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-3-8.5a1 1 0 0 1 1-1c5.523 0 10 4.477 10 10a1 1 0 1 1-2 0 8 8 0 0 0-8-8 1 1 0 0 1-1-1zm0 4a1 1 0 0 1 1-1 6 6 0 0 1 6 6 1 1 0 1 1-2 0 4 4 0 0 0-4-4 1 1 0 0 1-1-1z"/>'),dg=d("RssFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm1.5 2.5c5.523 0 10 4.477 10 10a1 1 0 1 1-2 0 8 8 0 0 0-8-8 1 1 0 0 1 0-2zm0 4a6 6 0 0 1 6 6 1 1 0 1 1-2 0 4 4 0 0 0-4-4 1 1 0 0 1 0-2zm.5 7a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),hg=d("Scissors",'<path d="M3.5 3.5c-.614-.884-.074-1.962.858-2.5L8 7.226 11.642 1c.932.538 1.472 1.616.858 2.5L8.81 8.61l1.556 2.661a2.5 2.5 0 1 1-.794.637L8 9.73l-1.572 2.177a2.5 2.5 0 1 1-.794-.637L7.19 8.61 3.5 3.5zm2.5 10a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0zm7 0a1.5 1.5 0 1 0-3 0 1.5 1.5 0 0 0 3 0z"/>'),fg=d("Screwdriver",'<path d="M0 1l1-1 3.081 2.2a1 1 0 0 1 .419.815v.07a1 1 0 0 0 .293.708L10.5 9.5l.914-.305a1 1 0 0 1 1.023.242l3.356 3.356a1 1 0 0 1 0 1.414l-1.586 1.586a1 1 0 0 1-1.414 0l-3.356-3.356a1 1 0 0 1-.242-1.023L9.5 10.5 3.793 4.793a1 1 0 0 0-.707-.293h-.071a1 1 0 0 1-.814-.419L0 1zm11.354 9.646a.5.5 0 0 0-.708.708l3 3a.5.5 0 0 0 .708-.708l-3-3z"/>'),pg=d("Search",'<path d="M11.742 10.344a6.5 6.5 0 1 0-1.397 1.398h-.001c.03.04.062.078.098.115l3.85 3.85a1 1 0 0 0 1.415-1.414l-3.85-3.85a1.007 1.007 0 0 0-.115-.1zM12 6.5a5.5 5.5 0 1 1-11 0 5.5 5.5 0 0 1 11 0z"/>'),mg=d("SegmentedNav",'<path d="M0 6a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V6zm6 3h4V5H6v4zm9-1V6a1 1 0 0 0-1-1h-3v4h3a1 1 0 0 0 1-1z"/>'),bg=d("Server",'<path d="M1.333 2.667C1.333 1.194 4.318 0 8 0s6.667 1.194 6.667 2.667V4c0 1.473-2.985 2.667-6.667 2.667S1.333 5.473 1.333 4V2.667z"/><path d="M1.333 6.334v3C1.333 10.805 4.318 12 8 12s6.667-1.194 6.667-2.667V6.334c-.43.32-.931.58-1.458.79C11.81 7.684 9.967 8 8 8c-1.967 0-3.81-.317-5.21-.876a6.508 6.508 0 0 1-1.457-.79z"/><path d="M14.667 11.668c-.43.319-.931.578-1.458.789-1.4.56-3.242.876-5.209.876-1.967 0-3.81-.316-5.21-.876a6.51 6.51 0 0 1-1.457-.79v1.666C1.333 14.806 4.318 16 8 16s6.667-1.194 6.667-2.667v-1.665z"/>'),gg=d("Share",'<path d="M13.5 1a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zM11 2.5a2.5 2.5 0 1 1 .603 1.628l-6.718 3.12a2.499 2.499 0 0 1 0 1.504l6.718 3.12a2.5 2.5 0 1 1-.488.876l-6.718-3.12a2.5 2.5 0 1 1 0-3.256l6.718-3.12A2.5 2.5 0 0 1 11 2.5zm-8.5 4a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zm11 5.5a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3z"/>'),vg=d("ShareFill",'<path d="M11 2.5a2.5 2.5 0 1 1 .603 1.628l-6.718 3.12a2.499 2.499 0 0 1 0 1.504l6.718 3.12a2.5 2.5 0 1 1-.488.876l-6.718-3.12a2.5 2.5 0 1 1 0-3.256l6.718-3.12A2.5 2.5 0 0 1 11 2.5z"/>'),wg=d("Shield",'<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/>'),yg=d("ShieldCheck",'<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M10.854 5.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 7.793l2.646-2.647a.5.5 0 0 1 .708 0z"/>'),kg=d("ShieldExclamation",'<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z"/>'),_g=d("ShieldFill",'<path d="M5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/>'),Og=d("ShieldFillCheck",'<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm2.146 5.146a.5.5 0 0 1 .708.708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 7.793l2.646-2.647z"/>'),zg=d("ShieldFillExclamation",'<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm-.55 8.502L7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0zM8.002 12a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>'),Ag=d("ShieldFillMinus",'<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zM6 7.5a.5.5 0 0 1 0-1h4a.5.5 0 0 1 0 1H6z"/>'),jg=d("ShieldFillPlus",'<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm-.5 5a.5.5 0 0 1 1 0v1.5H10a.5.5 0 0 1 0 1H8.5V9a.5.5 0 0 1-1 0V7.5H6a.5.5 0 0 1 0-1h1.5V5z"/>'),Mg=d("ShieldFillX",'<path d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zM6.854 5.146L8 6.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 7l1.147 1.146a.5.5 0 0 1-.708.708L8 7.707 6.854 8.854a.5.5 0 1 1-.708-.708L7.293 7 6.146 5.854a.5.5 0 1 1 .708-.708z"/>'),Cg=d("ShieldLock",'<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M9.5 6.5a1.5 1.5 0 0 1-1 1.415l.385 1.99a.5.5 0 0 1-.491.595h-.788a.5.5 0 0 1-.49-.595l.384-1.99a1.5 1.5 0 1 1 2-1.415z"/>'),Vg=d("ShieldLockFill",'<path fill-rule="evenodd" d="M8 0c-.69 0-1.843.265-2.928.56-1.11.3-2.229.655-2.887.87a1.54 1.54 0 0 0-1.044 1.262c-.596 4.477.787 7.795 2.465 9.99a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.775 11.775 0 0 0 2.517-2.453c1.678-2.195 3.061-5.513 2.465-9.99a1.541 1.541 0 0 0-1.044-1.263 62.467 62.467 0 0 0-2.887-.87C9.843.266 8.69 0 8 0zm0 5a1.5 1.5 0 0 1 .5 2.915l.385 1.99a.5.5 0 0 1-.491.595h-.788a.5.5 0 0 1-.49-.595l.384-1.99A1.5 1.5 0 0 1 8 5z"/>'),Sg=d("ShieldMinus",'<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M5.5 7a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1H6a.5.5 0 0 1-.5-.5z"/>'),xg=d("ShieldPlus",'<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M8 4.5a.5.5 0 0 1 .5.5v1.5H10a.5.5 0 0 1 0 1H8.5V9a.5.5 0 0 1-1 0V7.5H6a.5.5 0 0 1 0-1h1.5V5a.5.5 0 0 1 .5-.5z"/>'),Tg=d("ShieldShaded",'<path fill-rule="evenodd" d="M8 14.933a.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067v13.866zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/>'),Pg=d("ShieldSlash",'<path fill-rule="evenodd" d="M1.093 3.093c-.465 4.275.885 7.46 2.513 9.589a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.32 11.32 0 0 0 1.733-1.525l-.745-.745a10.27 10.27 0 0 1-1.578 1.392c-.346.244-.652.42-.893.533-.12.057-.218.095-.293.118a.55.55 0 0 1-.101.025.615.615 0 0 1-.1-.025 2.348 2.348 0 0 1-.294-.118 6.141 6.141 0 0 1-.893-.533 10.725 10.725 0 0 1-2.287-2.233C3.053 10.228 1.879 7.594 2.06 4.06l-.967-.967zM3.98 1.98l-.852-.852A58.935 58.935 0 0 1 5.072.559C6.157.266 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.483 3.626-.332 6.491-1.551 8.616l-.77-.77c1.042-1.915 1.72-4.469 1.29-7.702a.48.48 0 0 0-.33-.39c-.65-.213-1.75-.56-2.836-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524a49.7 49.7 0 0 0-1.357.39zm9.666 12.374l-13-13 .708-.708 13 13-.707.707z"/>'),Ig=d("ShieldSlashFill",'<path fill-rule="evenodd" d="M1.093 3.093c-.465 4.275.885 7.46 2.513 9.589a11.777 11.777 0 0 0 2.517 2.453c.386.273.744.482 1.048.625.28.132.581.24.829.24s.548-.108.829-.24a7.159 7.159 0 0 0 1.048-.625 11.32 11.32 0 0 0 1.733-1.525L1.093 3.093zm12.215 8.215L3.128 1.128A61.369 61.369 0 0 1 5.073.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.483 3.626-.332 6.491-1.551 8.616zm.338 3.046l-13-13 .708-.708 13 13-.707.707z"/>'),Eg=d("ShieldX",'<path d="M5.338 1.59a61.44 61.44 0 0 0-2.837.856.481.481 0 0 0-.328.39c-.554 4.157.726 7.19 2.253 9.188a10.725 10.725 0 0 0 2.287 2.233c.346.244.652.42.893.533.12.057.218.095.293.118a.55.55 0 0 0 .101.025.615.615 0 0 0 .1-.025c.076-.023.174-.061.294-.118.24-.113.547-.29.893-.533a10.726 10.726 0 0 0 2.287-2.233c1.527-1.997 2.807-5.031 2.253-9.188a.48.48 0 0 0-.328-.39c-.651-.213-1.75-.56-2.837-.855C9.552 1.29 8.531 1.067 8 1.067c-.53 0-1.552.223-2.662.524zM5.072.56C6.157.265 7.31 0 8 0s1.843.265 2.928.56c1.11.3 2.229.655 2.887.87a1.54 1.54 0 0 1 1.044 1.262c.596 4.477-.787 7.795-2.465 9.99a11.775 11.775 0 0 1-2.517 2.453 7.159 7.159 0 0 1-1.048.625c-.28.132-.581.24-.829.24s-.548-.108-.829-.24a7.158 7.158 0 0 1-1.048-.625 11.777 11.777 0 0 1-2.517-2.453C1.928 10.487.545 7.169 1.141 2.692A1.54 1.54 0 0 1 2.185 1.43 62.456 62.456 0 0 1 5.072.56z"/><path d="M6.146 5.146a.5.5 0 0 1 .708 0L8 6.293l1.146-1.147a.5.5 0 1 1 .708.708L8.707 7l1.147 1.146a.5.5 0 0 1-.708.708L8 7.707 6.854 8.854a.5.5 0 1 1-.708-.708L7.293 7 6.146 5.854a.5.5 0 0 1 0-.708z"/>'),Lg=d("Shift",'<path d="M7.27 2.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v3a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-3H1.654C.78 10.5.326 9.455.924 8.816L7.27 2.047zM14.346 9.5L8 2.731 1.654 9.5H4.5a1 1 0 0 1 1 1v3h5v-3a1 1 0 0 1 1-1h2.846z"/>'),Bg=d("ShiftFill",'<path d="M7.27 2.047a1 1 0 0 1 1.46 0l6.345 6.77c.6.638.146 1.683-.73 1.683H11.5v3a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-3H1.654C.78 10.5.326 9.455.924 8.816L7.27 2.047z"/>'),Hg=d("Shop",'<path d="M2.97 1.35A1 1 0 0 1 3.73 1h8.54a1 1 0 0 1 .76.35l2.609 3.044A1.5 1.5 0 0 1 16 5.37v.255a2.375 2.375 0 0 1-4.25 1.458A2.371 2.371 0 0 1 9.875 8 2.37 2.37 0 0 1 8 7.083 2.37 2.37 0 0 1 6.125 8a2.37 2.37 0 0 1-1.875-.917A2.375 2.375 0 0 1 0 5.625V5.37a1.5 1.5 0 0 1 .361-.976l2.61-3.045zm1.78 4.275a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 1 0 2.75 0V5.37a.5.5 0 0 0-.12-.325L12.27 2H3.73L1.12 5.045A.5.5 0 0 0 1 5.37v.255a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0zM1.5 8.5A.5.5 0 0 1 2 9v6h1v-5a1 1 0 0 1 1-1h3a1 1 0 0 1 1 1v5h6V9a.5.5 0 0 1 1 0v6h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1V9a.5.5 0 0 1 .5-.5zM4 15h3v-5H4v5zm5-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1v-3zm3 0h-2v3h2v-3z"/>'),Fg=d("ShopWindow",'<path d="M2.97 1.35A1 1 0 0 1 3.73 1h8.54a1 1 0 0 1 .76.35l2.609 3.044A1.5 1.5 0 0 1 16 5.37v.255a2.375 2.375 0 0 1-4.25 1.458A2.371 2.371 0 0 1 9.875 8 2.37 2.37 0 0 1 8 7.083 2.37 2.37 0 0 1 6.125 8a2.37 2.37 0 0 1-1.875-.917A2.375 2.375 0 0 1 0 5.625V5.37a1.5 1.5 0 0 1 .361-.976l2.61-3.045zm1.78 4.275a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0 1.375 1.375 0 1 0 2.75 0V5.37a.5.5 0 0 0-.12-.325L12.27 2H3.73L1.12 5.045A.5.5 0 0 0 1 5.37v.255a1.375 1.375 0 0 0 2.75 0 .5.5 0 0 1 1 0zM1.5 8.5A.5.5 0 0 1 2 9v6h12V9a.5.5 0 0 1 1 0v6h.5a.5.5 0 0 1 0 1H.5a.5.5 0 0 1 0-1H1V9a.5.5 0 0 1 .5-.5zm2 .5a.5.5 0 0 1 .5.5V13h8V9.5a.5.5 0 0 1 1 0V13a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V9.5a.5.5 0 0 1 .5-.5z"/>'),Dg=d("Shuffle",'<path fill-rule="evenodd" d="M0 3.5A.5.5 0 0 1 .5 3H1c2.202 0 3.827 1.24 4.874 2.418.49.552.865 1.102 1.126 1.532.26-.43.636-.98 1.126-1.532C9.173 4.24 10.798 3 13 3v1c-1.798 0-3.173 1.01-4.126 2.082A9.624 9.624 0 0 0 7.556 8a9.624 9.624 0 0 0 1.317 1.918C9.828 10.99 11.204 12 13 12v1c-2.202 0-3.827-1.24-4.874-2.418A10.595 10.595 0 0 1 7 9.05c-.26.43-.636.98-1.126 1.532C4.827 11.76 3.202 13 1 13H.5a.5.5 0 0 1 0-1H1c1.798 0 3.173-1.01 4.126-2.082A9.624 9.624 0 0 0 6.444 8a9.624 9.624 0 0 0-1.317-1.918C4.172 5.01 2.796 4 1 4H.5a.5.5 0 0 1-.5-.5z"/><path d="M13 5.466V1.534a.25.25 0 0 1 .41-.192l2.36 1.966c.12.1.12.284 0 .384l-2.36 1.966a.25.25 0 0 1-.41-.192zm0 9v-3.932a.25.25 0 0 1 .41-.192l2.36 1.966c.12.1.12.284 0 .384l-2.36 1.966a.25.25 0 0 1-.41-.192z"/>'),Rg=d("Signpost",'<path d="M7 1.414V4H2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h5v6h2v-6h3.532a1 1 0 0 0 .768-.36l1.933-2.32a.5.5 0 0 0 0-.64L13.3 4.36a1 1 0 0 0-.768-.36H9V1.414a1 1 0 0 0-2 0zM12.532 5l1.666 2-1.666 2H2V5h10.532z"/>'),Ng=d("Signpost2",'<path d="M7 1.414V2H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h5v1H2.5a1 1 0 0 0-.8.4L.725 8.7a.5.5 0 0 0 0 .6l.975 1.3a1 1 0 0 0 .8.4H7v5h2v-5h5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H9V6h4.5a1 1 0 0 0 .8-.4l.975-1.3a.5.5 0 0 0 0-.6L14.3 2.4a1 1 0 0 0-.8-.4H9v-.586a1 1 0 0 0-2 0zM13.5 3l.75 1-.75 1H2V3h11.5zm.5 5v2H2.5l-.75-1 .75-1H14z"/>'),$g=d("Signpost2Fill",'<path d="M7.293.707A1 1 0 0 0 7 1.414V2H2a1 1 0 0 0-1 1v2a1 1 0 0 0 1 1h5v1H2.5a1 1 0 0 0-.8.4L.725 8.7a.5.5 0 0 0 0 .6l.975 1.3a1 1 0 0 0 .8.4H7v5h2v-5h5a1 1 0 0 0 1-1V8a1 1 0 0 0-1-1H9V6h4.5a1 1 0 0 0 .8-.4l.975-1.3a.5.5 0 0 0 0-.6L14.3 2.4a1 1 0 0 0-.8-.4H9v-.586A1 1 0 0 0 7.293.707z"/>'),Ug=d("SignpostFill",'<path d="M7.293.707A1 1 0 0 0 7 1.414V4H2a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h5v6h2v-6h3.532a1 1 0 0 0 .768-.36l1.933-2.32a.5.5 0 0 0 0-.64L13.3 4.36a1 1 0 0 0-.768-.36H9V1.414A1 1 0 0 0 7.293.707z"/>'),qg=d("SignpostSplit",'<path d="M7 7V1.414a1 1 0 0 1 2 0V2h5a1 1 0 0 1 .8.4l.975 1.3a.5.5 0 0 1 0 .6L14.8 5.6a1 1 0 0 1-.8.4H9v10H7v-5H2a1 1 0 0 1-.8-.4L.225 9.3a.5.5 0 0 1 0-.6L1.2 7.4A1 1 0 0 1 2 7h5zm1 3V8H2l-.75 1L2 10h6zm0-5h6l.75-1L14 3H8v2z"/>'),Wg=d("SignpostSplitFill",'<path d="M7 16h2V6h5a1 1 0 0 0 .8-.4l.975-1.3a.5.5 0 0 0 0-.6L14.8 2.4A1 1 0 0 0 14 2H9v-.586a1 1 0 0 0-2 0V7H2a1 1 0 0 0-.8.4L.225 8.7a.5.5 0 0 0 0 .6l.975 1.3a1 1 0 0 0 .8.4h5v5z"/>'),Gg=d("Sim",'<path d="M2 1.5A1.5 1.5 0 0 1 3.5 0h7.086a1.5 1.5 0 0 1 1.06.44l1.915 1.914A1.5 1.5 0 0 1 14 3.414V14.5a1.5 1.5 0 0 1-1.5 1.5h-9A1.5 1.5 0 0 1 2 14.5v-13zM3.5 1a.5.5 0 0 0-.5.5v13a.5.5 0 0 0 .5.5h9a.5.5 0 0 0 .5-.5V3.414a.5.5 0 0 0-.146-.353l-1.915-1.915A.5.5 0 0 0 10.586 1H3.5z"/><path d="M5.5 4a.5.5 0 0 0-.5.5V6h2.5V4h-2zm3 0v2H11V4.5a.5.5 0 0 0-.5-.5h-2zM11 7H5v2h6V7zm0 3H8.5v2h2a.5.5 0 0 0 .5-.5V10zm-3.5 2v-2H5v1.5a.5.5 0 0 0 .5.5h2zM4 4.5A1.5 1.5 0 0 1 5.5 3h5A1.5 1.5 0 0 1 12 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-5A1.5 1.5 0 0 1 4 11.5v-7z"/>'),Yg=d("SimFill",'<path d="M5 4.5a.5.5 0 0 1 .5-.5h2v2H5V4.5zM8.5 6V4h2a.5.5 0 0 1 .5.5V6H8.5zM5 7h6v2H5V7zm3.5 3H11v1.5a.5.5 0 0 1-.5.5h-2v-2zm-1 0v2h-2a.5.5 0 0 1-.5-.5V10h2.5z"/><path d="M3.5 0A1.5 1.5 0 0 0 2 1.5v13A1.5 1.5 0 0 0 3.5 16h9a1.5 1.5 0 0 0 1.5-1.5V3.414a1.5 1.5 0 0 0-.44-1.06L11.647.439A1.5 1.5 0 0 0 10.586 0H3.5zm2 3h5A1.5 1.5 0 0 1 12 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-5A1.5 1.5 0 0 1 4 11.5v-7A1.5 1.5 0 0 1 5.5 3z"/>'),Kg=d("SkipBackward",'<path d="M.5 3.5A.5.5 0 0 1 1 4v3.248l6.267-3.636c.52-.302 1.233.043 1.233.696v2.94l6.267-3.636c.52-.302 1.233.043 1.233.696v7.384c0 .653-.713.998-1.233.696L8.5 8.752v2.94c0 .653-.713.998-1.233.696L1 8.752V12a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5zm7 1.133L1.696 8 7.5 11.367V4.633zm7.5 0L9.196 8 15 11.367V4.633z"/>'),Qg=d("SkipBackwardBtn",'<path d="M4.79 5.093A.5.5 0 0 0 4 5.5v5a.5.5 0 0 0 .79.407L7.5 8.972V10.5a.5.5 0 0 0 .79.407L11 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 5.093a.5.5 0 0 0-.79.407v1.528L4.79 5.093z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),Xg=d("SkipBackwardBtnFill",'<path d="M0 10V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm4.79-6.907A.5.5 0 0 0 4 3.5v5a.5.5 0 0 0 .79.407L7.5 6.972V8.5a.5.5 0 0 0 .79.407L11 6.972V8.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 3.093a.5.5 0 0 0-.79.407v1.528L4.79 3.093z"/>'),Jg=d("SkipBackwardCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.271 5.055a.5.5 0 0 1 .52.038L7.5 7.028V5.5a.5.5 0 0 1 .79-.407L11 7.028V5.5a.5.5 0 0 1 1 0v5a.5.5 0 0 1-1 0V8.972l-2.71 1.935a.5.5 0 0 1-.79-.407V8.972l-2.71 1.935A.5.5 0 0 1 4 10.5v-5a.5.5 0 0 1 .271-.445z"/>'),Zg=d("SkipBackwardCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4.79 5.093A.5.5 0 0 0 4 5.5v5a.5.5 0 0 0 .79.407L7.5 8.972V10.5a.5.5 0 0 0 .79.407L11 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 5.093a.5.5 0 0 0-.79.407v1.528L4.79 5.093z"/>'),tv=d("SkipBackwardFill",'<path d="M.5 3.5A.5.5 0 0 0 0 4v8a.5.5 0 0 0 1 0V8.753l6.267 3.636c.54.313 1.233-.066 1.233-.697v-2.94l6.267 3.636c.54.314 1.233-.065 1.233-.696V4.308c0-.63-.693-1.01-1.233-.696L8.5 7.248v-2.94c0-.63-.692-1.01-1.233-.696L1 7.248V4a.5.5 0 0 0-.5-.5z"/>'),ev=d("SkipEnd",'<path d="M12.5 4a.5.5 0 0 0-1 0v3.248L5.233 3.612C4.713 3.31 4 3.655 4 4.308v7.384c0 .653.713.998 1.233.696L11.5 8.752V12a.5.5 0 0 0 1 0V4zM5 4.633L10.804 8 5 11.367V4.633z"/>'),nv=d("SkipEndBtn",'<path d="M6.79 5.093L9.5 7.028V5.5a.5.5 0 0 1 1 0v5a.5.5 0 0 1-1 0V8.972l-2.71 1.935A.5.5 0 0 1 6 10.5v-5a.5.5 0 0 1 .79-.407z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),rv=d("SkipEndBtnFill",'<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.79-6.907A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407L9.5 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L6.79 5.093z"/>'),iv=d("SkipEndCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M6.271 5.055a.5.5 0 0 1 .52.038L9.5 7.028V5.5a.5.5 0 0 1 1 0v5a.5.5 0 0 1-1 0V8.972l-2.71 1.935A.5.5 0 0 1 6 10.5v-5a.5.5 0 0 1 .271-.445z"/>'),ov=d("SkipEndCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.79 5.093A.5.5 0 0 0 6 5.5v5a.5.5 0 0 0 .79.407L9.5 8.972V10.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L6.79 5.093z"/>'),av=d("SkipEndFill",'<path d="M12.5 4a.5.5 0 0 0-1 0v3.248L5.233 3.612C4.693 3.3 4 3.678 4 4.308v7.384c0 .63.692 1.01 1.233.697L11.5 8.753V12a.5.5 0 0 0 1 0V4z"/>'),sv=d("SkipForward",'<path d="M15.5 3.5a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V8.752l-6.267 3.636c-.52.302-1.233-.043-1.233-.696v-2.94l-6.267 3.636C.713 12.69 0 12.345 0 11.692V4.308c0-.653.713-.998 1.233-.696L7.5 7.248v-2.94c0-.653.713-.998 1.233-.696L15 7.248V4a.5.5 0 0 1 .5-.5zM1 4.633v6.734L6.804 8 1 4.633zm7.5 0v6.734L14.304 8 8.5 4.633z"/>'),cv=d("SkipForwardBtn",'<path d="M11.21 5.093A.5.5 0 0 1 12 5.5v5a.5.5 0 0 1-.79.407L8.5 8.972V10.5a.5.5 0 0 1-.79.407L5 8.972V10.5a.5.5 0 0 1-1 0v-5a.5.5 0 0 1 1 0v1.528l2.71-1.935a.5.5 0 0 1 .79.407v1.528l2.71-1.935z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),lv=d("SkipForwardBtnFill",'<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm11.21-6.907L8.5 7.028V5.5a.5.5 0 0 0-.79-.407L5 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407V8.972l2.71 1.935A.5.5 0 0 0 12 10.5v-5a.5.5 0 0 0-.79-.407z"/>'),uv=d("SkipForwardCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11.729 5.055a.5.5 0 0 0-.52.038L8.5 7.028V5.5a.5.5 0 0 0-.79-.407L5 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407V8.972l2.71 1.935A.5.5 0 0 0 12 10.5v-5a.5.5 0 0 0-.271-.445z"/>'),dv=d("SkipForwardCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.79-2.907L8.5 7.028V5.5a.5.5 0 0 0-.79-.407L5 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407V8.972l2.71 1.935A.5.5 0 0 0 12 10.5v-5a.5.5 0 0 0-.79-.407z"/>'),hv=d("SkipForwardFill",'<path d="M15.5 3.5a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V8.753l-6.267 3.636c-.54.313-1.233-.066-1.233-.697v-2.94l-6.267 3.636C.693 12.703 0 12.324 0 11.693V4.308c0-.63.693-1.01 1.233-.696L7.5 7.248v-2.94c0-.63.693-1.01 1.233-.696L15 7.248V4a.5.5 0 0 1 .5-.5z"/>'),fv=d("SkipStart",'<path d="M4 4a.5.5 0 0 1 1 0v3.248l6.267-3.636c.52-.302 1.233.043 1.233.696v7.384c0 .653-.713.998-1.233.696L5 8.752V12a.5.5 0 0 1-1 0V4zm7.5.633L5.696 8l5.804 3.367V4.633z"/>'),pv=d("SkipStartBtn",'<path d="M9.71 5.093a.5.5 0 0 1 .79.407v5a.5.5 0 0 1-.79.407L7 8.972V10.5a.5.5 0 0 1-1 0v-5a.5.5 0 0 1 1 0v1.528l2.71-1.935z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),mv=d("SkipStartBtnFill",'<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm9.71-6.907L7 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407v-5a.5.5 0 0 0-.79-.407z"/>'),bv=d("SkipStartCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M10.229 5.055a.5.5 0 0 0-.52.038L7 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407v-5a.5.5 0 0 0-.271-.445z"/>'),gv=d("SkipStartCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM9.71 5.093L7 7.028V5.5a.5.5 0 0 0-1 0v5a.5.5 0 0 0 1 0V8.972l2.71 1.935a.5.5 0 0 0 .79-.407v-5a.5.5 0 0 0-.79-.407z"/>'),vv=d("SkipStartFill",'<path d="M4 4a.5.5 0 0 1 1 0v3.248l6.267-3.636c.54-.313 1.232.066 1.232.696v7.384c0 .63-.692 1.01-1.232.697L5 8.753V12a.5.5 0 0 1-1 0V4z"/>'),wv=d("Slack",'<path d="M3.362 10.11c0 .926-.756 1.681-1.681 1.681S0 11.036 0 10.111C0 9.186.756 8.43 1.68 8.43h1.682v1.68zm.846 0c0-.924.756-1.68 1.681-1.68s1.681.756 1.681 1.68v4.21c0 .924-.756 1.68-1.68 1.68a1.685 1.685 0 0 1-1.682-1.68v-4.21zM5.89 3.362c-.926 0-1.682-.756-1.682-1.681S4.964 0 5.89 0s1.68.756 1.68 1.68v1.682H5.89zm0 .846c.924 0 1.68.756 1.68 1.681S6.814 7.57 5.89 7.57H1.68C.757 7.57 0 6.814 0 5.89c0-.926.756-1.682 1.68-1.682h4.21zm6.749 1.682c0-.926.755-1.682 1.68-1.682.925 0 1.681.756 1.681 1.681s-.756 1.681-1.68 1.681h-1.681V5.89zm-.848 0c0 .924-.755 1.68-1.68 1.68A1.685 1.685 0 0 1 8.43 5.89V1.68C8.43.757 9.186 0 10.11 0c.926 0 1.681.756 1.681 1.68v4.21zm-1.681 6.748c.926 0 1.682.756 1.682 1.681S11.036 16 10.11 16s-1.681-.756-1.681-1.68v-1.682h1.68zm0-.847c-.924 0-1.68-.755-1.68-1.68 0-.925.756-1.681 1.68-1.681h4.21c.924 0 1.68.756 1.68 1.68 0 .926-.756 1.681-1.68 1.681h-4.21z"/>'),yv=d("Slash",'<path d="M11.354 4.646a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708l6-6a.5.5 0 0 1 .708 0z"/>'),kv=d("SlashCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M11.354 4.646a.5.5 0 0 0-.708 0l-6 6a.5.5 0 0 0 .708.708l6-6a.5.5 0 0 0 0-.708z"/>'),_v=d("SlashCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-4.646-2.646a.5.5 0 0 0-.708-.708l-6 6a.5.5 0 0 0 .708.708l6-6z"/>'),Ov=d("SlashSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M11.354 4.646a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708l6-6a.5.5 0 0 1 .708 0z"/>'),zv=d("SlashSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm9.354 5.354l-6 6a.5.5 0 0 1-.708-.708l6-6a.5.5 0 0 1 .708.708z"/>'),Av=d("Sliders",'<path fill-rule="evenodd" d="M11.5 2a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zM9.05 3a2.5 2.5 0 0 1 4.9 0H16v1h-2.05a2.5 2.5 0 0 1-4.9 0H0V3h9.05zM4.5 7a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zM2.05 8a2.5 2.5 0 0 1 4.9 0H16v1H6.95a2.5 2.5 0 0 1-4.9 0H0V8h2.05zm9.45 4a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zm-2.45 1a2.5 2.5 0 0 1 4.9 0H16v1h-2.05a2.5 2.5 0 0 1-4.9 0H0v-1h9.05z"/>'),jv=d("Smartwatch",'<path d="M9 5a.5.5 0 0 0-1 0v3H6a.5.5 0 0 0 0 1h2.5a.5.5 0 0 0 .5-.5V5z"/><path d="M4 1.667v.383A2.5 2.5 0 0 0 2 4.5v7a2.5 2.5 0 0 0 2 2.45v.383C4 15.253 4.746 16 5.667 16h4.666c.92 0 1.667-.746 1.667-1.667v-.383a2.5 2.5 0 0 0 2-2.45V8h.5a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 0-.5-.5H14v-.5a2.5 2.5 0 0 0-2-2.45v-.383C12 .747 11.254 0 10.333 0H5.667C4.747 0 4 .746 4 1.667zM4.5 3h7A1.5 1.5 0 0 1 13 4.5v7a1.5 1.5 0 0 1-1.5 1.5h-7A1.5 1.5 0 0 1 3 11.5v-7A1.5 1.5 0 0 1 4.5 3z"/>'),Mv=d("SortAlphaDown",'<path fill-rule="evenodd" d="M10.082 5.629L9.664 7H8.598l1.789-5.332h1.234L13.402 7h-1.12l-.419-1.371h-1.781zm1.57-.785L11 2.687h-.047l-.652 2.157h1.351z"/><path d="M12.96 14H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V14zM4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>'),Cv=d("SortAlphaDownAlt",'<path d="M12.96 7H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V7z"/><path fill-rule="evenodd" d="M10.082 12.629L9.664 14H8.598l1.789-5.332h1.234L13.402 14h-1.12l-.419-1.371h-1.781zm1.57-.785L11 9.688h-.047l-.652 2.156h1.351z"/><path d="M4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>'),Vv=d("SortAlphaUp",'<path fill-rule="evenodd" d="M10.082 5.629L9.664 7H8.598l1.789-5.332h1.234L13.402 7h-1.12l-.419-1.371h-1.781zm1.57-.785L11 2.687h-.047l-.652 2.157h1.351z"/><path d="M12.96 14H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V14zm-8.46-.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>'),Sv=d("SortAlphaUpAlt",'<path d="M12.96 7H9.028v-.691l2.579-3.72v-.054H9.098v-.867h3.785v.691l-2.567 3.72v.054h2.645V7z"/><path fill-rule="evenodd" d="M10.082 12.629L9.664 14H8.598l1.789-5.332h1.234L13.402 14h-1.12l-.419-1.371h-1.781zm1.57-.785L11 9.688h-.047l-.652 2.156h1.351z"/><path d="M4.5 13.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>'),xv=d("SortDown",'<path d="M3.5 2.5a.5.5 0 0 0-1 0v8.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L3.5 11.293V2.5zm3.5 1a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM7.5 6a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zm0 3a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/>'),Tv=d("SortDownAlt",'<path d="M3.5 3.5a.5.5 0 0 0-1 0v8.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L3.5 12.293V3.5zm4 .5a.5.5 0 0 1 0-1h1a.5.5 0 0 1 0 1h-1zm0 3a.5.5 0 0 1 0-1h3a.5.5 0 0 1 0 1h-3zm0 3a.5.5 0 0 1 0-1h5a.5.5 0 0 1 0 1h-5zM7 12.5a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7a.5.5 0 0 0-.5.5z"/>'),Pv=d("SortNumericDown",'<path d="M12.438 1.668V7H11.39V2.684h-.051l-1.211.859v-.969l1.262-.906h1.046z"/><path fill-rule="evenodd" d="M11.36 14.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.835 1.973-1.835 1.09 0 2.063.636 2.063 2.687 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>'),Iv=d("SortNumericDownAlt",'<path fill-rule="evenodd" d="M11.36 7.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.836 1.973-1.836 1.09 0 2.063.637 2.063 2.688 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M12.438 8.668V14H11.39V9.684h-.051l-1.211.859v-.969l1.262-.906h1.046zM4.5 2.5a.5.5 0 0 0-1 0v9.793l-1.146-1.147a.5.5 0 0 0-.708.708l2 1.999.007.007a.497.497 0 0 0 .7-.006l2-2a.5.5 0 0 0-.707-.708L4.5 12.293V2.5z"/>'),Ev=d("SortNumericUp",'<path d="M12.438 1.668V7H11.39V2.684h-.051l-1.211.859v-.969l1.262-.906h1.046z"/><path fill-rule="evenodd" d="M11.36 14.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.835 1.973-1.835 1.09 0 2.063.636 2.063 2.687 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M4.5 13.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>'),Lv=d("SortNumericUpAlt",'<path fill-rule="evenodd" d="M11.36 7.098c-1.137 0-1.708-.657-1.762-1.278h1.004c.058.223.343.45.773.45.824 0 1.164-.829 1.133-1.856h-.059c-.148.39-.57.742-1.261.742-.91 0-1.72-.613-1.72-1.758 0-1.148.848-1.836 1.973-1.836 1.09 0 2.063.637 2.063 2.688 0 1.867-.723 2.848-2.145 2.848zm.062-2.735c.504 0 .933-.336.933-.972 0-.633-.398-1.008-.94-1.008-.52 0-.927.375-.927 1 0 .64.418.98.934.98z"/><path d="M12.438 8.668V14H11.39V9.684h-.051l-1.211.859v-.969l1.262-.906h1.046zM4.5 13.5a.5.5 0 0 1-1 0V3.707L2.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L4.5 3.707V13.5z"/>'),Bv=d("SortUp",'<path d="M3.5 12.5a.5.5 0 0 1-1 0V3.707L1.354 4.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L3.5 3.707V12.5zm3.5-9a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zM7.5 6a.5.5 0 0 0 0 1h5a.5.5 0 0 0 0-1h-5zm0 3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1h-3zm0 3a.5.5 0 0 0 0 1h1a.5.5 0 0 0 0-1h-1z"/>'),Hv=d("SortUpAlt",'<path d="M3.5 13.5a.5.5 0 0 1-1 0V4.707L1.354 5.854a.5.5 0 1 1-.708-.708l2-1.999.007-.007a.498.498 0 0 1 .7.006l2 2a.5.5 0 1 1-.707.708L3.5 4.707V13.5zm4-9.5a.5.5 0 0 1 0-1h1a.5.5 0 0 1 0 1h-1zm0 3a.5.5 0 0 1 0-1h3a.5.5 0 0 1 0 1h-3zm0 3a.5.5 0 0 1 0-1h5a.5.5 0 0 1 0 1h-5zM7 12.5a.5.5 0 0 0 .5.5h7a.5.5 0 0 0 0-1h-7a.5.5 0 0 0-.5.5z"/>'),Fv=d("Soundwave",'<path fill-rule="evenodd" d="M8.5 2a.5.5 0 0 1 .5.5v11a.5.5 0 0 1-1 0v-11a.5.5 0 0 1 .5-.5zm-2 2a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 .5-.5zm4 0a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 .5-.5zm-6 1.5A.5.5 0 0 1 5 6v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm8 0a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm-10 1A.5.5 0 0 1 3 7v2a.5.5 0 0 1-1 0V7a.5.5 0 0 1 .5-.5zm12 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0V7a.5.5 0 0 1 .5-.5z"/>'),Dv=d("Speaker",'<path d="M12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M8 4.75a.75.75 0 1 1 0-1.5.75.75 0 0 1 0 1.5zM8 6a2 2 0 1 0 0-4 2 2 0 0 0 0 4zm0 3a1.5 1.5 0 1 0 0 3 1.5 1.5 0 0 0 0-3zm-3.5 1.5a3.5 3.5 0 1 1 7 0 3.5 3.5 0 0 1-7 0z"/>'),Rv=d("SpeakerFill",'<path d="M9 4a1 1 0 1 1-2 0 1 1 0 0 1 2 0zm-2.5 6.5a1.5 1.5 0 1 1 3 0 1.5 1.5 0 0 1-3 0z"/><path d="M4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4zm6 4a2 2 0 1 1-4 0 2 2 0 0 1 4 0zM8 7a3.5 3.5 0 1 1 0 7 3.5 3.5 0 0 1 0-7z"/>'),Nv=d("Spellcheck",'<path d="M8.217 11.068c1.216 0 1.948-.869 1.948-2.31v-.702c0-1.44-.727-2.305-1.929-2.305-.742 0-1.328.347-1.499.889h-.063V3.983h-1.29V11h1.27v-.791h.064c.21.532.776.86 1.499.86zm-.43-1.025c-.66 0-1.113-.518-1.113-1.28V8.12c0-.825.42-1.343 1.098-1.343.684 0 1.075.518 1.075 1.416v.45c0 .888-.386 1.401-1.06 1.401zm-5.583 1.035c.767 0 1.201-.356 1.406-.737h.059V11h1.216V7.519c0-1.314-.947-1.783-2.11-1.783C1.355 5.736.75 6.42.69 7.27h1.216c.064-.323.313-.552.84-.552.527 0 .864.249.864.771v.464H2.346C1.145 7.953.5 8.568.5 9.496c0 .977.693 1.582 1.704 1.582zm.42-.947c-.44 0-.845-.235-.845-.718 0-.395.269-.684.84-.684h.991v.538c0 .503-.444.864-.986.864zm8.897.567c-.577-.4-.9-1.088-.9-1.983v-.65c0-1.42.894-2.338 2.305-2.338 1.352 0 2.119.82 2.139 1.806h-1.187c-.04-.351-.283-.776-.918-.776-.674 0-1.045.517-1.045 1.328v.625c0 .468.121.834.343 1.067l-.737.92z"/><path d="M14.469 9.414a.75.75 0 0 1 .117 1.055l-4 5a.75.75 0 0 1-1.116.061l-2.5-2.5a.75.75 0 1 1 1.06-1.06l1.908 1.907 3.476-4.346a.75.75 0 0 1 1.055-.117z"/>'),$v=d("Square",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/>'),Uv=d("SquareFill",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2z"/>'),qv=d("SquareHalf",'<path d="M8 15V1h6a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H8zm6 1a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12z"/>'),Wv=d("Star",'<path d="M2.866 14.85c-.078.444.36.791.746.593l4.39-2.256 4.389 2.256c.386.198.824-.149.746-.592l-.83-4.73 3.523-3.356c.329-.314.158-.888-.283-.95l-4.898-.696L8.465.792a.513.513 0 0 0-.927 0L5.354 5.12l-4.898.696c-.441.062-.612.636-.283.95l3.523 3.356-.83 4.73zm4.905-2.767l-3.686 1.894.694-3.957a.565.565 0 0 0-.163-.505L1.71 6.745l4.052-.576a.525.525 0 0 0 .393-.288l1.847-3.658 1.846 3.658a.525.525 0 0 0 .393.288l4.052.575-2.906 2.77a.564.564 0 0 0-.163.506l.694 3.957-3.686-1.894a.503.503 0 0 0-.461 0z"/>'),Gv=d("StarFill",'<path d="M3.612 15.443c-.386.198-.824-.149-.746-.592l.83-4.73L.173 6.765c-.329-.314-.158-.888.283-.95l4.898-.696L7.538.792c.197-.39.73-.39.927 0l2.184 4.327 4.898.696c.441.062.612.636.283.95l-3.523 3.356.83 4.73c.078.443-.36.79-.746.592L8 13.187l-4.389 2.256z"/>'),Yv=d("StarHalf",'<path d="M5.354 5.119L7.538.792A.516.516 0 0 1 8 .5c.183 0 .366.097.465.292l2.184 4.327 4.898.696A.537.537 0 0 1 16 6.32a.55.55 0 0 1-.17.445l-3.523 3.356.83 4.73c.078.443-.36.79-.746.592L8 13.187l-4.389 2.256a.519.519 0 0 1-.146.05c-.341.06-.668-.254-.6-.642l.83-4.73L.173 6.765a.55.55 0 0 1-.171-.403.59.59 0 0 1 .084-.302.513.513 0 0 1 .37-.245l4.898-.696zM8 12.027c.08 0 .16.018.232.056l3.686 1.894-.694-3.957a.564.564 0 0 1 .163-.505l2.906-2.77-4.052-.576a.525.525 0 0 1-.393-.288L8.002 2.223 8 2.226v9.8z"/>'),Kv=d("Stickies",'<path d="M1.5 0A1.5 1.5 0 0 0 0 1.5V13a1 1 0 0 0 1 1V1.5a.5.5 0 0 1 .5-.5H14a1 1 0 0 0-1-1H1.5z"/><path d="M3.5 2A1.5 1.5 0 0 0 2 3.5v11A1.5 1.5 0 0 0 3.5 16h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 16 9.586V3.5A1.5 1.5 0 0 0 14.5 2h-11zM3 3.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 .5.5V9h-4.5A1.5 1.5 0 0 0 9 10.5V15H3.5a.5.5 0 0 1-.5-.5v-11zm7 11.293V10.5a.5.5 0 0 1 .5-.5h4.293L10 14.793z"/>'),Qv=d("StickiesFill",'<path d="M0 1.5V13a1 1 0 0 0 1 1V1.5a.5.5 0 0 1 .5-.5H14a1 1 0 0 0-1-1H1.5A1.5 1.5 0 0 0 0 1.5z"/><path d="M3.5 2A1.5 1.5 0 0 0 2 3.5v11A1.5 1.5 0 0 0 3.5 16h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 16 9.586V3.5A1.5 1.5 0 0 0 14.5 2h-11zm6 8.5a1 1 0 0 1 1-1h4.396a.25.25 0 0 1 .177.427l-5.146 5.146a.25.25 0 0 1-.427-.177V10.5z"/>'),Xv=d("Sticky",'<path d="M2.5 1A1.5 1.5 0 0 0 1 2.5v11A1.5 1.5 0 0 0 2.5 15h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 15 8.586V2.5A1.5 1.5 0 0 0 13.5 1h-11zM2 2.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 .5.5V8H9.5A1.5 1.5 0 0 0 8 9.5V14H2.5a.5.5 0 0 1-.5-.5v-11zm7 11.293V9.5a.5.5 0 0 1 .5-.5h4.293L9 13.793z"/>'),Jv=d("StickyFill",'<path d="M2.5 1A1.5 1.5 0 0 0 1 2.5v11A1.5 1.5 0 0 0 2.5 15h6.086a1.5 1.5 0 0 0 1.06-.44l4.915-4.914A1.5 1.5 0 0 0 15 8.586V2.5A1.5 1.5 0 0 0 13.5 1h-11zm6 8.5a1 1 0 0 1 1-1h4.396a.25.25 0 0 1 .177.427l-5.146 5.146a.25.25 0 0 1-.427-.177V9.5z"/>'),Zv=d("Stop",'<path d="M3.5 5A1.5 1.5 0 0 1 5 3.5h6A1.5 1.5 0 0 1 12.5 5v6a1.5 1.5 0 0 1-1.5 1.5H5A1.5 1.5 0 0 1 3.5 11V5zM5 4.5a.5.5 0 0 0-.5.5v6a.5.5 0 0 0 .5.5h6a.5.5 0 0 0 .5-.5V5a.5.5 0 0 0-.5-.5H5z"/>'),tw=d("StopBtn",'<path d="M6.5 5A1.5 1.5 0 0 0 5 6.5v3A1.5 1.5 0 0 0 6.5 11h3A1.5 1.5 0 0 0 11 9.5v-3A1.5 1.5 0 0 0 9.5 5h-3z"/><path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm15 0a1 1 0 0 0-1-1H2a1 1 0 0 0-1 1v8a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V4z"/>'),ew=d("StopBtnFill",'<path d="M0 12V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm6.5-7A1.5 1.5 0 0 0 5 6.5v3A1.5 1.5 0 0 0 6.5 11h3A1.5 1.5 0 0 0 11 9.5v-3A1.5 1.5 0 0 0 9.5 5h-3z"/>'),nw=d("StopCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M5 6.5A1.5 1.5 0 0 1 6.5 5h3A1.5 1.5 0 0 1 11 6.5v3A1.5 1.5 0 0 1 9.5 11h-3A1.5 1.5 0 0 1 5 9.5v-3z"/>'),rw=d("StopCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM6.5 5A1.5 1.5 0 0 0 5 6.5v3A1.5 1.5 0 0 0 6.5 11h3A1.5 1.5 0 0 0 11 9.5v-3A1.5 1.5 0 0 0 9.5 5h-3z"/>'),iw=d("StopFill",'<path d="M5 3.5h6A1.5 1.5 0 0 1 12.5 5v6a1.5 1.5 0 0 1-1.5 1.5H5A1.5 1.5 0 0 1 3.5 11V5A1.5 1.5 0 0 1 5 3.5z"/>'),ow=d("Stoplights",'<path d="M8 5a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zm0 4a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zm1.5 2.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/><path d="M4 2a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2h2c-.167.5-.8 1.6-2 2v2h2c-.167.5-.8 1.6-2 2v2h2c-.167.5-.8 1.6-2 2v1a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-1c-1.2-.4-1.833-1.5-2-2h2V8c-1.2-.4-1.833-1.5-2-2h2V4c-1.2-.4-1.833-1.5-2-2h2zm2-1a1 1 0 0 0-1 1v11a1 1 0 0 0 1 1h4a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H6z"/>'),aw=d("StoplightsFill",'<path fill-rule="evenodd" d="M6 0a2 2 0 0 0-2 2H2c.167.5.8 1.6 2 2v2H2c.167.5.8 1.6 2 2v2H2c.167.5.8 1.6 2 2v1a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2v-1c1.2-.4 1.833-1.5 2-2h-2V8c1.2-.4 1.833-1.5 2-2h-2V4c1.2-.4 1.833-1.5 2-2h-2a2 2 0 0 0-2-2H6zm3.5 3.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM8 13a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),sw=d("Stopwatch",'<path d="M8.5 5.6a.5.5 0 1 0-1 0v2.9h-3a.5.5 0 0 0 0 1H8a.5.5 0 0 0 .5-.5V5.6z"/><path d="M6.5 1A.5.5 0 0 1 7 .5h2a.5.5 0 0 1 0 1v.57c1.36.196 2.594.78 3.584 1.64a.715.715 0 0 1 .012-.013l.354-.354-.354-.353a.5.5 0 0 1 .707-.708l1.414 1.415a.5.5 0 1 1-.707.707l-.353-.354-.354.354a.512.512 0 0 1-.013.012A7 7 0 1 1 7 2.071V1.5a.5.5 0 0 1-.5-.5zM8 3a6 6 0 1 0 .001 12A6 6 0 0 0 8 3z"/>'),cw=d("StopwatchFill",'<path d="M6.5 0a.5.5 0 0 0 0 1H7v1.07A7.001 7.001 0 0 0 8 16a7 7 0 0 0 5.29-11.584.531.531 0 0 0 .013-.012l.354-.354.353.354a.5.5 0 1 0 .707-.707l-1.414-1.415a.5.5 0 1 0-.707.707l.354.354-.354.354a.717.717 0 0 0-.012.012A6.973 6.973 0 0 0 9 2.071V1h.5a.5.5 0 0 0 0-1h-3zm2 5.6V9a.5.5 0 0 1-.5.5H4.5a.5.5 0 0 1 0-1h3V5.6a.5.5 0 1 1 1 0z"/>'),lw=d("Subtract",'<path d="M0 10V2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm4.79-6.907A.5.5 0 0 0 4 3.5v5a.5.5 0 0 0 .79.407L7.5 6.972V8.5a.5.5 0 0 0 .79.407L11 6.972V8.5a.5.5 0 0 0 1 0v-5a.5.5 0 0 0-1 0v1.528L8.29 3.093a.5.5 0 0 0-.79.407v1.528L4.79 3.093z"/>'),uw=d("SuitClub",'<path d="M8 1a3.25 3.25 0 0 0-3.25 3.25c0 .186 0 .29.016.41.014.12.045.27.12.527l.19.665-.692-.028a3.25 3.25 0 1 0 2.357 5.334.5.5 0 0 1 .844.518l-.003.005-.006.015-.024.055a21.893 21.893 0 0 1-.438.92 22.38 22.38 0 0 1-1.266 2.197c-.013.018-.02.05.001.09.01.02.021.03.03.036A.036.036 0 0 0 5.9 15h4.2c.01 0 .016-.002.022-.006a.092.092 0 0 0 .029-.035c.02-.04.014-.073.001-.091a22.875 22.875 0 0 1-1.704-3.117l-.024-.054-.006-.015-.002-.004a.5.5 0 0 1 .838-.524c.601.7 1.516 1.168 2.496 1.168a3.25 3.25 0 1 0-.139-6.498l-.699.03.199-.671c.14-.47.14-.745.139-.927V4.25A3.25 3.25 0 0 0 8 1zm2.207 12.024c.225.405.487.848.78 1.294C11.437 15 10.975 16 10.1 16H5.9c-.876 0-1.338-1-.887-1.683.291-.442.552-.88.776-1.283a4.25 4.25 0 1 1-2.007-8.187 2.79 2.79 0 0 1-.009-.064c-.023-.187-.023-.348-.023-.52V4.25a4.25 4.25 0 0 1 8.5 0c0 .14 0 .333-.04.596a4.25 4.25 0 0 1-.46 8.476 4.186 4.186 0 0 1-1.543-.298z"/>'),dw=d("SuitClubFill",'<path d="M11.5 12.5a3.493 3.493 0 0 1-2.684-1.254 19.92 19.92 0 0 0 1.582 2.907c.231.35-.02.847-.438.847H6.04c-.419 0-.67-.497-.438-.847a19.919 19.919 0 0 0 1.582-2.907 3.5 3.5 0 1 1-2.538-5.743 3.5 3.5 0 1 1 6.708 0A3.5 3.5 0 1 1 11.5 12.5z"/>'),hw=d("SuitDiamond",'<path d="M8.384 1.226a.463.463 0 0 0-.768 0l-4.56 6.468a.537.537 0 0 0 0 .612l4.56 6.469a.463.463 0 0 0 .768 0l4.56-6.469a.537.537 0 0 0 0-.612l-4.56-6.468zM6.848.613a1.39 1.39 0 0 1 2.304 0l4.56 6.468a1.61 1.61 0 0 1 0 1.838l-4.56 6.468a1.39 1.39 0 0 1-2.304 0L2.288 8.92a1.61 1.61 0 0 1 0-1.838L6.848.613z"/>'),fw=d("SuitDiamondFill",'<path d="M2.45 7.4L7.2 1.067a1 1 0 0 1 1.6 0L13.55 7.4a1 1 0 0 1 0 1.2L8.8 14.933a1 1 0 0 1-1.6 0L2.45 8.6a1 1 0 0 1 0-1.2z"/>'),pw=d("SuitHeart",'<path d="M8 6.236l-.894-1.789c-.222-.443-.607-1.08-1.152-1.595C5.418 2.345 4.776 2 4 2 2.324 2 1 3.326 1 4.92c0 1.211.554 2.066 1.868 3.37.337.334.721.695 1.146 1.093C5.122 10.423 6.5 11.717 8 13.447c1.5-1.73 2.878-3.024 3.986-4.064.425-.398.81-.76 1.146-1.093C14.446 6.986 15 6.131 15 4.92 15 3.326 13.676 2 12 2c-.777 0-1.418.345-1.954.852-.545.515-.93 1.152-1.152 1.595L8 6.236zm.392 8.292a.513.513 0 0 1-.784 0c-1.601-1.902-3.05-3.262-4.243-4.381C1.3 8.208 0 6.989 0 4.92 0 2.755 1.79 1 4 1c1.6 0 2.719 1.05 3.404 2.008.26.365.458.716.596.992a7.55 7.55 0 0 1 .596-.992C9.281 2.049 10.4 1 12 1c2.21 0 4 1.755 4 3.92 0 2.069-1.3 3.288-3.365 5.227-1.193 1.12-2.642 2.48-4.243 4.38z"/>'),mw=d("SuitHeartFill",'<path d="M4 1c2.21 0 4 1.755 4 3.92C8 2.755 9.79 1 12 1s4 1.755 4 3.92c0 3.263-3.234 4.414-7.608 9.608a.513.513 0 0 1-.784 0C3.234 9.334 0 8.183 0 4.92 0 2.755 1.79 1 4 1z"/>'),bw=d("SuitSpade",'<path d="M8 0a.5.5 0 0 1 .429.243c1.359 2.265 2.925 3.682 4.25 4.882.096.086.19.17.282.255C14.308 6.604 15.5 7.747 15.5 9.5a4 4 0 0 1-5.406 3.746c.235.39.491.782.722 1.131.434.659-.01 1.623-.856 1.623H6.04c-.845 0-1.29-.964-.856-1.623.263-.397.51-.777.728-1.134A4 4 0 0 1 .5 9.5c0-1.753 1.192-2.896 2.539-4.12l.281-.255c1.326-1.2 2.892-2.617 4.251-4.882A.5.5 0 0 1 8 0zM3.711 6.12C2.308 7.396 1.5 8.253 1.5 9.5a3 3 0 0 0 5.275 1.956.5.5 0 0 1 .868.43c-.094.438-.33.932-.611 1.428a29.247 29.247 0 0 1-1.013 1.614.03.03 0 0 0-.005.018.074.074 0 0 0 .024.054h3.924a.074.074 0 0 0 .024-.054.03.03 0 0 0-.005-.018c-.3-.455-.658-1.005-.96-1.535-.294-.514-.57-1.064-.664-1.507a.5.5 0 0 1 .868-.43A3 3 0 0 0 14.5 9.5c0-1.247-.808-2.104-2.211-3.38L12 5.86c-1.196-1.084-2.668-2.416-4-4.424-1.332 2.008-2.804 3.34-4 4.422l-.289.261z"/>'),gw=d("SuitSpadeFill",'<path d="M7.184 11.246A3.5 3.5 0 0 1 1 9c0-1.602 1.14-2.633 2.66-4.008C4.986 3.792 6.602 2.33 8 0c1.398 2.33 3.014 3.792 4.34 4.992C13.86 6.367 15 7.398 15 9a3.5 3.5 0 0 1-6.184 2.246 19.92 19.92 0 0 0 1.582 2.907c.231.35-.02.847-.438.847H6.04c-.419 0-.67-.497-.438-.847a19.919 19.919 0 0 0 1.582-2.907z"/>'),vw=d("Sun",'<path d="M3.5 8a4.5 4.5 0 1 1 9 0 4.5 4.5 0 0 1-9 0z"/><path d="M8.202.28a.25.25 0 0 0-.404 0l-.91 1.255a.25.25 0 0 1-.334.067L5.232.79a.25.25 0 0 0-.374.154l-.36 1.51a.25.25 0 0 1-.282.188l-1.532-.244a.25.25 0 0 0-.286.286l.244 1.532a.25.25 0 0 1-.189.282l-1.509.36a.25.25 0 0 0-.154.374l.812 1.322a.25.25 0 0 1-.067.333l-1.256.91a.25.25 0 0 0 0 .405l1.256.91a.25.25 0 0 1 .067.334L.79 10.768a.25.25 0 0 0 .154.374l1.51.36a.25.25 0 0 1 .188.282l-.244 1.532a.25.25 0 0 0 .286.286l1.532-.244a.25.25 0 0 1 .282.189l.36 1.508a.25.25 0 0 0 .374.155l1.322-.812a.25.25 0 0 1 .333.067l.91 1.256a.25.25 0 0 0 .405 0l.91-1.256a.25.25 0 0 1 .334-.067l1.322.812a.25.25 0 0 0 .374-.155l.36-1.508a.25.25 0 0 1 .282-.19l1.532.245a.25.25 0 0 0 .286-.286l-.244-1.532a.25.25 0 0 1 .189-.282l1.508-.36a.25.25 0 0 0 .155-.374l-.812-1.322a.25.25 0 0 1 .067-.333l1.256-.91a.25.25 0 0 0 0-.405l-1.256-.91a.25.25 0 0 1-.067-.334l.812-1.322a.25.25 0 0 0-.155-.374l-1.508-.36a.25.25 0 0 1-.19-.282l.245-1.532a.25.25 0 0 0-.286-.286l-1.532.244a.25.25 0 0 1-.282-.189l-.36-1.509a.25.25 0 0 0-.374-.154l-1.322.812a.25.25 0 0 1-.333-.067L8.203.28zM8 2.5a5.5 5.5 0 1 1 0 11 5.5 5.5 0 0 1 0-11z"/>'),ww=d("Sunglasses",'<path d="M3 5a2 2 0 0 0-2 2v.5H.5a.5.5 0 0 0 0 1H1V9a2 2 0 0 0 2 2h1a3 3 0 0 0 3-3 1 1 0 1 1 2 0 3 3 0 0 0 3 3h1a2 2 0 0 0 2-2v-.5h.5a.5.5 0 0 0 0-1H15V7a2 2 0 0 0-2-2h-2a2 2 0 0 0-1.888 1.338A1.99 1.99 0 0 0 8 6a1.99 1.99 0 0 0-1.112.338A2 2 0 0 0 5 5H3zm0 1h.941c.264 0 .348.356.112.474l-.457.228a2 2 0 0 0-.894.894l-.228.457C2.356 8.289 2 8.205 2 7.94V7a1 1 0 0 1 1-1z"/>'),yw=d("Table",'<path d="M0 2a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm15 2h-4v3h4V4zm0 4h-4v3h4V8zm0 4h-4v3h3a1 1 0 0 0 1-1v-2zm-5 3v-3H6v3h4zm-5 0v-3H1v2a1 1 0 0 0 1 1h3zm-4-4h4V8H1v3zm0-4h4V4H1v3zm5-3v3h4V4H6zm4 4H6v3h4V8z"/>'),kw=d("Tablet",'<path d="M12 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h8zM4 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H4z"/><path d="M8 14a1 1 0 1 0 0-2 1 1 0 0 0 0 2z"/>'),_w=d("TabletFill",'<path d="M2 2a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V2zm7 11a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>'),Ow=d("TabletLandscape",'<path d="M1 4a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V4zm-1 8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H2a2 2 0 0 0-2 2v8z"/><path d="M14 8a1 1 0 1 0-2 0 1 1 0 0 0 2 0z"/>'),zw=d("TabletLandscapeFill",'<path d="M2 14a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2zm11-7a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>'),Aw=d("Tag",'<path d="M6 4.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm-1 0a.5.5 0 1 0-1 0 .5.5 0 0 0 1 0z"/><path d="M2 1h4.586a1 1 0 0 1 .707.293l7 7a1 1 0 0 1 0 1.414l-4.586 4.586a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 1 6.586V2a1 1 0 0 1 1-1zm0 5.586l7 7L13.586 9l-7-7H2v4.586z"/>'),jw=d("TagFill",'<path d="M2 1a1 1 0 0 0-1 1v4.586a1 1 0 0 0 .293.707l7 7a1 1 0 0 0 1.414 0l4.586-4.586a1 1 0 0 0 0-1.414l-7-7A1 1 0 0 0 6.586 1H2zm4 3.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),Mw=d("Tags",'<path d="M3 2v4.586l7 7L14.586 9l-7-7H3zM2 2a1 1 0 0 1 1-1h4.586a1 1 0 0 1 .707.293l7 7a1 1 0 0 1 0 1.414l-4.586 4.586a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 2 6.586V2z"/><path d="M5.5 5a.5.5 0 1 1 0-1 .5.5 0 0 1 0 1zm0 1a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zM1 7.086a1 1 0 0 0 .293.707L8.75 15.25l-.043.043a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 0 7.586V3a1 1 0 0 1 1-1v5.086z"/>'),Cw=d("TagsFill",'<path d="M2 2a1 1 0 0 1 1-1h4.586a1 1 0 0 1 .707.293l7 7a1 1 0 0 1 0 1.414l-4.586 4.586a1 1 0 0 1-1.414 0l-7-7A1 1 0 0 1 2 6.586V2zm3.5 4a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3z"/><path d="M1.293 7.793A1 1 0 0 1 1 7.086V2a1 1 0 0 0-1 1v4.586a1 1 0 0 0 .293.707l7 7a1 1 0 0 0 1.414 0l.043-.043-7.457-7.457z"/>'),Vw=d("Telephone",'<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>'),Sw=d("TelephoneFill",'<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>'),xw=d("TelephoneForward",'<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zm10.762.135a.5.5 0 0 1 .708 0l2.5 2.5a.5.5 0 0 1 0 .708l-2.5 2.5a.5.5 0 0 1-.708-.708L14.293 4H9.5a.5.5 0 0 1 0-1h4.793l-1.647-1.646a.5.5 0 0 1 0-.708z"/>'),Tw=d("TelephoneForwardFill",'<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zm10.761.135a.5.5 0 0 1 .708 0l2.5 2.5a.5.5 0 0 1 0 .708l-2.5 2.5a.5.5 0 0 1-.708-.708L14.293 4H9.5a.5.5 0 0 1 0-1h4.793l-1.647-1.646a.5.5 0 0 1 0-.708z"/>'),Pw=d("TelephoneInbound",'<path d="M15.854.146a.5.5 0 0 1 0 .708L11.707 5H14.5a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 1 0v2.793L15.146.146a.5.5 0 0 1 .708 0zm-12.2 1.182a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>'),Iw=d("TelephoneInboundFill",'<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM15.854.146a.5.5 0 0 1 0 .708L11.707 5H14.5a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5v-4a.5.5 0 0 1 1 0v2.793L15.146.146a.5.5 0 0 1 .708 0z"/>'),Ew=d("TelephoneMinus",'<path fill-rule="evenodd" d="M10 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/><path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/>'),Lw=d("TelephoneMinusFill",'<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM10 3.5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 0 1h-4a.5.5 0 0 1-.5-.5z"/>'),Bw=d("TelephoneOutbound",'<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM11 .5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V1.707l-4.146 4.147a.5.5 0 0 1-.708-.708L14.293 1H11.5a.5.5 0 0 1-.5-.5z"/>'),Hw=d("TelephoneOutboundFill",'<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM11 .5a.5.5 0 0 1 .5-.5h4a.5.5 0 0 1 .5.5v4a.5.5 0 0 1-1 0V1.707l-4.146 4.147a.5.5 0 0 1-.708-.708L14.293 1H11.5a.5.5 0 0 1-.5-.5z"/>'),Fw=d("TelephonePlus",'<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/><path fill-rule="evenodd" d="M12.5 1a.5.5 0 0 1 .5.5V3h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V4h-1.5a.5.5 0 0 1 0-1H12V1.5a.5.5 0 0 1 .5-.5z"/>'),Dw=d("TelephonePlusFill",'<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zM12.5 1a.5.5 0 0 1 .5.5V3h1.5a.5.5 0 0 1 0 1H13v1.5a.5.5 0 0 1-1 0V4h-1.5a.5.5 0 0 1 0-1H12V1.5a.5.5 0 0 1 .5-.5z"/>'),Rw=d("TelephoneX",'<path d="M3.654 1.328a.678.678 0 0 0-1.015-.063L1.605 2.3c-.483.484-.661 1.169-.45 1.77a17.568 17.568 0 0 0 4.168 6.608 17.569 17.569 0 0 0 6.608 4.168c.601.211 1.286.033 1.77-.45l1.034-1.034a.678.678 0 0 0-.063-1.015l-2.307-1.794a.678.678 0 0 0-.58-.122l-2.19.547a1.745 1.745 0 0 1-1.657-.459L5.482 8.062a1.745 1.745 0 0 1-.46-1.657l.548-2.19a.678.678 0 0 0-.122-.58L3.654 1.328zM1.884.511a1.745 1.745 0 0 1 2.612.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511z"/><path fill-rule="evenodd" d="M11.146 1.646a.5.5 0 0 1 .708 0L13 2.793l1.146-1.147a.5.5 0 0 1 .708.708L13.707 3.5l1.147 1.146a.5.5 0 0 1-.708.708L13 4.207l-1.146 1.147a.5.5 0 0 1-.708-.708L12.293 3.5l-1.147-1.146a.5.5 0 0 1 0-.708z"/>'),Nw=d("TelephoneXFill",'<path fill-rule="evenodd" d="M1.885.511a1.745 1.745 0 0 1 2.61.163L6.29 2.98c.329.423.445.974.315 1.494l-.547 2.19a.678.678 0 0 0 .178.643l2.457 2.457a.678.678 0 0 0 .644.178l2.189-.547a1.745 1.745 0 0 1 1.494.315l2.306 1.794c.829.645.905 1.87.163 2.611l-1.034 1.034c-.74.74-1.846 1.065-2.877.702a18.634 18.634 0 0 1-7.01-4.42 18.634 18.634 0 0 1-4.42-7.009c-.362-1.03-.037-2.137.703-2.877L1.885.511zm9.261 1.135a.5.5 0 0 1 .708 0L13 2.793l1.146-1.147a.5.5 0 0 1 .708.708L13.707 3.5l1.147 1.146a.5.5 0 0 1-.708.708L13 4.207l-1.146 1.147a.5.5 0 0 1-.708-.708L12.293 3.5l-1.147-1.146a.5.5 0 0 1 0-.708z"/>'),$w=d("Terminal",'<path d="M6 9a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3A.5.5 0 0 1 6 9zM3.854 4.146a.5.5 0 1 0-.708.708L4.793 6.5 3.146 8.146a.5.5 0 1 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2z"/><path d="M2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2zm12 1a1 1 0 0 1 1 1v10a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h12z"/>'),Uw=d("TerminalFill",'<path d="M0 3a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3zm9.5 5.5h-3a.5.5 0 0 0 0 1h3a.5.5 0 0 0 0-1zm-6.354-.354a.5.5 0 1 0 .708.708l2-2a.5.5 0 0 0 0-.708l-2-2a.5.5 0 1 0-.708.708L4.793 6.5 3.146 8.146z"/>'),qw=d("TextCenter",'<path fill-rule="evenodd" d="M4 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm2-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-2-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Ww=d("TextIndentLeft",'<path d="M2 3.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm.646 2.146a.5.5 0 0 1 .708 0l2 2a.5.5 0 0 1 0 .708l-2 2a.5.5 0 0 1-.708-.708L4.293 8 2.646 6.354a.5.5 0 0 1 0-.708zM7 6.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm-5 3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Gw=d("TextIndentRight",'<path d="M2 3.5a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm10.646 2.146a.5.5 0 0 1 .708.708L11.707 8l1.647 1.646a.5.5 0 0 1-.708.708l-2-2a.5.5 0 0 1 0-.708l2-2zM2 6.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5zm0 3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Yw=d("TextLeft",'<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Kw=d("TextParagraph",'<path fill-rule="evenodd" d="M2 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm4-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5z"/>'),Qw=d("TextRight",'<path fill-rule="evenodd" d="M6 12.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-4-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5zm4-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm-4-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"/>'),Xw=d("Textarea",'<path d="M1.5 2.5A1.5 1.5 0 0 1 3 1h10a1.5 1.5 0 0 1 1.5 1.5v3.563a2 2 0 0 1 0 3.874V13.5A1.5 1.5 0 0 1 13 15H3a1.5 1.5 0 0 1-1.5-1.5V9.937a2 2 0 0 1 0-3.874V2.5zm1 3.563a2 2 0 0 1 0 3.874V13.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5V9.937a2 2 0 0 1 0-3.874V2.5A.5.5 0 0 0 13 2H3a.5.5 0 0 0-.5.5v3.563zM2 7a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm12 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>'),Jw=d("TextareaResize",'<path d="M.5 4A2.5 2.5 0 0 1 3 1.5h12A2.5 2.5 0 0 1 17.5 4v8a2.5 2.5 0 0 1-2.5 2.5H3A2.5 2.5 0 0 1 .5 12V4zM3 2.5A1.5 1.5 0 0 0 1.5 4v8A1.5 1.5 0 0 0 3 13.5h12a1.5 1.5 0 0 0 1.5-1.5V4A1.5 1.5 0 0 0 15 2.5H3zm11.854 5.646a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708-.708l3-3a.5.5 0 0 1 .708 0zm0 2.5a.5.5 0 0 1 0 .708l-.5.5a.5.5 0 0 1-.708-.708l.5-.5a.5.5 0 0 1 .708 0z"/>'),Zw=d("TextareaT",'<path d="M1.5 2.5A1.5 1.5 0 0 1 3 1h10a1.5 1.5 0 0 1 1.5 1.5v3.563a2 2 0 0 1 0 3.874V13.5A1.5 1.5 0 0 1 13 15H3a1.5 1.5 0 0 1-1.5-1.5V9.937a2 2 0 0 1 0-3.874V2.5zm1 3.563a2 2 0 0 1 0 3.874V13.5a.5.5 0 0 0 .5.5h10a.5.5 0 0 0 .5-.5V9.937a2 2 0 0 1 0-3.874V2.5A.5.5 0 0 0 13 2H3a.5.5 0 0 0-.5.5v3.563zM2 7a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm12 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/><path d="M11.434 4H4.566L4.5 5.994h.386c.21-1.252.612-1.446 2.173-1.495l.343-.011v6.343c0 .537-.116.665-1.049.748V12h3.294v-.421c-.938-.083-1.054-.21-1.054-.748V4.488l.348.01c1.56.05 1.963.244 2.173 1.496h.386L11.434 4z"/>'),ty=d("Thermometer",'<path d="M6 2a2 2 0 1 1 4 0v7.627a3.5 3.5 0 1 1-4 0V2zm2-1a1 1 0 0 0-1 1v7.901a.5.5 0 0 1-.25.433A2.499 2.499 0 0 0 8 15a2.5 2.5 0 0 0 1.25-4.666.5.5 0 0 1-.25-.433V2a1 1 0 0 0-1-1z"/><path d="M9.5 12.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),ey=d("ThermometerHalf",'<path d="M8 1.75a.25.25 0 0 1 .25.25v9.02a1.5 1.5 0 1 1-.5 0V2A.25.25 0 0 1 8 1.75z"/><path d="M6 2a2 2 0 1 1 4 0v7.627a3.5 3.5 0 1 1-4 0V2zm2-1a1 1 0 0 0-1 1v7.901a.5.5 0 0 1-.25.433A2.499 2.499 0 0 0 8 15a2.5 2.5 0 0 0 1.25-4.666.5.5 0 0 1-.25-.433V2a1 1 0 0 0-1-1z"/>'),ny=d("ThreeDots",'<path d="M3 9.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm5 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm5 0a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),ry=d("ThreeDotsVertical",'<path d="M9.5 13a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zm0-5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z"/>'),iy=d("Toggle2Off",'<path d="M9 11c.628-.836 1-1.874 1-3a4.978 4.978 0 0 0-1-3h4a3 3 0 1 1 0 6H9z"/><path d="M5 12a4 4 0 1 1 0-8 4 4 0 0 1 0 8zm0 1A5 5 0 1 0 5 3a5 5 0 0 0 0 10z"/>'),oy=d("Toggle2On",'<path d="M7 5H3a3 3 0 0 0 0 6h4a4.995 4.995 0 0 1-.584-1H3a2 2 0 1 1 0-4h3.416c.156-.357.352-.692.584-1z"/><path d="M16 8A5 5 0 1 1 6 8a5 5 0 0 1 10 0z"/>'),ay=d("ToggleOff",'<path d="M11 4a4 4 0 0 1 0 8H8a4.992 4.992 0 0 0 2-4 4.992 4.992 0 0 0-2-4h3zm-6 8a4 4 0 1 1 0-8 4 4 0 0 1 0 8zM0 8a5 5 0 0 0 5 5h6a5 5 0 0 0 0-10H5a5 5 0 0 0-5 5z"/>'),sy=d("ToggleOn",'<path d="M5 3a5 5 0 0 0 0 10h6a5 5 0 0 0 0-10H5zm6 9a4 4 0 1 1 0-8 4 4 0 0 1 0 8z"/>'),cy=d("Toggles",'<path d="M4.5 9a3.5 3.5 0 1 0 0 7h7a3.5 3.5 0 1 0 0-7h-7zm7 6a2.5 2.5 0 1 1 0-5 2.5 2.5 0 0 1 0 5zm-7-14a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5zm2.45 0A3.49 3.49 0 0 1 8 3.5 3.49 3.49 0 0 1 6.95 6h4.55a2.5 2.5 0 0 0 0-5H6.95zM4.5 0h7a3.5 3.5 0 1 1 0 7h-7a3.5 3.5 0 1 1 0-7z"/>'),ly=d("Toggles2",'<path d="M9.465 10H12a2 2 0 1 1 0 4H9.465c.34-.588.535-1.271.535-2 0-.729-.195-1.412-.535-2z"/><path d="M6 15a3 3 0 1 0 0-6 3 3 0 0 0 0 6zm0 1a4 4 0 1 1 0-8 4 4 0 0 1 0 8zm.535-10a3.975 3.975 0 0 1-.409-1H4a1 1 0 0 1 0-2h2.126c.091-.355.23-.69.41-1H4a2 2 0 1 0 0 4h2.535z"/><path d="M14 4a4 4 0 1 1-8 0 4 4 0 0 1 8 0z"/>'),uy=d("Tools",'<path d="M1 0L0 1l2.2 3.081a1 1 0 0 0 .815.419h.07a1 1 0 0 1 .708.293l2.675 2.675-2.617 2.654A3.003 3.003 0 0 0 0 13a3 3 0 1 0 5.878-.851l2.654-2.617.968.968-.305.914a1 1 0 0 0 .242 1.023l3.356 3.356a1 1 0 0 0 1.414 0l1.586-1.586a1 1 0 0 0 0-1.414l-3.356-3.356a1 1 0 0 0-1.023-.242L10.5 9.5l-.96-.96 2.68-2.643A3.005 3.005 0 0 0 16 3c0-.269-.035-.53-.102-.777l-2.14 2.141L12 4l-.364-1.757L13.777.102a3 3 0 0 0-3.675 3.68L7.462 6.46 4.793 3.793a1 1 0 0 1-.293-.707v-.071a1 1 0 0 0-.419-.814L1 0zm9.646 10.646a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708l-3-3a.5.5 0 0 1 0-.708zM3 11l.471.242.529.026.287.445.445.287.026.529L5 13l-.242.471-.026.529-.445.287-.287.445-.529.026L3 15l-.471-.242L2 14.732l-.287-.445L1.268 14l-.026-.529L1 13l.242-.471.026-.529.445-.287.287-.445.529-.026L3 11z"/>'),dy=d("Trash",'<path d="M5.5 5.5A.5.5 0 0 1 6 6v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm2.5 0a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm3 .5a.5.5 0 0 0-1 0v6a.5.5 0 0 0 1 0V6z"/><path fill-rule="evenodd" d="M14.5 3a1 1 0 0 1-1 1H13v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V4h-.5a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1H6a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1h3.5a1 1 0 0 1 1 1v1zM4.118 4L4 4.059V13a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1V4.059L11.882 4H4.118zM2.5 3V2h11v1h-11z"/>'),hy=d("Trash2",'<path d="M14 3a.702.702 0 0 1-.037.225l-1.684 10.104A2 2 0 0 1 10.305 15H5.694a2 2 0 0 1-1.973-1.671L2.037 3.225A.703.703 0 0 1 2 3c0-1.105 2.686-2 6-2s6 .895 6 2zM3.215 4.207l1.493 8.957a1 1 0 0 0 .986.836h4.612a1 1 0 0 0 .986-.836l1.493-8.957C11.69 4.689 9.954 5 8 5c-1.954 0-3.69-.311-4.785-.793z"/>'),fy=d("Trash2Fill",'<path d="M2.037 3.225A.703.703 0 0 1 2 3c0-1.105 2.686-2 6-2s6 .895 6 2a.702.702 0 0 1-.037.225l-1.684 10.104A2 2 0 0 1 10.305 15H5.694a2 2 0 0 1-1.973-1.671L2.037 3.225zm9.89-.69C10.966 2.214 9.578 2 8 2c-1.58 0-2.968.215-3.926.534-.477.16-.795.327-.975.466.18.14.498.307.975.466C5.032 3.786 6.42 4 8 4s2.967-.215 3.926-.534c.477-.16.795-.327.975-.466-.18-.14-.498-.307-.975-.466z"/>'),py=d("TrashFill",'<path d="M2.5 1a1 1 0 0 0-1 1v1a1 1 0 0 0 1 1H3v9a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2V4h.5a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H10a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1H2.5zm3 4a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 .5-.5zM8 5a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-1 0v-7A.5.5 0 0 1 8 5zm3 .5v7a.5.5 0 0 1-1 0v-7a.5.5 0 0 1 1 0z"/>'),my=d("Tree",'<path d="M8.416.223a.5.5 0 0 0-.832 0l-3 4.5A.5.5 0 0 0 5 5.5h.098L3.076 8.735A.5.5 0 0 0 3.5 9.5h.191l-1.638 3.276a.5.5 0 0 0 .447.724H7V16h2v-2.5h4.5a.5.5 0 0 0 .447-.724L12.31 9.5h.191a.5.5 0 0 0 .424-.765L10.902 5.5H11a.5.5 0 0 0 .416-.777l-3-4.5zM6.437 4.758A.5.5 0 0 0 6 4.5h-.066L8 1.401 10.066 4.5H10a.5.5 0 0 0-.424.765L11.598 8.5H11.5a.5.5 0 0 0-.447.724L12.69 12.5H3.309l1.638-3.276A.5.5 0 0 0 4.5 8.5h-.098l2.022-3.235a.5.5 0 0 0 .013-.507z"/>'),by=d("TreeFill",'<path d="M8.416.223a.5.5 0 0 0-.832 0l-3 4.5A.5.5 0 0 0 5 5.5h.098L3.076 8.735A.5.5 0 0 0 3.5 9.5h.191l-1.638 3.276a.5.5 0 0 0 .447.724H7V16h2v-2.5h4.5a.5.5 0 0 0 .447-.724L12.31 9.5h.191a.5.5 0 0 0 .424-.765L10.902 5.5H11a.5.5 0 0 0 .416-.777l-3-4.5z"/>'),gy=d("Triangle",'<path d="M7.938 2.016A.13.13 0 0 1 8.002 2a.13.13 0 0 1 .063.016.146.146 0 0 1 .054.057l6.857 11.667c.036.06.035.124.002.183a.163.163 0 0 1-.054.06.116.116 0 0 1-.066.017H1.146a.115.115 0 0 1-.066-.017.163.163 0 0 1-.054-.06.176.176 0 0 1 .002-.183L7.884 2.073a.147.147 0 0 1 .054-.057zm1.044-.45a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566z"/>'),vy=d("TriangleFill",'<path fill-rule="evenodd" d="M7.022 1.566a1.13 1.13 0 0 1 1.96 0l6.857 11.667c.457.778-.092 1.767-.98 1.767H1.144c-.889 0-1.437-.99-.98-1.767L7.022 1.566z"/>'),wy=d("TriangleHalf",'<path d="M8.065 2.016A.13.13 0 0 0 8.002 2v11.983l6.856.017a.12.12 0 0 0 .066-.017.162.162 0 0 0 .055-.06.177.177 0 0 0-.003-.183L8.12 2.073a.146.146 0 0 0-.054-.057zm-1.043-.45a1.13 1.13 0 0 1 1.96 0l6.857 11.667c.457.778-.092 1.767-.98 1.767H1.144c-.889 0-1.437-.99-.98-1.767L7.022 1.566z"/>'),yy=d("Trophy",'<path d="M2.5.5A.5.5 0 0 1 3 0h10a.5.5 0 0 1 .5.5c0 .538-.012 1.05-.034 1.536a3 3 0 1 1-1.133 5.89c-.79 1.865-1.878 2.777-2.833 3.011v2.173l1.425.356c.194.048.377.135.537.255L13.3 15.1a.5.5 0 0 1-.3.9H3a.5.5 0 0 1-.3-.9l1.838-1.379c.16-.12.343-.207.537-.255L6.5 13.11v-2.173c-.955-.234-2.043-1.146-2.833-3.012a3 3 0 1 1-1.132-5.89A33.076 33.076 0 0 1 2.5.5zm.099 2.54a2 2 0 0 0 .72 3.935c-.333-1.05-.588-2.346-.72-3.935zm10.083 3.935a2 2 0 0 0 .72-3.935c-.133 1.59-.388 2.885-.72 3.935zM3.504 1c.007.517.026 1.006.056 1.469.13 2.028.457 3.546.87 4.667C5.294 9.48 6.484 10 7 10a.5.5 0 0 1 .5.5v2.61a1 1 0 0 1-.757.97l-1.426.356a.5.5 0 0 0-.179.085L4.5 15h7l-.638-.479a.501.501 0 0 0-.18-.085l-1.425-.356a1 1 0 0 1-.757-.97V10.5A.5.5 0 0 1 9 10c.516 0 1.706-.52 2.57-2.864.413-1.12.74-2.64.87-4.667.03-.463.049-.952.056-1.469H3.504z"/>'),ky=d("TrophyFill",'<path d="M2.5.5A.5.5 0 0 1 3 0h10a.5.5 0 0 1 .5.5c0 .538-.012 1.05-.034 1.536a3 3 0 1 1-1.133 5.89c-.79 1.865-1.878 2.777-2.833 3.011v2.173l1.425.356c.194.048.377.135.537.255L13.3 15.1a.5.5 0 0 1-.3.9H3a.5.5 0 0 1-.3-.9l1.838-1.379c.16-.12.343-.207.537-.255L6.5 13.11v-2.173c-.955-.234-2.043-1.146-2.833-3.012a3 3 0 1 1-1.132-5.89A33.076 33.076 0 0 1 2.5.5zm.099 2.54a2 2 0 0 0 .72 3.935c-.333-1.05-.588-2.346-.72-3.935zm10.083 3.935a2 2 0 0 0 .72-3.935c-.133 1.59-.388 2.885-.72 3.935z"/>'),_y=d("Truck",'<path d="M0 3.5A1.5 1.5 0 0 1 1.5 2h9A1.5 1.5 0 0 1 12 3.5V5h1.02a1.5 1.5 0 0 1 1.17.563l1.481 1.85a1.5 1.5 0 0 1 .329.938V10.5a1.5 1.5 0 0 1-1.5 1.5H14a2 2 0 1 1-4 0H5a2 2 0 1 1-3.998-.085A1.5 1.5 0 0 1 0 10.5v-7zm1.294 7.456A1.999 1.999 0 0 1 4.732 11h5.536a2.01 2.01 0 0 1 .732-.732V3.5a.5.5 0 0 0-.5-.5h-9a.5.5 0 0 0-.5.5v7a.5.5 0 0 0 .294.456zM12 10a2 2 0 0 1 1.732 1h.768a.5.5 0 0 0 .5-.5V8.35a.5.5 0 0 0-.11-.312l-1.48-1.85A.5.5 0 0 0 13.02 6H12v4zm-9 1a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm9 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2z"/>'),Oy=d("TruckFlatbed",'<path d="M11.5 4a.5.5 0 0 1 .5.5V5h1.02a1.5 1.5 0 0 1 1.17.563l1.481 1.85a1.5 1.5 0 0 1 .329.938V10.5a1.5 1.5 0 0 1-1.5 1.5H14a2 2 0 1 1-4 0H5a2 2 0 1 1-4 0 1 1 0 0 1-1-1v-1h11V4.5a.5.5 0 0 1 .5-.5zM3 11a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm9 0a1 1 0 1 0 0 2 1 1 0 0 0 0-2zm1.732 0h.768a.5.5 0 0 0 .5-.5V8.35a.5.5 0 0 0-.11-.312l-1.48-1.85A.5.5 0 0 0 13.02 6H12v4a2 2 0 0 1 1.732 1z"/>'),zy=d("Tv",'<path d="M2.5 13.5A.5.5 0 0 1 3 13h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zM13.991 3l.024.001a1.46 1.46 0 0 1 .538.143.757.757 0 0 1 .302.254c.067.1.145.277.145.602v5.991l-.001.024a1.464 1.464 0 0 1-.143.538.758.758 0 0 1-.254.302c-.1.067-.277.145-.602.145H2.009l-.024-.001a1.464 1.464 0 0 1-.538-.143.758.758 0 0 1-.302-.254C1.078 10.502 1 10.325 1 10V4.009l.001-.024a1.46 1.46 0 0 1 .143-.538.758.758 0 0 1 .254-.302C1.498 3.078 1.675 3 2 3h11.991zM14 2H2C0 2 0 4 0 4v6c0 2 2 2 2 2h12c2 0 2-2 2-2V4c0-2-2-2-2-2z"/>'),Ay=d("TvFill",'<path d="M2.5 13.5A.5.5 0 0 1 3 13h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zM2 2h12s2 0 2 2v6s0 2-2 2H2s-2 0-2-2V4s0-2 2-2z"/>'),jy=d("Twitch",'<path d="M3.857 0L1 2.857v10.286h3.429V16l2.857-2.857H9.57L14.714 8V0H3.857zm9.714 7.429l-2.285 2.285H9l-2 2v-2H4.429V1.143h9.142v6.286z"/><path d="M11.857 3.143h-1.143V6.57h1.143V3.143zm-3.143 0H7.571V6.57h1.143V3.143z"/>'),My=d("Twitter",'<path d="M5.026 15c6.038 0 9.341-5.003 9.341-9.334 0-.14 0-.282-.006-.422A6.685 6.685 0 0 0 16 3.542a6.658 6.658 0 0 1-1.889.518 3.301 3.301 0 0 0 1.447-1.817 6.533 6.533 0 0 1-2.087.793A3.286 3.286 0 0 0 7.875 6.03a9.325 9.325 0 0 1-6.767-3.429 3.289 3.289 0 0 0 1.018 4.382A3.323 3.323 0 0 1 .64 6.575v.045a3.288 3.288 0 0 0 2.632 3.218 3.203 3.203 0 0 1-.865.115 3.23 3.23 0 0 1-.614-.057 3.283 3.283 0 0 0 3.067 2.277A6.588 6.588 0 0 1 .78 13.58a6.32 6.32 0 0 1-.78-.045A9.344 9.344 0 0 0 5.026 15z"/>'),Cy=d("Type",'<path d="M2.244 13.081l.943-2.803H6.66l.944 2.803H8.86L5.54 3.75H4.322L1 13.081h1.244zm2.7-7.923L6.34 9.314H3.51l1.4-4.156h.034zm9.146 7.027h.035v.896h1.128V8.125c0-1.51-1.114-2.345-2.646-2.345-1.736 0-2.59.916-2.666 2.174h1.108c.068-.718.595-1.19 1.517-1.19.971 0 1.518.52 1.518 1.464v.731H12.19c-1.647.007-2.522.8-2.522 2.058 0 1.319.957 2.18 2.345 2.18 1.06 0 1.716-.43 2.078-1.011zm-1.763.035c-.752 0-1.456-.397-1.456-1.244 0-.65.424-1.115 1.408-1.115h1.805v.834c0 .896-.752 1.525-1.757 1.525z"/>'),Vy=d("TypeBold",'<path d="M8.21 13c2.106 0 3.412-1.087 3.412-2.823 0-1.306-.984-2.283-2.324-2.386v-.055a2.176 2.176 0 0 0 1.852-2.14c0-1.51-1.162-2.46-3.014-2.46H3.843V13H8.21zM5.908 4.674h1.696c.963 0 1.517.451 1.517 1.244 0 .834-.629 1.32-1.73 1.32H5.908V4.673zm0 6.788V8.598h1.73c1.217 0 1.88.492 1.88 1.415 0 .943-.643 1.449-1.832 1.449H5.907z"/>'),Sy=d("TypeH1",'<path d="M8.637 13V3.669H7.379V7.62H2.758V3.67H1.5V13h1.258V8.728h4.62V13h1.259zm5.329 0V3.669h-1.244L10.5 5.316v1.265l2.16-1.565h.062V13h1.244z"/>'),xy=d("TypeH2",'<path d="M7.638 13V3.669H6.38V7.62H1.759V3.67H.5V13h1.258V8.728h4.62V13h1.259zm3.022-6.733v-.048c0-.889.63-1.668 1.716-1.668.957 0 1.675.608 1.675 1.572 0 .855-.554 1.504-1.067 2.085l-3.513 3.999V13H15.5v-1.094h-4.245v-.075l2.481-2.844c.875-.998 1.586-1.784 1.586-2.953 0-1.463-1.155-2.556-2.919-2.556-1.941 0-2.966 1.326-2.966 2.74v.049h1.223z"/>'),Ty=d("TypeH3",'<path d="M7.637 13V3.669H6.379V7.62H1.758V3.67H.5V13h1.258V8.728h4.62V13h1.259zm3.625-4.272h1.018c1.142 0 1.935.67 1.949 1.674.013 1.005-.78 1.737-2.01 1.73-1.08-.007-1.853-.588-1.935-1.32H9.108c.069 1.327 1.224 2.386 3.083 2.386 1.935 0 3.343-1.155 3.309-2.789-.027-1.51-1.251-2.16-2.037-2.249v-.068c.704-.123 1.764-.91 1.723-2.229-.035-1.353-1.176-2.4-2.954-2.385-1.873.006-2.857 1.162-2.898 2.358h1.196c.062-.69.711-1.299 1.696-1.299.998 0 1.695.622 1.695 1.525.007.922-.718 1.592-1.695 1.592h-.964v1.074z"/>'),Py=d("TypeItalic",'<path d="M7.991 11.674L9.53 4.455c.123-.595.246-.71 1.347-.807l.11-.52H7.211l-.11.52c1.06.096 1.128.212 1.005.807L6.57 11.674c-.123.595-.246.71-1.346.806l-.11.52h3.774l.11-.52c-1.06-.095-1.129-.211-1.006-.806z"/>'),Iy=d("TypeStrikethrough",'<path d="M6.333 5.686c0 .31.083.581.27.814H5.166a2.776 2.776 0 0 1-.099-.76c0-1.627 1.436-2.768 3.48-2.768 1.969 0 3.39 1.175 3.445 2.85h-1.23c-.11-1.08-.964-1.743-2.25-1.743-1.23 0-2.18.602-2.18 1.607zm2.194 7.478c-2.153 0-3.589-1.107-3.705-2.81h1.23c.144 1.06 1.129 1.703 2.544 1.703 1.34 0 2.31-.705 2.31-1.675 0-.827-.547-1.374-1.914-1.675L8.046 8.5H1v-1h14v1h-3.504c.468.437.675.994.675 1.697 0 1.826-1.436 2.967-3.644 2.967z"/>'),Ey=d("TypeUnderline",'<path d="M5.313 3.136h-1.23V9.54c0 2.105 1.47 3.623 3.917 3.623s3.917-1.518 3.917-3.623V3.136h-1.23v6.323c0 1.49-.978 2.57-2.687 2.57-1.709 0-2.687-1.08-2.687-2.57V3.136zM12.5 15h-9v-1h9v1z"/>'),Ly=d("UiChecks",'<path d="M7 2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zM2 1a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2zm0 8a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2v-2a2 2 0 0 0-2-2H2zm.854-3.646a.5.5 0 0 1-.708 0l-1-1a.5.5 0 1 1 .708-.708l.646.647 1.646-1.647a.5.5 0 1 1 .708.708l-2 2zm0 8a.5.5 0 0 1-.708 0l-1-1a.5.5 0 0 1 .708-.708l.646.647 1.646-1.647a.5.5 0 0 1 .708.708l-2 2zM7 10.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zm0-5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5z"/>'),By=d("UiChecksGrid",'<path d="M2 10h3a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1v-3a1 1 0 0 1 1-1zm9-9h3a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1h-3a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1zm0 9a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h3a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1h-3zm0-10a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h3a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2h-3zM2 9a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h3a2 2 0 0 0 2-2v-3a2 2 0 0 0-2-2H2zm7 2a2 2 0 0 1 2-2h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2h-3a2 2 0 0 1-2-2v-3zM0 2a2 2 0 0 1 2-2h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V2zm5.354.854a.5.5 0 1 0-.708-.708L3 3.793l-.646-.647a.5.5 0 1 0-.708.708l1 1a.5.5 0 0 0 .708 0l2-2z"/>'),Hy=d("UiRadios",'<path d="M7 2.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zM0 12a3 3 0 1 1 6 0 3 3 0 0 1-6 0zm7-1.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-7a.5.5 0 0 1-.5-.5v-1zm0-5a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zm0 8a.5.5 0 0 1 .5-.5h5a.5.5 0 0 1 0 1h-5a.5.5 0 0 1-.5-.5zM3 1a3 3 0 1 0 0 6 3 3 0 0 0 0-6zm0 4.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3z"/>'),Fy=d("UiRadiosGrid",'<path d="M3.5 15a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5zm9-9a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5zm0 9a2.5 2.5 0 1 1 0-5 2.5 2.5 0 0 1 0 5zM16 3.5a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0zm-9 9a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0zm5.5 3.5a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7zm-9-11a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3zm0 2a3.5 3.5 0 1 0 0-7 3.5 3.5 0 0 0 0 7z"/>'),Dy=d("Union",'<path d="M3 6a.5.5 0 0 0-.496.438l-.5 4A.5.5 0 0 0 2.5 11h3v2.016c-.863.055-1.5.251-1.5.484 0 .276.895.5 2 .5s2-.224 2-.5c0-.233-.637-.429-1.5-.484V11h3a.5.5 0 0 0 .496-.562l-.5-4A.5.5 0 0 0 9 6H3zm2 3.78V7.22c0-.096.106-.156.19-.106l2.13 1.279a.125.125 0 0 1 0 .214l-2.13 1.28A.125.125 0 0 1 5 9.778z"/><path d="M12 14V4.5L7.5 0H2a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2zM7.5 3A1.5 1.5 0 0 0 9 4.5h2V14a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h5.5v2z"/>'),Ry=d("Unlock",'<path d="M11 1a2 2 0 0 0-2 2v4a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V9a2 2 0 0 1 2-2h5V3a3 3 0 0 1 6 0v4a.5.5 0 0 1-1 0V3a2 2 0 0 0-2-2zM3 8a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1V9a1 1 0 0 0-1-1H3z"/>'),Ny=d("UnlockFill",'<path d="M11 1a2 2 0 0 0-2 2v4a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V9a2 2 0 0 1 2-2h5V3a3 3 0 0 1 6 0v4a.5.5 0 0 1-1 0V3a2 2 0 0 0-2-2z"/>'),$y=d("Upc",'<path d="M3 4.5a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-7zm3 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7z"/>'),Uy=d("UpcScan",'<path d="M1.5 1a.5.5 0 0 0-.5.5v3a.5.5 0 0 1-1 0v-3A1.5 1.5 0 0 1 1.5 0h3a.5.5 0 0 1 0 1h-3zM11 .5a.5.5 0 0 1 .5-.5h3A1.5 1.5 0 0 1 16 1.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 1-.5-.5zM.5 11a.5.5 0 0 1 .5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 1 0 1h-3A1.5 1.5 0 0 1 0 14.5v-3a.5.5 0 0 1 .5-.5zm15 0a.5.5 0 0 1 .5.5v3a1.5 1.5 0 0 1-1.5 1.5h-3a.5.5 0 0 1 0-1h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 1 .5-.5zM3 4.5a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7zm2 0a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v7a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-7zm3 0a.5.5 0 0 1 1 0v7a.5.5 0 0 1-1 0v-7z"/>'),qy=d("Upload",'<path d="M.5 9.9a.5.5 0 0 1 .5.5v2.5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0v2.5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5z"/><path d="M7.646 1.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1-.708.708L8.5 2.707V11.5a.5.5 0 0 1-1 0V2.707L5.354 4.854a.5.5 0 1 1-.708-.708l3-3z"/>'),Wy=d("VectorPen",'<path fill-rule="evenodd" d="M10.646.646a.5.5 0 0 1 .708 0l4 4a.5.5 0 0 1 0 .708l-1.902 1.902-.829 3.313a1.5 1.5 0 0 1-1.024 1.073L1.254 14.746 4.358 4.4A1.5 1.5 0 0 1 5.43 3.377l3.313-.828L10.646.646zm-1.8 2.908l-3.173.793a.5.5 0 0 0-.358.342l-2.57 8.565 8.567-2.57a.5.5 0 0 0 .34-.357l.794-3.174-3.6-3.6z"/><path fill-rule="evenodd" d="M2.832 13.228L8 9a1 1 0 1 0-1-1l-4.228 5.168-.026.086.086-.026z"/>'),Gy=d("ViewList",'<path d="M3 4.5h10a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2zm0 1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1H3zM1 2a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 2zm0 12a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13A.5.5 0 0 1 1 14z"/>'),Yy=d("ViewStacked",'<path d="M3 0h10a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V2a2 2 0 0 1 2-2zm0 1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1V2a1 1 0 0 0-1-1H3zm0 8h10a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2zm0 1a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h10a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1H3z"/>'),Ky=d("Vinyl",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M8 6a2 2 0 1 0 0 4 2 2 0 0 0 0-4zM4 8a4 4 0 1 1 8 0 4 4 0 0 1-8 0z"/><path d="M9 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0z"/>'),Qy=d("VinylFill",'<path d="M8 6a2 2 0 1 0 0 4 2 2 0 0 0 0-4zm0 3a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/><path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM4 8a4 4 0 1 0 8 0 4 4 0 0 0-8 0z"/>'),Xy=d("Voicemail",'<path d="M7 8.5A3.49 3.49 0 0 1 5.95 11h4.1a3.5 3.5 0 1 1 2.45 1h-9A3.5 3.5 0 1 1 7 8.5zm-6 0a2.5 2.5 0 1 0 5 0 2.5 2.5 0 0 0-5 0zm14 0a2.5 2.5 0 1 0-5 0 2.5 2.5 0 0 0 5 0z"/>'),Jy=d("VolumeDown",'<path d="M9 4a.5.5 0 0 0-.812-.39L5.825 5.5H3.5A.5.5 0 0 0 3 6v4a.5.5 0 0 0 .5.5h2.325l2.363 1.89A.5.5 0 0 0 9 12V4zM6.312 6.39L8 5.04v5.92L6.312 9.61A.5.5 0 0 0 6 9.5H4v-3h2a.5.5 0 0 0 .312-.11zM12.025 8a4.486 4.486 0 0 1-1.318 3.182L10 10.475A3.489 3.489 0 0 0 11.025 8 3.49 3.49 0 0 0 10 5.525l.707-.707A4.486 4.486 0 0 1 12.025 8z"/>'),Zy=d("VolumeDownFill",'<path d="M9 4a.5.5 0 0 0-.812-.39L5.825 5.5H3.5A.5.5 0 0 0 3 6v4a.5.5 0 0 0 .5.5h2.325l2.363 1.89A.5.5 0 0 0 9 12V4zm3.025 4a4.486 4.486 0 0 1-1.318 3.182L10 10.475A3.489 3.489 0 0 0 11.025 8 3.49 3.49 0 0 0 10 5.525l.707-.707A4.486 4.486 0 0 1 12.025 8z"/>'),tk=d("VolumeMute",'<path d="M6.717 3.55A.5.5 0 0 1 7 4v8a.5.5 0 0 1-.812.39L3.825 10.5H1.5A.5.5 0 0 1 1 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06zM6 5.04L4.312 6.39A.5.5 0 0 1 4 6.5H2v3h2a.5.5 0 0 1 .312.11L6 10.96V5.04zm7.854.606a.5.5 0 0 1 0 .708L12.207 8l1.647 1.646a.5.5 0 0 1-.708.708L11.5 8.707l-1.646 1.647a.5.5 0 0 1-.708-.708L10.793 8 9.146 6.354a.5.5 0 1 1 .708-.708L11.5 7.293l1.646-1.647a.5.5 0 0 1 .708 0z"/>'),ek=d("VolumeMuteFill",'<path d="M6.717 3.55A.5.5 0 0 1 7 4v8a.5.5 0 0 1-.812.39L3.825 10.5H1.5A.5.5 0 0 1 1 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06zm7.137 2.096a.5.5 0 0 1 0 .708L12.207 8l1.647 1.646a.5.5 0 0 1-.708.708L11.5 8.707l-1.646 1.647a.5.5 0 0 1-.708-.708L10.793 8 9.146 6.354a.5.5 0 1 1 .708-.708L11.5 7.293l1.646-1.647a.5.5 0 0 1 .708 0z"/>'),nk=d("VolumeOff",'<path d="M10.717 3.55A.5.5 0 0 1 11 4v8a.5.5 0 0 1-.812.39L7.825 10.5H5.5A.5.5 0 0 1 5 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06zM10 5.04L8.312 6.39A.5.5 0 0 1 8 6.5H6v3h2a.5.5 0 0 1 .312.11L10 10.96V5.04z"/>'),rk=d("VolumeOffFill",'<path d="M10.717 3.55A.5.5 0 0 1 11 4v8a.5.5 0 0 1-.812.39L7.825 10.5H5.5A.5.5 0 0 1 5 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06z"/>'),ik=d("VolumeUp",'<path d="M11.536 14.01A8.473 8.473 0 0 0 14.026 8a8.473 8.473 0 0 0-2.49-6.01l-.708.707A7.476 7.476 0 0 1 13.025 8c0 2.071-.84 3.946-2.197 5.303l.708.707z"/><path d="M10.121 12.596A6.48 6.48 0 0 0 12.025 8a6.48 6.48 0 0 0-1.904-4.596l-.707.707A5.483 5.483 0 0 1 11.025 8a5.483 5.483 0 0 1-1.61 3.89l.706.706z"/><path d="M10.025 8a4.486 4.486 0 0 1-1.318 3.182L8 10.475A3.489 3.489 0 0 0 9.025 8c0-.966-.392-1.841-1.025-2.475l.707-.707A4.486 4.486 0 0 1 10.025 8zM7 4a.5.5 0 0 0-.812-.39L3.825 5.5H1.5A.5.5 0 0 0 1 6v4a.5.5 0 0 0 .5.5h2.325l2.363 1.89A.5.5 0 0 0 7 12V4zM4.312 6.39L6 5.04v5.92L4.312 9.61A.5.5 0 0 0 4 9.5H2v-3h2a.5.5 0 0 0 .312-.11z"/>'),ok=d("VolumeUpFill",'<path d="M11.536 14.01A8.473 8.473 0 0 0 14.026 8a8.473 8.473 0 0 0-2.49-6.01l-.708.707A7.476 7.476 0 0 1 13.025 8c0 2.071-.84 3.946-2.197 5.303l.708.707z"/><path d="M10.121 12.596A6.48 6.48 0 0 0 12.025 8a6.48 6.48 0 0 0-1.904-4.596l-.707.707A5.483 5.483 0 0 1 11.025 8a5.483 5.483 0 0 1-1.61 3.89l.706.706z"/><path d="M8.707 11.182A4.486 4.486 0 0 0 10.025 8a4.486 4.486 0 0 0-1.318-3.182L8 5.525A3.489 3.489 0 0 1 9.025 8 3.49 3.49 0 0 1 8 10.475l.707.707zM6.717 3.55A.5.5 0 0 1 7 4v8a.5.5 0 0 1-.812.39L3.825 10.5H1.5A.5.5 0 0 1 1 10V6a.5.5 0 0 1 .5-.5h2.325l2.363-1.89a.5.5 0 0 1 .529-.06z"/>'),ak=d("Vr",'<path d="M3 12V4a1 1 0 0 1 1-1h2.5V2H4a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h2.5v-1H4a1 1 0 0 1-1-1zm6.5 1v1H12a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H9.5v1H12a1 1 0 0 1 1 1v8a1 1 0 0 1-1 1H9.5zM8 16a.5.5 0 0 1-.5-.5V.5a.5.5 0 0 1 1 0v15a.5.5 0 0 1-.5.5z"/>'),sk=d("Wallet",'<path d="M0 3a2 2 0 0 1 2-2h13.5a.5.5 0 0 1 0 1H15v2a1 1 0 0 1 1 1v8.5a1.5 1.5 0 0 1-1.5 1.5h-12A2.5 2.5 0 0 1 0 12.5V3zm1 1.732V12.5A1.5 1.5 0 0 0 2.5 14h12a.5.5 0 0 0 .5-.5V5H2a1.99 1.99 0 0 1-1-.268zM1 3a1 1 0 0 0 1 1h12V2H2a1 1 0 0 0-1 1z"/>'),ck=d("Wallet2",'<path d="M12.136.326A1.5 1.5 0 0 1 14 1.78V3h.5A1.5 1.5 0 0 1 16 4.5v9a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 13.5v-9a1.5 1.5 0 0 1 1.432-1.499L12.136.326zM5.562 3H13V1.78a.5.5 0 0 0-.621-.484L5.562 3zM1.5 4a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-13z"/>'),lk=d("WalletFill",'<path d="M1.5 2A1.5 1.5 0 0 0 0 3.5v2h6a.5.5 0 0 1 .5.5c0 .253.08.644.306.958.207.288.557.542 1.194.542.637 0 .987-.254 1.194-.542.226-.314.306-.705.306-.958a.5.5 0 0 1 .5-.5h6v-2A1.5 1.5 0 0 0 14.5 2h-13z"/><path d="M16 6.5h-5.551a2.678 2.678 0 0 1-.443 1.042C9.613 8.088 8.963 8.5 8 8.5c-.963 0-1.613-.412-2.006-.958A2.679 2.679 0 0 1 5.551 6.5H0v6A1.5 1.5 0 0 0 1.5 14h13a1.5 1.5 0 0 0 1.5-1.5v-6z"/>'),uk=d("Watch",'<path d="M8.5 5a.5.5 0 0 0-1 0v2.5H6a.5.5 0 0 0 0 1h2a.5.5 0 0 0 .5-.5V5z"/><path d="M5.667 16C4.747 16 4 15.254 4 14.333v-1.86A5.985 5.985 0 0 1 2 8c0-1.777.772-3.374 2-4.472V1.667C4 .747 4.746 0 5.667 0h4.666C11.253 0 12 .746 12 1.667v1.86a5.99 5.99 0 0 1 1.918 3.48.502.502 0 0 1 .582.493v1a.5.5 0 0 1-.582.493A5.99 5.99 0 0 1 12 12.473v1.86c0 .92-.746 1.667-1.667 1.667H5.667zM13 8A5 5 0 1 0 3 8a5 5 0 0 0 10 0z"/>'),dk=d("Wifi",'<path d="M15.385 6.115a.485.485 0 0 0-.048-.736A12.443 12.443 0 0 0 8 3 12.44 12.44 0 0 0 .663 5.379a.485.485 0 0 0-.048.736.518.518 0 0 0 .668.05A11.448 11.448 0 0 1 8 4c2.507 0 4.827.802 6.717 2.164.204.148.489.13.668-.049z"/><path d="M13.229 8.271c.216-.216.194-.578-.063-.745A9.456 9.456 0 0 0 8 6c-1.905 0-3.68.56-5.166 1.526a.48.48 0 0 0-.063.745.525.525 0 0 0 .652.065A8.46 8.46 0 0 1 8 7a8.46 8.46 0 0 1 4.577 1.336c.205.132.48.108.652-.065zm-2.183 2.183c.226-.226.185-.605-.1-.75A6.472 6.472 0 0 0 8 9c-1.06 0-2.062.254-2.946.704-.285.145-.326.524-.1.75l.015.015c.16.16.408.19.611.09A5.478 5.478 0 0 1 8 10c.868 0 1.69.201 2.42.56.203.1.45.07.611-.091l.015-.015zM9.06 12.44c.196-.196.198-.52-.04-.66A1.99 1.99 0 0 0 8 11.5a1.99 1.99 0 0 0-1.02.28c-.238.14-.236.464-.04.66l.706.706a.5.5 0 0 0 .708 0l.707-.707z"/>'),hk=d("Wifi1",'<path d="M11.046 10.454c.226-.226.185-.605-.1-.75A6.473 6.473 0 0 0 8 9c-1.06 0-2.062.254-2.946.704-.285.145-.326.524-.1.75l.015.015c.16.16.407.19.611.09A5.478 5.478 0 0 1 8 10c.868 0 1.69.201 2.42.56.203.1.45.07.611-.091l.015-.015zM9.06 12.44c.196-.196.198-.52-.04-.66A1.99 1.99 0 0 0 8 11.5a1.99 1.99 0 0 0-1.02.28c-.238.14-.236.464-.04.66l.706.706a.5.5 0 0 0 .707 0l.708-.707z"/>'),fk=d("Wifi2",'<path d="M13.229 8.271c.216-.216.194-.578-.063-.745A9.456 9.456 0 0 0 8 6c-1.905 0-3.68.56-5.166 1.526a.48.48 0 0 0-.063.745.525.525 0 0 0 .652.065A8.46 8.46 0 0 1 8 7a8.46 8.46 0 0 1 4.577 1.336c.205.132.48.108.652-.065zm-2.183 2.183c.226-.226.185-.605-.1-.75A6.473 6.473 0 0 0 8 9c-1.06 0-2.062.254-2.946.704-.285.145-.326.524-.1.75l.015.015c.16.16.408.19.611.09A5.478 5.478 0 0 1 8 10c.868 0 1.69.201 2.42.56.203.1.45.07.611-.091l.015-.015zM9.06 12.44c.196-.196.198-.52-.04-.66A1.99 1.99 0 0 0 8 11.5a1.99 1.99 0 0 0-1.02.28c-.238.14-.236.464-.04.66l.706.706a.5.5 0 0 0 .708 0l.707-.707z"/>'),pk=d("WifiOff",'<path d="M10.706 3.294A12.546 12.546 0 0 0 8 3 12.44 12.44 0 0 0 .663 5.379a.485.485 0 0 0-.048.736.518.518 0 0 0 .668.05A11.448 11.448 0 0 1 8 4c.63 0 1.249.05 1.852.148l.854-.854zM8 6c-1.905 0-3.68.56-5.166 1.526a.48.48 0 0 0-.063.745.525.525 0 0 0 .652.065 8.448 8.448 0 0 1 3.51-1.27L8 6zm2.596 1.404l.785-.785c.63.24 1.228.545 1.785.907a.482.482 0 0 1 .063.745.525.525 0 0 1-.652.065 8.462 8.462 0 0 0-1.98-.932zM8 10l.934-.933a6.454 6.454 0 0 1 2.012.637c.285.145.326.524.1.75l-.015.015a.532.532 0 0 1-.611.09A5.478 5.478 0 0 0 8 10zm4.905-4.905l.747-.747c.59.3 1.153.645 1.685 1.03a.485.485 0 0 1 .048.737.518.518 0 0 1-.668.05 11.496 11.496 0 0 0-1.812-1.07zM9.02 11.78c.238.14.236.464.04.66l-.706.706a.5.5 0 0 1-.708 0l-.707-.707c-.195-.195-.197-.518.04-.66A1.99 1.99 0 0 1 8 11.5c.373 0 .722.102 1.02.28zm4.355-9.905a.53.53 0 1 1 .75.75l-10.75 10.75a.53.53 0 0 1-.75-.75l10.75-10.75z"/>'),mk=d("Window",'<path d="M2.5 4a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1zm2-.5a.5.5 0 1 1-1 0 .5.5 0 0 1 1 0zm1 .5a.5.5 0 1 0 0-1 .5.5 0 0 0 0 1z"/><path d="M2 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V3a2 2 0 0 0-2-2H2zm13 2v2H1V3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1zM2 14a1 1 0 0 1-1-1V6h14v7a1 1 0 0 1-1 1H2z"/>'),bk=d("Wrench",'<path d="M.102 2.223A3.004 3.004 0 0 0 3.78 5.897l6.341 6.252A3.003 3.003 0 0 0 13 16a3 3 0 1 0-.851-5.878L5.897 3.781A3.004 3.004 0 0 0 2.223.1l2.141 2.142L4 4l-1.757.364L.102 2.223zm13.37 9.019l.528.026.287.445.445.287.026.529L15 13l-.242.471-.026.529-.445.287-.287.445-.529.026L13 15l-.471-.242-.529-.026-.287-.445-.445-.287-.026-.529L11 13l.242-.471.026-.529.445-.287.287-.445.529-.026L13 11l.471.242z"/>'),gk=d("X",'<path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>'),vk=d("XCircle",'<path d="M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z"/><path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>'),wk=d("XCircleFill",'<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zM5.354 4.646a.5.5 0 1 0-.708.708L7.293 8l-2.647 2.646a.5.5 0 0 0 .708.708L8 8.707l2.646 2.647a.5.5 0 0 0 .708-.708L8.707 8l2.647-2.646a.5.5 0 0 0-.708-.708L8 7.293 5.354 4.646z"/>'),yk=d("XDiamond",'<path d="M7.987 16a1.526 1.526 0 0 1-1.07-.448L.45 9.082a1.531 1.531 0 0 1 0-2.165L6.917.45a1.531 1.531 0 0 1 2.166 0l6.469 6.468A1.526 1.526 0 0 1 16 8.013a1.526 1.526 0 0 1-.448 1.07l-6.47 6.469A1.526 1.526 0 0 1 7.988 16zM7.639 1.17L4.766 4.044 8 7.278l3.234-3.234L8.361 1.17a.51.51 0 0 0-.722 0zM8.722 8l3.234 3.234 2.873-2.873c.2-.2.2-.523 0-.722l-2.873-2.873L8.722 8zM8 8.722l-3.234 3.234 2.873 2.873c.2.2.523.2.722 0l2.873-2.873L8 8.722zM7.278 8L4.044 4.766 1.17 7.639a.511.511 0 0 0 0 .722l2.874 2.873L7.278 8z"/>'),kk=d("XDiamondFill",'<path d="M9.05.435c-.58-.58-1.52-.58-2.1 0L4.047 3.339 8 7.293l3.954-3.954L9.049.435zm3.61 3.611L8.708 8l3.954 3.954 2.904-2.905c.58-.58.58-1.519 0-2.098l-2.904-2.905zm-.706 8.614L8 8.708l-3.954 3.954 2.905 2.904c.58.58 1.519.58 2.098 0l2.905-2.904zm-8.614-.706L7.292 8 3.339 4.046.435 6.951c-.58.58-.58 1.519 0 2.098l2.904 2.905z"/>'),_k=d("XOctagon",'<path d="M4.54.146A.5.5 0 0 1 4.893 0h6.214a.5.5 0 0 1 .353.146l4.394 4.394a.5.5 0 0 1 .146.353v6.214a.5.5 0 0 1-.146.353l-4.394 4.394a.5.5 0 0 1-.353.146H4.893a.5.5 0 0 1-.353-.146L.146 11.46A.5.5 0 0 1 0 11.107V4.893a.5.5 0 0 1 .146-.353L4.54.146zM5.1 1L1 5.1v5.8L5.1 15h5.8l4.1-4.1V5.1L10.9 1H5.1z"/><path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>'),Ok=d("XOctagonFill",'<path d="M11.46.146A.5.5 0 0 0 11.107 0H4.893a.5.5 0 0 0-.353.146L.146 4.54A.5.5 0 0 0 0 4.893v6.214a.5.5 0 0 0 .146.353l4.394 4.394a.5.5 0 0 0 .353.146h6.214a.5.5 0 0 0 .353-.146l4.394-4.394a.5.5 0 0 0 .146-.353V4.893a.5.5 0 0 0-.146-.353L11.46.146zm-6.106 4.5L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 1 1 .708-.708z"/>'),zk=d("XSquare",'<path d="M14 1a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1h12zM2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2z"/><path d="M4.646 4.646a.5.5 0 0 1 .708 0L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 0 1 0-.708z"/>'),Ak=d("XSquareFill",'<path d="M2 0a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V2a2 2 0 0 0-2-2H2zm3.354 4.646L8 7.293l2.646-2.647a.5.5 0 0 1 .708.708L8.707 8l2.647 2.646a.5.5 0 0 1-.708.708L8 8.707l-2.646 2.647a.5.5 0 0 1-.708-.708L7.293 8 4.646 5.354a.5.5 0 1 1 .708-.708z"/>'),jk=d("Youtube",'<path d="M8.051 1.999h.089c.822.003 4.987.033 6.11.335a2.01 2.01 0 0 1 1.415 1.42c.101.38.172.883.22 1.402l.01.104.022.26.008.104c.065.914.073 1.77.074 1.957v.075c-.001.194-.01 1.108-.082 2.06l-.008.105-.009.104c-.05.572-.124 1.14-.235 1.558a2.007 2.007 0 0 1-1.415 1.42c-1.16.312-5.569.334-6.18.335h-.142c-.309 0-1.587-.006-2.927-.052l-.17-.006-.087-.004-.171-.007-.171-.007c-1.11-.049-2.167-.128-2.654-.26a2.007 2.007 0 0 1-1.415-1.419c-.111-.417-.185-.986-.235-1.558L.09 9.82l-.008-.104A31.4 31.4 0 0 1 0 7.68v-.122C.002 7.343.01 6.6.064 5.78l.007-.103.003-.052.008-.104.022-.26.01-.104c.048-.519.119-1.023.22-1.402a2.007 2.007 0 0 1 1.415-1.42c.487-.13 1.544-.21 2.654-.26l.17-.007.172-.006.086-.003.171-.007A99.788 99.788 0 0 1 7.858 2h.193zM6.4 5.209v4.818l4.157-2.408L6.4 5.209z"/>'),Mk=d("ZoomIn",'<path fill-rule="evenodd" d="M6.5 12a5.5 5.5 0 1 0 0-11 5.5 5.5 0 0 0 0 11zM13 6.5a6.5 6.5 0 1 1-13 0 6.5 6.5 0 0 1 13 0z"/><path d="M10.344 11.742c.03.04.062.078.098.115l3.85 3.85a1 1 0 0 0 1.415-1.414l-3.85-3.85a1.007 1.007 0 0 0-.115-.1 6.538 6.538 0 0 1-1.398 1.4z"/><path fill-rule="evenodd" d="M6.5 3a.5.5 0 0 1 .5.5V6h2.5a.5.5 0 0 1 0 1H7v2.5a.5.5 0 0 1-1 0V7H3.5a.5.5 0 0 1 0-1H6V3.5a.5.5 0 0 1 .5-.5z"/>'),Ck=d("ZoomOut",'<path fill-rule="evenodd" d="M6.5 12a5.5 5.5 0 1 0 0-11 5.5 5.5 0 0 0 0 11zM13 6.5a6.5 6.5 0 1 1-13 0 6.5 6.5 0 0 1 13 0z"/><path d="M10.344 11.742c.03.04.062.078.098.115l3.85 3.85a1 1 0 0 0 1.415-1.414l-3.85-3.85a1.007 1.007 0 0 0-.115-.1 6.538 6.538 0 0 1-1.398 1.4z"/><path fill-rule="evenodd" d="M3 6.5a.5.5 0 0 1 .5-.5h6a.5.5 0 0 1 0 1h-6a.5.5 0 0 1-.5-.5z"/>');
/*!
 * BootstrapVue Icons, generated from Bootstrap Icons 1.2.2
 *
 * @link https://icons.getbootstrap.com/
 * @license MIT
 * https://github.com/twbs/icons/blob/master/LICENSE.md
 */},"7a77":function(t,e,n){"use strict";function r(t){this.message=t}r.prototype.toString=function(){return"Cancel"+(this.message?": "+this.message:"")},r.prototype.__CANCEL__=!0,t.exports=r},"7aac":function(t,e,n){"use strict";var r=n("c532");t.exports=r.isStandardBrowserEnv()?function(){return{write:function(t,e,n,i,o,a){var s=[];s.push(t+"="+encodeURIComponent(e)),r.isNumber(n)&&s.push("expires="+new Date(n).toGMTString()),r.isString(i)&&s.push("path="+i),r.isString(o)&&s.push("domain="+o),!0===a&&s.push("secure"),document.cookie=s.join("; ")},read:function(t){var e=document.cookie.match(new RegExp("(^|;\\s*)("+t+")=([^;]*)"));return e?decodeURIComponent(e[3]):null},remove:function(t){this.write(t,"",Date.now()-864e5)}}}():function(){return{write:function(){},read:function(){return null},remove:function(){}}}()},"7b1e":function(t,e,n){"use strict";n.d(e,"o",(function(){return c})),n.d(e,"g",(function(){return l})),n.d(e,"p",(function(){return u})),n.d(e,"f",(function(){return d})),n.d(e,"b",(function(){return h})),n.d(e,"n",(function(){return f})),n.d(e,"h",(function(){return p})),n.d(e,"i",(function(){return m})),n.d(e,"a",(function(){return b})),n.d(e,"j",(function(){return g})),n.d(e,"k",(function(){return v})),n.d(e,"c",(function(){return w})),n.d(e,"d",(function(){return y})),n.d(e,"e",(function(){return k})),n.d(e,"m",(function(){return _})),n.d(e,"l",(function(){return O}));var r=n("992e"),i=n("ca88");function o(t){return o="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"===typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},o(t)}var a=function(t){return o(t)},s=function(t){return Object.prototype.toString.call(t).slice(8,-1)},c=function(t){return void 0===t},l=function(t){return null===t},u=function(t){return c(t)||l(t)},d=function(t){return"function"===a(t)},h=function(t){return"boolean"===a(t)},f=function(t){return"string"===a(t)},p=function(t){return"number"===a(t)},m=function(t){return r["s"].test(String(t))},b=function(t){return Array.isArray(t)},g=function(t){return null!==t&&"object"===o(t)},v=function(t){return"[object Object]"===Object.prototype.toString.call(t)},w=function(t){return t instanceof Date},y=function(t){return t instanceof Event},k=function(t){return t instanceof i["b"]},_=function(t){return"RegExp"===s(t)},O=function(t){return!u(t)&&d(t.then)&&d(t.catch)}},"83b9":function(t,e,n){"use strict";var r=n("d925"),i=n("e683");t.exports=function(t,e){return t&&!r(e)?i(t,e):e}},"8c4f":function(t,e,n){"use strict";
/*!
  * vue-router v3.5.1
  * (c) 2021 Evan You
  * @license MIT
  */function r(t,e){0}function i(t,e){for(var n in e)t[n]=e[n];return t}var o=/[!'()*]/g,a=function(t){return"%"+t.charCodeAt(0).toString(16)},s=/%2C/g,c=function(t){return encodeURIComponent(t).replace(o,a).replace(s,",")};function l(t){try{return decodeURIComponent(t)}catch(e){0}return t}function u(t,e,n){void 0===e&&(e={});var r,i=n||h;try{r=i(t||"")}catch(s){r={}}for(var o in e){var a=e[o];r[o]=Array.isArray(a)?a.map(d):d(a)}return r}var d=function(t){return null==t||"object"===typeof t?t:String(t)};function h(t){var e={};return t=t.trim().replace(/^(\?|#|&)/,""),t?(t.split("&").forEach((function(t){var n=t.replace(/\+/g," ").split("="),r=l(n.shift()),i=n.length>0?l(n.join("=")):null;void 0===e[r]?e[r]=i:Array.isArray(e[r])?e[r].push(i):e[r]=[e[r],i]})),e):e}function f(t){var e=t?Object.keys(t).map((function(e){var n=t[e];if(void 0===n)return"";if(null===n)return c(e);if(Array.isArray(n)){var r=[];return n.forEach((function(t){void 0!==t&&(null===t?r.push(c(e)):r.push(c(e)+"="+c(t)))})),r.join("&")}return c(e)+"="+c(n)})).filter((function(t){return t.length>0})).join("&"):null;return e?"?"+e:""}var p=/\/?$/;function m(t,e,n,r){var i=r&&r.options.stringifyQuery,o=e.query||{};try{o=b(o)}catch(s){}var a={name:e.name||t&&t.name,meta:t&&t.meta||{},path:e.path||"/",hash:e.hash||"",query:o,params:e.params||{},fullPath:w(e,i),matched:t?v(t):[]};return n&&(a.redirectedFrom=w(n,i)),Object.freeze(a)}function b(t){if(Array.isArray(t))return t.map(b);if(t&&"object"===typeof t){var e={};for(var n in t)e[n]=b(t[n]);return e}return t}var g=m(null,{path:"/"});function v(t){var e=[];while(t)e.unshift(t),t=t.parent;return e}function w(t,e){var n=t.path,r=t.query;void 0===r&&(r={});var i=t.hash;void 0===i&&(i="");var o=e||f;return(n||"/")+o(r)+i}function y(t,e,n){return e===g?t===e:!!e&&(t.path&&e.path?t.path.replace(p,"")===e.path.replace(p,"")&&(n||t.hash===e.hash&&k(t.query,e.query)):!(!t.name||!e.name)&&(t.name===e.name&&(n||t.hash===e.hash&&k(t.query,e.query)&&k(t.params,e.params))))}function k(t,e){if(void 0===t&&(t={}),void 0===e&&(e={}),!t||!e)return t===e;var n=Object.keys(t).sort(),r=Object.keys(e).sort();return n.length===r.length&&n.every((function(n,i){var o=t[n],a=r[i];if(a!==n)return!1;var s=e[n];return null==o||null==s?o===s:"object"===typeof o&&"object"===typeof s?k(o,s):String(o)===String(s)}))}function _(t,e){return 0===t.path.replace(p,"/").indexOf(e.path.replace(p,"/"))&&(!e.hash||t.hash===e.hash)&&O(t.query,e.query)}function O(t,e){for(var n in e)if(!(n in t))return!1;return!0}function z(t){for(var e=0;e<t.matched.length;e++){var n=t.matched[e];for(var r in n.instances){var i=n.instances[r],o=n.enteredCbs[r];if(i&&o){delete n.enteredCbs[r];for(var a=0;a<o.length;a++)i._isBeingDestroyed||o[a](i)}}}}var A={name:"RouterView",functional:!0,props:{name:{type:String,default:"default"}},render:function(t,e){var n=e.props,r=e.children,o=e.parent,a=e.data;a.routerView=!0;var s=o.$createElement,c=n.name,l=o.$route,u=o._routerViewCache||(o._routerViewCache={}),d=0,h=!1;while(o&&o._routerRoot!==o){var f=o.$vnode?o.$vnode.data:{};f.routerView&&d++,f.keepAlive&&o._directInactive&&o._inactive&&(h=!0),o=o.$parent}if(a.routerViewDepth=d,h){var p=u[c],m=p&&p.component;return m?(p.configProps&&j(m,a,p.route,p.configProps),s(m,a,r)):s()}var b=l.matched[d],g=b&&b.components[c];if(!b||!g)return u[c]=null,s();u[c]={component:g},a.registerRouteInstance=function(t,e){var n=b.instances[c];(e&&n!==t||!e&&n===t)&&(b.instances[c]=e)},(a.hook||(a.hook={})).prepatch=function(t,e){b.instances[c]=e.componentInstance},a.hook.init=function(t){t.data.keepAlive&&t.componentInstance&&t.componentInstance!==b.instances[c]&&(b.instances[c]=t.componentInstance),z(l)};var v=b.props&&b.props[c];return v&&(i(u[c],{route:l,configProps:v}),j(g,a,l,v)),s(g,a,r)}};function j(t,e,n,r){var o=e.props=M(n,r);if(o){o=e.props=i({},o);var a=e.attrs=e.attrs||{};for(var s in o)t.props&&s in t.props||(a[s]=o[s],delete o[s])}}function M(t,e){switch(typeof e){case"undefined":return;case"object":return e;case"function":return e(t);case"boolean":return e?t.params:void 0;default:0}}function C(t,e,n){var r=t.charAt(0);if("/"===r)return t;if("?"===r||"#"===r)return e+t;var i=e.split("/");n&&i[i.length-1]||i.pop();for(var o=t.replace(/^\//,"").split("/"),a=0;a<o.length;a++){var s=o[a];".."===s?i.pop():"."!==s&&i.push(s)}return""!==i[0]&&i.unshift(""),i.join("/")}function V(t){var e="",n="",r=t.indexOf("#");r>=0&&(e=t.slice(r),t=t.slice(0,r));var i=t.indexOf("?");return i>=0&&(n=t.slice(i+1),t=t.slice(0,i)),{path:t,query:n,hash:e}}function S(t){return t.replace(/\/\//g,"/")}var x=Array.isArray||function(t){return"[object Array]"==Object.prototype.toString.call(t)},T=X,P=H,I=F,E=N,L=Q,B=new RegExp(["(\\\\.)","([\\/.])?(?:(?:\\:(\\w+)(?:\\(((?:\\\\.|[^\\\\()])+)\\))?|\\(((?:\\\\.|[^\\\\()])+)\\))([+*?])?|(\\*))"].join("|"),"g");function H(t,e){var n,r=[],i=0,o=0,a="",s=e&&e.delimiter||"/";while(null!=(n=B.exec(t))){var c=n[0],l=n[1],u=n.index;if(a+=t.slice(o,u),o=u+c.length,l)a+=l[1];else{var d=t[o],h=n[2],f=n[3],p=n[4],m=n[5],b=n[6],g=n[7];a&&(r.push(a),a="");var v=null!=h&&null!=d&&d!==h,w="+"===b||"*"===b,y="?"===b||"*"===b,k=n[2]||s,_=p||m;r.push({name:f||i++,prefix:h||"",delimiter:k,optional:y,repeat:w,partial:v,asterisk:!!g,pattern:_?U(_):g?".*":"[^"+$(k)+"]+?"})}}return o<t.length&&(a+=t.substr(o)),a&&r.push(a),r}function F(t,e){return N(H(t,e),e)}function D(t){return encodeURI(t).replace(/[\/?#]/g,(function(t){return"%"+t.charCodeAt(0).toString(16).toUpperCase()}))}function R(t){return encodeURI(t).replace(/[?#]/g,(function(t){return"%"+t.charCodeAt(0).toString(16).toUpperCase()}))}function N(t,e){for(var n=new Array(t.length),r=0;r<t.length;r++)"object"===typeof t[r]&&(n[r]=new RegExp("^(?:"+t[r].pattern+")$",W(e)));return function(e,r){for(var i="",o=e||{},a=r||{},s=a.pretty?D:encodeURIComponent,c=0;c<t.length;c++){var l=t[c];if("string"!==typeof l){var u,d=o[l.name];if(null==d){if(l.optional){l.partial&&(i+=l.prefix);continue}throw new TypeError('Expected "'+l.name+'" to be defined')}if(x(d)){if(!l.repeat)throw new TypeError('Expected "'+l.name+'" to not repeat, but received `'+JSON.stringify(d)+"`");if(0===d.length){if(l.optional)continue;throw new TypeError('Expected "'+l.name+'" to not be empty')}for(var h=0;h<d.length;h++){if(u=s(d[h]),!n[c].test(u))throw new TypeError('Expected all "'+l.name+'" to match "'+l.pattern+'", but received `'+JSON.stringify(u)+"`");i+=(0===h?l.prefix:l.delimiter)+u}}else{if(u=l.asterisk?R(d):s(d),!n[c].test(u))throw new TypeError('Expected "'+l.name+'" to match "'+l.pattern+'", but received "'+u+'"');i+=l.prefix+u}}else i+=l}return i}}function $(t){return t.replace(/([.+*?=^!:${}()[\]|\/\\])/g,"\\$1")}function U(t){return t.replace(/([=!:$\/()])/g,"\\$1")}function q(t,e){return t.keys=e,t}function W(t){return t&&t.sensitive?"":"i"}function G(t,e){var n=t.source.match(/\((?!\?)/g);if(n)for(var r=0;r<n.length;r++)e.push({name:r,prefix:null,delimiter:null,optional:!1,repeat:!1,partial:!1,asterisk:!1,pattern:null});return q(t,e)}function Y(t,e,n){for(var r=[],i=0;i<t.length;i++)r.push(X(t[i],e,n).source);var o=new RegExp("(?:"+r.join("|")+")",W(n));return q(o,e)}function K(t,e,n){return Q(H(t,n),e,n)}function Q(t,e,n){x(e)||(n=e||n,e=[]),n=n||{};for(var r=n.strict,i=!1!==n.end,o="",a=0;a<t.length;a++){var s=t[a];if("string"===typeof s)o+=$(s);else{var c=$(s.prefix),l="(?:"+s.pattern+")";e.push(s),s.repeat&&(l+="(?:"+c+l+")*"),l=s.optional?s.partial?c+"("+l+")?":"(?:"+c+"("+l+"))?":c+"("+l+")",o+=l}}var u=$(n.delimiter||"/"),d=o.slice(-u.length)===u;return r||(o=(d?o.slice(0,-u.length):o)+"(?:"+u+"(?=$))?"),o+=i?"$":r&&d?"":"(?="+u+"|$)",q(new RegExp("^"+o,W(n)),e)}function X(t,e,n){return x(e)||(n=e||n,e=[]),n=n||{},t instanceof RegExp?G(t,e):x(t)?Y(t,e,n):K(t,e,n)}T.parse=P,T.compile=I,T.tokensToFunction=E,T.tokensToRegExp=L;var J=Object.create(null);function Z(t,e,n){e=e||{};try{var r=J[t]||(J[t]=T.compile(t));return"string"===typeof e.pathMatch&&(e[0]=e.pathMatch),r(e,{pretty:!0})}catch(i){return""}finally{delete e[0]}}function tt(t,e,n,r){var o="string"===typeof t?{path:t}:t;if(o._normalized)return o;if(o.name){o=i({},t);var a=o.params;return a&&"object"===typeof a&&(o.params=i({},a)),o}if(!o.path&&o.params&&e){o=i({},o),o._normalized=!0;var s=i(i({},e.params),o.params);if(e.name)o.name=e.name,o.params=s;else if(e.matched.length){var c=e.matched[e.matched.length-1].path;o.path=Z(c,s,"path "+e.path)}else 0;return o}var l=V(o.path||""),d=e&&e.path||"/",h=l.path?C(l.path,d,n||o.append):d,f=u(l.query,o.query,r&&r.options.parseQuery),p=o.hash||l.hash;return p&&"#"!==p.charAt(0)&&(p="#"+p),{_normalized:!0,path:h,query:f,hash:p}}var et,nt=[String,Object],rt=[String,Array],it=function(){},ot={name:"RouterLink",props:{to:{type:nt,required:!0},tag:{type:String,default:"a"},custom:Boolean,exact:Boolean,exactPath:Boolean,append:Boolean,replace:Boolean,activeClass:String,exactActiveClass:String,ariaCurrentValue:{type:String,default:"page"},event:{type:rt,default:"click"}},render:function(t){var e=this,n=this.$router,r=this.$route,o=n.resolve(this.to,r,this.append),a=o.location,s=o.route,c=o.href,l={},u=n.options.linkActiveClass,d=n.options.linkExactActiveClass,h=null==u?"router-link-active":u,f=null==d?"router-link-exact-active":d,p=null==this.activeClass?h:this.activeClass,b=null==this.exactActiveClass?f:this.exactActiveClass,g=s.redirectedFrom?m(null,tt(s.redirectedFrom),null,n):s;l[b]=y(r,g,this.exactPath),l[p]=this.exact||this.exactPath?l[b]:_(r,g);var v=l[b]?this.ariaCurrentValue:null,w=function(t){at(t)&&(e.replace?n.replace(a,it):n.push(a,it))},k={click:at};Array.isArray(this.event)?this.event.forEach((function(t){k[t]=w})):k[this.event]=w;var O={class:l},z=!this.$scopedSlots.$hasNormal&&this.$scopedSlots.default&&this.$scopedSlots.default({href:c,route:s,navigate:w,isActive:l[p],isExactActive:l[b]});if(z){if(1===z.length)return z[0];if(z.length>1||!z.length)return 0===z.length?t():t("span",{},z)}if("a"===this.tag)O.on=k,O.attrs={href:c,"aria-current":v};else{var A=st(this.$slots.default);if(A){A.isStatic=!1;var j=A.data=i({},A.data);for(var M in j.on=j.on||{},j.on){var C=j.on[M];M in k&&(j.on[M]=Array.isArray(C)?C:[C])}for(var V in k)V in j.on?j.on[V].push(k[V]):j.on[V]=w;var S=A.data.attrs=i({},A.data.attrs);S.href=c,S["aria-current"]=v}else O.on=k}return t(this.tag,O,this.$slots.default)}};function at(t){if(!(t.metaKey||t.altKey||t.ctrlKey||t.shiftKey)&&!t.defaultPrevented&&(void 0===t.button||0===t.button)){if(t.currentTarget&&t.currentTarget.getAttribute){var e=t.currentTarget.getAttribute("target");if(/\b_blank\b/i.test(e))return}return t.preventDefault&&t.preventDefault(),!0}}function st(t){if(t)for(var e,n=0;n<t.length;n++){if(e=t[n],"a"===e.tag)return e;if(e.children&&(e=st(e.children)))return e}}function ct(t){if(!ct.installed||et!==t){ct.installed=!0,et=t;var e=function(t){return void 0!==t},n=function(t,n){var r=t.$options._parentVnode;e(r)&&e(r=r.data)&&e(r=r.registerRouteInstance)&&r(t,n)};t.mixin({beforeCreate:function(){e(this.$options.router)?(this._routerRoot=this,this._router=this.$options.router,this._router.init(this),t.util.defineReactive(this,"_route",this._router.history.current)):this._routerRoot=this.$parent&&this.$parent._routerRoot||this,n(this,this)},destroyed:function(){n(this)}}),Object.defineProperty(t.prototype,"$router",{get:function(){return this._routerRoot._router}}),Object.defineProperty(t.prototype,"$route",{get:function(){return this._routerRoot._route}}),t.component("RouterView",A),t.component("RouterLink",ot);var r=t.config.optionMergeStrategies;r.beforeRouteEnter=r.beforeRouteLeave=r.beforeRouteUpdate=r.created}}var lt="undefined"!==typeof window;function ut(t,e,n,r,i){var o=e||[],a=n||Object.create(null),s=r||Object.create(null);t.forEach((function(t){dt(o,a,s,t,i)}));for(var c=0,l=o.length;c<l;c++)"*"===o[c]&&(o.push(o.splice(c,1)[0]),l--,c--);return{pathList:o,pathMap:a,nameMap:s}}function dt(t,e,n,r,i,o){var a=r.path,s=r.name;var c=r.pathToRegexpOptions||{},l=ft(a,i,c.strict);"boolean"===typeof r.caseSensitive&&(c.sensitive=r.caseSensitive);var u={path:l,regex:ht(l,c),components:r.components||{default:r.component},alias:r.alias?"string"===typeof r.alias?[r.alias]:r.alias:[],instances:{},enteredCbs:{},name:s,parent:i,matchAs:o,redirect:r.redirect,beforeEnter:r.beforeEnter,meta:r.meta||{},props:null==r.props?{}:r.components?r.props:{default:r.props}};if(r.children&&r.children.forEach((function(r){var i=o?S(o+"/"+r.path):void 0;dt(t,e,n,r,u,i)})),e[u.path]||(t.push(u.path),e[u.path]=u),void 0!==r.alias)for(var d=Array.isArray(r.alias)?r.alias:[r.alias],h=0;h<d.length;++h){var f=d[h];0;var p={path:f,children:r.children};dt(t,e,n,p,i,u.path||"/")}s&&(n[s]||(n[s]=u))}function ht(t,e){var n=T(t,[],e);return n}function ft(t,e,n){return n||(t=t.replace(/\/$/,"")),"/"===t[0]||null==e?t:S(e.path+"/"+t)}function pt(t,e){var n=ut(t),r=n.pathList,i=n.pathMap,o=n.nameMap;function a(t){ut(t,r,i,o)}function s(t,e){var n="object"!==typeof t?o[t]:void 0;ut([e||t],r,i,o,n),n&&ut(n.alias.map((function(t){return{path:t,children:[e]}})),r,i,o,n)}function c(){return r.map((function(t){return i[t]}))}function l(t,n,a){var s=tt(t,n,!1,e),c=s.name;if(c){var l=o[c];if(!l)return h(null,s);var u=l.regex.keys.filter((function(t){return!t.optional})).map((function(t){return t.name}));if("object"!==typeof s.params&&(s.params={}),n&&"object"===typeof n.params)for(var d in n.params)!(d in s.params)&&u.indexOf(d)>-1&&(s.params[d]=n.params[d]);return s.path=Z(l.path,s.params,'named route "'+c+'"'),h(l,s,a)}if(s.path){s.params={};for(var f=0;f<r.length;f++){var p=r[f],m=i[p];if(mt(m.regex,s.path,s.params))return h(m,s,a)}}return h(null,s)}function u(t,n){var r=t.redirect,i="function"===typeof r?r(m(t,n,null,e)):r;if("string"===typeof i&&(i={path:i}),!i||"object"!==typeof i)return h(null,n);var a=i,s=a.name,c=a.path,u=n.query,d=n.hash,f=n.params;if(u=a.hasOwnProperty("query")?a.query:u,d=a.hasOwnProperty("hash")?a.hash:d,f=a.hasOwnProperty("params")?a.params:f,s){o[s];return l({_normalized:!0,name:s,query:u,hash:d,params:f},void 0,n)}if(c){var p=bt(c,t),b=Z(p,f,'redirect route with path "'+p+'"');return l({_normalized:!0,path:b,query:u,hash:d},void 0,n)}return h(null,n)}function d(t,e,n){var r=Z(n,e.params,'aliased route with path "'+n+'"'),i=l({_normalized:!0,path:r});if(i){var o=i.matched,a=o[o.length-1];return e.params=i.params,h(a,e)}return h(null,e)}function h(t,n,r){return t&&t.redirect?u(t,r||n):t&&t.matchAs?d(t,n,t.matchAs):m(t,n,r,e)}return{match:l,addRoute:s,getRoutes:c,addRoutes:a}}function mt(t,e,n){var r=e.match(t);if(!r)return!1;if(!n)return!0;for(var i=1,o=r.length;i<o;++i){var a=t.keys[i-1];a&&(n[a.name||"pathMatch"]="string"===typeof r[i]?l(r[i]):r[i])}return!0}function bt(t,e){return C(t,e.parent?e.parent.path:"/",!0)}var gt=lt&&window.performance&&window.performance.now?window.performance:Date;function vt(){return gt.now().toFixed(3)}var wt=vt();function yt(){return wt}function kt(t){return wt=t}var _t=Object.create(null);function Ot(){"scrollRestoration"in window.history&&(window.history.scrollRestoration="manual");var t=window.location.protocol+"//"+window.location.host,e=window.location.href.replace(t,""),n=i({},window.history.state);return n.key=yt(),window.history.replaceState(n,"",e),window.addEventListener("popstate",jt),function(){window.removeEventListener("popstate",jt)}}function zt(t,e,n,r){if(t.app){var i=t.options.scrollBehavior;i&&t.app.$nextTick((function(){var o=Mt(),a=i.call(t,e,n,r?o:null);a&&("function"===typeof a.then?a.then((function(t){It(t,o)})).catch((function(t){0})):It(a,o))}))}}function At(){var t=yt();t&&(_t[t]={x:window.pageXOffset,y:window.pageYOffset})}function jt(t){At(),t.state&&t.state.key&&kt(t.state.key)}function Mt(){var t=yt();if(t)return _t[t]}function Ct(t,e){var n=document.documentElement,r=n.getBoundingClientRect(),i=t.getBoundingClientRect();return{x:i.left-r.left-e.x,y:i.top-r.top-e.y}}function Vt(t){return Tt(t.x)||Tt(t.y)}function St(t){return{x:Tt(t.x)?t.x:window.pageXOffset,y:Tt(t.y)?t.y:window.pageYOffset}}function xt(t){return{x:Tt(t.x)?t.x:0,y:Tt(t.y)?t.y:0}}function Tt(t){return"number"===typeof t}var Pt=/^#\d/;function It(t,e){var n="object"===typeof t;if(n&&"string"===typeof t.selector){var r=Pt.test(t.selector)?document.getElementById(t.selector.slice(1)):document.querySelector(t.selector);if(r){var i=t.offset&&"object"===typeof t.offset?t.offset:{};i=xt(i),e=Ct(r,i)}else Vt(t)&&(e=St(t))}else n&&Vt(t)&&(e=St(t));e&&("scrollBehavior"in document.documentElement.style?window.scrollTo({left:e.x,top:e.y,behavior:t.behavior}):window.scrollTo(e.x,e.y))}var Et=lt&&function(){var t=window.navigator.userAgent;return(-1===t.indexOf("Android 2.")&&-1===t.indexOf("Android 4.0")||-1===t.indexOf("Mobile Safari")||-1!==t.indexOf("Chrome")||-1!==t.indexOf("Windows Phone"))&&(window.history&&"function"===typeof window.history.pushState)}();function Lt(t,e){At();var n=window.history;try{if(e){var r=i({},n.state);r.key=yt(),n.replaceState(r,"",t)}else n.pushState({key:kt(vt())},"",t)}catch(o){window.location[e?"replace":"assign"](t)}}function Bt(t){Lt(t,!0)}function Ht(t,e,n){var r=function(i){i>=t.length?n():t[i]?e(t[i],(function(){r(i+1)})):r(i+1)};r(0)}var Ft={redirected:2,aborted:4,cancelled:8,duplicated:16};function Dt(t,e){return Ut(t,e,Ft.redirected,'Redirected when going from "'+t.fullPath+'" to "'+Wt(e)+'" via a navigation guard.')}function Rt(t,e){var n=Ut(t,e,Ft.duplicated,'Avoided redundant navigation to current location: "'+t.fullPath+'".');return n.name="NavigationDuplicated",n}function Nt(t,e){return Ut(t,e,Ft.cancelled,'Navigation cancelled from "'+t.fullPath+'" to "'+e.fullPath+'" with a new navigation.')}function $t(t,e){return Ut(t,e,Ft.aborted,'Navigation aborted from "'+t.fullPath+'" to "'+e.fullPath+'" via a navigation guard.')}function Ut(t,e,n,r){var i=new Error(r);return i._isRouter=!0,i.from=t,i.to=e,i.type=n,i}var qt=["params","query","hash"];function Wt(t){if("string"===typeof t)return t;if("path"in t)return t.path;var e={};return qt.forEach((function(n){n in t&&(e[n]=t[n])})),JSON.stringify(e,null,2)}function Gt(t){return Object.prototype.toString.call(t).indexOf("Error")>-1}function Yt(t,e){return Gt(t)&&t._isRouter&&(null==e||t.type===e)}function Kt(t){return function(e,n,r){var i=!1,o=0,a=null;Qt(t,(function(t,e,n,s){if("function"===typeof t&&void 0===t.cid){i=!0,o++;var c,l=te((function(e){Zt(e)&&(e=e.default),t.resolved="function"===typeof e?e:et.extend(e),n.components[s]=e,o--,o<=0&&r()})),u=te((function(t){var e="Failed to resolve async component "+s+": "+t;a||(a=Gt(t)?t:new Error(e),r(a))}));try{c=t(l,u)}catch(h){u(h)}if(c)if("function"===typeof c.then)c.then(l,u);else{var d=c.component;d&&"function"===typeof d.then&&d.then(l,u)}}})),i||r()}}function Qt(t,e){return Xt(t.map((function(t){return Object.keys(t.components).map((function(n){return e(t.components[n],t.instances[n],t,n)}))})))}function Xt(t){return Array.prototype.concat.apply([],t)}var Jt="function"===typeof Symbol&&"symbol"===typeof Symbol.toStringTag;function Zt(t){return t.__esModule||Jt&&"Module"===t[Symbol.toStringTag]}function te(t){var e=!1;return function(){var n=[],r=arguments.length;while(r--)n[r]=arguments[r];if(!e)return e=!0,t.apply(this,n)}}var ee=function(t,e){this.router=t,this.base=ne(e),this.current=g,this.pending=null,this.ready=!1,this.readyCbs=[],this.readyErrorCbs=[],this.errorCbs=[],this.listeners=[]};function ne(t){if(!t)if(lt){var e=document.querySelector("base");t=e&&e.getAttribute("href")||"/",t=t.replace(/^https?:\/\/[^\/]+/,"")}else t="/";return"/"!==t.charAt(0)&&(t="/"+t),t.replace(/\/$/,"")}function re(t,e){var n,r=Math.max(t.length,e.length);for(n=0;n<r;n++)if(t[n]!==e[n])break;return{updated:e.slice(0,n),activated:e.slice(n),deactivated:t.slice(n)}}function ie(t,e,n,r){var i=Qt(t,(function(t,r,i,o){var a=oe(t,e);if(a)return Array.isArray(a)?a.map((function(t){return n(t,r,i,o)})):n(a,r,i,o)}));return Xt(r?i.reverse():i)}function oe(t,e){return"function"!==typeof t&&(t=et.extend(t)),t.options[e]}function ae(t){return ie(t,"beforeRouteLeave",ce,!0)}function se(t){return ie(t,"beforeRouteUpdate",ce)}function ce(t,e){if(e)return function(){return t.apply(e,arguments)}}function le(t){return ie(t,"beforeRouteEnter",(function(t,e,n,r){return ue(t,n,r)}))}function ue(t,e,n){return function(r,i,o){return t(r,i,(function(t){"function"===typeof t&&(e.enteredCbs[n]||(e.enteredCbs[n]=[]),e.enteredCbs[n].push(t)),o(t)}))}}ee.prototype.listen=function(t){this.cb=t},ee.prototype.onReady=function(t,e){this.ready?t():(this.readyCbs.push(t),e&&this.readyErrorCbs.push(e))},ee.prototype.onError=function(t){this.errorCbs.push(t)},ee.prototype.transitionTo=function(t,e,n){var r,i=this;try{r=this.router.match(t,this.current)}catch(a){throw this.errorCbs.forEach((function(t){t(a)})),a}var o=this.current;this.confirmTransition(r,(function(){i.updateRoute(r),e&&e(r),i.ensureURL(),i.router.afterHooks.forEach((function(t){t&&t(r,o)})),i.ready||(i.ready=!0,i.readyCbs.forEach((function(t){t(r)})))}),(function(t){n&&n(t),t&&!i.ready&&(Yt(t,Ft.redirected)&&o===g||(i.ready=!0,i.readyErrorCbs.forEach((function(e){e(t)}))))}))},ee.prototype.confirmTransition=function(t,e,n){var i=this,o=this.current;this.pending=t;var a=function(t){!Yt(t)&&Gt(t)&&(i.errorCbs.length?i.errorCbs.forEach((function(e){e(t)})):(r(!1,"uncaught error during route navigation:"),console.error(t))),n&&n(t)},s=t.matched.length-1,c=o.matched.length-1;if(y(t,o)&&s===c&&t.matched[s]===o.matched[c])return this.ensureURL(),a(Rt(o,t));var l=re(this.current.matched,t.matched),u=l.updated,d=l.deactivated,h=l.activated,f=[].concat(ae(d),this.router.beforeHooks,se(u),h.map((function(t){return t.beforeEnter})),Kt(h)),p=function(e,n){if(i.pending!==t)return a(Nt(o,t));try{e(t,o,(function(e){!1===e?(i.ensureURL(!0),a($t(o,t))):Gt(e)?(i.ensureURL(!0),a(e)):"string"===typeof e||"object"===typeof e&&("string"===typeof e.path||"string"===typeof e.name)?(a(Dt(o,t)),"object"===typeof e&&e.replace?i.replace(e):i.push(e)):n(e)}))}catch(r){a(r)}};Ht(f,p,(function(){var n=le(h),r=n.concat(i.router.resolveHooks);Ht(r,p,(function(){if(i.pending!==t)return a(Nt(o,t));i.pending=null,e(t),i.router.app&&i.router.app.$nextTick((function(){z(t)}))}))}))},ee.prototype.updateRoute=function(t){this.current=t,this.cb&&this.cb(t)},ee.prototype.setupListeners=function(){},ee.prototype.teardown=function(){this.listeners.forEach((function(t){t()})),this.listeners=[],this.current=g,this.pending=null};var de=function(t){function e(e,n){t.call(this,e,n),this._startLocation=he(this.base)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setupListeners=function(){var t=this;if(!(this.listeners.length>0)){var e=this.router,n=e.options.scrollBehavior,r=Et&&n;r&&this.listeners.push(Ot());var i=function(){var n=t.current,i=he(t.base);t.current===g&&i===t._startLocation||t.transitionTo(i,(function(t){r&&zt(e,t,n,!0)}))};window.addEventListener("popstate",i),this.listeners.push((function(){window.removeEventListener("popstate",i)}))}},e.prototype.go=function(t){window.history.go(t)},e.prototype.push=function(t,e,n){var r=this,i=this,o=i.current;this.transitionTo(t,(function(t){Lt(S(r.base+t.fullPath)),zt(r.router,t,o,!1),e&&e(t)}),n)},e.prototype.replace=function(t,e,n){var r=this,i=this,o=i.current;this.transitionTo(t,(function(t){Bt(S(r.base+t.fullPath)),zt(r.router,t,o,!1),e&&e(t)}),n)},e.prototype.ensureURL=function(t){if(he(this.base)!==this.current.fullPath){var e=S(this.base+this.current.fullPath);t?Lt(e):Bt(e)}},e.prototype.getCurrentLocation=function(){return he(this.base)},e}(ee);function he(t){var e=window.location.pathname;return t&&0===e.toLowerCase().indexOf(t.toLowerCase())&&(e=e.slice(t.length)),(e||"/")+window.location.search+window.location.hash}var fe=function(t){function e(e,n,r){t.call(this,e,n),r&&pe(this.base)||me()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setupListeners=function(){var t=this;if(!(this.listeners.length>0)){var e=this.router,n=e.options.scrollBehavior,r=Et&&n;r&&this.listeners.push(Ot());var i=function(){var e=t.current;me()&&t.transitionTo(be(),(function(n){r&&zt(t.router,n,e,!0),Et||we(n.fullPath)}))},o=Et?"popstate":"hashchange";window.addEventListener(o,i),this.listeners.push((function(){window.removeEventListener(o,i)}))}},e.prototype.push=function(t,e,n){var r=this,i=this,o=i.current;this.transitionTo(t,(function(t){ve(t.fullPath),zt(r.router,t,o,!1),e&&e(t)}),n)},e.prototype.replace=function(t,e,n){var r=this,i=this,o=i.current;this.transitionTo(t,(function(t){we(t.fullPath),zt(r.router,t,o,!1),e&&e(t)}),n)},e.prototype.go=function(t){window.history.go(t)},e.prototype.ensureURL=function(t){var e=this.current.fullPath;be()!==e&&(t?ve(e):we(e))},e.prototype.getCurrentLocation=function(){return be()},e}(ee);function pe(t){var e=he(t);if(!/^\/#/.test(e))return window.location.replace(S(t+"/#"+e)),!0}function me(){var t=be();return"/"===t.charAt(0)||(we("/"+t),!1)}function be(){var t=window.location.href,e=t.indexOf("#");return e<0?"":(t=t.slice(e+1),t)}function ge(t){var e=window.location.href,n=e.indexOf("#"),r=n>=0?e.slice(0,n):e;return r+"#"+t}function ve(t){Et?Lt(ge(t)):window.location.hash=t}function we(t){Et?Bt(ge(t)):window.location.replace(ge(t))}var ye=function(t){function e(e,n){t.call(this,e,n),this.stack=[],this.index=-1}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.push=function(t,e,n){var r=this;this.transitionTo(t,(function(t){r.stack=r.stack.slice(0,r.index+1).concat(t),r.index++,e&&e(t)}),n)},e.prototype.replace=function(t,e,n){var r=this;this.transitionTo(t,(function(t){r.stack=r.stack.slice(0,r.index).concat(t),e&&e(t)}),n)},e.prototype.go=function(t){var e=this,n=this.index+t;if(!(n<0||n>=this.stack.length)){var r=this.stack[n];this.confirmTransition(r,(function(){var t=e.current;e.index=n,e.updateRoute(r),e.router.afterHooks.forEach((function(e){e&&e(r,t)}))}),(function(t){Yt(t,Ft.duplicated)&&(e.index=n)}))}},e.prototype.getCurrentLocation=function(){var t=this.stack[this.stack.length-1];return t?t.fullPath:"/"},e.prototype.ensureURL=function(){},e}(ee),ke=function(t){void 0===t&&(t={}),this.app=null,this.apps=[],this.options=t,this.beforeHooks=[],this.resolveHooks=[],this.afterHooks=[],this.matcher=pt(t.routes||[],this);var e=t.mode||"hash";switch(this.fallback="history"===e&&!Et&&!1!==t.fallback,this.fallback&&(e="hash"),lt||(e="abstract"),this.mode=e,e){case"history":this.history=new de(this,t.base);break;case"hash":this.history=new fe(this,t.base,this.fallback);break;case"abstract":this.history=new ye(this,t.base);break;default:0}},_e={currentRoute:{configurable:!0}};function Oe(t,e){return t.push(e),function(){var n=t.indexOf(e);n>-1&&t.splice(n,1)}}function ze(t,e,n){var r="hash"===n?"#"+e:e;return t?S(t+"/"+r):r}ke.prototype.match=function(t,e,n){return this.matcher.match(t,e,n)},_e.currentRoute.get=function(){return this.history&&this.history.current},ke.prototype.init=function(t){var e=this;if(this.apps.push(t),t.$once("hook:destroyed",(function(){var n=e.apps.indexOf(t);n>-1&&e.apps.splice(n,1),e.app===t&&(e.app=e.apps[0]||null),e.app||e.history.teardown()})),!this.app){this.app=t;var n=this.history;if(n instanceof de||n instanceof fe){var r=function(t){var r=n.current,i=e.options.scrollBehavior,o=Et&&i;o&&"fullPath"in t&&zt(e,t,r,!1)},i=function(t){n.setupListeners(),r(t)};n.transitionTo(n.getCurrentLocation(),i,i)}n.listen((function(t){e.apps.forEach((function(e){e._route=t}))}))}},ke.prototype.beforeEach=function(t){return Oe(this.beforeHooks,t)},ke.prototype.beforeResolve=function(t){return Oe(this.resolveHooks,t)},ke.prototype.afterEach=function(t){return Oe(this.afterHooks,t)},ke.prototype.onReady=function(t,e){this.history.onReady(t,e)},ke.prototype.onError=function(t){this.history.onError(t)},ke.prototype.push=function(t,e,n){var r=this;if(!e&&!n&&"undefined"!==typeof Promise)return new Promise((function(e,n){r.history.push(t,e,n)}));this.history.push(t,e,n)},ke.prototype.replace=function(t,e,n){var r=this;if(!e&&!n&&"undefined"!==typeof Promise)return new Promise((function(e,n){r.history.replace(t,e,n)}));this.history.replace(t,e,n)},ke.prototype.go=function(t){this.history.go(t)},ke.prototype.back=function(){this.go(-1)},ke.prototype.forward=function(){this.go(1)},ke.prototype.getMatchedComponents=function(t){var e=t?t.matched?t:this.resolve(t).route:this.currentRoute;return e?[].concat.apply([],e.matched.map((function(t){return Object.keys(t.components).map((function(e){return t.components[e]}))}))):[]},ke.prototype.resolve=function(t,e,n){e=e||this.history.current;var r=tt(t,e,n,this),i=this.match(r,e),o=i.redirectedFrom||i.fullPath,a=this.history.base,s=ze(a,o,this.mode);return{location:r,route:i,href:s,normalizedTo:r,resolved:i}},ke.prototype.getRoutes=function(){return this.matcher.getRoutes()},ke.prototype.addRoute=function(t,e){this.matcher.addRoute(t,e),this.history.current!==g&&this.history.transitionTo(this.history.getCurrentLocation())},ke.prototype.addRoutes=function(t){this.matcher.addRoutes(t),this.history.current!==g&&this.history.transitionTo(this.history.getCurrentLocation())},Object.defineProperties(ke.prototype,_e),ke.install=ct,ke.version="3.5.1",ke.isNavigationFailure=Yt,ke.NavigationFailureType=Ft,ke.START_LOCATION=g,lt&&window.Vue&&window.Vue.use(ke),e["a"]=ke},"8df4":function(t,e,n){"use strict";var r=n("7a77");function i(t){if("function"!==typeof t)throw new TypeError("executor must be a function.");var e;this.promise=new Promise((function(t){e=t}));var n=this;t((function(t){n.reason||(n.reason=new r(t),e(n.reason))}))}i.prototype.throwIfRequested=function(){if(this.reason)throw this.reason},i.source=function(){var t,e=new i((function(e){t=e}));return{token:e,cancel:t}},t.exports=i},"938d":function(t,e,n){"use strict";(function(t){n.d(e,"a",(function(){return i}));var r=function(e){var n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null,r="undefined"!==typeof t&&t?Object({NODE_ENV:"production",BASE_URL:"/static/unicms_editorial_board_vue/"})||!1:{};return e?r[e]||n:r},i=function(){return r("BOOTSTRAP_VUE_NO_WARN")||"production"===r("NODE_ENV")}}).call(this,n("4362"))},9483:function(t,e,n){"use strict";n.d(e,"a",(function(){return o}));var r,i=function(){return Boolean("localhost"===window.location.hostname||"[::1]"===window.location.hostname||window.location.hostname.match(/^127(?:\.(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)){3}$/))};function o(t,e){void 0===e&&(e={});var n=e.registrationOptions;void 0===n&&(n={}),delete e.registrationOptions;var o=function(t){var n=[],r=arguments.length-1;while(r-- >0)n[r]=arguments[r+1];e&&e[t]&&e[t].apply(e,n)};"serviceWorker"in navigator&&r.then((function(){i()?(c(t,o,n),navigator.serviceWorker.ready.then((function(t){o("ready",t)})).catch((function(t){return a(o,t)}))):(s(t,o,n),navigator.serviceWorker.ready.then((function(t){o("ready",t)})).catch((function(t){return a(o,t)})))}))}function a(t,e){navigator.onLine||t("offline"),t("error",e)}function s(t,e,n){navigator.serviceWorker.register(t,n).then((function(t){e("registered",t),t.waiting?e("updated",t):t.onupdatefound=function(){e("updatefound",t);var n=t.installing;n.onstatechange=function(){"installed"===n.state&&(navigator.serviceWorker.controller?e("updated",t):e("cached",t))}}})).catch((function(t){return a(e,t)}))}function c(t,e,n){fetch(t).then((function(r){404===r.status?(e("error",new Error("Service worker not found at "+t)),l()):-1===r.headers.get("content-type").indexOf("javascript")?(e("error",new Error("Expected "+t+" to have javascript content-type, but received "+r.headers.get("content-type"))),l()):s(t,e,n)})).catch((function(t){return a(e,t)}))}function l(){"serviceWorker"in navigator&&navigator.serviceWorker.ready.then((function(t){t.unregister()})).catch((function(t){return a(emit,t)}))}"undefined"!==typeof window&&(r="undefined"!==typeof Promise?new Promise((function(t){return window.addEventListener("load",t)})):{then:function(t){return window.addEventListener("load",t)}})},"992e":function(t,e,n){"use strict";n.d(e,"a",(function(){return r})),n.d(e,"d",(function(){return i})),n.d(e,"h",(function(){return o})),n.d(e,"k",(function(){return a})),n.d(e,"l",(function(){return s})),n.d(e,"m",(function(){return c})),n.d(e,"o",(function(){return l})),n.d(e,"p",(function(){return u})),n.d(e,"r",(function(){return d})),n.d(e,"s",(function(){return h})),n.d(e,"t",(function(){return f})),n.d(e,"v",(function(){return p})),n.d(e,"w",(function(){return m})),n.d(e,"x",(function(){return b})),n.d(e,"y",(function(){return g})),n.d(e,"z",(function(){return v})),n.d(e,"C",(function(){return w})),n.d(e,"D",(function(){return y})),n.d(e,"E",(function(){return k})),n.d(e,"F",(function(){return _})),n.d(e,"f",(function(){return O})),n.d(e,"g",(function(){return z})),n.d(e,"B",(function(){return A})),n.d(e,"n",(function(){return j})),n.d(e,"i",(function(){return M})),n.d(e,"j",(function(){return C})),n.d(e,"u",(function(){return V})),n.d(e,"b",(function(){return S})),n.d(e,"c",(function(){return x})),n.d(e,"e",(function(){return T})),n.d(e,"q",(function(){return P})),n.d(e,"A",(function(){return I}));var r=/\[(\d+)]/g,i=/^(BV?)/,o=/^\d+$/,a=/^\..+/,s=/^#/,c=/^#[A-Za-z]+[\w\-:.]*$/,l=/(<([^>]+)>)/gi,u=/\B([A-Z])/g,d=/([a-z])([A-Z])/g,h=/^[0-9]*\.?[0-9]+$/,f=/\+/g,p=/[-/\\^$*+?.()|[\]{}]/g,m=/[\s\uFEFF\xA0]+/g,b=/\s+/,g=/\/\*$/,v=/(\s|^)(\w)/g,w=/^\s+/,y=/\s+$/,k=/_/g,_=/-(\w)/g,O=/^\d+-\d\d?-\d\d?(?:\s|T|$)/,z=/-|\s|T/,A=/^([0-1]?[0-9]|2[0-3]):[0-5]?[0-9](:[0-5]?[0-9])?$/,j=/^.*(#[^#]+)$/,M=/%2C/g,C=/[!'()*]/g,V=/^(\?|#|&)/,S=/^\d+(\.\d*)?[/:]\d+(\.\d*)?$/,x=/[/:]/,T=/^col-/,P=/^BIcon/,I=/-u-.+/},a723:function(t,e,n){"use strict";n.d(e,"a",(function(){return r})),n.d(e,"b",(function(){return i})),n.d(e,"g",(function(){return o})),n.d(e,"l",(function(){return s})),n.d(e,"n",(function(){return c})),n.d(e,"q",(function(){return l})),n.d(e,"t",(function(){return u})),n.d(e,"u",(function(){return d})),n.d(e,"c",(function(){return h})),n.d(e,"d",(function(){return f})),n.d(e,"e",(function(){return p})),n.d(e,"f",(function(){return m})),n.d(e,"h",(function(){return b})),n.d(e,"i",(function(){return g})),n.d(e,"j",(function(){return v})),n.d(e,"k",(function(){return w})),n.d(e,"m",(function(){return y})),n.d(e,"p",(function(){return k})),n.d(e,"o",(function(){return _})),n.d(e,"r",(function(){return O})),n.d(e,"s",(function(){return z}));var r=void 0,i=Array,o=Boolean,a=Date,s=Function,c=Number,l=Object,u=RegExp,d=String,h=[i,s],f=[i,l],p=[i,l,d],m=[i,d],b=[o,c],g=[o,c,d],v=[o,d],w=[a,d],y=[s,d],k=[c,d],_=[c,l,d],O=[l,s],z=[l,d]},a874:function(t,e,n){"use strict";n.d(e,"b",(function(){return a})),n.d(e,"a",(function(){return s}));var r=n("992e"),i=n("6c06"),o=n("7b1e"),a=function(t,e){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:void 0;if(e=Object(o["a"])(e)?e.join("."):e,!e||!Object(o["j"])(t))return n;if(e in t)return t[e];e=String(e).replace(r["a"],".$1");var a=e.split(".").filter(i["a"]);return 0===a.length?n:a.every((function(e){return Object(o["j"])(t)&&e in t&&!Object(o["p"])(t=t[e])}))?t:Object(o["g"])(t)?null:n},s=function(t,e){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null,r=a(t,e);return Object(o["p"])(r)?n:r}},a8c8:function(t,e,n){"use strict";n.d(e,"e",(function(){return r})),n.d(e,"d",(function(){return i})),n.d(e,"a",(function(){return o})),n.d(e,"b",(function(){return a})),n.d(e,"c",(function(){return s})),n.d(e,"f",(function(){return c})),n.d(e,"g",(function(){return l}));var r=Math.min,i=Math.max,o=Math.abs,a=Math.ceil,s=Math.floor,c=Math.pow,l=Math.round},aa0d:function(t,e,n){"use strict";n.d(e,"b",(function(){return m})),n.d(e,"a",(function(){return b}));var r=n("2b0e"),i=n("b42e"),o=n("c637"),a=n("a723"),s=n("6c06"),c=n("7b1e"),l=n("a8c8"),u=n("3a58"),d=n("cf75");function h(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var f={viewBox:"0 0 16 16",width:"1em",height:"1em",focusable:"false",role:"img","aria-label":"icon"},p={width:null,height:null,focusable:null,role:null,"aria-label":null},m={animation:Object(d["c"])(a["u"]),content:Object(d["c"])(a["u"]),flipH:Object(d["c"])(a["g"],!1),flipV:Object(d["c"])(a["g"],!1),fontScale:Object(d["c"])(a["p"],1),rotate:Object(d["c"])(a["p"],0),scale:Object(d["c"])(a["p"],1),shiftH:Object(d["c"])(a["p"],0),shiftV:Object(d["c"])(a["p"],0),stacked:Object(d["c"])(a["g"],!1),title:Object(d["c"])(a["u"]),variant:Object(d["c"])(a["u"])},b=r["default"].extend({name:o["nb"],functional:!0,props:m,render:function(t,e){var n,r=e.data,o=e.props,a=e.children,d=o.animation,m=o.content,b=o.flipH,g=o.flipV,v=o.stacked,w=o.title,y=o.variant,k=Object(l["d"])(Object(u["b"])(o.fontScale,1),0)||1,_=Object(l["d"])(Object(u["b"])(o.scale,1),0)||1,O=Object(u["b"])(o.rotate,0),z=Object(u["b"])(o.shiftH,0),A=Object(u["b"])(o.shiftV,0),j=b||g||1!==_,M=j||O,C=z||A,V=!Object(c["p"])(m),S=[M?"translate(8 8)":null,j?"scale(".concat((b?-1:1)*_," ").concat((g?-1:1)*_,")"):null,O?"rotate(".concat(O,")"):null,M?"translate(-8 -8)":null].filter(s["a"]),x=t("g",{attrs:{transform:S.join(" ")||null},domProps:V?{innerHTML:m||""}:{}},a);C&&(x=t("g",{attrs:{transform:"translate(".concat(16*z/16," ").concat(-16*A/16,")")}},[x])),v&&(x=t("g",[x]));var T=w?t("title",w):null,P=[T,x].filter(s["a"]);return t("svg",Object(i["a"])({staticClass:"b-icon bi",class:(n={},h(n,"text-".concat(y),y),h(n,"b-icon-animation-".concat(d),d),n),attrs:f,style:v?{}:{fontSize:1===k?null:"".concat(100*k,"%")}},r,v?{attrs:p}:{},{attrs:{xmlns:v?null:"http://www.w3.org/2000/svg",fill:"currentColor"}}),P)}})},b1e0:function(t,e,n){"use strict";n.d(e,"a",(function(){return s}));var r=n("3790"),i=n("0759"),o=n("5d4e"),a=n("7386"),s=Object(r["c"])({components:{BIcon:i["a"],BIconstack:o["a"],BIconBlank:a["Fc"],BIconAlarm:a["a"],BIconAlarmFill:a["b"],BIconAlignBottom:a["c"],BIconAlignCenter:a["d"],BIconAlignEnd:a["e"],BIconAlignMiddle:a["f"],BIconAlignStart:a["g"],BIconAlignTop:a["h"],BIconAlt:a["i"],BIconApp:a["j"],BIconAppIndicator:a["k"],BIconArchive:a["l"],BIconArchiveFill:a["m"],BIconArrow90degDown:a["n"],BIconArrow90degLeft:a["o"],BIconArrow90degRight:a["p"],BIconArrow90degUp:a["q"],BIconArrowBarDown:a["r"],BIconArrowBarLeft:a["s"],BIconArrowBarRight:a["t"],BIconArrowBarUp:a["u"],BIconArrowClockwise:a["v"],BIconArrowCounterclockwise:a["w"],BIconArrowDown:a["x"],BIconArrowDownCircle:a["y"],BIconArrowDownCircleFill:a["z"],BIconArrowDownLeft:a["A"],BIconArrowDownLeftCircle:a["B"],BIconArrowDownLeftCircleFill:a["C"],BIconArrowDownLeftSquare:a["D"],BIconArrowDownLeftSquareFill:a["E"],BIconArrowDownRight:a["F"],BIconArrowDownRightCircle:a["G"],BIconArrowDownRightCircleFill:a["H"],BIconArrowDownRightSquare:a["I"],BIconArrowDownRightSquareFill:a["J"],BIconArrowDownShort:a["K"],BIconArrowDownSquare:a["L"],BIconArrowDownSquareFill:a["M"],BIconArrowDownUp:a["N"],BIconArrowLeft:a["O"],BIconArrowLeftCircle:a["P"],BIconArrowLeftCircleFill:a["Q"],BIconArrowLeftRight:a["R"],BIconArrowLeftShort:a["S"],BIconArrowLeftSquare:a["T"],BIconArrowLeftSquareFill:a["U"],BIconArrowRepeat:a["V"],BIconArrowReturnLeft:a["W"],BIconArrowReturnRight:a["X"],BIconArrowRight:a["Y"],BIconArrowRightCircle:a["Z"],BIconArrowRightCircleFill:a["ab"],BIconArrowRightShort:a["bb"],BIconArrowRightSquare:a["cb"],BIconArrowRightSquareFill:a["db"],BIconArrowUp:a["eb"],BIconArrowUpCircle:a["fb"],BIconArrowUpCircleFill:a["gb"],BIconArrowUpLeft:a["hb"],BIconArrowUpLeftCircle:a["ib"],BIconArrowUpLeftCircleFill:a["jb"],BIconArrowUpLeftSquare:a["kb"],BIconArrowUpLeftSquareFill:a["lb"],BIconArrowUpRight:a["mb"],BIconArrowUpRightCircle:a["nb"],BIconArrowUpRightCircleFill:a["ob"],BIconArrowUpRightSquare:a["pb"],BIconArrowUpRightSquareFill:a["qb"],BIconArrowUpShort:a["rb"],BIconArrowUpSquare:a["sb"],BIconArrowUpSquareFill:a["tb"],BIconArrowsAngleContract:a["ub"],BIconArrowsAngleExpand:a["vb"],BIconArrowsCollapse:a["wb"],BIconArrowsExpand:a["xb"],BIconArrowsFullscreen:a["yb"],BIconArrowsMove:a["zb"],BIconAspectRatio:a["Ab"],BIconAspectRatioFill:a["Bb"],BIconAsterisk:a["Cb"],BIconAt:a["Db"],BIconAward:a["Eb"],BIconAwardFill:a["Fb"],BIconBack:a["Gb"],BIconBackspace:a["Hb"],BIconBackspaceFill:a["Ib"],BIconBackspaceReverse:a["Jb"],BIconBackspaceReverseFill:a["Kb"],BIconBadge4k:a["Lb"],BIconBadge4kFill:a["Mb"],BIconBadge8k:a["Nb"],BIconBadge8kFill:a["Ob"],BIconBadgeAd:a["Pb"],BIconBadgeAdFill:a["Qb"],BIconBadgeCc:a["Rb"],BIconBadgeCcFill:a["Sb"],BIconBadgeHd:a["Tb"],BIconBadgeHdFill:a["Ub"],BIconBadgeTm:a["Vb"],BIconBadgeTmFill:a["Wb"],BIconBadgeVo:a["Xb"],BIconBadgeVoFill:a["Yb"],BIconBag:a["Zb"],BIconBagCheck:a["ac"],BIconBagCheckFill:a["bc"],BIconBagDash:a["cc"],BIconBagDashFill:a["dc"],BIconBagFill:a["ec"],BIconBagPlus:a["fc"],BIconBagPlusFill:a["gc"],BIconBagX:a["hc"],BIconBagXFill:a["ic"],BIconBarChart:a["jc"],BIconBarChartFill:a["kc"],BIconBarChartLine:a["lc"],BIconBarChartLineFill:a["mc"],BIconBarChartSteps:a["nc"],BIconBasket:a["oc"],BIconBasket2:a["pc"],BIconBasket2Fill:a["qc"],BIconBasket3:a["rc"],BIconBasket3Fill:a["sc"],BIconBasketFill:a["tc"],BIconBattery:a["uc"],BIconBatteryCharging:a["vc"],BIconBatteryFull:a["wc"],BIconBatteryHalf:a["xc"],BIconBell:a["yc"],BIconBellFill:a["zc"],BIconBezier:a["Ac"],BIconBezier2:a["Bc"],BIconBicycle:a["Cc"],BIconBinoculars:a["Dc"],BIconBinocularsFill:a["Ec"],BIconBlockquoteLeft:a["Gc"],BIconBlockquoteRight:a["Hc"],BIconBook:a["Ic"],BIconBookFill:a["Jc"],BIconBookHalf:a["Kc"],BIconBookmark:a["Lc"],BIconBookmarkCheck:a["Mc"],BIconBookmarkCheckFill:a["Nc"],BIconBookmarkDash:a["Oc"],BIconBookmarkDashFill:a["Pc"],BIconBookmarkFill:a["Qc"],BIconBookmarkHeart:a["Rc"],BIconBookmarkHeartFill:a["Sc"],BIconBookmarkPlus:a["Tc"],BIconBookmarkPlusFill:a["Uc"],BIconBookmarkStar:a["Vc"],BIconBookmarkStarFill:a["Wc"],BIconBookmarkX:a["Xc"],BIconBookmarkXFill:a["Yc"],BIconBookmarks:a["Zc"],BIconBookmarksFill:a["ad"],BIconBookshelf:a["bd"],BIconBootstrap:a["cd"],BIconBootstrapFill:a["dd"],BIconBootstrapReboot:a["ed"],BIconBorderStyle:a["fd"],BIconBorderWidth:a["gd"],BIconBoundingBox:a["hd"],BIconBoundingBoxCircles:a["id"],BIconBox:a["jd"],BIconBoxArrowDown:a["kd"],BIconBoxArrowDownLeft:a["ld"],BIconBoxArrowDownRight:a["md"],BIconBoxArrowInDown:a["nd"],BIconBoxArrowInDownLeft:a["od"],BIconBoxArrowInDownRight:a["pd"],BIconBoxArrowInLeft:a["qd"],BIconBoxArrowInRight:a["rd"],BIconBoxArrowInUp:a["sd"],BIconBoxArrowInUpLeft:a["td"],BIconBoxArrowInUpRight:a["ud"],BIconBoxArrowLeft:a["vd"],BIconBoxArrowRight:a["wd"],BIconBoxArrowUp:a["xd"],BIconBoxArrowUpLeft:a["yd"],BIconBoxArrowUpRight:a["zd"],BIconBoxSeam:a["Ad"],BIconBraces:a["Bd"],BIconBricks:a["Cd"],BIconBriefcase:a["Dd"],BIconBriefcaseFill:a["Ed"],BIconBrightnessAltHigh:a["Fd"],BIconBrightnessAltHighFill:a["Gd"],BIconBrightnessAltLow:a["Hd"],BIconBrightnessAltLowFill:a["Id"],BIconBrightnessHigh:a["Jd"],BIconBrightnessHighFill:a["Kd"],BIconBrightnessLow:a["Ld"],BIconBrightnessLowFill:a["Md"],BIconBroadcast:a["Nd"],BIconBroadcastPin:a["Od"],BIconBrush:a["Pd"],BIconBrushFill:a["Qd"],BIconBucket:a["Rd"],BIconBucketFill:a["Sd"],BIconBug:a["Td"],BIconBugFill:a["Ud"],BIconBuilding:a["Vd"],BIconBullseye:a["Wd"],BIconCalculator:a["Xd"],BIconCalculatorFill:a["Yd"],BIconCalendar:a["Zd"],BIconCalendar2:a["ae"],BIconCalendar2Check:a["be"],BIconCalendar2CheckFill:a["ce"],BIconCalendar2Date:a["de"],BIconCalendar2DateFill:a["ee"],BIconCalendar2Day:a["fe"],BIconCalendar2DayFill:a["ge"],BIconCalendar2Event:a["he"],BIconCalendar2EventFill:a["ie"],BIconCalendar2Fill:a["je"],BIconCalendar2Minus:a["ke"],BIconCalendar2MinusFill:a["le"],BIconCalendar2Month:a["me"],BIconCalendar2MonthFill:a["ne"],BIconCalendar2Plus:a["oe"],BIconCalendar2PlusFill:a["pe"],BIconCalendar2Range:a["qe"],BIconCalendar2RangeFill:a["re"],BIconCalendar2Week:a["se"],BIconCalendar2WeekFill:a["te"],BIconCalendar2X:a["ue"],BIconCalendar2XFill:a["ve"],BIconCalendar3:a["we"],BIconCalendar3Event:a["xe"],BIconCalendar3EventFill:a["ye"],BIconCalendar3Fill:a["ze"],BIconCalendar3Range:a["Ae"],BIconCalendar3RangeFill:a["Be"],BIconCalendar3Week:a["Ce"],BIconCalendar3WeekFill:a["De"],BIconCalendar4:a["Ee"],BIconCalendar4Event:a["Fe"],BIconCalendar4Range:a["Ge"],BIconCalendar4Week:a["He"],BIconCalendarCheck:a["Ie"],BIconCalendarCheckFill:a["Je"],BIconCalendarDate:a["Ke"],BIconCalendarDateFill:a["Le"],BIconCalendarDay:a["Me"],BIconCalendarDayFill:a["Ne"],BIconCalendarEvent:a["Oe"],BIconCalendarEventFill:a["Pe"],BIconCalendarFill:a["Qe"],BIconCalendarMinus:a["Re"],BIconCalendarMinusFill:a["Se"],BIconCalendarMonth:a["Te"],BIconCalendarMonthFill:a["Ue"],BIconCalendarPlus:a["Ve"],BIconCalendarPlusFill:a["We"],BIconCalendarRange:a["Xe"],BIconCalendarRangeFill:a["Ye"],BIconCalendarWeek:a["Ze"],BIconCalendarWeekFill:a["af"],BIconCalendarX:a["bf"],BIconCalendarXFill:a["cf"],BIconCamera:a["df"],BIconCamera2:a["ef"],BIconCameraFill:a["ff"],BIconCameraReels:a["gf"],BIconCameraReelsFill:a["hf"],BIconCameraVideo:a["if"],BIconCameraVideoFill:a["jf"],BIconCameraVideoOff:a["kf"],BIconCameraVideoOffFill:a["lf"],BIconCapslock:a["mf"],BIconCapslockFill:a["nf"],BIconCardChecklist:a["of"],BIconCardHeading:a["pf"],BIconCardImage:a["qf"],BIconCardList:a["rf"],BIconCardText:a["sf"],BIconCaretDown:a["tf"],BIconCaretDownFill:a["uf"],BIconCaretDownSquare:a["vf"],BIconCaretDownSquareFill:a["wf"],BIconCaretLeft:a["xf"],BIconCaretLeftFill:a["yf"],BIconCaretLeftSquare:a["zf"],BIconCaretLeftSquareFill:a["Af"],BIconCaretRight:a["Bf"],BIconCaretRightFill:a["Cf"],BIconCaretRightSquare:a["Df"],BIconCaretRightSquareFill:a["Ef"],BIconCaretUp:a["Ff"],BIconCaretUpFill:a["Gf"],BIconCaretUpSquare:a["Hf"],BIconCaretUpSquareFill:a["If"],BIconCart:a["Jf"],BIconCart2:a["Kf"],BIconCart3:a["Lf"],BIconCart4:a["Mf"],BIconCartCheck:a["Nf"],BIconCartCheckFill:a["Of"],BIconCartDash:a["Pf"],BIconCartDashFill:a["Qf"],BIconCartFill:a["Rf"],BIconCartPlus:a["Sf"],BIconCartPlusFill:a["Tf"],BIconCartX:a["Uf"],BIconCartXFill:a["Vf"],BIconCash:a["Wf"],BIconCashStack:a["Xf"],BIconCast:a["Yf"],BIconChat:a["Zf"],BIconChatDots:a["ag"],BIconChatDotsFill:a["bg"],BIconChatFill:a["cg"],BIconChatLeft:a["dg"],BIconChatLeftDots:a["eg"],BIconChatLeftDotsFill:a["fg"],BIconChatLeftFill:a["gg"],BIconChatLeftQuote:a["hg"],BIconChatLeftQuoteFill:a["ig"],BIconChatLeftText:a["jg"],BIconChatLeftTextFill:a["kg"],BIconChatQuote:a["lg"],BIconChatQuoteFill:a["mg"],BIconChatRight:a["ng"],BIconChatRightDots:a["og"],BIconChatRightDotsFill:a["pg"],BIconChatRightFill:a["qg"],BIconChatRightQuote:a["rg"],BIconChatRightQuoteFill:a["sg"],BIconChatRightText:a["tg"],BIconChatRightTextFill:a["ug"],BIconChatSquare:a["vg"],BIconChatSquareDots:a["wg"],BIconChatSquareDotsFill:a["xg"],BIconChatSquareFill:a["yg"],BIconChatSquareQuote:a["zg"],BIconChatSquareQuoteFill:a["Ag"],BIconChatSquareText:a["Bg"],BIconChatSquareTextFill:a["Cg"],BIconChatText:a["Dg"],BIconChatTextFill:a["Eg"],BIconCheck:a["Fg"],BIconCheck2:a["Gg"],BIconCheck2All:a["Hg"],BIconCheck2Circle:a["Ig"],BIconCheck2Square:a["Jg"],BIconCheckAll:a["Kg"],BIconCheckCircle:a["Lg"],BIconCheckCircleFill:a["Mg"],BIconCheckSquare:a["Ng"],BIconCheckSquareFill:a["Og"],BIconChevronBarContract:a["Pg"],BIconChevronBarDown:a["Qg"],BIconChevronBarExpand:a["Rg"],BIconChevronBarLeft:a["Sg"],BIconChevronBarRight:a["Tg"],BIconChevronBarUp:a["Ug"],BIconChevronCompactDown:a["Vg"],BIconChevronCompactLeft:a["Wg"],BIconChevronCompactRight:a["Xg"],BIconChevronCompactUp:a["Yg"],BIconChevronContract:a["Zg"],BIconChevronDoubleDown:a["ah"],BIconChevronDoubleLeft:a["bh"],BIconChevronDoubleRight:a["ch"],BIconChevronDoubleUp:a["dh"],BIconChevronDown:a["eh"],BIconChevronExpand:a["fh"],BIconChevronLeft:a["gh"],BIconChevronRight:a["hh"],BIconChevronUp:a["ih"],BIconCircle:a["jh"],BIconCircleFill:a["kh"],BIconCircleHalf:a["lh"],BIconCircleSquare:a["mh"],BIconClipboard:a["nh"],BIconClipboardCheck:a["oh"],BIconClipboardData:a["ph"],BIconClipboardMinus:a["qh"],BIconClipboardPlus:a["rh"],BIconClipboardX:a["sh"],BIconClock:a["th"],BIconClockFill:a["uh"],BIconClockHistory:a["vh"],BIconCloud:a["wh"],BIconCloudArrowDown:a["xh"],BIconCloudArrowDownFill:a["yh"],BIconCloudArrowUp:a["zh"],BIconCloudArrowUpFill:a["Ah"],BIconCloudCheck:a["Bh"],BIconCloudCheckFill:a["Ch"],BIconCloudDownload:a["Dh"],BIconCloudDownloadFill:a["Eh"],BIconCloudFill:a["Fh"],BIconCloudMinus:a["Gh"],BIconCloudMinusFill:a["Hh"],BIconCloudPlus:a["Ih"],BIconCloudPlusFill:a["Jh"],BIconCloudSlash:a["Kh"],BIconCloudSlashFill:a["Lh"],BIconCloudUpload:a["Mh"],BIconCloudUploadFill:a["Nh"],BIconCode:a["Oh"],BIconCodeSlash:a["Ph"],BIconCodeSquare:a["Qh"],BIconCollection:a["Rh"],BIconCollectionFill:a["Sh"],BIconCollectionPlay:a["Th"],BIconCollectionPlayFill:a["Uh"],BIconColumns:a["Vh"],BIconColumnsGap:a["Wh"],BIconCommand:a["Xh"],BIconCompass:a["Yh"],BIconCompassFill:a["Zh"],BIconCone:a["ai"],BIconConeStriped:a["bi"],BIconController:a["ci"],BIconCpu:a["di"],BIconCpuFill:a["ei"],BIconCreditCard:a["fi"],BIconCreditCard2Back:a["gi"],BIconCreditCard2BackFill:a["hi"],BIconCreditCard2Front:a["ii"],BIconCreditCard2FrontFill:a["ji"],BIconCreditCardFill:a["ki"],BIconCrop:a["li"],BIconCup:a["mi"],BIconCupFill:a["ni"],BIconCupStraw:a["oi"],BIconCursor:a["pi"],BIconCursorFill:a["qi"],BIconCursorText:a["ri"],BIconDash:a["si"],BIconDashCircle:a["ti"],BIconDashCircleFill:a["ui"],BIconDashSquare:a["vi"],BIconDashSquareFill:a["wi"],BIconDiagram2:a["xi"],BIconDiagram2Fill:a["yi"],BIconDiagram3:a["zi"],BIconDiagram3Fill:a["Ai"],BIconDiamond:a["Bi"],BIconDiamondFill:a["Ci"],BIconDiamondHalf:a["Di"],BIconDice1:a["Ei"],BIconDice1Fill:a["Fi"],BIconDice2:a["Gi"],BIconDice2Fill:a["Hi"],BIconDice3:a["Ii"],BIconDice3Fill:a["Ji"],BIconDice4:a["Ki"],BIconDice4Fill:a["Li"],BIconDice5:a["Mi"],BIconDice5Fill:a["Ni"],BIconDice6:a["Oi"],BIconDice6Fill:a["Pi"],BIconDisc:a["Qi"],BIconDiscFill:a["Ri"],BIconDiscord:a["Si"],BIconDisplay:a["Ti"],BIconDisplayFill:a["Ui"],BIconDistributeHorizontal:a["Vi"],BIconDistributeVertical:a["Wi"],BIconDoorClosed:a["Xi"],BIconDoorClosedFill:a["Yi"],BIconDoorOpen:a["Zi"],BIconDoorOpenFill:a["aj"],BIconDot:a["bj"],BIconDownload:a["cj"],BIconDroplet:a["dj"],BIconDropletFill:a["ej"],BIconDropletHalf:a["fj"],BIconEarbuds:a["gj"],BIconEasel:a["hj"],BIconEaselFill:a["ij"],BIconEgg:a["jj"],BIconEggFill:a["kj"],BIconEggFried:a["lj"],BIconEject:a["mj"],BIconEjectFill:a["nj"],BIconEmojiAngry:a["oj"],BIconEmojiAngryFill:a["pj"],BIconEmojiDizzy:a["qj"],BIconEmojiDizzyFill:a["rj"],BIconEmojiExpressionless:a["sj"],BIconEmojiExpressionlessFill:a["tj"],BIconEmojiFrown:a["uj"],BIconEmojiFrownFill:a["vj"],BIconEmojiHeartEyes:a["wj"],BIconEmojiHeartEyesFill:a["xj"],BIconEmojiLaughing:a["yj"],BIconEmojiLaughingFill:a["zj"],BIconEmojiNeutral:a["Aj"],BIconEmojiNeutralFill:a["Bj"],BIconEmojiSmile:a["Cj"],BIconEmojiSmileFill:a["Dj"],BIconEmojiSmileUpsideDown:a["Ej"],BIconEmojiSmileUpsideDownFill:a["Fj"],BIconEmojiSunglasses:a["Gj"],BIconEmojiSunglassesFill:a["Hj"],BIconEmojiWink:a["Ij"],BIconEmojiWinkFill:a["Jj"],BIconEnvelope:a["Kj"],BIconEnvelopeFill:a["Lj"],BIconEnvelopeOpen:a["Mj"],BIconEnvelopeOpenFill:a["Nj"],BIconExclamation:a["Oj"],BIconExclamationCircle:a["Pj"],BIconExclamationCircleFill:a["Qj"],BIconExclamationDiamond:a["Rj"],BIconExclamationDiamondFill:a["Sj"],BIconExclamationOctagon:a["Tj"],BIconExclamationOctagonFill:a["Uj"],BIconExclamationSquare:a["Vj"],BIconExclamationSquareFill:a["Wj"],BIconExclamationTriangle:a["Xj"],BIconExclamationTriangleFill:a["Yj"],BIconExclude:a["Zj"],BIconEye:a["ak"],BIconEyeFill:a["bk"],BIconEyeSlash:a["ck"],BIconEyeSlashFill:a["dk"],BIconEyeglasses:a["ek"],BIconFacebook:a["fk"],BIconFile:a["gk"],BIconFileArrowDown:a["hk"],BIconFileArrowDownFill:a["ik"],BIconFileArrowUp:a["jk"],BIconFileArrowUpFill:a["kk"],BIconFileBarGraph:a["lk"],BIconFileBarGraphFill:a["mk"],BIconFileBinary:a["nk"],BIconFileBinaryFill:a["ok"],BIconFileBreak:a["pk"],BIconFileBreakFill:a["qk"],BIconFileCheck:a["rk"],BIconFileCheckFill:a["sk"],BIconFileCode:a["tk"],BIconFileCodeFill:a["uk"],BIconFileDiff:a["vk"],BIconFileDiffFill:a["wk"],BIconFileEarmark:a["xk"],BIconFileEarmarkArrowDown:a["yk"],BIconFileEarmarkArrowDownFill:a["zk"],BIconFileEarmarkArrowUp:a["Ak"],BIconFileEarmarkArrowUpFill:a["Bk"],BIconFileEarmarkBarGraph:a["Ck"],BIconFileEarmarkBarGraphFill:a["Dk"],BIconFileEarmarkBinary:a["Ek"],BIconFileEarmarkBinaryFill:a["Fk"],BIconFileEarmarkBreak:a["Gk"],BIconFileEarmarkBreakFill:a["Hk"],BIconFileEarmarkCheck:a["Ik"],BIconFileEarmarkCheckFill:a["Jk"],BIconFileEarmarkCode:a["Kk"],BIconFileEarmarkCodeFill:a["Lk"],BIconFileEarmarkDiff:a["Mk"],BIconFileEarmarkDiffFill:a["Nk"],BIconFileEarmarkEasel:a["Ok"],BIconFileEarmarkEaselFill:a["Pk"],BIconFileEarmarkExcel:a["Qk"],BIconFileEarmarkExcelFill:a["Rk"],BIconFileEarmarkFill:a["Sk"],BIconFileEarmarkFont:a["Tk"],BIconFileEarmarkFontFill:a["Uk"],BIconFileEarmarkImage:a["Vk"],BIconFileEarmarkImageFill:a["Wk"],BIconFileEarmarkLock:a["Xk"],BIconFileEarmarkLock2:a["Yk"],BIconFileEarmarkLock2Fill:a["Zk"],BIconFileEarmarkLockFill:a["al"],BIconFileEarmarkMedical:a["bl"],BIconFileEarmarkMedicalFill:a["cl"],BIconFileEarmarkMinus:a["dl"],BIconFileEarmarkMinusFill:a["el"],BIconFileEarmarkMusic:a["fl"],BIconFileEarmarkMusicFill:a["gl"],BIconFileEarmarkPerson:a["hl"],BIconFileEarmarkPersonFill:a["il"],BIconFileEarmarkPlay:a["jl"],BIconFileEarmarkPlayFill:a["kl"],BIconFileEarmarkPlus:a["ll"],BIconFileEarmarkPlusFill:a["ml"],BIconFileEarmarkPost:a["nl"],BIconFileEarmarkPostFill:a["ol"],BIconFileEarmarkPpt:a["pl"],BIconFileEarmarkPptFill:a["ql"],BIconFileEarmarkRichtext:a["rl"],BIconFileEarmarkRichtextFill:a["sl"],BIconFileEarmarkRuled:a["tl"],BIconFileEarmarkRuledFill:a["ul"],BIconFileEarmarkSlides:a["vl"],BIconFileEarmarkSlidesFill:a["wl"],BIconFileEarmarkSpreadsheet:a["xl"],BIconFileEarmarkSpreadsheetFill:a["yl"],BIconFileEarmarkText:a["zl"],BIconFileEarmarkTextFill:a["Al"],BIconFileEarmarkWord:a["Bl"],BIconFileEarmarkWordFill:a["Cl"],BIconFileEarmarkX:a["Dl"],BIconFileEarmarkXFill:a["El"],BIconFileEarmarkZip:a["Fl"],BIconFileEarmarkZipFill:a["Gl"],BIconFileEasel:a["Hl"],BIconFileEaselFill:a["Il"],BIconFileExcel:a["Jl"],BIconFileExcelFill:a["Kl"],BIconFileFill:a["Ll"],BIconFileFont:a["Ml"],BIconFileFontFill:a["Nl"],BIconFileImage:a["Ol"],BIconFileImageFill:a["Pl"],BIconFileLock:a["Ql"],BIconFileLock2:a["Rl"],BIconFileLock2Fill:a["Sl"],BIconFileLockFill:a["Tl"],BIconFileMedical:a["Ul"],BIconFileMedicalFill:a["Vl"],BIconFileMinus:a["Wl"],BIconFileMinusFill:a["Xl"],BIconFileMusic:a["Yl"],BIconFileMusicFill:a["Zl"],BIconFilePerson:a["am"],BIconFilePersonFill:a["bm"],BIconFilePlay:a["cm"],BIconFilePlayFill:a["dm"],BIconFilePlus:a["em"],BIconFilePlusFill:a["fm"],BIconFilePost:a["gm"],BIconFilePostFill:a["hm"],BIconFilePpt:a["im"],BIconFilePptFill:a["jm"],BIconFileRichtext:a["km"],BIconFileRichtextFill:a["lm"],BIconFileRuled:a["mm"],BIconFileRuledFill:a["nm"],BIconFileSlides:a["om"],BIconFileSlidesFill:a["pm"],BIconFileSpreadsheet:a["qm"],BIconFileSpreadsheetFill:a["rm"],BIconFileText:a["sm"],BIconFileTextFill:a["tm"],BIconFileWord:a["um"],BIconFileWordFill:a["vm"],BIconFileX:a["wm"],BIconFileXFill:a["xm"],BIconFileZip:a["ym"],BIconFileZipFill:a["zm"],BIconFiles:a["Am"],BIconFilesAlt:a["Bm"],BIconFilm:a["Cm"],BIconFilter:a["Dm"],BIconFilterCircle:a["Em"],BIconFilterCircleFill:a["Fm"],BIconFilterLeft:a["Gm"],BIconFilterRight:a["Hm"],BIconFilterSquare:a["Im"],BIconFilterSquareFill:a["Jm"],BIconFlag:a["Km"],BIconFlagFill:a["Lm"],BIconFlower1:a["Mm"],BIconFlower2:a["Nm"],BIconFlower3:a["Om"],BIconFolder:a["Pm"],BIconFolder2:a["Qm"],BIconFolder2Open:a["Rm"],BIconFolderCheck:a["Sm"],BIconFolderFill:a["Tm"],BIconFolderMinus:a["Um"],BIconFolderPlus:a["Vm"],BIconFolderSymlink:a["Wm"],BIconFolderSymlinkFill:a["Xm"],BIconFolderX:a["Ym"],BIconFonts:a["Zm"],BIconForward:a["an"],BIconForwardFill:a["bn"],BIconFront:a["cn"],BIconFullscreen:a["dn"],BIconFullscreenExit:a["en"],BIconFunnel:a["fn"],BIconFunnelFill:a["gn"],BIconGear:a["hn"],BIconGearFill:a["in"],BIconGearWide:a["jn"],BIconGearWideConnected:a["kn"],BIconGem:a["ln"],BIconGeo:a["mn"],BIconGeoAlt:a["nn"],BIconGeoAltFill:a["on"],BIconGeoFill:a["pn"],BIconGift:a["qn"],BIconGiftFill:a["rn"],BIconGithub:a["sn"],BIconGlobe:a["tn"],BIconGlobe2:a["un"],BIconGoogle:a["vn"],BIconGraphDown:a["wn"],BIconGraphUp:a["xn"],BIconGrid:a["yn"],BIconGrid1x2:a["zn"],BIconGrid1x2Fill:a["An"],BIconGrid3x2:a["Bn"],BIconGrid3x2Gap:a["Cn"],BIconGrid3x2GapFill:a["Dn"],BIconGrid3x3:a["En"],BIconGrid3x3Gap:a["Fn"],BIconGrid3x3GapFill:a["Gn"],BIconGridFill:a["Hn"],BIconGripHorizontal:a["In"],BIconGripVertical:a["Jn"],BIconHammer:a["Kn"],BIconHandIndex:a["Ln"],BIconHandIndexThumb:a["Mn"],BIconHandThumbsDown:a["Nn"],BIconHandThumbsUp:a["On"],BIconHandbag:a["Pn"],BIconHandbagFill:a["Qn"],BIconHash:a["Rn"],BIconHdd:a["Sn"],BIconHddFill:a["Tn"],BIconHddNetwork:a["Un"],BIconHddNetworkFill:a["Vn"],BIconHddRack:a["Wn"],BIconHddRackFill:a["Xn"],BIconHddStack:a["Yn"],BIconHddStackFill:a["Zn"],BIconHeadphones:a["ao"],BIconHeadset:a["bo"],BIconHeart:a["co"],BIconHeartFill:a["do"],BIconHeartHalf:a["eo"],BIconHeptagon:a["fo"],BIconHeptagonFill:a["go"],BIconHeptagonHalf:a["ho"],BIconHexagon:a["io"],BIconHexagonFill:a["jo"],BIconHexagonHalf:a["ko"],BIconHourglass:a["lo"],BIconHourglassBottom:a["mo"],BIconHourglassSplit:a["no"],BIconHourglassTop:a["oo"],BIconHouse:a["po"],BIconHouseDoor:a["qo"],BIconHouseDoorFill:a["ro"],BIconHouseFill:a["so"],BIconHr:a["to"],BIconImage:a["uo"],BIconImageAlt:a["vo"],BIconImageFill:a["wo"],BIconImages:a["xo"],BIconInbox:a["yo"],BIconInboxFill:a["zo"],BIconInboxes:a["Ao"],BIconInboxesFill:a["Bo"],BIconInfo:a["Co"],BIconInfoCircle:a["Do"],BIconInfoCircleFill:a["Eo"],BIconInfoSquare:a["Fo"],BIconInfoSquareFill:a["Go"],BIconInputCursor:a["Ho"],BIconInputCursorText:a["Io"],BIconInstagram:a["Jo"],BIconIntersect:a["Ko"],BIconJournal:a["Lo"],BIconJournalAlbum:a["Mo"],BIconJournalArrowDown:a["No"],BIconJournalArrowUp:a["Oo"],BIconJournalBookmark:a["Po"],BIconJournalBookmarkFill:a["Qo"],BIconJournalCheck:a["Ro"],BIconJournalCode:a["So"],BIconJournalMedical:a["To"],BIconJournalMinus:a["Uo"],BIconJournalPlus:a["Vo"],BIconJournalRichtext:a["Wo"],BIconJournalText:a["Xo"],BIconJournalX:a["Yo"],BIconJournals:a["Zo"],BIconJoystick:a["ap"],BIconJustify:a["bp"],BIconJustifyLeft:a["cp"],BIconJustifyRight:a["dp"],BIconKanban:a["ep"],BIconKanbanFill:a["fp"],BIconKey:a["gp"],BIconKeyFill:a["hp"],BIconKeyboard:a["ip"],BIconKeyboardFill:a["jp"],BIconLadder:a["kp"],BIconLamp:a["lp"],BIconLampFill:a["mp"],BIconLaptop:a["np"],BIconLaptopFill:a["op"],BIconLayers:a["pp"],BIconLayersFill:a["qp"],BIconLayersHalf:a["rp"],BIconLayoutSidebar:a["sp"],BIconLayoutSidebarInset:a["tp"],BIconLayoutSidebarInsetReverse:a["up"],BIconLayoutSidebarReverse:a["vp"],BIconLayoutSplit:a["wp"],BIconLayoutTextSidebar:a["xp"],BIconLayoutTextSidebarReverse:a["yp"],BIconLayoutTextWindow:a["zp"],BIconLayoutTextWindowReverse:a["Ap"],BIconLayoutThreeColumns:a["Bp"],BIconLayoutWtf:a["Cp"],BIconLifePreserver:a["Dp"],BIconLightning:a["Ep"],BIconLightningFill:a["Fp"],BIconLink:a["Gp"],BIconLink45deg:a["Hp"],BIconLinkedin:a["Ip"],BIconList:a["Jp"],BIconListCheck:a["Kp"],BIconListNested:a["Lp"],BIconListOl:a["Mp"],BIconListStars:a["Np"],BIconListTask:a["Op"],BIconListUl:a["Pp"],BIconLock:a["Qp"],BIconLockFill:a["Rp"],BIconMailbox:a["Sp"],BIconMailbox2:a["Tp"],BIconMap:a["Up"],BIconMapFill:a["Vp"],BIconMarkdown:a["Wp"],BIconMarkdownFill:a["Xp"],BIconMenuApp:a["Yp"],BIconMenuAppFill:a["Zp"],BIconMenuButton:a["aq"],BIconMenuButtonFill:a["bq"],BIconMenuButtonWide:a["cq"],BIconMenuButtonWideFill:a["dq"],BIconMenuDown:a["eq"],BIconMenuUp:a["fq"],BIconMic:a["gq"],BIconMicFill:a["hq"],BIconMicMute:a["iq"],BIconMicMuteFill:a["jq"],BIconMinecart:a["kq"],BIconMinecartLoaded:a["lq"],BIconMoon:a["mq"],BIconMouse:a["nq"],BIconMouse2:a["oq"],BIconMouse3:a["pq"],BIconMusicNote:a["qq"],BIconMusicNoteBeamed:a["rq"],BIconMusicNoteList:a["sq"],BIconMusicPlayer:a["tq"],BIconMusicPlayerFill:a["uq"],BIconNewspaper:a["vq"],BIconNodeMinus:a["wq"],BIconNodeMinusFill:a["xq"],BIconNodePlus:a["yq"],BIconNodePlusFill:a["zq"],BIconNut:a["Aq"],BIconNutFill:a["Bq"],BIconOctagon:a["Cq"],BIconOctagonFill:a["Dq"],BIconOctagonHalf:a["Eq"],BIconOption:a["Fq"],BIconOutlet:a["Gq"],BIconPaperclip:a["Hq"],BIconParagraph:a["Iq"],BIconPatchCheck:a["Jq"],BIconPatchCheckFill:a["Kq"],BIconPatchExclamation:a["Lq"],BIconPatchExclamationFill:a["Mq"],BIconPatchMinus:a["Nq"],BIconPatchMinusFill:a["Oq"],BIconPatchPlus:a["Pq"],BIconPatchPlusFill:a["Qq"],BIconPatchQuestion:a["Rq"],BIconPatchQuestionFill:a["Sq"],BIconPause:a["Tq"],BIconPauseBtn:a["Uq"],BIconPauseBtnFill:a["Vq"],BIconPauseCircle:a["Wq"],BIconPauseCircleFill:a["Xq"],BIconPauseFill:a["Yq"],BIconPeace:a["Zq"],BIconPeaceFill:a["ar"],BIconPen:a["br"],BIconPenFill:a["cr"],BIconPencil:a["dr"],BIconPencilFill:a["er"],BIconPencilSquare:a["fr"],BIconPentagon:a["gr"],BIconPentagonFill:a["hr"],BIconPentagonHalf:a["ir"],BIconPeople:a["jr"],BIconPeopleFill:a["kr"],BIconPercent:a["lr"],BIconPerson:a["mr"],BIconPersonBadge:a["nr"],BIconPersonBadgeFill:a["or"],BIconPersonBoundingBox:a["pr"],BIconPersonCheck:a["qr"],BIconPersonCheckFill:a["rr"],BIconPersonCircle:a["sr"],BIconPersonDash:a["tr"],BIconPersonDashFill:a["ur"],BIconPersonFill:a["vr"],BIconPersonLinesFill:a["wr"],BIconPersonPlus:a["xr"],BIconPersonPlusFill:a["yr"],BIconPersonSquare:a["zr"],BIconPersonX:a["Ar"],BIconPersonXFill:a["Br"],BIconPhone:a["Cr"],BIconPhoneFill:a["Dr"],BIconPhoneLandscape:a["Er"],BIconPhoneLandscapeFill:a["Fr"],BIconPhoneVibrate:a["Gr"],BIconPieChart:a["Hr"],BIconPieChartFill:a["Ir"],BIconPip:a["Jr"],BIconPipFill:a["Kr"],BIconPlay:a["Lr"],BIconPlayBtn:a["Mr"],BIconPlayBtnFill:a["Nr"],BIconPlayCircle:a["Or"],BIconPlayCircleFill:a["Pr"],BIconPlayFill:a["Qr"],BIconPlug:a["Rr"],BIconPlugFill:a["Sr"],BIconPlus:a["Tr"],BIconPlusCircle:a["Ur"],BIconPlusCircleFill:a["Vr"],BIconPlusSquare:a["Wr"],BIconPlusSquareFill:a["Xr"],BIconPower:a["Yr"],BIconPrinter:a["Zr"],BIconPrinterFill:a["as"],BIconPuzzle:a["bs"],BIconPuzzleFill:a["cs"],BIconQuestion:a["ds"],BIconQuestionCircle:a["es"],BIconQuestionCircleFill:a["fs"],BIconQuestionDiamond:a["gs"],BIconQuestionDiamondFill:a["hs"],BIconQuestionOctagon:a["is"],BIconQuestionOctagonFill:a["js"],BIconQuestionSquare:a["ks"],BIconQuestionSquareFill:a["ls"],BIconReceipt:a["ms"],BIconReceiptCutoff:a["ns"],BIconReception0:a["os"],BIconReception1:a["ps"],BIconReception2:a["qs"],BIconReception3:a["rs"],BIconReception4:a["ss"],BIconRecord:a["ts"],BIconRecord2:a["us"],BIconRecord2Fill:a["vs"],BIconRecordBtn:a["ws"],BIconRecordBtnFill:a["xs"],BIconRecordCircle:a["ys"],BIconRecordCircleFill:a["zs"],BIconRecordFill:a["As"],BIconReply:a["Bs"],BIconReplyAll:a["Cs"],BIconReplyAllFill:a["Ds"],BIconReplyFill:a["Es"],BIconRss:a["Fs"],BIconRssFill:a["Gs"],BIconScissors:a["Hs"],BIconScrewdriver:a["Is"],BIconSearch:a["Js"],BIconSegmentedNav:a["Ks"],BIconServer:a["Ls"],BIconShare:a["Ms"],BIconShareFill:a["Ns"],BIconShield:a["Os"],BIconShieldCheck:a["Ps"],BIconShieldExclamation:a["Qs"],BIconShieldFill:a["Rs"],BIconShieldFillCheck:a["Ss"],BIconShieldFillExclamation:a["Ts"],BIconShieldFillMinus:a["Us"],BIconShieldFillPlus:a["Vs"],BIconShieldFillX:a["Ws"],BIconShieldLock:a["Xs"],BIconShieldLockFill:a["Ys"],BIconShieldMinus:a["Zs"],BIconShieldPlus:a["at"],BIconShieldShaded:a["bt"],BIconShieldSlash:a["ct"],BIconShieldSlashFill:a["dt"],BIconShieldX:a["et"],BIconShift:a["ft"],BIconShiftFill:a["gt"],BIconShop:a["ht"],BIconShopWindow:a["it"],BIconShuffle:a["jt"],BIconSignpost:a["kt"],BIconSignpost2:a["lt"],BIconSignpost2Fill:a["mt"],BIconSignpostFill:a["nt"],BIconSignpostSplit:a["ot"],BIconSignpostSplitFill:a["pt"],BIconSim:a["qt"],BIconSimFill:a["rt"],BIconSkipBackward:a["st"],BIconSkipBackwardBtn:a["tt"],BIconSkipBackwardBtnFill:a["ut"],BIconSkipBackwardCircle:a["vt"],BIconSkipBackwardCircleFill:a["wt"],BIconSkipBackwardFill:a["xt"],BIconSkipEnd:a["yt"],BIconSkipEndBtn:a["zt"],BIconSkipEndBtnFill:a["At"],BIconSkipEndCircle:a["Bt"],BIconSkipEndCircleFill:a["Ct"],BIconSkipEndFill:a["Dt"],BIconSkipForward:a["Et"],BIconSkipForwardBtn:a["Ft"],BIconSkipForwardBtnFill:a["Gt"],BIconSkipForwardCircle:a["Ht"],BIconSkipForwardCircleFill:a["It"],BIconSkipForwardFill:a["Jt"],BIconSkipStart:a["Kt"],BIconSkipStartBtn:a["Lt"],BIconSkipStartBtnFill:a["Mt"],BIconSkipStartCircle:a["Nt"],BIconSkipStartCircleFill:a["Ot"],BIconSkipStartFill:a["Pt"],BIconSlack:a["Qt"],BIconSlash:a["Rt"],BIconSlashCircle:a["St"],BIconSlashCircleFill:a["Tt"],BIconSlashSquare:a["Ut"],BIconSlashSquareFill:a["Vt"],BIconSliders:a["Wt"],BIconSmartwatch:a["Xt"],BIconSortAlphaDown:a["Yt"],BIconSortAlphaDownAlt:a["Zt"],BIconSortAlphaUp:a["au"],BIconSortAlphaUpAlt:a["bu"],BIconSortDown:a["cu"],BIconSortDownAlt:a["du"],BIconSortNumericDown:a["eu"],BIconSortNumericDownAlt:a["fu"],BIconSortNumericUp:a["gu"],BIconSortNumericUpAlt:a["hu"],BIconSortUp:a["iu"],BIconSortUpAlt:a["ju"],BIconSoundwave:a["ku"],BIconSpeaker:a["lu"],BIconSpeakerFill:a["mu"],BIconSpellcheck:a["nu"],BIconSquare:a["ou"],BIconSquareFill:a["pu"],BIconSquareHalf:a["qu"],BIconStar:a["ru"],BIconStarFill:a["su"],BIconStarHalf:a["tu"],BIconStickies:a["uu"],BIconStickiesFill:a["vu"],BIconSticky:a["wu"],BIconStickyFill:a["xu"],BIconStop:a["yu"],BIconStopBtn:a["zu"],BIconStopBtnFill:a["Au"],BIconStopCircle:a["Bu"],BIconStopCircleFill:a["Cu"],BIconStopFill:a["Du"],BIconStoplights:a["Eu"],BIconStoplightsFill:a["Fu"],BIconStopwatch:a["Gu"],BIconStopwatchFill:a["Hu"],BIconSubtract:a["Iu"],BIconSuitClub:a["Ju"],BIconSuitClubFill:a["Ku"],BIconSuitDiamond:a["Lu"],BIconSuitDiamondFill:a["Mu"],BIconSuitHeart:a["Nu"],BIconSuitHeartFill:a["Ou"],BIconSuitSpade:a["Pu"],BIconSuitSpadeFill:a["Qu"],BIconSun:a["Ru"],BIconSunglasses:a["Su"],BIconTable:a["Tu"],BIconTablet:a["Uu"],BIconTabletFill:a["Vu"],BIconTabletLandscape:a["Wu"],BIconTabletLandscapeFill:a["Xu"],BIconTag:a["Yu"],BIconTagFill:a["Zu"],BIconTags:a["av"],BIconTagsFill:a["bv"],BIconTelephone:a["cv"],BIconTelephoneFill:a["dv"],BIconTelephoneForward:a["ev"],BIconTelephoneForwardFill:a["fv"],BIconTelephoneInbound:a["gv"],BIconTelephoneInboundFill:a["hv"],BIconTelephoneMinus:a["iv"],BIconTelephoneMinusFill:a["jv"],BIconTelephoneOutbound:a["kv"],BIconTelephoneOutboundFill:a["lv"],BIconTelephonePlus:a["mv"],BIconTelephonePlusFill:a["nv"],BIconTelephoneX:a["ov"],BIconTelephoneXFill:a["pv"],BIconTerminal:a["qv"],BIconTerminalFill:a["rv"],BIconTextCenter:a["sv"],BIconTextIndentLeft:a["tv"],BIconTextIndentRight:a["uv"],BIconTextLeft:a["vv"],BIconTextParagraph:a["wv"],BIconTextRight:a["xv"],BIconTextarea:a["yv"],BIconTextareaResize:a["zv"],BIconTextareaT:a["Av"],BIconThermometer:a["Bv"],BIconThermometerHalf:a["Cv"],BIconThreeDots:a["Dv"],BIconThreeDotsVertical:a["Ev"],BIconToggle2Off:a["Fv"],BIconToggle2On:a["Gv"],BIconToggleOff:a["Hv"],BIconToggleOn:a["Iv"],BIconToggles:a["Jv"],BIconToggles2:a["Kv"],BIconTools:a["Lv"],BIconTrash:a["Mv"],BIconTrash2:a["Nv"],BIconTrash2Fill:a["Ov"],BIconTrashFill:a["Pv"],BIconTree:a["Qv"],BIconTreeFill:a["Rv"],BIconTriangle:a["Sv"],BIconTriangleFill:a["Tv"],BIconTriangleHalf:a["Uv"],BIconTrophy:a["Vv"],BIconTrophyFill:a["Wv"],BIconTruck:a["Xv"],BIconTruckFlatbed:a["Yv"],BIconTv:a["Zv"],BIconTvFill:a["aw"],BIconTwitch:a["bw"],BIconTwitter:a["cw"],BIconType:a["dw"],BIconTypeBold:a["ew"],BIconTypeH1:a["fw"],BIconTypeH2:a["gw"],BIconTypeH3:a["hw"],BIconTypeItalic:a["iw"],BIconTypeStrikethrough:a["jw"],BIconTypeUnderline:a["kw"],BIconUiChecks:a["lw"],BIconUiChecksGrid:a["mw"],BIconUiRadios:a["nw"],BIconUiRadiosGrid:a["ow"],BIconUnion:a["pw"],BIconUnlock:a["qw"],BIconUnlockFill:a["rw"],BIconUpc:a["sw"],BIconUpcScan:a["tw"],BIconUpload:a["uw"],BIconVectorPen:a["vw"],BIconViewList:a["ww"],BIconViewStacked:a["xw"],BIconVinyl:a["yw"],BIconVinylFill:a["zw"],BIconVoicemail:a["Aw"],BIconVolumeDown:a["Bw"],BIconVolumeDownFill:a["Cw"],BIconVolumeMute:a["Dw"],BIconVolumeMuteFill:a["Ew"],BIconVolumeOff:a["Fw"],BIconVolumeOffFill:a["Gw"],BIconVolumeUp:a["Hw"],BIconVolumeUpFill:a["Iw"],BIconVr:a["Jw"],BIconWallet:a["Kw"],BIconWallet2:a["Lw"],BIconWalletFill:a["Mw"],BIconWatch:a["Nw"],BIconWifi:a["Ow"],BIconWifi1:a["Pw"],BIconWifi2:a["Qw"],BIconWifiOff:a["Rw"],BIconWindow:a["Sw"],BIconWrench:a["Tw"],BIconX:a["Uw"],BIconXCircle:a["Vw"],BIconXCircleFill:a["Ww"],BIconXDiamond:a["Xw"],BIconXDiamondFill:a["Yw"],BIconXOctagon:a["Zw"],BIconXOctagonFill:a["ax"],BIconXSquare:a["bx"],BIconXSquareFill:a["cx"],BIconYoutube:a["dx"],BIconZoomIn:a["ex"],BIconZoomOut:a["fx"]}})},b42e:function(t,e,n){"use strict";n.d(e,"a",(function(){return s}));var r=function(){return(r=Object.assign||function(t){for(var e,n=1,r=arguments.length;n<r;n++)for(var i in e=arguments[n])Object.prototype.hasOwnProperty.call(e,i)&&(t[i]=e[i]);return t}).apply(this,arguments)},i={kebab:/-(\w)/g,styleProp:/:(.*)/,styleList:/;(?![^(]*\))/g};function o(t,e){return e?e.toUpperCase():""}function a(t){for(var e,n={},r=0,a=t.split(i.styleList);r<a.length;r++){var s=a[r].split(i.styleProp),c=s[0],l=s[1];(c=c.trim())&&("string"==typeof l&&(l=l.trim()),n[(e=c,e.replace(i.kebab,o))]=l)}return n}function s(){for(var t,e,n={},i=arguments.length;i--;)for(var o=0,s=Object.keys(arguments[i]);o<s.length;o++)switch(t=s[o]){case"class":case"style":case"directives":if(Array.isArray(n[t])||(n[t]=[]),"style"===t){var c=void 0;c=Array.isArray(arguments[i].style)?arguments[i].style:[arguments[i].style];for(var l=0;l<c.length;l++){var u=c[l];"string"==typeof u&&(c[l]=a(u))}arguments[i].style=c}n[t]=n[t].concat(arguments[i][t]);break;case"staticClass":if(!arguments[i][t])break;void 0===n[t]&&(n[t]=""),n[t]&&(n[t]+=" "),n[t]+=arguments[i][t].trim();break;case"on":case"nativeOn":n[t]||(n[t]={});for(var d=0,h=Object.keys(arguments[i][t]||{});d<h.length;d++)e=h[d],n[t][e]?n[t][e]=[].concat(n[t][e],arguments[i][t][e]):n[t][e]=arguments[i][t][e];break;case"attrs":case"props":case"domProps":case"scopedSlots":case"staticStyle":case"hook":case"transition":n[t]||(n[t]={}),n[t]=r({},arguments[i][t],n[t]);break;case"slot":case"key":case"ref":case"tag":case"show":case"keepAlive":default:n[t]||(n[t]=arguments[i][t])}return n}},b508:function(t,e,n){"use strict";n.d(e,"a",(function(){return i}));var r=n("d82f"),i=function(t){var e=Object(r["c"])(null);return function(){for(var n=arguments.length,r=new Array(n),i=0;i<n;i++)r[i]=arguments[i];var o=JSON.stringify(r);return e[o]=e[o]||t.apply(null,r)}}},b50d:function(t,e,n){"use strict";var r=n("c532"),i=n("467f"),o=n("7aac"),a=n("30b5"),s=n("83b9"),c=n("c345"),l=n("3934"),u=n("2d83");t.exports=function(t){return new Promise((function(e,n){var d=t.data,h=t.headers;r.isFormData(d)&&delete h["Content-Type"];var f=new XMLHttpRequest;if(t.auth){var p=t.auth.username||"",m=t.auth.password?unescape(encodeURIComponent(t.auth.password)):"";h.Authorization="Basic "+btoa(p+":"+m)}var b=s(t.baseURL,t.url);if(f.open(t.method.toUpperCase(),a(b,t.params,t.paramsSerializer),!0),f.timeout=t.timeout,f.onreadystatechange=function(){if(f&&4===f.readyState&&(0!==f.status||f.responseURL&&0===f.responseURL.indexOf("file:"))){var r="getAllResponseHeaders"in f?c(f.getAllResponseHeaders()):null,o=t.responseType&&"text"!==t.responseType?f.response:f.responseText,a={data:o,status:f.status,statusText:f.statusText,headers:r,config:t,request:f};i(e,n,a),f=null}},f.onabort=function(){f&&(n(u("Request aborted",t,"ECONNABORTED",f)),f=null)},f.onerror=function(){n(u("Network Error",t,null,f)),f=null},f.ontimeout=function(){var e="timeout of "+t.timeout+"ms exceeded";t.timeoutErrorMessage&&(e=t.timeoutErrorMessage),n(u(e,t,"ECONNABORTED",f)),f=null},r.isStandardBrowserEnv()){var g=(t.withCredentials||l(b))&&t.xsrfCookieName?o.read(t.xsrfCookieName):void 0;g&&(h[t.xsrfHeaderName]=g)}if("setRequestHeader"in f&&r.forEach(h,(function(t,e){"undefined"===typeof d&&"content-type"===e.toLowerCase()?delete h[e]:f.setRequestHeader(e,t)})),r.isUndefined(t.withCredentials)||(f.withCredentials=!!t.withCredentials),t.responseType)try{f.responseType=t.responseType}catch(v){if("json"!==t.responseType)throw v}"function"===typeof t.onDownloadProgress&&f.addEventListener("progress",t.onDownloadProgress),"function"===typeof t.onUploadProgress&&f.upload&&f.upload.addEventListener("progress",t.onUploadProgress),t.cancelToken&&t.cancelToken.promise.then((function(t){f&&(f.abort(),n(t),f=null)})),d||(d=null),f.send(d)}))}},bc3a:function(t,e,n){t.exports=n("cee4")},c345:function(t,e,n){"use strict";var r=n("c532"),i=["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"];t.exports=function(t){var e,n,o,a={};return t?(r.forEach(t.split("\n"),(function(t){if(o=t.indexOf(":"),e=r.trim(t.substr(0,o)).toLowerCase(),n=r.trim(t.substr(o+1)),e){if(a[e]&&i.indexOf(e)>=0)return;a[e]="set-cookie"===e?(a[e]?a[e]:[]).concat([n]):a[e]?a[e]+", "+n:n}})),a):a}},c401:function(t,e,n){"use strict";var r=n("c532");t.exports=function(t,e,n){return r.forEach(n,(function(n){t=n(t,e)})),t}},c532:function(t,e,n){"use strict";var r=n("1d2b"),i=Object.prototype.toString;function o(t){return"[object Array]"===i.call(t)}function a(t){return"undefined"===typeof t}function s(t){return null!==t&&!a(t)&&null!==t.constructor&&!a(t.constructor)&&"function"===typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}function c(t){return"[object ArrayBuffer]"===i.call(t)}function l(t){return"undefined"!==typeof FormData&&t instanceof FormData}function u(t){var e;return e="undefined"!==typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(t):t&&t.buffer&&t.buffer instanceof ArrayBuffer,e}function d(t){return"string"===typeof t}function h(t){return"number"===typeof t}function f(t){return null!==t&&"object"===typeof t}function p(t){if("[object Object]"!==i.call(t))return!1;var e=Object.getPrototypeOf(t);return null===e||e===Object.prototype}function m(t){return"[object Date]"===i.call(t)}function b(t){return"[object File]"===i.call(t)}function g(t){return"[object Blob]"===i.call(t)}function v(t){return"[object Function]"===i.call(t)}function w(t){return f(t)&&v(t.pipe)}function y(t){return"undefined"!==typeof URLSearchParams&&t instanceof URLSearchParams}function k(t){return t.replace(/^\s*/,"").replace(/\s*$/,"")}function _(){return("undefined"===typeof navigator||"ReactNative"!==navigator.product&&"NativeScript"!==navigator.product&&"NS"!==navigator.product)&&("undefined"!==typeof window&&"undefined"!==typeof document)}function O(t,e){if(null!==t&&"undefined"!==typeof t)if("object"!==typeof t&&(t=[t]),o(t))for(var n=0,r=t.length;n<r;n++)e.call(null,t[n],n,t);else for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&e.call(null,t[i],i,t)}function z(){var t={};function e(e,n){p(t[n])&&p(e)?t[n]=z(t[n],e):p(e)?t[n]=z({},e):o(e)?t[n]=e.slice():t[n]=e}for(var n=0,r=arguments.length;n<r;n++)O(arguments[n],e);return t}function A(t,e,n){return O(e,(function(e,i){t[i]=n&&"function"===typeof e?r(e,n):e})),t}function j(t){return 65279===t.charCodeAt(0)&&(t=t.slice(1)),t}t.exports={isArray:o,isArrayBuffer:c,isBuffer:s,isFormData:l,isArrayBufferView:u,isString:d,isNumber:h,isObject:f,isPlainObject:p,isUndefined:a,isDate:m,isFile:b,isBlob:g,isFunction:v,isStream:w,isURLSearchParams:y,isStandardBrowserEnv:_,forEach:O,merge:z,extend:A,trim:k,stripBOM:j}},c637:function(t,e,n){"use strict";n.d(e,"a",(function(){return r})),n.d(e,"b",(function(){return i})),n.d(e,"c",(function(){return o})),n.d(e,"d",(function(){return a})),n.d(e,"e",(function(){return s})),n.d(e,"f",(function(){return c})),n.d(e,"g",(function(){return l})),n.d(e,"h",(function(){return u})),n.d(e,"i",(function(){return d})),n.d(e,"j",(function(){return h})),n.d(e,"k",(function(){return f})),n.d(e,"l",(function(){return p})),n.d(e,"m",(function(){return m})),n.d(e,"n",(function(){return b})),n.d(e,"o",(function(){return g})),n.d(e,"p",(function(){return v})),n.d(e,"q",(function(){return w})),n.d(e,"r",(function(){return y})),n.d(e,"s",(function(){return k})),n.d(e,"t",(function(){return _})),n.d(e,"u",(function(){return O})),n.d(e,"v",(function(){return z})),n.d(e,"w",(function(){return A})),n.d(e,"x",(function(){return j})),n.d(e,"y",(function(){return M})),n.d(e,"z",(function(){return C})),n.d(e,"A",(function(){return V})),n.d(e,"C",(function(){return S})),n.d(e,"D",(function(){return x})),n.d(e,"E",(function(){return T})),n.d(e,"F",(function(){return P})),n.d(e,"G",(function(){return I})),n.d(e,"H",(function(){return E})),n.d(e,"I",(function(){return L})),n.d(e,"J",(function(){return B})),n.d(e,"K",(function(){return H})),n.d(e,"L",(function(){return F})),n.d(e,"M",(function(){return D})),n.d(e,"O",(function(){return R})),n.d(e,"P",(function(){return N})),n.d(e,"Q",(function(){return $})),n.d(e,"R",(function(){return U})),n.d(e,"S",(function(){return q})),n.d(e,"T",(function(){return W})),n.d(e,"U",(function(){return G})),n.d(e,"V",(function(){return Y})),n.d(e,"W",(function(){return K})),n.d(e,"X",(function(){return Q})),n.d(e,"Y",(function(){return X})),n.d(e,"ab",(function(){return J})),n.d(e,"bb",(function(){return Z})),n.d(e,"cb",(function(){return tt})),n.d(e,"db",(function(){return et})),n.d(e,"eb",(function(){return nt})),n.d(e,"fb",(function(){return rt})),n.d(e,"gb",(function(){return it})),n.d(e,"hb",(function(){return ot})),n.d(e,"ib",(function(){return at})),n.d(e,"jb",(function(){return st})),n.d(e,"kb",(function(){return ct})),n.d(e,"lb",(function(){return lt})),n.d(e,"mb",(function(){return ut})),n.d(e,"nb",(function(){return dt})),n.d(e,"ob",(function(){return ht})),n.d(e,"pb",(function(){return ft})),n.d(e,"qb",(function(){return pt})),n.d(e,"rb",(function(){return mt})),n.d(e,"sb",(function(){return bt})),n.d(e,"tb",(function(){return gt})),n.d(e,"ub",(function(){return vt})),n.d(e,"vb",(function(){return wt})),n.d(e,"wb",(function(){return yt})),n.d(e,"xb",(function(){return kt})),n.d(e,"yb",(function(){return _t})),n.d(e,"zb",(function(){return Ot})),n.d(e,"Ab",(function(){return zt})),n.d(e,"Bb",(function(){return At})),n.d(e,"Cb",(function(){return jt})),n.d(e,"Db",(function(){return Mt})),n.d(e,"Eb",(function(){return Ct})),n.d(e,"Fb",(function(){return Vt})),n.d(e,"Gb",(function(){return St})),n.d(e,"Hb",(function(){return xt})),n.d(e,"Ib",(function(){return Tt})),n.d(e,"Jb",(function(){return Pt})),n.d(e,"Kb",(function(){return It})),n.d(e,"Lb",(function(){return Et})),n.d(e,"Mb",(function(){return Lt})),n.d(e,"Nb",(function(){return Bt})),n.d(e,"Ob",(function(){return Ht})),n.d(e,"Pb",(function(){return Ft})),n.d(e,"Qb",(function(){return Dt})),n.d(e,"Ub",(function(){return Rt})),n.d(e,"Vb",(function(){return Nt})),n.d(e,"Wb",(function(){return $t})),n.d(e,"Xb",(function(){return Ut})),n.d(e,"Yb",(function(){return qt})),n.d(e,"Zb",(function(){return Wt})),n.d(e,"ac",(function(){return Gt})),n.d(e,"bc",(function(){return Yt})),n.d(e,"cc",(function(){return Kt})),n.d(e,"dc",(function(){return Qt})),n.d(e,"ec",(function(){return Xt})),n.d(e,"fc",(function(){return Jt})),n.d(e,"gc",(function(){return Zt})),n.d(e,"hc",(function(){return te})),n.d(e,"ic",(function(){return ee})),n.d(e,"jc",(function(){return ne})),n.d(e,"lc",(function(){return re})),n.d(e,"mc",(function(){return ie})),n.d(e,"nc",(function(){return oe})),n.d(e,"oc",(function(){return ae})),n.d(e,"pc",(function(){return se})),n.d(e,"qc",(function(){return ce})),n.d(e,"rc",(function(){return le})),n.d(e,"tc",(function(){return ue})),n.d(e,"wc",(function(){return de})),n.d(e,"B",(function(){return he})),n.d(e,"N",(function(){return fe})),n.d(e,"Z",(function(){return pe})),n.d(e,"Rb",(function(){return me})),n.d(e,"Sb",(function(){return be})),n.d(e,"Tb",(function(){return ge})),n.d(e,"kc",(function(){return ve})),n.d(e,"sc",(function(){return we})),n.d(e,"uc",(function(){return ye})),n.d(e,"vc",(function(){return ke})),n.d(e,"xc",(function(){return _e})),n.d(e,"yc",(function(){return Oe})),n.d(e,"zc",(function(){return ze}));var r="BAlert",i="BAspect",o="BAvatar",a="BAvatarGroup",s="BBadge",c="BBreadcrumb",l="BBreadcrumbItem",u="BBreadcrumbLink",d="BButton",h="BButtonClose",f="BButtonGroup",p="BButtonToolbar",m="BCalendar",b="BCard",g="BCardBody",v="BCardFooter",w="BCardGroup",y="BCardHeader",k="BCardImg",_="BCardImgLazy",O="BCardSubTitle",z="BCardText",A="BCardTitle",j="BCarousel",M="BCarouselSlide",C="BCol",V="BCollapse",S="BContainer",x="BDropdown",T="BDropdownDivider",P="BDropdownForm",I="BDropdownGroup",E="BDropdownHeader",L="BDropdownItem",B="BDropdownItemButton",H="BDropdownText",F="BEmbed",D="BForm",R="BFormCheckbox",N="BFormCheckboxGroup",$="BFormDatalist",U="BFormDatepicker",q="BFormFile",W="BFormGroup",G="BFormInput",Y="BFormInvalidFeedback",K="BFormRadio",Q="BFormRadioGroup",X="BFormRating",J="BFormRow",Z="BFormSelect",tt="BFormSelectOption",et="BFormSelectOptionGroup",nt="BFormSpinbutton",rt="BFormTag",it="BFormTags",ot="BFormText",at="BFormTextarea",st="BFormTimepicker",ct="BFormValidFeedback",lt="BIcon",ut="BIconstack",dt="BIconBase",ht="BImg",ft="BImgLazy",pt="BInputGroup",mt="BInputGroupAddon",bt="BInputGroupAppend",gt="BInputGroupPrepend",vt="BInputGroupText",wt="BJumbotron",yt="BLink",kt="BListGroup",_t="BListGroupItem",Ot="BMedia",zt="BMediaAside",At="BMediaBody",jt="BModal",Mt="BMsgBox",Ct="BNav",Vt="BNavbar",St="BNavbarBrand",xt="BNavbarNav",Tt="BNavbarToggle",Pt="BNavForm",It="BNavItem",Et="BNavItemDropdown",Lt="BNavText",Bt="BOverlay",Ht="BPagination",Ft="BPaginationNav",Dt="BPopover",Rt="BProgress",Nt="BProgressBar",$t="BRow",Ut="BSidebar",qt="BSkeleton",Wt="BSkeletonIcon",Gt="BSkeletonImg",Yt="BSkeletonTable",Kt="BSkeletonWrapper",Qt="BSpinner",Xt="BTab",Jt="BTable",Zt="BTableCell",te="BTableLite",ee="BTableSimple",ne="BTabs",re="BTbody",ie="BTfoot",oe="BTh",ae="BThead",se="BTime",ce="BToast",le="BToaster",ue="BTooltip",de="BTr",he="BVCollapse",fe="BVFormBtnLabelControl",pe="BVFormRatingStar",me="BVPopover",be="BVPopoverTemplate",ge="BVPopper",ve="BVTabButton",we="BVToastPop",ye="BVTooltip",ke="BVTooltipTemplate",_e="BVTransition",Oe="BVTransporter",ze="BVTransporterTarget"},c8af:function(t,e,n){"use strict";var r=n("c532");t.exports=function(t,e){r.forEach(t,(function(n,r){r!==e&&r.toUpperCase()===e.toUpperCase()&&(t[e]=n,delete t[r])}))}},c8ba:function(t,e){var n;n=function(){return this}();try{n=n||new Function("return this")()}catch(r){"object"===typeof window&&(n=window)}t.exports=n},c9a9:function(t,e,n){"use strict";n.d(e,"a",(function(){return p}));var r=n("7b1e"),i=n("d82f");function o(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function a(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?o(Object(n),!0).forEach((function(e){s(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):o(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function s(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}function c(t){return h(t)||d(t)||u(t)||l()}function l(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function u(t,e){if(t){if("string"===typeof t)return f(t,e);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?f(t,e):void 0}}function d(t){if("undefined"!==typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}function h(t){if(Array.isArray(t))return f(t)}function f(t,e){(null==e||e>t.length)&&(e=t.length);for(var n=0,r=new Array(e);n<e;n++)r[n]=t[n];return r}var p=function t(e){var n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:e;return Object(r["a"])(e)?e.reduce((function(e,n){return[].concat(c(e),[t(n,n)])}),[]):Object(r["k"])(e)?Object(i["h"])(e).reduce((function(n,r){return a(a({},n),{},s({},r,t(e[r],e[r])))}),{}):n}},ca88:function(t,e,n){"use strict";n.d(e,"a",(function(){return b})),n.d(e,"c",(function(){return g})),n.d(e,"d",(function(){return v})),n.d(e,"b",(function(){return w}));var r=n("e863");function i(t){return i="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"===typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},i(t)}function o(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function a(t,e){if("function"!==typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),e&&p(t,e)}function s(t){var e=h();return function(){var n,r=m(t);if(e){var i=m(this).constructor;n=Reflect.construct(r,arguments,i)}else n=r.apply(this,arguments);return c(this,n)}}function c(t,e){return!e||"object"!==i(e)&&"function"!==typeof e?l(t):e}function l(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}function u(t){var e="function"===typeof Map?new Map:void 0;return u=function(t){if(null===t||!f(t))return t;if("function"!==typeof t)throw new TypeError("Super expression must either be null or a function");if("undefined"!==typeof e){if(e.has(t))return e.get(t);e.set(t,n)}function n(){return d(t,arguments,m(this).constructor)}return n.prototype=Object.create(t.prototype,{constructor:{value:n,enumerable:!1,writable:!0,configurable:!0}}),p(n,t)},u(t)}function d(t,e,n){return d=h()?Reflect.construct:function(t,e,n){var r=[null];r.push.apply(r,e);var i=Function.bind.apply(t,r),o=new i;return n&&p(o,n.prototype),o},d.apply(null,arguments)}function h(){if("undefined"===typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],(function(){}))),!0}catch(t){return!1}}function f(t){return-1!==Function.toString.call(t).indexOf("[native code]")}function p(t,e){return p=Object.setPrototypeOf||function(t,e){return t.__proto__=e,t},p(t,e)}function m(t){return m=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)},m(t)}var b=r["h"]?r["k"].Element:function(t){a(n,t);var e=s(n);function n(){return o(this,n),e.apply(this,arguments)}return n}(u(Object)),g=r["h"]?r["k"].HTMLElement:function(t){a(n,t);var e=s(n);function n(){return o(this,n),e.apply(this,arguments)}return n}(b),v=r["h"]?r["k"].SVGElement:function(t){a(n,t);var e=s(n);function n(){return o(this,n),e.apply(this,arguments)}return n}(b),w=r["h"]?r["k"].File:function(t){a(n,t);var e=s(n);function n(){return o(this,n),e.apply(this,arguments)}return n}(u(Object))},cee4:function(t,e,n){"use strict";var r=n("c532"),i=n("1d2b"),o=n("0a06"),a=n("4a7b"),s=n("2444");function c(t){var e=new o(t),n=i(o.prototype.request,e);return r.extend(n,o.prototype,e),r.extend(n,e),n}var l=c(s);l.Axios=o,l.create=function(t){return c(a(l.defaults,t))},l.Cancel=n("7a77"),l.CancelToken=n("8df4"),l.isCancel=n("2e67"),l.all=function(t){return Promise.all(t)},l.spread=n("0df6"),l.isAxiosError=n("5f02"),t.exports=l,t.exports.default=l},cf75:function(t,e,n){"use strict";n.d(e,"f",(function(){return f})),n.d(e,"h",(function(){return p})),n.d(e,"g",(function(){return m})),n.d(e,"c",(function(){return b})),n.d(e,"a",(function(){return g})),n.d(e,"e",(function(){return v})),n.d(e,"d",(function(){return y})),n.d(e,"b",(function(){return _}));var r=n("a723"),i=n("c9a9"),o=n("228e"),a=n("6c06"),s=n("7b1e"),c=n("d82f"),l=n("fa73");function u(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function d(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?u(Object(n),!0).forEach((function(e){h(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):u(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function h(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var f=function(t,e){return t+Object(l["j"])(e)},p=function(t,e){return Object(l["d"])(e.replace(t,""))},m=function(t,e){return e+(t?Object(l["j"])(t):"")},b=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:r["a"],e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:void 0,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:void 0,i=arguments.length>3&&void 0!==arguments[3]?arguments[3]:void 0,o=!0===n;return i=o?i:n,d(d(d({},t?{type:t}:{}),o?{required:o}:Object(s["o"])(e)?{}:{default:Object(s["j"])(e)?function(){return e}:e}),Object(s["o"])(i)?{}:{validator:i})},g=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:a["a"];if(Object(s["a"])(t))return t.map(e);var n={};for(var r in t)Object(c["g"])(t,r)&&(n[e(r)]=Object(s["j"])(t[r])?Object(c["b"])(t[r]):t[r]);return n},v=function(t,e){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:a["a"];return(Object(s["a"])(t)?t.slice():Object(c["h"])(t)).reduce((function(t,r){return t[n(r)]=e[r],t}),{})},w=function(t,e,n){return d(d({},Object(i["a"])(t)),{},{default:function(){var r=Object(o["c"])(n,e,t.default);return Object(s["f"])(r)?r():r}})},y=function(t,e){return Object(c["h"])(t).reduce((function(n,r){return d(d({},n),{},h({},r,w(t[r],r,e)))}),{})},k=w({},"","").default.name,_=function(t){return Object(s["f"])(t)&&t.name!==k}},d82f:function(t,e,n){"use strict";n.d(e,"a",(function(){return s})),n.d(e,"c",(function(){return c})),n.d(e,"d",(function(){return l})),n.d(e,"e",(function(){return u})),n.d(e,"f",(function(){return d})),n.d(e,"h",(function(){return h})),n.d(e,"g",(function(){return f})),n.d(e,"n",(function(){return p})),n.d(e,"b",(function(){return m})),n.d(e,"k",(function(){return b})),n.d(e,"j",(function(){return g})),n.d(e,"i",(function(){return v})),n.d(e,"m",(function(){return w})),n.d(e,"l",(function(){return y}));var r=n("7b1e");function i(t,e){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(t);e&&(r=r.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),n.push.apply(n,r)}return n}function o(t){for(var e=1;e<arguments.length;e++){var n=null!=arguments[e]?arguments[e]:{};e%2?i(Object(n),!0).forEach((function(e){a(t,e,n[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(n)):i(Object(n)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(n,e))}))}return t}function a(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var s=function(){return Object.assign.apply(Object,arguments)},c=function(t,e){return Object.create(t,e)},l=function(t,e){return Object.defineProperties(t,e)},u=function(t,e,n){return Object.defineProperty(t,e,n)},d=function(t){return Object.getOwnPropertyNames(t)},h=function(t){return Object.keys(t)},f=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},p=function(t){return Object.prototype.toString.call(t)},m=function(t){return o({},t)},b=function(t,e){return h(t).filter((function(t){return-1!==e.indexOf(t)})).reduce((function(e,n){return o(o({},e),{},a({},n,t[n]))}),{})},g=function(t,e){return h(t).filter((function(t){return-1===e.indexOf(t)})).reduce((function(e,n){return o(o({},e),{},a({},n,t[n]))}),{})},v=function t(e,n){return Object(r["j"])(e)&&Object(r["j"])(n)&&h(n).forEach((function(i){Object(r["j"])(n[i])?(e[i]&&Object(r["j"])(e[i])||(e[i]=n[i]),t(e[i],n[i])):s(e,a({},i,n[i]))})),e},w=function(t){return h(t).sort().reduce((function(e,n){return o(o({},e),{},a({},n,t[n]))}),{})},y=function(){return{enumerable:!0,configurable:!1,writable:!1}}},d925:function(t,e,n){"use strict";t.exports=function(t){return/^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(t)}},df7c:function(t,e,n){(function(t){function n(t,e){for(var n=0,r=t.length-1;r>=0;r--){var i=t[r];"."===i?t.splice(r,1):".."===i?(t.splice(r,1),n++):n&&(t.splice(r,1),n--)}if(e)for(;n--;n)t.unshift("..");return t}function r(t){"string"!==typeof t&&(t+="");var e,n=0,r=-1,i=!0;for(e=t.length-1;e>=0;--e)if(47===t.charCodeAt(e)){if(!i){n=e+1;break}}else-1===r&&(i=!1,r=e+1);return-1===r?"":t.slice(n,r)}function i(t,e){if(t.filter)return t.filter(e);for(var n=[],r=0;r<t.length;r++)e(t[r],r,t)&&n.push(t[r]);return n}e.resolve=function(){for(var e="",r=!1,o=arguments.length-1;o>=-1&&!r;o--){var a=o>=0?arguments[o]:t.cwd();if("string"!==typeof a)throw new TypeError("Arguments to path.resolve must be strings");a&&(e=a+"/"+e,r="/"===a.charAt(0))}return e=n(i(e.split("/"),(function(t){return!!t})),!r).join("/"),(r?"/":"")+e||"."},e.normalize=function(t){var r=e.isAbsolute(t),a="/"===o(t,-1);return t=n(i(t.split("/"),(function(t){return!!t})),!r).join("/"),t||r||(t="."),t&&a&&(t+="/"),(r?"/":"")+t},e.isAbsolute=function(t){return"/"===t.charAt(0)},e.join=function(){var t=Array.prototype.slice.call(arguments,0);return e.normalize(i(t,(function(t,e){if("string"!==typeof t)throw new TypeError("Arguments to path.join must be strings");return t})).join("/"))},e.relative=function(t,n){function r(t){for(var e=0;e<t.length;e++)if(""!==t[e])break;for(var n=t.length-1;n>=0;n--)if(""!==t[n])break;return e>n?[]:t.slice(e,n-e+1)}t=e.resolve(t).substr(1),n=e.resolve(n).substr(1);for(var i=r(t.split("/")),o=r(n.split("/")),a=Math.min(i.length,o.length),s=a,c=0;c<a;c++)if(i[c]!==o[c]){s=c;break}var l=[];for(c=s;c<i.length;c++)l.push("..");return l=l.concat(o.slice(s)),l.join("/")},e.sep="/",e.delimiter=":",e.dirname=function(t){if("string"!==typeof t&&(t+=""),0===t.length)return".";for(var e=t.charCodeAt(0),n=47===e,r=-1,i=!0,o=t.length-1;o>=1;--o)if(e=t.charCodeAt(o),47===e){if(!i){r=o;break}}else i=!1;return-1===r?n?"/":".":n&&1===r?"/":t.slice(0,r)},e.basename=function(t,e){var n=r(t);return e&&n.substr(-1*e.length)===e&&(n=n.substr(0,n.length-e.length)),n},e.extname=function(t){"string"!==typeof t&&(t+="");for(var e=-1,n=0,r=-1,i=!0,o=0,a=t.length-1;a>=0;--a){var s=t.charCodeAt(a);if(47!==s)-1===r&&(i=!1,r=a+1),46===s?-1===e?e=a:1!==o&&(o=1):-1!==e&&(o=-1);else if(!i){n=a+1;break}}return-1===e||-1===r||0===o||1===o&&e===r-1&&e===n+1?"":t.slice(e,r)};var o="b"==="ab".substr(-1)?function(t,e,n){return t.substr(e,n)}:function(t,e,n){return e<0&&(e=t.length+e),t.substr(e,n)}}).call(this,n("4362"))},e683:function(t,e,n){"use strict";t.exports=function(t,e){return e?t.replace(/\/+$/,"")+"/"+e.replace(/^\/+/,""):t}},e863:function(t,e,n){"use strict";n.d(e,"h",(function(){return r})),n.d(e,"f",(function(){return a})),n.d(e,"c",(function(){return s})),n.d(e,"i",(function(){return c})),n.d(e,"k",(function(){return l})),n.d(e,"a",(function(){return u})),n.d(e,"j",(function(){return f})),n.d(e,"d",(function(){return p})),n.d(e,"g",(function(){return m})),n.d(e,"e",(function(){return b})),n.d(e,"b",(function(){return g}));var r="undefined"!==typeof window,i="undefined"!==typeof document,o="undefined"!==typeof navigator,a="undefined"!==typeof Promise,s="undefined"!==typeof MutationObserver||"undefined"!==typeof WebKitMutationObserver||"undefined"!==typeof MozMutationObserver,c=r&&i&&o,l=r?window:{},u=i?document:{},d=o?navigator:{},h=(d.userAgent||"").toLowerCase(),f=h.indexOf("jsdom")>0,p=(/msie|trident/.test(h),function(){var t=!1;if(c)try{var e={get passive(){t=!0}};l.addEventListener("test",e,e),l.removeEventListener("test",e,e)}catch(n){t=!1}return t}()),m=c&&("ontouchstart"in u.documentElement||d.maxTouchPoints>0),b=c&&Boolean(l.PointerEvent||l.MSPointerEvent),g=c&&"IntersectionObserver"in l&&"IntersectionObserverEntry"in l&&"intersectionRatio"in l.IntersectionObserverEntry.prototype},f0bd:function(t,e,n){"use strict";(function(t){
/**!
 * @fileOverview Kickass library to create and place poppers near their reference elements.
 * @version 1.16.1
 * @license
 * Copyright (c) 2016 Federico Zivolo and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var n="undefined"!==typeof window&&"undefined"!==typeof document&&"undefined"!==typeof navigator,r=function(){for(var t=["Edge","Trident","Firefox"],e=0;e<t.length;e+=1)if(n&&navigator.userAgent.indexOf(t[e])>=0)return 1;return 0}();function i(t){var e=!1;return function(){e||(e=!0,window.Promise.resolve().then((function(){e=!1,t()})))}}function o(t){var e=!1;return function(){e||(e=!0,setTimeout((function(){e=!1,t()}),r))}}var a=n&&window.Promise,s=a?i:o;function c(t){var e={};return t&&"[object Function]"===e.toString.call(t)}function l(t,e){if(1!==t.nodeType)return[];var n=t.ownerDocument.defaultView,r=n.getComputedStyle(t,null);return e?r[e]:r}function u(t){return"HTML"===t.nodeName?t:t.parentNode||t.host}function d(t){if(!t)return document.body;switch(t.nodeName){case"HTML":case"BODY":return t.ownerDocument.body;case"#document":return t.body}var e=l(t),n=e.overflow,r=e.overflowX,i=e.overflowY;return/(auto|scroll|overlay)/.test(n+i+r)?t:d(u(t))}function h(t){return t&&t.referenceNode?t.referenceNode:t}var f=n&&!(!window.MSInputMethodContext||!document.documentMode),p=n&&/MSIE 10/.test(navigator.userAgent);function m(t){return 11===t?f:10===t?p:f||p}function b(t){if(!t)return document.documentElement;var e=m(10)?document.body:null,n=t.offsetParent||null;while(n===e&&t.nextElementSibling)n=(t=t.nextElementSibling).offsetParent;var r=n&&n.nodeName;return r&&"BODY"!==r&&"HTML"!==r?-1!==["TH","TD","TABLE"].indexOf(n.nodeName)&&"static"===l(n,"position")?b(n):n:t?t.ownerDocument.documentElement:document.documentElement}function g(t){var e=t.nodeName;return"BODY"!==e&&("HTML"===e||b(t.firstElementChild)===t)}function v(t){return null!==t.parentNode?v(t.parentNode):t}function w(t,e){if(!t||!t.nodeType||!e||!e.nodeType)return document.documentElement;var n=t.compareDocumentPosition(e)&Node.DOCUMENT_POSITION_FOLLOWING,r=n?t:e,i=n?e:t,o=document.createRange();o.setStart(r,0),o.setEnd(i,0);var a=o.commonAncestorContainer;if(t!==a&&e!==a||r.contains(i))return g(a)?a:b(a);var s=v(t);return s.host?w(s.host,e):w(t,v(e).host)}function y(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"top",n="top"===e?"scrollTop":"scrollLeft",r=t.nodeName;if("BODY"===r||"HTML"===r){var i=t.ownerDocument.documentElement,o=t.ownerDocument.scrollingElement||i;return o[n]}return t[n]}function k(t,e){var n=arguments.length>2&&void 0!==arguments[2]&&arguments[2],r=y(e,"top"),i=y(e,"left"),o=n?-1:1;return t.top+=r*o,t.bottom+=r*o,t.left+=i*o,t.right+=i*o,t}function _(t,e){var n="x"===e?"Left":"Top",r="Left"===n?"Right":"Bottom";return parseFloat(t["border"+n+"Width"])+parseFloat(t["border"+r+"Width"])}function O(t,e,n,r){return Math.max(e["offset"+t],e["scroll"+t],n["client"+t],n["offset"+t],n["scroll"+t],m(10)?parseInt(n["offset"+t])+parseInt(r["margin"+("Height"===t?"Top":"Left")])+parseInt(r["margin"+("Height"===t?"Bottom":"Right")]):0)}function z(t){var e=t.body,n=t.documentElement,r=m(10)&&getComputedStyle(n);return{height:O("Height",e,n,r),width:O("Width",e,n,r)}}var A=function(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")},j=function(){function t(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}return function(e,n,r){return n&&t(e.prototype,n),r&&t(e,r),e}}(),M=function(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t},C=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var n=arguments[e];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[r]=n[r])}return t};function V(t){return C({},t,{right:t.left+t.width,bottom:t.top+t.height})}function S(t){var e={};try{if(m(10)){e=t.getBoundingClientRect();var n=y(t,"top"),r=y(t,"left");e.top+=n,e.left+=r,e.bottom+=n,e.right+=r}else e=t.getBoundingClientRect()}catch(h){}var i={left:e.left,top:e.top,width:e.right-e.left,height:e.bottom-e.top},o="HTML"===t.nodeName?z(t.ownerDocument):{},a=o.width||t.clientWidth||i.width,s=o.height||t.clientHeight||i.height,c=t.offsetWidth-a,u=t.offsetHeight-s;if(c||u){var d=l(t);c-=_(d,"x"),u-=_(d,"y"),i.width-=c,i.height-=u}return V(i)}function x(t,e){var n=arguments.length>2&&void 0!==arguments[2]&&arguments[2],r=m(10),i="HTML"===e.nodeName,o=S(t),a=S(e),s=d(t),c=l(e),u=parseFloat(c.borderTopWidth),h=parseFloat(c.borderLeftWidth);n&&i&&(a.top=Math.max(a.top,0),a.left=Math.max(a.left,0));var f=V({top:o.top-a.top-u,left:o.left-a.left-h,width:o.width,height:o.height});if(f.marginTop=0,f.marginLeft=0,!r&&i){var p=parseFloat(c.marginTop),b=parseFloat(c.marginLeft);f.top-=u-p,f.bottom-=u-p,f.left-=h-b,f.right-=h-b,f.marginTop=p,f.marginLeft=b}return(r&&!n?e.contains(s):e===s&&"BODY"!==s.nodeName)&&(f=k(f,e)),f}function T(t){var e=arguments.length>1&&void 0!==arguments[1]&&arguments[1],n=t.ownerDocument.documentElement,r=x(t,n),i=Math.max(n.clientWidth,window.innerWidth||0),o=Math.max(n.clientHeight,window.innerHeight||0),a=e?0:y(n),s=e?0:y(n,"left"),c={top:a-r.top+r.marginTop,left:s-r.left+r.marginLeft,width:i,height:o};return V(c)}function P(t){var e=t.nodeName;if("BODY"===e||"HTML"===e)return!1;if("fixed"===l(t,"position"))return!0;var n=u(t);return!!n&&P(n)}function I(t){if(!t||!t.parentElement||m())return document.documentElement;var e=t.parentElement;while(e&&"none"===l(e,"transform"))e=e.parentElement;return e||document.documentElement}function E(t,e,n,r){var i=arguments.length>4&&void 0!==arguments[4]&&arguments[4],o={top:0,left:0},a=i?I(t):w(t,h(e));if("viewport"===r)o=T(a,i);else{var s=void 0;"scrollParent"===r?(s=d(u(e)),"BODY"===s.nodeName&&(s=t.ownerDocument.documentElement)):s="window"===r?t.ownerDocument.documentElement:r;var c=x(s,a,i);if("HTML"!==s.nodeName||P(a))o=c;else{var l=z(t.ownerDocument),f=l.height,p=l.width;o.top+=c.top-c.marginTop,o.bottom=f+c.top,o.left+=c.left-c.marginLeft,o.right=p+c.left}}n=n||0;var m="number"===typeof n;return o.left+=m?n:n.left||0,o.top+=m?n:n.top||0,o.right-=m?n:n.right||0,o.bottom-=m?n:n.bottom||0,o}function L(t){var e=t.width,n=t.height;return e*n}function B(t,e,n,r,i){var o=arguments.length>5&&void 0!==arguments[5]?arguments[5]:0;if(-1===t.indexOf("auto"))return t;var a=E(n,r,o,i),s={top:{width:a.width,height:e.top-a.top},right:{width:a.right-e.right,height:a.height},bottom:{width:a.width,height:a.bottom-e.bottom},left:{width:e.left-a.left,height:a.height}},c=Object.keys(s).map((function(t){return C({key:t},s[t],{area:L(s[t])})})).sort((function(t,e){return e.area-t.area})),l=c.filter((function(t){var e=t.width,r=t.height;return e>=n.clientWidth&&r>=n.clientHeight})),u=l.length>0?l[0].key:c[0].key,d=t.split("-")[1];return u+(d?"-"+d:"")}function H(t,e,n){var r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:null,i=r?I(e):w(e,h(n));return x(n,i,r)}function F(t){var e=t.ownerDocument.defaultView,n=e.getComputedStyle(t),r=parseFloat(n.marginTop||0)+parseFloat(n.marginBottom||0),i=parseFloat(n.marginLeft||0)+parseFloat(n.marginRight||0),o={width:t.offsetWidth+i,height:t.offsetHeight+r};return o}function D(t){var e={left:"right",right:"left",bottom:"top",top:"bottom"};return t.replace(/left|right|bottom|top/g,(function(t){return e[t]}))}function R(t,e,n){n=n.split("-")[0];var r=F(t),i={width:r.width,height:r.height},o=-1!==["right","left"].indexOf(n),a=o?"top":"left",s=o?"left":"top",c=o?"height":"width",l=o?"width":"height";return i[a]=e[a]+e[c]/2-r[c]/2,i[s]=n===s?e[s]-r[l]:e[D(s)],i}function N(t,e){return Array.prototype.find?t.find(e):t.filter(e)[0]}function $(t,e,n){if(Array.prototype.findIndex)return t.findIndex((function(t){return t[e]===n}));var r=N(t,(function(t){return t[e]===n}));return t.indexOf(r)}function U(t,e,n){var r=void 0===n?t:t.slice(0,$(t,"name",n));return r.forEach((function(t){t["function"]&&console.warn("`modifier.function` is deprecated, use `modifier.fn`!");var n=t["function"]||t.fn;t.enabled&&c(n)&&(e.offsets.popper=V(e.offsets.popper),e.offsets.reference=V(e.offsets.reference),e=n(e,t))})),e}function q(){if(!this.state.isDestroyed){var t={instance:this,styles:{},arrowStyles:{},attributes:{},flipped:!1,offsets:{}};t.offsets.reference=H(this.state,this.popper,this.reference,this.options.positionFixed),t.placement=B(this.options.placement,t.offsets.reference,this.popper,this.reference,this.options.modifiers.flip.boundariesElement,this.options.modifiers.flip.padding),t.originalPlacement=t.placement,t.positionFixed=this.options.positionFixed,t.offsets.popper=R(this.popper,t.offsets.reference,t.placement),t.offsets.popper.position=this.options.positionFixed?"fixed":"absolute",t=U(this.modifiers,t),this.state.isCreated?this.options.onUpdate(t):(this.state.isCreated=!0,this.options.onCreate(t))}}function W(t,e){return t.some((function(t){var n=t.name,r=t.enabled;return r&&n===e}))}function G(t){for(var e=[!1,"ms","Webkit","Moz","O"],n=t.charAt(0).toUpperCase()+t.slice(1),r=0;r<e.length;r++){var i=e[r],o=i?""+i+n:t;if("undefined"!==typeof document.body.style[o])return o}return null}function Y(){return this.state.isDestroyed=!0,W(this.modifiers,"applyStyle")&&(this.popper.removeAttribute("x-placement"),this.popper.style.position="",this.popper.style.top="",this.popper.style.left="",this.popper.style.right="",this.popper.style.bottom="",this.popper.style.willChange="",this.popper.style[G("transform")]=""),this.disableEventListeners(),this.options.removeOnDestroy&&this.popper.parentNode.removeChild(this.popper),this}function K(t){var e=t.ownerDocument;return e?e.defaultView:window}function Q(t,e,n,r){var i="BODY"===t.nodeName,o=i?t.ownerDocument.defaultView:t;o.addEventListener(e,n,{passive:!0}),i||Q(d(o.parentNode),e,n,r),r.push(o)}function X(t,e,n,r){n.updateBound=r,K(t).addEventListener("resize",n.updateBound,{passive:!0});var i=d(t);return Q(i,"scroll",n.updateBound,n.scrollParents),n.scrollElement=i,n.eventsEnabled=!0,n}function J(){this.state.eventsEnabled||(this.state=X(this.reference,this.options,this.state,this.scheduleUpdate))}function Z(t,e){return K(t).removeEventListener("resize",e.updateBound),e.scrollParents.forEach((function(t){t.removeEventListener("scroll",e.updateBound)})),e.updateBound=null,e.scrollParents=[],e.scrollElement=null,e.eventsEnabled=!1,e}function tt(){this.state.eventsEnabled&&(cancelAnimationFrame(this.scheduleUpdate),this.state=Z(this.reference,this.state))}function et(t){return""!==t&&!isNaN(parseFloat(t))&&isFinite(t)}function nt(t,e){Object.keys(e).forEach((function(n){var r="";-1!==["width","height","top","right","bottom","left"].indexOf(n)&&et(e[n])&&(r="px"),t.style[n]=e[n]+r}))}function rt(t,e){Object.keys(e).forEach((function(n){var r=e[n];!1!==r?t.setAttribute(n,e[n]):t.removeAttribute(n)}))}function it(t){return nt(t.instance.popper,t.styles),rt(t.instance.popper,t.attributes),t.arrowElement&&Object.keys(t.arrowStyles).length&&nt(t.arrowElement,t.arrowStyles),t}function ot(t,e,n,r,i){var o=H(i,e,t,n.positionFixed),a=B(n.placement,o,e,t,n.modifiers.flip.boundariesElement,n.modifiers.flip.padding);return e.setAttribute("x-placement",a),nt(e,{position:n.positionFixed?"fixed":"absolute"}),n}function at(t,e){var n=t.offsets,r=n.popper,i=n.reference,o=Math.round,a=Math.floor,s=function(t){return t},c=o(i.width),l=o(r.width),u=-1!==["left","right"].indexOf(t.placement),d=-1!==t.placement.indexOf("-"),h=c%2===l%2,f=c%2===1&&l%2===1,p=e?u||d||h?o:a:s,m=e?o:s;return{left:p(f&&!d&&e?r.left-1:r.left),top:m(r.top),bottom:m(r.bottom),right:p(r.right)}}var st=n&&/Firefox/i.test(navigator.userAgent);function ct(t,e){var n=e.x,r=e.y,i=t.offsets.popper,o=N(t.instance.modifiers,(function(t){return"applyStyle"===t.name})).gpuAcceleration;void 0!==o&&console.warn("WARNING: `gpuAcceleration` option moved to `computeStyle` modifier and will not be supported in future versions of Popper.js!");var a=void 0!==o?o:e.gpuAcceleration,s=b(t.instance.popper),c=S(s),l={position:i.position},u=at(t,window.devicePixelRatio<2||!st),d="bottom"===n?"top":"bottom",h="right"===r?"left":"right",f=G("transform"),p=void 0,m=void 0;if(m="bottom"===d?"HTML"===s.nodeName?-s.clientHeight+u.bottom:-c.height+u.bottom:u.top,p="right"===h?"HTML"===s.nodeName?-s.clientWidth+u.right:-c.width+u.right:u.left,a&&f)l[f]="translate3d("+p+"px, "+m+"px, 0)",l[d]=0,l[h]=0,l.willChange="transform";else{var g="bottom"===d?-1:1,v="right"===h?-1:1;l[d]=m*g,l[h]=p*v,l.willChange=d+", "+h}var w={"x-placement":t.placement};return t.attributes=C({},w,t.attributes),t.styles=C({},l,t.styles),t.arrowStyles=C({},t.offsets.arrow,t.arrowStyles),t}function lt(t,e,n){var r=N(t,(function(t){var n=t.name;return n===e})),i=!!r&&t.some((function(t){return t.name===n&&t.enabled&&t.order<r.order}));if(!i){var o="`"+e+"`",a="`"+n+"`";console.warn(a+" modifier is required by "+o+" modifier in order to work, be sure to include it before "+o+"!")}return i}function ut(t,e){var n;if(!lt(t.instance.modifiers,"arrow","keepTogether"))return t;var r=e.element;if("string"===typeof r){if(r=t.instance.popper.querySelector(r),!r)return t}else if(!t.instance.popper.contains(r))return console.warn("WARNING: `arrow.element` must be child of its popper element!"),t;var i=t.placement.split("-")[0],o=t.offsets,a=o.popper,s=o.reference,c=-1!==["left","right"].indexOf(i),u=c?"height":"width",d=c?"Top":"Left",h=d.toLowerCase(),f=c?"left":"top",p=c?"bottom":"right",m=F(r)[u];s[p]-m<a[h]&&(t.offsets.popper[h]-=a[h]-(s[p]-m)),s[h]+m>a[p]&&(t.offsets.popper[h]+=s[h]+m-a[p]),t.offsets.popper=V(t.offsets.popper);var b=s[h]+s[u]/2-m/2,g=l(t.instance.popper),v=parseFloat(g["margin"+d]),w=parseFloat(g["border"+d+"Width"]),y=b-t.offsets.popper[h]-v-w;return y=Math.max(Math.min(a[u]-m,y),0),t.arrowElement=r,t.offsets.arrow=(n={},M(n,h,Math.round(y)),M(n,f,""),n),t}function dt(t){return"end"===t?"start":"start"===t?"end":t}var ht=["auto-start","auto","auto-end","top-start","top","top-end","right-start","right","right-end","bottom-end","bottom","bottom-start","left-end","left","left-start"],ft=ht.slice(3);function pt(t){var e=arguments.length>1&&void 0!==arguments[1]&&arguments[1],n=ft.indexOf(t),r=ft.slice(n+1).concat(ft.slice(0,n));return e?r.reverse():r}var mt={FLIP:"flip",CLOCKWISE:"clockwise",COUNTERCLOCKWISE:"counterclockwise"};function bt(t,e){if(W(t.instance.modifiers,"inner"))return t;if(t.flipped&&t.placement===t.originalPlacement)return t;var n=E(t.instance.popper,t.instance.reference,e.padding,e.boundariesElement,t.positionFixed),r=t.placement.split("-")[0],i=D(r),o=t.placement.split("-")[1]||"",a=[];switch(e.behavior){case mt.FLIP:a=[r,i];break;case mt.CLOCKWISE:a=pt(r);break;case mt.COUNTERCLOCKWISE:a=pt(r,!0);break;default:a=e.behavior}return a.forEach((function(s,c){if(r!==s||a.length===c+1)return t;r=t.placement.split("-")[0],i=D(r);var l=t.offsets.popper,u=t.offsets.reference,d=Math.floor,h="left"===r&&d(l.right)>d(u.left)||"right"===r&&d(l.left)<d(u.right)||"top"===r&&d(l.bottom)>d(u.top)||"bottom"===r&&d(l.top)<d(u.bottom),f=d(l.left)<d(n.left),p=d(l.right)>d(n.right),m=d(l.top)<d(n.top),b=d(l.bottom)>d(n.bottom),g="left"===r&&f||"right"===r&&p||"top"===r&&m||"bottom"===r&&b,v=-1!==["top","bottom"].indexOf(r),w=!!e.flipVariations&&(v&&"start"===o&&f||v&&"end"===o&&p||!v&&"start"===o&&m||!v&&"end"===o&&b),y=!!e.flipVariationsByContent&&(v&&"start"===o&&p||v&&"end"===o&&f||!v&&"start"===o&&b||!v&&"end"===o&&m),k=w||y;(h||g||k)&&(t.flipped=!0,(h||g)&&(r=a[c+1]),k&&(o=dt(o)),t.placement=r+(o?"-"+o:""),t.offsets.popper=C({},t.offsets.popper,R(t.instance.popper,t.offsets.reference,t.placement)),t=U(t.instance.modifiers,t,"flip"))})),t}function gt(t){var e=t.offsets,n=e.popper,r=e.reference,i=t.placement.split("-")[0],o=Math.floor,a=-1!==["top","bottom"].indexOf(i),s=a?"right":"bottom",c=a?"left":"top",l=a?"width":"height";return n[s]<o(r[c])&&(t.offsets.popper[c]=o(r[c])-n[l]),n[c]>o(r[s])&&(t.offsets.popper[c]=o(r[s])),t}function vt(t,e,n,r){var i=t.match(/((?:\-|\+)?\d*\.?\d*)(.*)/),o=+i[1],a=i[2];if(!o)return t;if(0===a.indexOf("%")){var s=void 0;switch(a){case"%p":s=n;break;case"%":case"%r":default:s=r}var c=V(s);return c[e]/100*o}if("vh"===a||"vw"===a){var l=void 0;return l="vh"===a?Math.max(document.documentElement.clientHeight,window.innerHeight||0):Math.max(document.documentElement.clientWidth,window.innerWidth||0),l/100*o}return o}function wt(t,e,n,r){var i=[0,0],o=-1!==["right","left"].indexOf(r),a=t.split(/(\+|\-)/).map((function(t){return t.trim()})),s=a.indexOf(N(a,(function(t){return-1!==t.search(/,|\s/)})));a[s]&&-1===a[s].indexOf(",")&&console.warn("Offsets separated by white space(s) are deprecated, use a comma (,) instead.");var c=/\s*,\s*|\s+/,l=-1!==s?[a.slice(0,s).concat([a[s].split(c)[0]]),[a[s].split(c)[1]].concat(a.slice(s+1))]:[a];return l=l.map((function(t,r){var i=(1===r?!o:o)?"height":"width",a=!1;return t.reduce((function(t,e){return""===t[t.length-1]&&-1!==["+","-"].indexOf(e)?(t[t.length-1]=e,a=!0,t):a?(t[t.length-1]+=e,a=!1,t):t.concat(e)}),[]).map((function(t){return vt(t,i,e,n)}))})),l.forEach((function(t,e){t.forEach((function(n,r){et(n)&&(i[e]+=n*("-"===t[r-1]?-1:1))}))})),i}function yt(t,e){var n=e.offset,r=t.placement,i=t.offsets,o=i.popper,a=i.reference,s=r.split("-")[0],c=void 0;return c=et(+n)?[+n,0]:wt(n,o,a,s),"left"===s?(o.top+=c[0],o.left-=c[1]):"right"===s?(o.top+=c[0],o.left+=c[1]):"top"===s?(o.left+=c[0],o.top-=c[1]):"bottom"===s&&(o.left+=c[0],o.top+=c[1]),t.popper=o,t}function kt(t,e){var n=e.boundariesElement||b(t.instance.popper);t.instance.reference===n&&(n=b(n));var r=G("transform"),i=t.instance.popper.style,o=i.top,a=i.left,s=i[r];i.top="",i.left="",i[r]="";var c=E(t.instance.popper,t.instance.reference,e.padding,n,t.positionFixed);i.top=o,i.left=a,i[r]=s,e.boundaries=c;var l=e.priority,u=t.offsets.popper,d={primary:function(t){var n=u[t];return u[t]<c[t]&&!e.escapeWithReference&&(n=Math.max(u[t],c[t])),M({},t,n)},secondary:function(t){var n="right"===t?"left":"top",r=u[n];return u[t]>c[t]&&!e.escapeWithReference&&(r=Math.min(u[n],c[t]-("right"===t?u.width:u.height))),M({},n,r)}};return l.forEach((function(t){var e=-1!==["left","top"].indexOf(t)?"primary":"secondary";u=C({},u,d[e](t))})),t.offsets.popper=u,t}function _t(t){var e=t.placement,n=e.split("-")[0],r=e.split("-")[1];if(r){var i=t.offsets,o=i.reference,a=i.popper,s=-1!==["bottom","top"].indexOf(n),c=s?"left":"top",l=s?"width":"height",u={start:M({},c,o[c]),end:M({},c,o[c]+o[l]-a[l])};t.offsets.popper=C({},a,u[r])}return t}function Ot(t){if(!lt(t.instance.modifiers,"hide","preventOverflow"))return t;var e=t.offsets.reference,n=N(t.instance.modifiers,(function(t){return"preventOverflow"===t.name})).boundaries;if(e.bottom<n.top||e.left>n.right||e.top>n.bottom||e.right<n.left){if(!0===t.hide)return t;t.hide=!0,t.attributes["x-out-of-boundaries"]=""}else{if(!1===t.hide)return t;t.hide=!1,t.attributes["x-out-of-boundaries"]=!1}return t}function zt(t){var e=t.placement,n=e.split("-")[0],r=t.offsets,i=r.popper,o=r.reference,a=-1!==["left","right"].indexOf(n),s=-1===["top","left"].indexOf(n);return i[a?"left":"top"]=o[n]-(s?i[a?"width":"height"]:0),t.placement=D(e),t.offsets.popper=V(i),t}var At={shift:{order:100,enabled:!0,fn:_t},offset:{order:200,enabled:!0,fn:yt,offset:0},preventOverflow:{order:300,enabled:!0,fn:kt,priority:["left","right","top","bottom"],padding:5,boundariesElement:"scrollParent"},keepTogether:{order:400,enabled:!0,fn:gt},arrow:{order:500,enabled:!0,fn:ut,element:"[x-arrow]"},flip:{order:600,enabled:!0,fn:bt,behavior:"flip",padding:5,boundariesElement:"viewport",flipVariations:!1,flipVariationsByContent:!1},inner:{order:700,enabled:!1,fn:zt},hide:{order:800,enabled:!0,fn:Ot},computeStyle:{order:850,enabled:!0,fn:ct,gpuAcceleration:!0,x:"bottom",y:"right"},applyStyle:{order:900,enabled:!0,fn:it,onLoad:ot,gpuAcceleration:void 0}},jt={placement:"bottom",positionFixed:!1,eventsEnabled:!0,removeOnDestroy:!1,onCreate:function(){},onUpdate:function(){},modifiers:At},Mt=function(){function t(e,n){var r=this,i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};A(this,t),this.scheduleUpdate=function(){return requestAnimationFrame(r.update)},this.update=s(this.update.bind(this)),this.options=C({},t.Defaults,i),this.state={isDestroyed:!1,isCreated:!1,scrollParents:[]},this.reference=e&&e.jquery?e[0]:e,this.popper=n&&n.jquery?n[0]:n,this.options.modifiers={},Object.keys(C({},t.Defaults.modifiers,i.modifiers)).forEach((function(e){r.options.modifiers[e]=C({},t.Defaults.modifiers[e]||{},i.modifiers?i.modifiers[e]:{})})),this.modifiers=Object.keys(this.options.modifiers).map((function(t){return C({name:t},r.options.modifiers[t])})).sort((function(t,e){return t.order-e.order})),this.modifiers.forEach((function(t){t.enabled&&c(t.onLoad)&&t.onLoad(r.reference,r.popper,r.options,t,r.state)})),this.update();var o=this.options.eventsEnabled;o&&this.enableEventListeners(),this.state.eventsEnabled=o}return j(t,[{key:"update",value:function(){return q.call(this)}},{key:"destroy",value:function(){return Y.call(this)}},{key:"enableEventListeners",value:function(){return J.call(this)}},{key:"disableEventListeners",value:function(){return tt.call(this)}}]),t}();Mt.Utils=("undefined"!==typeof window?window:t).PopperUtils,Mt.placements=ht,Mt.Defaults=jt,e["a"]=Mt}).call(this,n("c8ba"))},f6b4:function(t,e,n){"use strict";var r=n("c532");function i(){this.handlers=[]}i.prototype.use=function(t,e){return this.handlers.push({fulfilled:t,rejected:e}),this.handlers.length-1},i.prototype.eject=function(t){this.handlers[t]&&(this.handlers[t]=null)},i.prototype.forEach=function(t){r.forEach(this.handlers,(function(e){null!==e&&t(e)}))},t.exports=i},f9e3:function(t,e,n){},fa73:function(t,e,n){"use strict";n.d(e,"b",(function(){return o})),n.d(e,"e",(function(){return a})),n.d(e,"f",(function(){return s})),n.d(e,"d",(function(){return c})),n.d(e,"j",(function(){return l})),n.d(e,"a",(function(){return u})),n.d(e,"g",(function(){return d})),n.d(e,"i",(function(){return h})),n.d(e,"h",(function(){return f})),n.d(e,"c",(function(){return p}));var r=n("992e"),i=n("7b1e"),o=function(t){return t.replace(r["p"],"-$1").toLowerCase()},a=function(t){return t=o(t).replace(r["F"],(function(t,e){return e?e.toUpperCase():""})),t.charAt(0).toUpperCase()+t.slice(1)},s=function(t){return t.replace(r["E"]," ").replace(r["r"],(function(t,e,n){return e+" "+n})).replace(r["z"],(function(t,e,n){return e+n.toUpperCase()}))},c=function(t){return t=Object(i["n"])(t)?t.trim():String(t),t.charAt(0).toLowerCase()+t.slice(1)},l=function(t){return t=Object(i["n"])(t)?t.trim():String(t),t.charAt(0).toUpperCase()+t.slice(1)},u=function(t){return t.replace(r["v"],"\\$&")},d=function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:2;return Object(i["p"])(t)?"":Object(i["a"])(t)||Object(i["k"])(t)&&t.toString===Object.prototype.toString?JSON.stringify(t,null,e):String(t)},h=function(t){return d(t).replace(r["C"],"")},f=function(t){return d(t).trim()},p=function(t){return d(t).toLowerCase()}},fb3d:function(t,e,n){
/*!
 * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md.
 */
!function(t){const e=t.en=t.en||{};e.dictionary=Object.assign(e.dictionary||{},{"%0 of %1":"%0 of %1","Block quote":"Block quote",Bold:"Bold","Bulleted List":"Bulleted List",Cancel:"Cancel","Cannot upload file:":"Cannot upload file:","Centered image":"Centered image","Change image text alternative":"Change image text alternative","Choose heading":"Choose heading",Column:"Column","Could not insert image at the current position.":"Could not insert image at the current position.","Could not obtain resized image URL.":"Could not obtain resized image URL.","Decrease indent":"Decrease indent","Delete column":"Delete column","Delete row":"Delete row",Downloadable:"Downloadable","Dropdown toolbar":"Dropdown toolbar","Edit link":"Edit link","Editor toolbar":"Editor toolbar","Enter image caption":"Enter image caption","Full size image":"Full size image","Header column":"Header column","Header row":"Header row",Heading:"Heading","Heading 1":"Heading 1","Heading 2":"Heading 2","Heading 3":"Heading 3","Heading 4":"Heading 4","Heading 5":"Heading 5","Heading 6":"Heading 6","Image toolbar":"Image toolbar","image widget":"image widget","Increase indent":"Increase indent","Insert column left":"Insert column left","Insert column right":"Insert column right","Insert image":"Insert image","Insert image or file":"Insert image or file","Insert media":"Insert media","Insert paragraph after block":"Insert paragraph after block","Insert paragraph before block":"Insert paragraph before block","Insert row above":"Insert row above","Insert row below":"Insert row below","Insert table":"Insert table","Inserting image failed":"Inserting image failed",Italic:"Italic","Left aligned image":"Left aligned image",Link:"Link","Link URL":"Link URL","Media URL":"Media URL","media widget":"media widget","Merge cell down":"Merge cell down","Merge cell left":"Merge cell left","Merge cell right":"Merge cell right","Merge cell up":"Merge cell up","Merge cells":"Merge cells",Next:"Next","Numbered List":"Numbered List","Open in a new tab":"Open in a new tab","Open link in new tab":"Open link in new tab",Paragraph:"Paragraph","Paste the media URL in the input.":"Paste the media URL in the input.",Previous:"Previous",Redo:"Redo","Rich Text Editor":"Rich Text Editor","Rich Text Editor, %0":"Rich Text Editor, %0","Right aligned image":"Right aligned image",Row:"Row",Save:"Save","Select all":"Select all","Select column":"Select column","Select row":"Select row","Selecting resized image failed":"Selecting resized image failed","Show more items":"Show more items","Side image":"Side image","Split cell horizontally":"Split cell horizontally","Split cell vertically":"Split cell vertically","Table toolbar":"Table toolbar","Text alternative":"Text alternative","The URL must not be empty.":"The URL must not be empty.","This link has no URL":"This link has no URL","This media URL is not supported.":"This media URL is not supported.","Tip: Paste the URL into the content to embed faster.":"Tip: Paste the URL into the content to embed faster.",Undo:"Undo",Unlink:"Unlink","Upload failed":"Upload failed","Upload in progress":"Upload in progress","Widget toolbar":"Widget toolbar"})}(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={})),function(e,n){t.exports=n()}(window,(function(){return function(t){var e={};function n(r){if(e[r])return e[r].exports;var i=e[r]={i:r,l:!1,exports:{}};return t[r].call(i.exports,i,i.exports,n),i.l=!0,i.exports}return n.m=t,n.c=e,n.d=function(t,e,r){n.o(t,e)||Object.defineProperty(t,e,{enumerable:!0,get:r})},n.r=function(t){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},n.t=function(t,e){if(1&e&&(t=n(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var i in t)n.d(r,i,function(e){return t[e]}.bind(null,i));return r},n.n=function(t){var e=t&&t.__esModule?function(){return t.default}:function(){return t};return n.d(e,"a",e),e},n.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},n.p="",n(n.s=98)}([function(t,e,n){"use strict";n.d(e,"a",(function(){return r})),n.d(e,"c",(function(){return i})),n.d(e,"b",(function(){return o}));class r extends Error{constructor(t,e,n){super(`${t}${n?" "+JSON.stringify(n):""}${a(t)}`),this.name="CKEditorError",this.context=e,this.data=n}is(t){return"CKEditorError"===t}static rethrowUnexpectedError(t,e){if(t.is&&t.is("CKEditorError"))throw t;const n=new r(t.message,e);throw n.stack=t.stack,n}}function i(t,e){console.warn(...s(t,e))}function o(t,e){console.error(...s(t,e))}function a(t){return"\nRead more: https://ckeditor.com/docs/ckeditor5/latest/framework/guides/support/error-codes.html#error-"+t}function s(t,e){const n=a(t);return e?[t,e,n]:[t,n]}},function(t,e,n){"use strict";var r,i=function(){return void 0===r&&(r=Boolean(window&&document&&document.all&&!window.atob)),r},o=function(){var t={};return function(e){if(void 0===t[e]){var n=document.querySelector(e);if(window.HTMLIFrameElement&&n instanceof window.HTMLIFrameElement)try{n=n.contentDocument.head}catch(t){n=null}t[e]=n}return t[e]}}(),a=[];function s(t){for(var e=-1,n=0;n<a.length;n++)if(a[n].identifier===t){e=n;break}return e}function c(t,e){for(var n={},r=[],i=0;i<t.length;i++){var o=t[i],c=e.base?o[0]+e.base:o[0],l=n[c]||0,u="".concat(c," ").concat(l);n[c]=l+1;var d=s(u),h={css:o[1],media:o[2],sourceMap:o[3]};-1!==d?(a[d].references++,a[d].updater(h)):a.push({identifier:u,updater:b(h,e),references:1}),r.push(u)}return r}function l(t){var e=document.createElement("style"),r=t.attributes||{};if(void 0===r.nonce){var i=n.nc;i&&(r.nonce=i)}if(Object.keys(r).forEach((function(t){e.setAttribute(t,r[t])})),"function"==typeof t.insert)t.insert(e);else{var a=o(t.insert||"head");if(!a)throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");a.appendChild(e)}return e}var u,d=(u=[],function(t,e){return u[t]=e,u.filter(Boolean).join("\n")});function h(t,e,n,r){var i=n?"":r.media?"@media ".concat(r.media," {").concat(r.css,"}"):r.css;if(t.styleSheet)t.styleSheet.cssText=d(e,i);else{var o=document.createTextNode(i),a=t.childNodes;a[e]&&t.removeChild(a[e]),a.length?t.insertBefore(o,a[e]):t.appendChild(o)}}function f(t,e,n){var r=n.css,i=n.media,o=n.sourceMap;if(i?t.setAttribute("media",i):t.removeAttribute("media"),o&&"undefined"!=typeof btoa&&(r+="\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(o))))," */")),t.styleSheet)t.styleSheet.cssText=r;else{for(;t.firstChild;)t.removeChild(t.firstChild);t.appendChild(document.createTextNode(r))}}var p=null,m=0;function b(t,e){var n,r,i;if(e.singleton){var o=m++;n=p||(p=l(e)),r=h.bind(null,n,o,!1),i=h.bind(null,n,o,!0)}else n=l(e),r=f.bind(null,n,e),i=function(){!function(t){if(null===t.parentNode)return!1;t.parentNode.removeChild(t)}(n)};return r(t),function(e){if(e){if(e.css===t.css&&e.media===t.media&&e.sourceMap===t.sourceMap)return;r(t=e)}else i()}}t.exports=function(t,e){(e=e||{}).singleton||"boolean"==typeof e.singleton||(e.singleton=i());var n=c(t=t||[],e);return function(t){if(t=t||[],"[object Array]"===Object.prototype.toString.call(t)){for(var r=0;r<n.length;r++){var i=s(n[r]);a[i].references--}for(var o=c(t,e),l=0;l<n.length;l++){var u=s(n[l]);0===a[u].references&&(a[u].updater(),a.splice(u,1))}n=o}}}},,function(t,e,n){"use strict";var r=n(8),i="object"==typeof self&&self&&self.Object===Object&&self,o=r.a||i||Function("return this")();e.a=o},function(t,n,r){"use strict";(function(t){var i=r(3),o=r(13),a=e&&!e.nodeType&&e,s=a&&"object"==typeof t&&t&&!t.nodeType&&t,c=s&&s.exports===a?i.a.Buffer:void 0,l=(c?c.isBuffer:void 0)||o.a;n.a=l}).call(this,r(10)(t))},function(t,n,r){"use strict";(function(t){var i=r(8),o=e&&!e.nodeType&&e,a=o&&"object"==typeof t&&t&&!t.nodeType&&t,s=a&&a.exports===o&&i.a.process,c=function(){try{var t=a&&a.require&&a.require("util").types;return t||s&&s.binding&&s.binding("util")}catch(t){}}();n.a=c}).call(this,r(10)(t))},function(t,e,n){"use strict";(function(t){var e=n(0);const r="object"==typeof window?window:t;if(r.CKEDITOR_VERSION)throw new e.a("ckeditor-duplicated-modules",null);r.CKEDITOR_VERSION="25.0.0"}).call(this,n(11))},function(t,e,n){var r=n(1),i=n(60);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e,n){"use strict";(function(t){var n="object"==typeof t&&t&&t.Object===Object&&t;e.a=n}).call(this,n(11))},function(t,n,r){"use strict";(function(t){var i=r(3),o=e&&!e.nodeType&&e,a=o&&"object"==typeof t&&t&&!t.nodeType&&t,s=a&&a.exports===o?i.a.Buffer:void 0,c=s?s.allocUnsafe:void 0;n.a=function(t,e){if(e)return t.slice();var n=t.length,r=c?c(n):new t.constructor(n);return t.copy(r),r}}).call(this,r(10)(t))},function(t,e){t.exports=function(t){if(!t.webpackPolyfill){var e=Object.create(t);e.children||(e.children=[]),Object.defineProperty(e,"loaded",{enumerable:!0,get:function(){return e.l}}),Object.defineProperty(e,"id",{enumerable:!0,get:function(){return e.i}}),Object.defineProperty(e,"exports",{enumerable:!0}),e.webpackPolyfill=1}return e}},function(t,e){var n;n=function(){return this}();try{n=n||new Function("return this")()}catch(t){"object"==typeof window&&(n=window)}t.exports=n},function(t,e,n){var r=n(1),i=n(73);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e,n){"use strict";e.a=function(){return!1}},function(t,e,n){var r=n(1),i=n(15);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-placeholder:before,.ck .ck-placeholder:before{content:attr(data-placeholder);pointer-events:none}.ck.ck-read-only .ck-placeholder:before{display:none}.ck.ck-placeholder:before,.ck .ck-placeholder:before{cursor:text;color:var(--ck-color-engine-placeholder-text)}"},function(t,e,n){var r=n(1),i=n(17);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck-hidden{display:none!important}.ck.ck-reset,.ck.ck-reset_all,.ck.ck-reset_all *{box-sizing:border-box;width:auto;height:auto;position:static}:root{--ck-z-default:1;--ck-z-modal:calc(var(--ck-z-default) + 999)}.ck-transitions-disabled,.ck-transitions-disabled *{transition:none!important}:root{--ck-color-base-foreground:#fafafa;--ck-color-base-background:#fff;--ck-color-base-border:#c4c4c4;--ck-color-base-action:#61b045;--ck-color-base-focus:#6cb5f9;--ck-color-base-text:#333;--ck-color-base-active:#198cf0;--ck-color-base-active-focus:#0e7fe1;--ck-color-base-error:#db3700;--ck-color-focus-border-coordinates:208,79%,51%;--ck-color-focus-border:hsl(var(--ck-color-focus-border-coordinates));--ck-color-focus-outer-shadow:#bcdefb;--ck-color-focus-disabled-shadow:rgba(119,186,248,0.3);--ck-color-focus-error-shadow:rgba(255,64,31,0.3);--ck-color-text:var(--ck-color-base-text);--ck-color-shadow-drop:rgba(0,0,0,0.15);--ck-color-shadow-drop-active:rgba(0,0,0,0.2);--ck-color-shadow-inner:rgba(0,0,0,0.1);--ck-color-button-default-background:transparent;--ck-color-button-default-hover-background:#e6e6e6;--ck-color-button-default-active-background:#d9d9d9;--ck-color-button-default-active-shadow:#bfbfbf;--ck-color-button-default-disabled-background:transparent;--ck-color-button-on-background:#dedede;--ck-color-button-on-hover-background:#c4c4c4;--ck-color-button-on-active-background:#bababa;--ck-color-button-on-active-shadow:#a1a1a1;--ck-color-button-on-disabled-background:#dedede;--ck-color-button-action-background:var(--ck-color-base-action);--ck-color-button-action-hover-background:#579e3d;--ck-color-button-action-active-background:#53973b;--ck-color-button-action-active-shadow:#498433;--ck-color-button-action-disabled-background:#7ec365;--ck-color-button-action-text:var(--ck-color-base-background);--ck-color-button-save:#008a00;--ck-color-button-cancel:#db3700;--ck-color-switch-button-off-background:#b0b0b0;--ck-color-switch-button-off-hover-background:#a3a3a3;--ck-color-switch-button-on-background:var(--ck-color-button-action-background);--ck-color-switch-button-on-hover-background:#579e3d;--ck-color-switch-button-inner-background:var(--ck-color-base-background);--ck-color-switch-button-inner-shadow:rgba(0,0,0,0.1);--ck-color-dropdown-panel-background:var(--ck-color-base-background);--ck-color-dropdown-panel-border:var(--ck-color-base-border);--ck-color-input-background:var(--ck-color-base-background);--ck-color-input-border:#c7c7c7;--ck-color-input-error-border:var(--ck-color-base-error);--ck-color-input-text:var(--ck-color-base-text);--ck-color-input-disabled-background:#f2f2f2;--ck-color-input-disabled-border:#c7c7c7;--ck-color-input-disabled-text:#757575;--ck-color-list-background:var(--ck-color-base-background);--ck-color-list-button-hover-background:var(--ck-color-button-default-hover-background);--ck-color-list-button-on-background:var(--ck-color-base-active);--ck-color-list-button-on-background-focus:var(--ck-color-base-active-focus);--ck-color-list-button-on-text:var(--ck-color-base-background);--ck-color-panel-background:var(--ck-color-base-background);--ck-color-panel-border:var(--ck-color-base-border);--ck-color-toolbar-background:var(--ck-color-base-foreground);--ck-color-toolbar-border:var(--ck-color-base-border);--ck-color-tooltip-background:var(--ck-color-base-text);--ck-color-tooltip-text:var(--ck-color-base-background);--ck-color-engine-placeholder-text:#707070;--ck-color-upload-bar-background:#6cb5f9;--ck-color-link-default:#0000f0;--ck-color-link-selected-background:rgba(31,177,255,0.1);--ck-color-link-fake-selection:rgba(31,177,255,0.3);--ck-disabled-opacity:.5;--ck-focus-outer-shadow-geometry:0 0 0 3px;--ck-focus-outer-shadow:var(--ck-focus-outer-shadow-geometry) var(--ck-color-focus-outer-shadow);--ck-focus-disabled-outer-shadow:var(--ck-focus-outer-shadow-geometry) var(--ck-color-focus-disabled-shadow);--ck-focus-error-outer-shadow:var(--ck-focus-outer-shadow-geometry) var(--ck-color-focus-error-shadow);--ck-focus-ring:1px solid var(--ck-color-focus-border);--ck-font-size-base:13px;--ck-line-height-base:1.84615;--ck-font-face:Helvetica,Arial,Tahoma,Verdana,Sans-Serif;--ck-font-size-tiny:0.7em;--ck-font-size-small:0.75em;--ck-font-size-normal:1em;--ck-font-size-big:1.4em;--ck-font-size-large:1.8em;--ck-ui-component-min-height:2.3em}.ck.ck-reset,.ck.ck-reset_all,.ck.ck-reset_all *{margin:0;padding:0;border:0;background:transparent;text-decoration:none;vertical-align:middle;transition:none;word-wrap:break-word}.ck.ck-reset_all,.ck.ck-reset_all *{border-collapse:collapse;font:normal normal normal var(--ck-font-size-base)/var(--ck-line-height-base) var(--ck-font-face);color:var(--ck-color-text);text-align:left;white-space:nowrap;cursor:auto;float:none}.ck.ck-reset_all .ck-rtl *{text-align:right}.ck.ck-reset_all iframe{vertical-align:inherit}.ck.ck-reset_all textarea{white-space:pre-wrap}.ck.ck-reset_all input[type=password],.ck.ck-reset_all input[type=text],.ck.ck-reset_all textarea{cursor:text}.ck.ck-reset_all input[type=password][disabled],.ck.ck-reset_all input[type=text][disabled],.ck.ck-reset_all textarea[disabled]{cursor:default}.ck.ck-reset_all fieldset{padding:10px;border:2px groove #dfdee3}.ck.ck-reset_all button::-moz-focus-inner{padding:0;border:0}.ck[dir=rtl],.ck[dir=rtl] .ck{text-align:right}:root{--ck-border-radius:2px;--ck-inner-shadow:2px 2px 3px var(--ck-color-shadow-inner) inset;--ck-drop-shadow:0 1px 2px 1px var(--ck-color-shadow-drop);--ck-drop-shadow-active:0 3px 6px 1px var(--ck-color-shadow-drop-active);--ck-spacing-unit:0.6em;--ck-spacing-large:calc(var(--ck-spacing-unit)*1.5);--ck-spacing-standard:var(--ck-spacing-unit);--ck-spacing-medium:calc(var(--ck-spacing-unit)*0.8);--ck-spacing-small:calc(var(--ck-spacing-unit)*0.5);--ck-spacing-tiny:calc(var(--ck-spacing-unit)*0.3);--ck-spacing-extra-tiny:calc(var(--ck-spacing-unit)*0.16)}"},function(t,e,n){var r=n(1),i=n(19);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=":root{--ck-color-editable-blur-selection:#d9d9d9}.ck.ck-editor__editable:not(.ck-editor__nested-editable){border-radius:0}.ck-rounded-corners .ck.ck-editor__editable:not(.ck-editor__nested-editable),.ck.ck-editor__editable:not(.ck-editor__nested-editable).ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-editor__editable:not(.ck-editor__nested-editable).ck-focused{outline:none;border:var(--ck-focus-ring);box-shadow:var(--ck-inner-shadow),0 0}.ck.ck-editor__editable_inline{overflow:auto;padding:0 var(--ck-spacing-standard);border:1px solid transparent}.ck.ck-editor__editable_inline[dir=ltr]{text-align:left}.ck.ck-editor__editable_inline[dir=rtl]{text-align:right}.ck.ck-editor__editable_inline>:first-child{margin-top:var(--ck-spacing-large)}.ck.ck-editor__editable_inline>:last-child{margin-bottom:var(--ck-spacing-large)}.ck.ck-editor__editable_inline.ck-blurred ::selection{background:var(--ck-color-editable-blur-selection)}.ck.ck-balloon-panel.ck-toolbar-container[class*=arrow_n]:after{border-bottom-color:var(--ck-color-base-foreground)}.ck.ck-balloon-panel.ck-toolbar-container[class*=arrow_s]:after{border-top-color:var(--ck-color-base-foreground)}"},function(t,e,n){var r=n(1),i=n(21);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-label{display:block}.ck.ck-voice-label{display:none}.ck.ck-label{font-weight:700}"},function(t,e,n){var r=n(1),i=n(23);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-sticky-panel .ck-sticky-panel__content_sticky{z-index:var(--ck-z-modal);position:fixed;top:0}.ck.ck-sticky-panel .ck-sticky-panel__content_sticky_bottom-limit{top:auto;position:absolute}.ck.ck-sticky-panel .ck-sticky-panel__content_sticky{box-shadow:var(--ck-drop-shadow),0 0;border-width:0 1px 1px;border-top-left-radius:0;border-top-right-radius:0}"},function(t,e,n){var r=n(1),i=n(25);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=":root{--ck-dropdown-max-width:75vw}.ck.ck-dropdown{display:inline-block;position:relative}.ck.ck-dropdown .ck-dropdown__arrow{pointer-events:none;z-index:var(--ck-z-default)}.ck.ck-dropdown .ck-button.ck-dropdown__button{width:100%}.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-on .ck-tooltip{display:none}.ck.ck-dropdown .ck-dropdown__panel{-webkit-backface-visibility:hidden;display:none;z-index:var(--ck-z-modal);max-width:var(--ck-dropdown-max-width);position:absolute}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel-visible{display:inline-block}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_n,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_ne,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_nme,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_nmw,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_nw{bottom:100%}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_s,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_se,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_sme,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_smw,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_sw{top:100%;bottom:auto}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_ne,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_se{left:0}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_nw,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_sw{right:0}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_n,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_s{left:50%;transform:translateX(-50%)}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_nmw,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_smw{left:75%;transform:translateX(-75%)}.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_nme,.ck.ck-dropdown .ck-dropdown__panel.ck-dropdown__panel_sme{left:25%;transform:translateX(-25%)}.ck.ck-toolbar .ck-dropdown__panel{z-index:calc(var(--ck-z-modal) + 1)}:root{--ck-dropdown-arrow-size:calc(var(--ck-icon-size)*0.5)}.ck.ck-dropdown{font-size:inherit}.ck.ck-dropdown .ck-dropdown__arrow{width:var(--ck-dropdown-arrow-size)}[dir=ltr] .ck.ck-dropdown .ck-dropdown__arrow{right:var(--ck-spacing-standard);margin-left:var(--ck-spacing-standard)}[dir=rtl] .ck.ck-dropdown .ck-dropdown__arrow{left:var(--ck-spacing-standard);margin-right:var(--ck-spacing-small)}.ck.ck-dropdown.ck-disabled .ck-dropdown__arrow{opacity:var(--ck-disabled-opacity)}[dir=ltr] .ck.ck-dropdown .ck-button.ck-dropdown__button:not(.ck-button_with-text){padding-left:var(--ck-spacing-small)}[dir=rtl] .ck.ck-dropdown .ck-button.ck-dropdown__button:not(.ck-button_with-text){padding-right:var(--ck-spacing-small)}.ck.ck-dropdown .ck-button.ck-dropdown__button .ck-button__label{width:7em;overflow:hidden;text-overflow:ellipsis}.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-disabled .ck-button__label{opacity:var(--ck-disabled-opacity)}.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-on{border-bottom-left-radius:0;border-bottom-right-radius:0}.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-dropdown__button_label-width_auto .ck-button__label{width:auto}.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-off:active,.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-on:active{box-shadow:none}.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-off:active:focus,.ck.ck-dropdown .ck-button.ck-dropdown__button.ck-on:active:focus{box-shadow:var(--ck-focus-outer-shadow),0 0}.ck.ck-dropdown__panel{border-radius:0}.ck-rounded-corners .ck.ck-dropdown__panel,.ck.ck-dropdown__panel.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-dropdown__panel{box-shadow:var(--ck-drop-shadow),0 0;background:var(--ck-color-dropdown-panel-background);border:1px solid var(--ck-color-dropdown-panel-border);bottom:0;min-width:100%}.ck.ck-dropdown__panel.ck-dropdown__panel_se{border-top-left-radius:0}.ck.ck-dropdown__panel.ck-dropdown__panel_sw{border-top-right-radius:0}.ck.ck-dropdown__panel.ck-dropdown__panel_ne{border-bottom-left-radius:0}.ck.ck-dropdown__panel.ck-dropdown__panel_nw{border-bottom-right-radius:0}"},function(t,e,n){var r=n(1),i=n(27);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-icon{vertical-align:middle}:root{--ck-icon-size:calc(var(--ck-line-height-base)*var(--ck-font-size-normal))}.ck.ck-icon{width:var(--ck-icon-size);height:var(--ck-icon-size);font-size:.8333350694em;will-change:transform}.ck.ck-icon,.ck.ck-icon *{color:inherit;cursor:inherit}.ck.ck-icon :not([fill]){fill:currentColor}"},function(t,e,n){var r=n(1),i=n(29);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports='.ck.ck-tooltip,.ck.ck-tooltip .ck-tooltip__text:after{position:absolute;pointer-events:none;-webkit-backface-visibility:hidden}.ck.ck-tooltip{visibility:hidden;opacity:0;display:none;z-index:var(--ck-z-modal)}.ck.ck-tooltip .ck-tooltip__text{display:inline-block}.ck.ck-tooltip .ck-tooltip__text:after{content:"";width:0;height:0}:root{--ck-tooltip-arrow-size:5px}.ck.ck-tooltip{left:50%;top:0;transition:opacity .2s ease-in-out .2s}.ck.ck-tooltip .ck-tooltip__text{border-radius:0}.ck-rounded-corners .ck.ck-tooltip .ck-tooltip__text,.ck.ck-tooltip .ck-tooltip__text.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-tooltip .ck-tooltip__text{font-size:.9em;line-height:1.5;color:var(--ck-color-tooltip-text);padding:var(--ck-spacing-small) var(--ck-spacing-medium);background:var(--ck-color-tooltip-background);position:relative;left:-50%}.ck.ck-tooltip .ck-tooltip__text:after{transition:opacity .2s ease-in-out .2s;border-style:solid;left:50%}.ck.ck-tooltip.ck-tooltip_s,.ck.ck-tooltip.ck-tooltip_se,.ck.ck-tooltip.ck-tooltip_sw{bottom:calc(var(--ck-tooltip-arrow-size)*-1);transform:translateY(100%)}.ck.ck-tooltip.ck-tooltip_s .ck-tooltip__text:after,.ck.ck-tooltip.ck-tooltip_se .ck-tooltip__text:after,.ck.ck-tooltip.ck-tooltip_sw .ck-tooltip__text:after{top:calc(var(--ck-tooltip-arrow-size)*-1 + 1px);transform:translateX(-50%);border-left-color:transparent;border-bottom-color:var(--ck-color-tooltip-background);border-right-color:transparent;border-top-color:transparent;border-left-width:var(--ck-tooltip-arrow-size);border-bottom-width:var(--ck-tooltip-arrow-size);border-right-width:var(--ck-tooltip-arrow-size);border-top-width:0}.ck.ck-tooltip.ck-tooltip_sw{right:50%;left:auto}.ck.ck-tooltip.ck-tooltip_sw .ck-tooltip__text{left:auto;right:calc(var(--ck-tooltip-arrow-size)*-2)}.ck.ck-tooltip.ck-tooltip_sw .ck-tooltip__text:after{left:auto;right:0}.ck.ck-tooltip.ck-tooltip_se{left:50%;right:auto}.ck.ck-tooltip.ck-tooltip_se .ck-tooltip__text{right:auto;left:calc(var(--ck-tooltip-arrow-size)*-2)}.ck.ck-tooltip.ck-tooltip_se .ck-tooltip__text:after{right:auto;left:0;transform:translateX(50%)}.ck.ck-tooltip.ck-tooltip_n{top:calc(var(--ck-tooltip-arrow-size)*-1);transform:translateY(-100%)}.ck.ck-tooltip.ck-tooltip_n .ck-tooltip__text:after{bottom:calc(var(--ck-tooltip-arrow-size)*-1);transform:translateX(-50%);border-left-color:transparent;border-bottom-color:transparent;border-right-color:transparent;border-top-color:var(--ck-color-tooltip-background);border-left-width:var(--ck-tooltip-arrow-size);border-bottom-width:0;border-right-width:var(--ck-tooltip-arrow-size);border-top-width:var(--ck-tooltip-arrow-size)}.ck.ck-tooltip.ck-tooltip_e{left:calc(100% + var(--ck-tooltip-arrow-size));top:50%}.ck.ck-tooltip.ck-tooltip_e .ck-tooltip__text{left:0;transform:translateY(-50%)}.ck.ck-tooltip.ck-tooltip_e .ck-tooltip__text:after{left:calc(var(--ck-tooltip-arrow-size)*-1);top:calc(50% - var(--ck-tooltip-arrow-size)*1);border-left-color:transparent;border-bottom-color:transparent;border-right-color:var(--ck-color-tooltip-background);border-top-color:transparent;border-left-width:0;border-bottom-width:var(--ck-tooltip-arrow-size);border-right-width:var(--ck-tooltip-arrow-size);border-top-width:var(--ck-tooltip-arrow-size)}.ck.ck-tooltip.ck-tooltip_w{right:calc(100% + var(--ck-tooltip-arrow-size));left:auto;top:50%}.ck.ck-tooltip.ck-tooltip_w .ck-tooltip__text{left:0;transform:translateY(-50%)}.ck.ck-tooltip.ck-tooltip_w .ck-tooltip__text:after{left:100%;top:calc(50% - var(--ck-tooltip-arrow-size)*1);border-left-color:var(--ck-color-tooltip-background);border-bottom-color:transparent;border-right-color:transparent;border-top-color:transparent;border-left-width:var(--ck-tooltip-arrow-size);border-bottom-width:var(--ck-tooltip-arrow-size);border-right-width:0;border-top-width:var(--ck-tooltip-arrow-size)}'},function(t,e,n){var r=n(1),i=n(31);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-button,a.ck.ck-button{-moz-user-select:none;-webkit-user-select:none;-ms-user-select:none;user-select:none}.ck.ck-button .ck-tooltip,a.ck.ck-button .ck-tooltip{display:block}@media (hover:none){.ck.ck-button .ck-tooltip,a.ck.ck-button .ck-tooltip{display:none}}.ck.ck-button,a.ck.ck-button{position:relative;display:inline-flex;align-items:center;justify-content:left}.ck.ck-button .ck-button__label,a.ck.ck-button .ck-button__label{display:none}.ck.ck-button.ck-button_with-text .ck-button__label,a.ck.ck-button.ck-button_with-text .ck-button__label{display:inline-block}.ck.ck-button:not(.ck-button_with-text),a.ck.ck-button:not(.ck-button_with-text){justify-content:center}.ck.ck-button:hover .ck-tooltip,a.ck.ck-button:hover .ck-tooltip{visibility:visible;opacity:1}.ck.ck-button:focus:not(:hover) .ck-tooltip,a.ck.ck-button:focus:not(:hover) .ck-tooltip{display:none}.ck.ck-button,a.ck.ck-button{background:var(--ck-color-button-default-background)}.ck.ck-button:not(.ck-disabled):hover,a.ck.ck-button:not(.ck-disabled):hover{background:var(--ck-color-button-default-hover-background)}.ck.ck-button:not(.ck-disabled):active,a.ck.ck-button:not(.ck-disabled):active{background:var(--ck-color-button-default-active-background);box-shadow:inset 0 2px 2px var(--ck-color-button-default-active-shadow)}.ck.ck-button.ck-disabled,a.ck.ck-button.ck-disabled{background:var(--ck-color-button-default-disabled-background)}.ck.ck-button,a.ck.ck-button{border-radius:0}.ck-rounded-corners .ck.ck-button,.ck-rounded-corners a.ck.ck-button,.ck.ck-button.ck-rounded-corners,a.ck.ck-button.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-button,a.ck.ck-button{white-space:nowrap;cursor:default;vertical-align:middle;padding:var(--ck-spacing-tiny);text-align:center;min-width:var(--ck-ui-component-min-height);min-height:var(--ck-ui-component-min-height);line-height:1;font-size:inherit;border:1px solid transparent;transition:box-shadow .2s ease-in-out,border .2s ease-in-out;-webkit-appearance:none}.ck.ck-button:active,.ck.ck-button:focus,a.ck.ck-button:active,a.ck.ck-button:focus{outline:none;border:var(--ck-focus-ring);box-shadow:var(--ck-focus-outer-shadow),0 0}.ck.ck-button .ck-button__icon use,.ck.ck-button .ck-button__icon use *,a.ck.ck-button .ck-button__icon use,a.ck.ck-button .ck-button__icon use *{color:inherit}.ck.ck-button .ck-button__label,a.ck.ck-button .ck-button__label{font-size:inherit;font-weight:inherit;color:inherit;cursor:inherit;vertical-align:middle}[dir=ltr] .ck.ck-button .ck-button__label,[dir=ltr] a.ck.ck-button .ck-button__label{text-align:left}[dir=rtl] .ck.ck-button .ck-button__label,[dir=rtl] a.ck.ck-button .ck-button__label{text-align:right}.ck.ck-button .ck-button__keystroke,a.ck.ck-button .ck-button__keystroke{color:inherit}[dir=ltr] .ck.ck-button .ck-button__keystroke,[dir=ltr] a.ck.ck-button .ck-button__keystroke{margin-left:var(--ck-spacing-large)}[dir=rtl] .ck.ck-button .ck-button__keystroke,[dir=rtl] a.ck.ck-button .ck-button__keystroke{margin-right:var(--ck-spacing-large)}.ck.ck-button .ck-button__keystroke,a.ck.ck-button .ck-button__keystroke{font-weight:700;opacity:.7}.ck.ck-button.ck-disabled:active,.ck.ck-button.ck-disabled:focus,a.ck.ck-button.ck-disabled:active,a.ck.ck-button.ck-disabled:focus{box-shadow:var(--ck-focus-disabled-outer-shadow),0 0}.ck.ck-button.ck-disabled .ck-button__icon,a.ck.ck-button.ck-disabled .ck-button__icon{opacity:var(--ck-disabled-opacity)}.ck.ck-button.ck-disabled .ck-button__label,a.ck.ck-button.ck-disabled .ck-button__label{opacity:var(--ck-disabled-opacity)}.ck.ck-button.ck-disabled .ck-button__keystroke,a.ck.ck-button.ck-disabled .ck-button__keystroke{opacity:.3}.ck.ck-button.ck-button_with-text,a.ck.ck-button.ck-button_with-text{padding:var(--ck-spacing-tiny) var(--ck-spacing-standard)}[dir=ltr] .ck.ck-button.ck-button_with-text .ck-button__icon,[dir=ltr] a.ck.ck-button.ck-button_with-text .ck-button__icon{margin-left:calc(var(--ck-spacing-small)*-1);margin-right:var(--ck-spacing-small)}[dir=rtl] .ck.ck-button.ck-button_with-text .ck-button__icon,[dir=rtl] a.ck.ck-button.ck-button_with-text .ck-button__icon{margin-right:calc(var(--ck-spacing-small)*-1);margin-left:var(--ck-spacing-small)}.ck.ck-button.ck-button_with-keystroke .ck-button__label,a.ck.ck-button.ck-button_with-keystroke .ck-button__label{flex-grow:1}.ck.ck-button.ck-on,a.ck.ck-button.ck-on{background:var(--ck-color-button-on-background)}.ck.ck-button.ck-on:not(.ck-disabled):hover,a.ck.ck-button.ck-on:not(.ck-disabled):hover{background:var(--ck-color-button-on-hover-background)}.ck.ck-button.ck-on:not(.ck-disabled):active,a.ck.ck-button.ck-on:not(.ck-disabled):active{background:var(--ck-color-button-on-active-background);box-shadow:inset 0 2px 2px var(--ck-color-button-on-active-shadow)}.ck.ck-button.ck-on.ck-disabled,a.ck.ck-button.ck-on.ck-disabled{background:var(--ck-color-button-on-disabled-background)}.ck.ck-button.ck-button-save,a.ck.ck-button.ck-button-save{color:var(--ck-color-button-save)}.ck.ck-button.ck-button-cancel,a.ck.ck-button.ck-button-cancel{color:var(--ck-color-button-cancel)}.ck.ck-button-action,a.ck.ck-button-action{background:var(--ck-color-button-action-background)}.ck.ck-button-action:not(.ck-disabled):hover,a.ck.ck-button-action:not(.ck-disabled):hover{background:var(--ck-color-button-action-hover-background)}.ck.ck-button-action:not(.ck-disabled):active,a.ck.ck-button-action:not(.ck-disabled):active{background:var(--ck-color-button-action-active-background);box-shadow:inset 0 2px 2px var(--ck-color-button-action-active-shadow)}.ck.ck-button-action.ck-disabled,a.ck.ck-button-action.ck-disabled{background:var(--ck-color-button-action-disabled-background)}.ck.ck-button-action,a.ck.ck-button-action{color:var(--ck-color-button-action-text)}.ck.ck-button-bold,a.ck.ck-button-bold{font-weight:700}"},function(t,e,n){var r=n(1),i=n(33);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-list{-moz-user-select:none;-webkit-user-select:none;-ms-user-select:none;user-select:none;display:flex;flex-direction:column}.ck.ck-list .ck-list__item,.ck.ck-list .ck-list__separator{display:block}.ck.ck-list .ck-list__item>:focus{position:relative;z-index:var(--ck-z-default)}.ck.ck-list{border-radius:0}.ck-rounded-corners .ck.ck-list,.ck.ck-list.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-list{list-style-type:none;background:var(--ck-color-list-background)}.ck.ck-list__item{cursor:default;min-width:12em}.ck.ck-list__item .ck-button{min-height:unset;width:100%;text-align:left;border-radius:0;padding:calc(var(--ck-line-height-base)*0.2*var(--ck-font-size-base)) calc(var(--ck-line-height-base)*0.4*var(--ck-font-size-base))}.ck.ck-list__item .ck-button .ck-button__label{line-height:calc(var(--ck-line-height-base)*1.2*var(--ck-font-size-base))}.ck.ck-list__item .ck-button:active{box-shadow:none}.ck.ck-list__item .ck-button.ck-on{background:var(--ck-color-list-button-on-background);color:var(--ck-color-list-button-on-text)}.ck.ck-list__item .ck-button.ck-on:active{box-shadow:none}.ck.ck-list__item .ck-button.ck-on:hover:not(.ck-disabled){background:var(--ck-color-list-button-on-background-focus)}.ck.ck-list__item .ck-button.ck-on:focus:not(.ck-disabled){border-color:var(--ck-color-base-background)}.ck.ck-list__item .ck-button:hover:not(.ck-disabled){background:var(--ck-color-list-button-hover-background)}.ck.ck-list__item .ck-switchbutton.ck-on{background:var(--ck-color-list-background);color:inherit}.ck.ck-list__item .ck-switchbutton.ck-on:hover:not(.ck-disabled){background:var(--ck-color-list-button-hover-background);color:inherit}.ck.ck-list__separator{height:1px;width:100%;background:var(--ck-color-base-border)}"},function(t,e,n){var r=n(1),i=n(35);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-button.ck-switchbutton .ck-button__toggle,.ck.ck-button.ck-switchbutton .ck-button__toggle .ck-button__toggle__inner{display:block}:root{--ck-switch-button-toggle-width:2.6153846154em;--ck-switch-button-toggle-inner-size:1.0769230769em;--ck-switch-button-toggle-spacing:1px;--ck-switch-button-translation:calc(var(--ck-switch-button-toggle-width) - var(--ck-switch-button-toggle-inner-size) - var(--ck-switch-button-toggle-spacing)*2)}[dir=ltr] .ck.ck-button.ck-switchbutton .ck-button__label{margin-right:calc(var(--ck-spacing-large)*2)}[dir=rtl] .ck.ck-button.ck-switchbutton .ck-button__label{margin-left:calc(var(--ck-spacing-large)*2)}.ck.ck-button.ck-switchbutton .ck-button__toggle{border-radius:0}.ck-rounded-corners .ck.ck-button.ck-switchbutton .ck-button__toggle,.ck.ck-button.ck-switchbutton .ck-button__toggle.ck-rounded-corners{border-radius:var(--ck-border-radius)}[dir=ltr] .ck.ck-button.ck-switchbutton .ck-button__toggle{margin-left:auto}[dir=rtl] .ck.ck-button.ck-switchbutton .ck-button__toggle{margin-right:auto}.ck.ck-button.ck-switchbutton .ck-button__toggle{transition:background .4s ease;width:var(--ck-switch-button-toggle-width);background:var(--ck-color-switch-button-off-background)}.ck.ck-button.ck-switchbutton .ck-button__toggle .ck-button__toggle__inner{border-radius:0}.ck-rounded-corners .ck.ck-button.ck-switchbutton .ck-button__toggle .ck-button__toggle__inner,.ck.ck-button.ck-switchbutton .ck-button__toggle .ck-button__toggle__inner.ck-rounded-corners{border-radius:var(--ck-border-radius);border-radius:calc(var(--ck-border-radius)*0.5)}.ck.ck-button.ck-switchbutton .ck-button__toggle .ck-button__toggle__inner{margin:var(--ck-switch-button-toggle-spacing);width:var(--ck-switch-button-toggle-inner-size);height:var(--ck-switch-button-toggle-inner-size);background:var(--ck-color-switch-button-inner-background);transition:all .3s ease}.ck.ck-button.ck-switchbutton .ck-button__toggle:hover{background:var(--ck-color-switch-button-off-hover-background)}.ck.ck-button.ck-switchbutton .ck-button__toggle:hover .ck-button__toggle__inner{box-shadow:0 0 0 5px var(--ck-color-switch-button-inner-shadow)}.ck.ck-button.ck-switchbutton.ck-disabled .ck-button__toggle{opacity:var(--ck-disabled-opacity)}.ck.ck-button.ck-switchbutton.ck-on .ck-button__toggle{background:var(--ck-color-switch-button-on-background)}.ck.ck-button.ck-switchbutton.ck-on .ck-button__toggle:hover{background:var(--ck-color-switch-button-on-hover-background)}[dir=ltr] .ck.ck-button.ck-switchbutton.ck-on .ck-button__toggle .ck-button__toggle__inner{transform:translateX(var(--ck-switch-button-translation))}[dir=rtl] .ck.ck-button.ck-switchbutton.ck-on .ck-button__toggle .ck-button__toggle__inner{transform:translateX(calc(var(--ck-switch-button-translation)*-1))}"},function(t,e,n){var r=n(1),i=n(37);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=":root{--ck-toolbar-dropdown-max-width:60vw}.ck.ck-toolbar-dropdown>.ck-dropdown__panel{width:max-content;max-width:var(--ck-toolbar-dropdown-max-width)}.ck.ck-toolbar-dropdown>.ck-dropdown__panel .ck-button:focus{z-index:calc(var(--ck-z-default) + 1)}.ck.ck-toolbar-dropdown .ck-toolbar{border:0}"},function(t,e,n){var r=n(1),i=n(39);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-dropdown .ck-dropdown__panel .ck-list{border-radius:0}.ck-rounded-corners .ck.ck-dropdown .ck-dropdown__panel .ck-list,.ck.ck-dropdown .ck-dropdown__panel .ck-list.ck-rounded-corners{border-radius:var(--ck-border-radius);border-top-left-radius:0}.ck.ck-dropdown .ck-dropdown__panel .ck-list .ck-list__item:first-child .ck-button{border-radius:0}.ck-rounded-corners .ck.ck-dropdown .ck-dropdown__panel .ck-list .ck-list__item:first-child .ck-button,.ck.ck-dropdown .ck-dropdown__panel .ck-list .ck-list__item:first-child .ck-button.ck-rounded-corners{border-radius:var(--ck-border-radius);border-top-left-radius:0;border-bottom-left-radius:0;border-bottom-right-radius:0}.ck.ck-dropdown .ck-dropdown__panel .ck-list .ck-list__item:last-child .ck-button{border-radius:0}.ck-rounded-corners .ck.ck-dropdown .ck-dropdown__panel .ck-list .ck-list__item:last-child .ck-button,.ck.ck-dropdown .ck-dropdown__panel .ck-list .ck-list__item:last-child .ck-button.ck-rounded-corners{border-radius:var(--ck-border-radius);border-top-left-radius:0;border-top-right-radius:0}"},function(t,e,n){var r=n(1),i=n(41);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-toolbar{-moz-user-select:none;-webkit-user-select:none;-ms-user-select:none;user-select:none;display:flex;flex-flow:row nowrap;align-items:center}.ck.ck-toolbar>.ck-toolbar__items{display:flex;flex-flow:row wrap;align-items:center;flex-grow:1}.ck.ck-toolbar .ck.ck-toolbar__separator{display:inline-block}.ck.ck-toolbar .ck.ck-toolbar__separator:first-child,.ck.ck-toolbar .ck.ck-toolbar__separator:last-child{display:none}.ck.ck-toolbar .ck-toolbar__line-break{flex-basis:100%}.ck.ck-toolbar.ck-toolbar_grouping>.ck-toolbar__items{flex-wrap:nowrap}.ck.ck-toolbar.ck-toolbar_vertical>.ck-toolbar__items{flex-direction:column}.ck.ck-toolbar.ck-toolbar_floating>.ck-toolbar__items{flex-wrap:nowrap}.ck.ck-toolbar>.ck.ck-toolbar__grouped-dropdown>.ck-dropdown__button .ck-dropdown__arrow{display:none}.ck.ck-toolbar{border-radius:0}.ck-rounded-corners .ck.ck-toolbar,.ck.ck-toolbar.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-toolbar{background:var(--ck-color-toolbar-background);padding:0 var(--ck-spacing-small);border:1px solid var(--ck-color-toolbar-border)}.ck.ck-toolbar .ck.ck-toolbar__separator{align-self:stretch;width:1px;min-width:1px;background:var(--ck-color-toolbar-border);margin-top:var(--ck-spacing-small);margin-bottom:var(--ck-spacing-small)}.ck.ck-toolbar .ck-toolbar__line-break{height:0}.ck.ck-toolbar>.ck-toolbar__items>:not(.ck-toolbar__line-break){margin-right:var(--ck-spacing-small)}.ck.ck-toolbar>.ck-toolbar__items:empty+.ck.ck-toolbar__separator{display:none}.ck.ck-toolbar>.ck-toolbar__items>:not(.ck-toolbar__line-break),.ck.ck-toolbar>.ck.ck-toolbar__grouped-dropdown{margin-top:var(--ck-spacing-small);margin-bottom:var(--ck-spacing-small)}.ck.ck-toolbar.ck-toolbar_vertical{padding:0}.ck.ck-toolbar.ck-toolbar_vertical>.ck-toolbar__items>.ck{width:100%;margin:0;border-radius:0;border:0}.ck.ck-toolbar.ck-toolbar_compact{padding:0}.ck.ck-toolbar.ck-toolbar_compact>.ck-toolbar__items>*{margin:0}.ck.ck-toolbar.ck-toolbar_compact>.ck-toolbar__items>:not(:first-child):not(:last-child){border-radius:0}.ck.ck-toolbar>.ck.ck-toolbar__grouped-dropdown>.ck.ck-button.ck-dropdown__button{padding-left:var(--ck-spacing-tiny)}.ck-toolbar-container .ck.ck-toolbar{border:0}.ck.ck-toolbar[dir=rtl]>.ck-toolbar__items>.ck,[dir=rtl] .ck.ck-toolbar>.ck-toolbar__items>.ck{margin-right:0}.ck.ck-toolbar[dir=rtl]:not(.ck-toolbar_compact)>.ck-toolbar__items>.ck,[dir=rtl] .ck.ck-toolbar:not(.ck-toolbar_compact)>.ck-toolbar__items>.ck{margin-left:var(--ck-spacing-small)}.ck.ck-toolbar[dir=rtl]>.ck-toolbar__items>.ck:last-child,[dir=rtl] .ck.ck-toolbar>.ck-toolbar__items>.ck:last-child{margin-left:0}.ck.ck-toolbar[dir=rtl].ck-toolbar_compact>.ck-toolbar__items>.ck:first-child,[dir=rtl] .ck.ck-toolbar.ck-toolbar_compact>.ck-toolbar__items>.ck:first-child{border-top-left-radius:0;border-bottom-left-radius:0}.ck.ck-toolbar[dir=rtl].ck-toolbar_compact>.ck-toolbar__items>.ck:last-child,[dir=rtl] .ck.ck-toolbar.ck-toolbar_compact>.ck-toolbar__items>.ck:last-child{border-top-right-radius:0;border-bottom-right-radius:0}.ck.ck-toolbar[dir=rtl]>.ck.ck-toolbar__separator,[dir=rtl] .ck.ck-toolbar>.ck.ck-toolbar__separator{margin-left:var(--ck-spacing-small)}.ck.ck-toolbar[dir=rtl].ck-toolbar_grouping>.ck-toolbar__items:not(:empty):not(:only-child),[dir=rtl] .ck.ck-toolbar.ck-toolbar_grouping>.ck-toolbar__items:not(:empty):not(:only-child){margin-left:var(--ck-spacing-small)}.ck.ck-toolbar[dir=ltr]>.ck-toolbar__items>.ck:last-child,[dir=ltr] .ck.ck-toolbar>.ck-toolbar__items>.ck:last-child{margin-right:0}.ck.ck-toolbar[dir=ltr].ck-toolbar_compact>.ck-toolbar__items>.ck:first-child,[dir=ltr] .ck.ck-toolbar.ck-toolbar_compact>.ck-toolbar__items>.ck:first-child{border-top-right-radius:0;border-bottom-right-radius:0}.ck.ck-toolbar[dir=ltr].ck-toolbar_compact>.ck-toolbar__items>.ck:last-child,[dir=ltr] .ck.ck-toolbar.ck-toolbar_compact>.ck-toolbar__items>.ck:last-child{border-top-left-radius:0;border-bottom-left-radius:0}.ck.ck-toolbar[dir=ltr]>.ck.ck-toolbar__separator,[dir=ltr] .ck.ck-toolbar>.ck.ck-toolbar__separator{margin-right:var(--ck-spacing-small)}.ck.ck-toolbar[dir=ltr].ck-toolbar_grouping>.ck-toolbar__items:not(:empty):not(:only-child),[dir=ltr] .ck.ck-toolbar.ck-toolbar_grouping>.ck-toolbar__items:not(:empty):not(:only-child){margin-right:var(--ck-spacing-small)}"},function(t,e,n){var r=n(1),i=n(43);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-editor{position:relative}.ck.ck-editor .ck-editor__top .ck-sticky-panel .ck-toolbar{z-index:var(--ck-z-modal)}.ck.ck-editor__top .ck-sticky-panel .ck-toolbar{border-radius:0}.ck-rounded-corners .ck.ck-editor__top .ck-sticky-panel .ck-toolbar,.ck.ck-editor__top .ck-sticky-panel .ck-toolbar.ck-rounded-corners{border-radius:var(--ck-border-radius);border-bottom-left-radius:0;border-bottom-right-radius:0}.ck.ck-editor__top .ck-sticky-panel .ck-toolbar{border-bottom-width:0}.ck.ck-editor__top .ck-sticky-panel .ck-sticky-panel__content_sticky .ck-toolbar{border-bottom-width:1px;border-radius:0}.ck-rounded-corners .ck.ck-editor__top .ck-sticky-panel .ck-sticky-panel__content_sticky .ck-toolbar,.ck.ck-editor__top .ck-sticky-panel .ck-sticky-panel__content_sticky .ck-toolbar.ck-rounded-corners{border-radius:var(--ck-border-radius);border-radius:0}.ck.ck-editor__main>.ck-editor__editable{background:var(--ck-color-base-background);border-radius:0}.ck-rounded-corners .ck.ck-editor__main>.ck-editor__editable,.ck.ck-editor__main>.ck-editor__editable.ck-rounded-corners{border-radius:var(--ck-border-radius);border-top-left-radius:0;border-top-right-radius:0}.ck.ck-editor__main>.ck-editor__editable:not(.ck-focused){border-color:var(--ck-color-base-border)}"},function(t,e,n){var r=n(1),i=n(45);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck-content blockquote{overflow:hidden;padding-right:1.5em;padding-left:1.5em;margin-left:0;margin-right:0;font-style:italic;border-left:5px solid #ccc}.ck-content[dir=rtl] blockquote{border-left:0;border-right:5px solid #ccc}"},function(t,e,n){var r=n(1),i=n(47);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=':root{--ck-balloon-panel-arrow-z-index:calc(var(--ck-z-default) - 3)}.ck.ck-balloon-panel{display:none;position:absolute;z-index:var(--ck-z-modal)}.ck.ck-balloon-panel.ck-balloon-panel_with-arrow:after,.ck.ck-balloon-panel.ck-balloon-panel_with-arrow:before{content:"";position:absolute}.ck.ck-balloon-panel.ck-balloon-panel_with-arrow:before{z-index:var(--ck-balloon-panel-arrow-z-index)}.ck.ck-balloon-panel.ck-balloon-panel_with-arrow:after{z-index:calc(var(--ck-balloon-panel-arrow-z-index) + 1)}.ck.ck-balloon-panel[class*=arrow_n]:before{z-index:var(--ck-balloon-panel-arrow-z-index)}.ck.ck-balloon-panel[class*=arrow_n]:after{z-index:calc(var(--ck-balloon-panel-arrow-z-index) + 1)}.ck.ck-balloon-panel[class*=arrow_s]:before{z-index:var(--ck-balloon-panel-arrow-z-index)}.ck.ck-balloon-panel[class*=arrow_s]:after{z-index:calc(var(--ck-balloon-panel-arrow-z-index) + 1)}.ck.ck-balloon-panel.ck-balloon-panel_visible{display:block}:root{--ck-balloon-arrow-offset:2px;--ck-balloon-arrow-height:10px;--ck-balloon-arrow-half-width:8px;--ck-balloon-arrow-drop-shadow:0 2px 2px var(--ck-color-shadow-drop)}.ck.ck-balloon-panel{border-radius:0}.ck-rounded-corners .ck.ck-balloon-panel,.ck.ck-balloon-panel.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-balloon-panel{box-shadow:var(--ck-drop-shadow),0 0;min-height:15px;background:var(--ck-color-panel-background);border:1px solid var(--ck-color-panel-border)}.ck.ck-balloon-panel.ck-balloon-panel_with-arrow:after,.ck.ck-balloon-panel.ck-balloon-panel_with-arrow:before{width:0;height:0;border-style:solid}.ck.ck-balloon-panel[class*=arrow_n]:after,.ck.ck-balloon-panel[class*=arrow_n]:before{border-left-width:var(--ck-balloon-arrow-half-width);border-bottom-width:var(--ck-balloon-arrow-height);border-right-width:var(--ck-balloon-arrow-half-width);border-top-width:0}.ck.ck-balloon-panel[class*=arrow_n]:before{border-bottom-color:var(--ck-color-panel-border)}.ck.ck-balloon-panel[class*=arrow_n]:after,.ck.ck-balloon-panel[class*=arrow_n]:before{border-left-color:transparent;border-right-color:transparent;border-top-color:transparent}.ck.ck-balloon-panel[class*=arrow_n]:after{border-bottom-color:var(--ck-color-panel-background);margin-top:var(--ck-balloon-arrow-offset)}.ck.ck-balloon-panel[class*=arrow_s]:after,.ck.ck-balloon-panel[class*=arrow_s]:before{border-left-width:var(--ck-balloon-arrow-half-width);border-bottom-width:0;border-right-width:var(--ck-balloon-arrow-half-width);border-top-width:var(--ck-balloon-arrow-height)}.ck.ck-balloon-panel[class*=arrow_s]:before{border-top-color:var(--ck-color-panel-border);filter:drop-shadow(var(--ck-balloon-arrow-drop-shadow))}.ck.ck-balloon-panel[class*=arrow_s]:after,.ck.ck-balloon-panel[class*=arrow_s]:before{border-left-color:transparent;border-bottom-color:transparent;border-right-color:transparent}.ck.ck-balloon-panel[class*=arrow_s]:after{border-top-color:var(--ck-color-panel-background);margin-bottom:var(--ck-balloon-arrow-offset)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_n:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_n:before{left:50%;margin-left:calc(var(--ck-balloon-arrow-half-width)*-1);top:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_nw:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_nw:before{left:calc(var(--ck-balloon-arrow-half-width)*2);top:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_ne:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_ne:before{right:calc(var(--ck-balloon-arrow-half-width)*2);top:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_s:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_s:before{left:50%;margin-left:calc(var(--ck-balloon-arrow-half-width)*-1);bottom:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_sw:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_sw:before{left:calc(var(--ck-balloon-arrow-half-width)*2);bottom:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_se:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_se:before{right:calc(var(--ck-balloon-arrow-half-width)*2);bottom:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_sme:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_sme:before{right:25%;margin-right:calc(var(--ck-balloon-arrow-half-width)*2);bottom:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_smw:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_smw:before{left:25%;margin-left:calc(var(--ck-balloon-arrow-half-width)*2);bottom:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_nme:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_nme:before{right:25%;margin-right:calc(var(--ck-balloon-arrow-half-width)*2);top:calc(var(--ck-balloon-arrow-height)*-1)}.ck.ck-balloon-panel.ck-balloon-panel_arrow_nmw:after,.ck.ck-balloon-panel.ck-balloon-panel_arrow_nmw:before{left:25%;margin-left:calc(var(--ck-balloon-arrow-half-width)*2);top:calc(var(--ck-balloon-arrow-height)*-1)}'},function(t,e,n){var r=n(1),i=n(49);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck .ck-link_selected{background:var(--ck-color-link-selected-background)}.ck .ck-fake-link-selection{background:var(--ck-color-link-fake-selection)}.ck .ck-fake-link-selection_collapsed{height:100%;border-right:1px solid var(--ck-color-base-text);margin-right:-1px;outline:1px solid hsla(0,0%,100%,.5)}"},function(t,e,n){var r=n(1),i=n(51);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports='.ck .ck-widget .ck-widget__type-around__button{display:block;position:absolute;overflow:hidden;z-index:var(--ck-z-default)}.ck .ck-widget .ck-widget__type-around__button svg{position:absolute;top:50%;left:50%;z-index:calc(var(--ck-z-default) + 2)}.ck .ck-widget .ck-widget__type-around__button.ck-widget__type-around__button_before{top:calc(var(--ck-widget-outline-thickness)*-0.5);left:min(10%,30px);transform:translateY(-50%)}.ck .ck-widget .ck-widget__type-around__button.ck-widget__type-around__button_after{bottom:calc(var(--ck-widget-outline-thickness)*-0.5);right:min(10%,30px);transform:translateY(50%)}.ck .ck-widget.ck-widget_selected>.ck-widget__type-around>.ck-widget__type-around__button:after,.ck .ck-widget>.ck-widget__type-around>.ck-widget__type-around__button:hover:after{content:"";display:block;position:absolute;top:1px;left:1px;z-index:calc(var(--ck-z-default) + 1)}.ck .ck-widget>.ck-widget__type-around>.ck-widget__type-around__fake-caret{display:none;position:absolute;left:0;right:0}.ck .ck-widget:hover>.ck-widget__type-around>.ck-widget__type-around__fake-caret{left:calc(var(--ck-widget-outline-thickness)*-1);right:calc(var(--ck-widget-outline-thickness)*-1)}.ck .ck-widget.ck-widget_type-around_show-fake-caret_before>.ck-widget__type-around>.ck-widget__type-around__fake-caret{top:calc(var(--ck-widget-outline-thickness)*-1 - 1px);display:block}.ck .ck-widget.ck-widget_type-around_show-fake-caret_after>.ck-widget__type-around>.ck-widget__type-around__fake-caret{bottom:calc(var(--ck-widget-outline-thickness)*-1 - 1px);display:block}.ck.ck-editor__editable.ck-read-only .ck-widget__type-around,.ck.ck-editor__editable.ck-restricted-editing_mode_restricted .ck-widget__type-around,.ck.ck-editor__editable.ck-widget__type-around_disabled .ck-widget__type-around{display:none}:root{--ck-widget-type-around-button-size:20px;--ck-color-widget-type-around-button-active:var(--ck-color-focus-border);--ck-color-widget-type-around-button-hover:var(--ck-color-widget-hover-border);--ck-color-widget-type-around-button-blurred-editable:var(--ck-color-widget-blurred-border);--ck-color-widget-type-around-button-radar-start-alpha:0;--ck-color-widget-type-around-button-radar-end-alpha:.3;--ck-color-widget-type-around-button-icon:var(--ck-color-base-background)}.ck .ck-widget .ck-widget__type-around__button{width:var(--ck-widget-type-around-button-size);height:var(--ck-widget-type-around-button-size);background:var(--ck-color-widget-type-around-button);border-radius:100px;transition:opacity var(--ck-widget-handler-animation-duration) var(--ck-widget-handler-animation-curve),background var(--ck-widget-handler-animation-duration) var(--ck-widget-handler-animation-curve);opacity:0;pointer-events:none}.ck .ck-widget .ck-widget__type-around__button svg{width:10px;height:8px;transform:translate(-50%,-50%);transition:transform .5s ease;margin-top:1px}.ck .ck-widget .ck-widget__type-around__button svg *{stroke-dasharray:10;stroke-dashoffset:0;fill:none;stroke:var(--ck-color-widget-type-around-button-icon);stroke-width:1.5px;stroke-linecap:round;stroke-linejoin:round}.ck .ck-widget .ck-widget__type-around__button svg line{stroke-dasharray:7}.ck .ck-widget .ck-widget__type-around__button:hover{animation:ck-widget-type-around-button-sonar 1s ease infinite}.ck .ck-widget .ck-widget__type-around__button:hover svg polyline{animation:ck-widget-type-around-arrow-dash 2s linear}.ck .ck-widget .ck-widget__type-around__button:hover svg line{animation:ck-widget-type-around-arrow-tip-dash 2s linear}.ck .ck-widget.ck-widget_selected>.ck-widget__type-around>.ck-widget__type-around__button,.ck .ck-widget:hover>.ck-widget__type-around>.ck-widget__type-around__button{opacity:1;pointer-events:auto}.ck .ck-widget:not(.ck-widget_selected)>.ck-widget__type-around>.ck-widget__type-around__button{background:var(--ck-color-widget-type-around-button-hover)}.ck .ck-widget.ck-widget_selected>.ck-widget__type-around>.ck-widget__type-around__button,.ck .ck-widget>.ck-widget__type-around>.ck-widget__type-around__button:hover{background:var(--ck-color-widget-type-around-button-active)}.ck .ck-widget.ck-widget_selected>.ck-widget__type-around>.ck-widget__type-around__button:after,.ck .ck-widget>.ck-widget__type-around>.ck-widget__type-around__button:hover:after{width:calc(var(--ck-widget-type-around-button-size) - 2px);height:calc(var(--ck-widget-type-around-button-size) - 2px);border-radius:100px;background:linear-gradient(135deg,hsla(0,0%,100%,0),hsla(0,0%,100%,.3))}.ck .ck-widget.ck-widget_with-selection-handle>.ck-widget__type-around>.ck-widget__type-around__button_before{margin-left:20px}.ck .ck-widget .ck-widget__type-around__fake-caret{pointer-events:none;height:1px;animation:ck-widget-type-around-fake-caret-pulse 1s linear infinite normal forwards;outline:1px solid hsla(0,0%,100%,.5);background:var(--ck-color-base-text)}.ck .ck-widget.ck-widget_selected.ck-widget_type-around_show-fake-caret_after,.ck .ck-widget.ck-widget_selected.ck-widget_type-around_show-fake-caret_before{outline-color:transparent}.ck .ck-widget.ck-widget_type-around_show-fake-caret_after.ck-widget_selected:hover,.ck .ck-widget.ck-widget_type-around_show-fake-caret_before.ck-widget_selected:hover{outline-color:var(--ck-color-widget-hover-border)}.ck .ck-widget.ck-widget_type-around_show-fake-caret_after>.ck-widget__type-around>.ck-widget__type-around__button,.ck .ck-widget.ck-widget_type-around_show-fake-caret_before>.ck-widget__type-around>.ck-widget__type-around__button{opacity:0;pointer-events:none}.ck .ck-widget.ck-widget_type-around_show-fake-caret_after.ck-widget_with-selection-handle.ck-widget_selected:hover>.ck-widget__selection-handle,.ck .ck-widget.ck-widget_type-around_show-fake-caret_after.ck-widget_with-selection-handle.ck-widget_selected>.ck-widget__selection-handle,.ck .ck-widget.ck-widget_type-around_show-fake-caret_before.ck-widget_with-selection-handle.ck-widget_selected:hover>.ck-widget__selection-handle,.ck .ck-widget.ck-widget_type-around_show-fake-caret_before.ck-widget_with-selection-handle.ck-widget_selected>.ck-widget__selection-handle{opacity:0}.ck .ck-widget.ck-widget_type-around_show-fake-caret_after.ck-widget_selected.ck-widget_with-resizer>.ck-widget__resizer,.ck .ck-widget.ck-widget_type-around_show-fake-caret_before.ck-widget_selected.ck-widget_with-resizer>.ck-widget__resizer{opacity:0}.ck[dir=rtl] .ck-widget.ck-widget_with-selection-handle .ck-widget__type-around>.ck-widget__type-around__button_before{margin-left:0;margin-right:20px}.ck-editor__nested-editable.ck-editor__editable_selected .ck-widget.ck-widget_selected>.ck-widget__type-around>.ck-widget__type-around__button,.ck-editor__nested-editable.ck-editor__editable_selected .ck-widget:hover>.ck-widget__type-around>.ck-widget__type-around__button{opacity:0;pointer-events:none}.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected>.ck-widget__type-around>.ck-widget__type-around__button:not(:hover){background:var(--ck-color-widget-type-around-button-blurred-editable)}.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected>.ck-widget__type-around>.ck-widget__type-around__button:not(:hover) svg *{stroke:#999}@keyframes ck-widget-type-around-arrow-dash{0%{stroke-dashoffset:10}20%,to{stroke-dashoffset:0}}@keyframes ck-widget-type-around-arrow-tip-dash{0%,20%{stroke-dashoffset:7}40%,to{stroke-dashoffset:0}}@keyframes ck-widget-type-around-button-sonar{0%{box-shadow:0 0 0 0 hsla(var(--ck-color-focus-border-coordinates),var(--ck-color-widget-type-around-button-radar-start-alpha))}50%{box-shadow:0 0 0 5px hsla(var(--ck-color-focus-border-coordinates),var(--ck-color-widget-type-around-button-radar-end-alpha))}to{box-shadow:0 0 0 5px hsla(var(--ck-color-focus-border-coordinates),var(--ck-color-widget-type-around-button-radar-start-alpha))}}@keyframes ck-widget-type-around-fake-caret-pulse{0%{opacity:1}49%{opacity:1}50%{opacity:0}99%{opacity:0}to{opacity:1}}'},function(t,e,n){var r=n(1),i=n(53);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=":root{--ck-color-resizer:var(--ck-color-focus-border);--ck-color-resizer-tooltip-background:#262626;--ck-color-resizer-tooltip-text:#f2f2f2;--ck-resizer-border-radius:var(--ck-border-radius);--ck-resizer-tooltip-offset:10px}.ck .ck-widget,.ck .ck-widget.ck-widget_with-selection-handle{position:relative}.ck .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle{position:absolute}.ck .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle .ck-icon{display:block}.ck .ck-widget.ck-widget_with-selection-handle.ck-widget_selected .ck-widget__selection-handle,.ck .ck-widget.ck-widget_with-selection-handle:hover .ck-widget__selection-handle{visibility:visible}.ck .ck-size-view{background:var(--ck-color-resizer-tooltip-background);color:var(--ck-color-resizer-tooltip-text);border:1px solid var(--ck-color-resizer-tooltip-text);border-radius:var(--ck-resizer-border-radius);font-size:var(--ck-font-size-tiny);display:block;padding:var(--ck-spacing-small)}.ck .ck-size-view.ck-orientation-bottom-left,.ck .ck-size-view.ck-orientation-bottom-right,.ck .ck-size-view.ck-orientation-top-left,.ck .ck-size-view.ck-orientation-top-right{position:absolute}.ck .ck-size-view.ck-orientation-top-left{top:var(--ck-resizer-tooltip-offset);left:var(--ck-resizer-tooltip-offset)}.ck .ck-size-view.ck-orientation-top-right{top:var(--ck-resizer-tooltip-offset);right:var(--ck-resizer-tooltip-offset)}.ck .ck-size-view.ck-orientation-bottom-right{bottom:var(--ck-resizer-tooltip-offset);right:var(--ck-resizer-tooltip-offset)}.ck .ck-size-view.ck-orientation-bottom-left{bottom:var(--ck-resizer-tooltip-offset);left:var(--ck-resizer-tooltip-offset)}:root{--ck-widget-outline-thickness:3px;--ck-widget-handler-icon-size:16px;--ck-widget-handler-animation-duration:200ms;--ck-widget-handler-animation-curve:ease;--ck-color-widget-blurred-border:#dedede;--ck-color-widget-hover-border:#ffc83d;--ck-color-widget-editable-focus-background:var(--ck-color-base-background);--ck-color-widget-drag-handler-icon-color:var(--ck-color-base-background)}.ck .ck-widget{outline-width:var(--ck-widget-outline-thickness);outline-style:solid;outline-color:transparent;transition:outline-color var(--ck-widget-handler-animation-duration) var(--ck-widget-handler-animation-curve)}.ck .ck-widget.ck-widget_selected,.ck .ck-widget.ck-widget_selected:hover{outline:var(--ck-widget-outline-thickness) solid var(--ck-color-focus-border)}.ck .ck-widget:hover{outline-color:var(--ck-color-widget-hover-border)}.ck .ck-editor__nested-editable{border:1px solid transparent}.ck .ck-editor__nested-editable.ck-editor__nested-editable_focused,.ck .ck-editor__nested-editable:focus{outline:none;border:var(--ck-focus-ring);box-shadow:var(--ck-inner-shadow),0 0;background-color:var(--ck-color-widget-editable-focus-background)}.ck .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle{padding:4px;box-sizing:border-box;background-color:transparent;opacity:0;transition:background-color var(--ck-widget-handler-animation-duration) var(--ck-widget-handler-animation-curve),visibility var(--ck-widget-handler-animation-duration) var(--ck-widget-handler-animation-curve),opacity var(--ck-widget-handler-animation-duration) var(--ck-widget-handler-animation-curve);border-radius:var(--ck-border-radius) var(--ck-border-radius) 0 0;transform:translateY(-100%);left:calc(0px - var(--ck-widget-outline-thickness))}.ck .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle .ck-icon{width:var(--ck-widget-handler-icon-size);height:var(--ck-widget-handler-icon-size);color:var(--ck-color-widget-drag-handler-icon-color)}.ck .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle .ck-icon .ck-icon__selected-indicator{opacity:0;transition:opacity .3s var(--ck-widget-handler-animation-curve)}.ck .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle:hover .ck-icon .ck-icon__selected-indicator{opacity:1}.ck .ck-widget.ck-widget_with-selection-handle:hover .ck-widget__selection-handle{opacity:1;background-color:var(--ck-color-widget-hover-border)}.ck .ck-widget.ck-widget_with-selection-handle.ck-widget_selected .ck-widget__selection-handle,.ck .ck-widget.ck-widget_with-selection-handle.ck-widget_selected:hover .ck-widget__selection-handle{opacity:1;background-color:var(--ck-color-focus-border)}.ck .ck-widget.ck-widget_with-selection-handle.ck-widget_selected .ck-widget__selection-handle .ck-icon .ck-icon__selected-indicator,.ck .ck-widget.ck-widget_with-selection-handle.ck-widget_selected:hover .ck-widget__selection-handle .ck-icon .ck-icon__selected-indicator{opacity:1}.ck[dir=rtl] .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle{left:auto;right:calc(0px - var(--ck-widget-outline-thickness))}.ck.ck-editor__editable.ck-read-only .ck-widget{transition:none}.ck.ck-editor__editable.ck-read-only .ck-widget:not(.ck-widget_selected){--ck-widget-outline-thickness:0px}.ck.ck-editor__editable.ck-read-only .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle,.ck.ck-editor__editable.ck-read-only .ck-widget.ck-widget_with-selection-handle .ck-widget__selection-handle:hover{background:var(--ck-color-widget-blurred-border)}.ck.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected,.ck.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected:hover{outline-color:var(--ck-color-widget-blurred-border)}.ck.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected.ck-widget_with-selection-handle .ck-widget__selection-handle,.ck.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected.ck-widget_with-selection-handle .ck-widget__selection-handle:hover,.ck.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected:hover.ck-widget_with-selection-handle .ck-widget__selection-handle,.ck.ck-editor__editable.ck-blurred .ck-widget.ck-widget_selected:hover.ck-widget_with-selection-handle .ck-widget__selection-handle:hover{background:var(--ck-color-widget-blurred-border)}.ck.ck-editor__editable>.ck-widget.ck-widget_with-selection-handle:first-child,.ck.ck-editor__editable blockquote>.ck-widget.ck-widget_with-selection-handle:first-child{margin-top:calc(1em + var(--ck-widget-handler-icon-size))}"},function(t,e,n){var r=n(1),i=n(55);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-labeled-field-view>.ck.ck-labeled-field-view__input-wrapper{display:flex;position:relative}.ck.ck-labeled-field-view .ck.ck-label{display:block;position:absolute}:root{--ck-labeled-field-view-transition:.1s cubic-bezier(0,0,0.24,0.95);--ck-labeled-field-empty-unfocused-max-width:100% - 2 * var(--ck-spacing-medium);--ck-color-labeled-field-label-background:var(--ck-color-base-background)}.ck.ck-labeled-field-view{border-radius:0}.ck-rounded-corners .ck.ck-labeled-field-view,.ck.ck-labeled-field-view.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-labeled-field-view>.ck.ck-labeled-field-view__input-wrapper{width:100%}.ck.ck-labeled-field-view>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{top:0}[dir=ltr] .ck.ck-labeled-field-view>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{left:0}[dir=rtl] .ck.ck-labeled-field-view>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{right:0}.ck.ck-labeled-field-view>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{pointer-events:none;transform-origin:0 0;transform:translate(var(--ck-spacing-medium),-6px) scale(.75);background:var(--ck-color-labeled-field-label-background);padding:0 calc(var(--ck-font-size-tiny)*0.5);line-height:normal;font-weight:400;text-overflow:ellipsis;overflow:hidden;max-width:100%;transition:transform var(--ck-labeled-field-view-transition),padding var(--ck-labeled-field-view-transition),background var(--ck-labeled-field-view-transition)}.ck.ck-labeled-field-view.ck-error .ck-input:not([readonly])+.ck.ck-label,.ck.ck-labeled-field-view.ck-error>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{color:var(--ck-color-base-error)}.ck.ck-labeled-field-view .ck-labeled-field-view__status{font-size:var(--ck-font-size-small);margin-top:var(--ck-spacing-small);white-space:normal}.ck.ck-labeled-field-view .ck-labeled-field-view__status.ck-labeled-field-view__status_error{color:var(--ck-color-base-error)}.ck.ck-labeled-field-view.ck-disabled>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label,.ck.ck-labeled-field-view.ck-labeled-field-view_empty:not(.ck-labeled-field-view_focused)>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{color:var(--ck-color-input-disabled-text)}[dir=ltr] .ck.ck-labeled-field-view.ck-disabled>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label,[dir=ltr] .ck.ck-labeled-field-view.ck-labeled-field-view_empty:not(.ck-labeled-field-view_focused):not(.ck-labeled-field-view_placeholder)>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{transform:translate(var(--ck-spacing-medium),calc(var(--ck-font-size-base)*0.6)) scale(1)}[dir=rtl] .ck.ck-labeled-field-view.ck-disabled>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label,[dir=rtl] .ck.ck-labeled-field-view.ck-labeled-field-view_empty:not(.ck-labeled-field-view_focused):not(.ck-labeled-field-view_placeholder)>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{transform:translate(calc(var(--ck-spacing-medium)*-1),calc(var(--ck-font-size-base)*0.6)) scale(1)}.ck.ck-labeled-field-view.ck-disabled>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label,.ck.ck-labeled-field-view.ck-labeled-field-view_empty:not(.ck-labeled-field-view_focused):not(.ck-labeled-field-view_placeholder)>.ck.ck-labeled-field-view__input-wrapper>.ck.ck-label{max-width:calc(var(--ck-labeled-field-empty-unfocused-max-width));background:transparent;padding:0}.ck.ck-labeled-field-view>.ck.ck-labeled-field-view__input-wrapper>.ck-dropdown>.ck.ck-button{background:transparent}.ck.ck-labeled-field-view.ck-labeled-field-view_empty>.ck.ck-labeled-field-view__input-wrapper>.ck-dropdown>.ck-button>.ck-button__label{opacity:0}.ck.ck-labeled-field-view.ck-labeled-field-view_empty:not(.ck-labeled-field-view_focused):not(.ck-labeled-field-view_placeholder)>.ck.ck-labeled-field-view__input-wrapper>.ck-dropdown+.ck-label{max-width:calc(var(--ck-labeled-field-empty-unfocused-max-width) - var(--ck-dropdown-arrow-size) - var(--ck-spacing-standard))}"},function(t,e,n){var r=n(1),i=n(57);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=":root{--ck-input-text-width:18em}.ck.ck-input-text{border-radius:0}.ck-rounded-corners .ck.ck-input-text,.ck.ck-input-text.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck.ck-input-text{background:var(--ck-color-input-background);border:1px solid var(--ck-color-input-border);padding:var(--ck-spacing-extra-tiny) var(--ck-spacing-medium);min-width:var(--ck-input-text-width);min-height:var(--ck-ui-component-min-height);transition:box-shadow .1s ease-in-out,border .1s ease-in-out}.ck.ck-input-text:focus{outline:none;border:var(--ck-focus-ring);box-shadow:var(--ck-focus-outer-shadow),0 0}.ck.ck-input-text[readonly]{border:1px solid var(--ck-color-input-disabled-border);background:var(--ck-color-input-disabled-background);color:var(--ck-color-input-disabled-text)}.ck.ck-input-text[readonly]:focus{box-shadow:var(--ck-focus-disabled-outer-shadow),0 0}.ck.ck-input-text.ck-error{border-color:var(--ck-color-input-error-border);animation:ck-text-input-shake .3s ease both}.ck.ck-input-text.ck-error:focus{box-shadow:var(--ck-focus-error-outer-shadow),0 0}@keyframes ck-text-input-shake{20%{transform:translateX(-2px)}40%{transform:translateX(2px)}60%{transform:translateX(-1px)}80%{transform:translateX(1px)}}"},function(t,e,n){var r=n(1),i=n(59);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-text-alternative-form{display:flex;flex-direction:row;flex-wrap:nowrap}.ck.ck-text-alternative-form .ck-labeled-field-view{display:inline-block}.ck.ck-text-alternative-form .ck-label{display:none}@media screen and (max-width:600px){.ck.ck-text-alternative-form{flex-wrap:wrap}.ck.ck-text-alternative-form .ck-labeled-field-view{flex-basis:100%}.ck.ck-text-alternative-form .ck-button{flex-basis:50%}}"},function(t,e){t.exports='.ck-vertical-form .ck-button:after{content:"";width:0;position:absolute;right:-1px;top:var(--ck-spacing-small);bottom:var(--ck-spacing-small);z-index:1}@media screen and (max-width:600px){.ck.ck-responsive-form .ck-button:after{content:"";width:0;position:absolute;right:-1px;top:var(--ck-spacing-small);bottom:var(--ck-spacing-small);z-index:1}}.ck-vertical-form>.ck-button:nth-last-child(2):after{border-right:1px solid var(--ck-color-base-border)}.ck.ck-responsive-form{padding:var(--ck-spacing-large)}.ck.ck-responsive-form:focus{outline:none}[dir=ltr] .ck.ck-responsive-form>:not(:first-child),[dir=rtl] .ck.ck-responsive-form>:not(:last-child){margin-left:var(--ck-spacing-standard)}@media screen and (max-width:600px){.ck.ck-responsive-form{padding:0;width:calc(var(--ck-input-text-width)*0.8)}.ck.ck-responsive-form .ck-labeled-field-view{margin:var(--ck-spacing-large) var(--ck-spacing-large) 0}.ck.ck-responsive-form .ck-labeled-field-view .ck-input-text{min-width:0;width:100%}.ck.ck-responsive-form .ck-labeled-field-view .ck-labeled-field-view__error{white-space:normal}.ck.ck-responsive-form>.ck-button:last-child,.ck.ck-responsive-form>.ck-button:nth-last-child(2){padding:var(--ck-spacing-standard);margin-top:var(--ck-spacing-large);border-radius:0;border:0;border-top:1px solid var(--ck-color-base-border)}[dir=ltr] .ck.ck-responsive-form>.ck-button:last-child,[dir=ltr] .ck.ck-responsive-form>.ck-button:nth-last-child(2),[dir=rtl] .ck.ck-responsive-form>.ck-button:last-child,[dir=rtl] .ck.ck-responsive-form>.ck-button:nth-last-child(2){margin-left:0}.ck.ck-responsive-form>.ck-button:nth-last-child(2):after,[dir=rtl] .ck.ck-responsive-form>.ck-button:last-child:last-of-type,[dir=rtl] .ck.ck-responsive-form>.ck-button:nth-last-child(2):last-of-type{border-right:1px solid var(--ck-color-base-border)}}'},function(t,e,n){var r=n(1),i=n(62);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck .ck-balloon-rotator__navigation{display:flex;align-items:center;justify-content:center}.ck .ck-balloon-rotator__content .ck-toolbar{justify-content:center}.ck .ck-balloon-rotator__navigation{background:var(--ck-color-toolbar-background);border-bottom:1px solid var(--ck-color-toolbar-border);padding:0 var(--ck-spacing-small)}.ck .ck-balloon-rotator__navigation>*{margin-right:var(--ck-spacing-small);margin-top:var(--ck-spacing-small);margin-bottom:var(--ck-spacing-small)}.ck .ck-balloon-rotator__navigation .ck-balloon-rotator__counter{margin-right:var(--ck-spacing-standard);margin-left:var(--ck-spacing-small)}.ck .ck-balloon-rotator__content .ck.ck-annotation-wrapper{box-shadow:none}"},function(t,e,n){var r=n(1),i=n(64);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck .ck-fake-panel{position:absolute;z-index:calc(var(--ck-z-modal) - 1)}.ck .ck-fake-panel div{position:absolute}.ck .ck-fake-panel div:first-child{z-index:2}.ck .ck-fake-panel div:nth-child(2){z-index:1}:root{--ck-balloon-fake-panel-offset-horizontal:6px;--ck-balloon-fake-panel-offset-vertical:6px}.ck .ck-fake-panel div{box-shadow:var(--ck-drop-shadow),0 0;min-height:15px;background:var(--ck-color-panel-background);border:1px solid var(--ck-color-panel-border);border-radius:var(--ck-border-radius);width:100%;height:100%}.ck .ck-fake-panel div:first-child{margin-left:var(--ck-balloon-fake-panel-offset-horizontal);margin-top:var(--ck-balloon-fake-panel-offset-vertical)}.ck .ck-fake-panel div:nth-child(2){margin-left:calc(var(--ck-balloon-fake-panel-offset-horizontal)*2);margin-top:calc(var(--ck-balloon-fake-panel-offset-vertical)*2)}.ck .ck-fake-panel div:nth-child(3){margin-left:calc(var(--ck-balloon-fake-panel-offset-horizontal)*3);margin-top:calc(var(--ck-balloon-fake-panel-offset-vertical)*3)}.ck .ck-balloon-panel_arrow_s+.ck-fake-panel,.ck .ck-balloon-panel_arrow_se+.ck-fake-panel,.ck .ck-balloon-panel_arrow_sw+.ck-fake-panel{--ck-balloon-fake-panel-offset-vertical:-6px}"},function(t,e,n){var r=n(1),i=n(66);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck-content .image{display:table;clear:both;text-align:center;margin:1em auto}.ck-content .image img{display:block;margin:0 auto;max-width:100%;min-width:50px}"},function(t,e,n){var r=n(1),i=n(68);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-editor__editable .image{position:relative}.ck.ck-editor__editable .image .ck-progress-bar{position:absolute;top:0;left:0}.ck.ck-editor__editable .image.ck-appear{animation:fadeIn .7s}.ck.ck-editor__editable .image .ck-progress-bar{height:2px;width:0;background:var(--ck-color-upload-bar-background);transition:width .1s}@keyframes fadeIn{0%{opacity:0}to{opacity:1}}"},function(t,e,n){var r=n(1),i=n(70);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports='.ck-image-upload-complete-icon{display:block;position:absolute;top:10px;right:10px;border-radius:50%}.ck-image-upload-complete-icon:after{content:"";position:absolute}:root{--ck-color-image-upload-icon:#fff;--ck-color-image-upload-icon-background:#008a00;--ck-image-upload-icon-size:20px;--ck-image-upload-icon-width:2px}.ck-image-upload-complete-icon{width:var(--ck-image-upload-icon-size);height:var(--ck-image-upload-icon-size);opacity:0;background:var(--ck-color-image-upload-icon-background);animation-name:ck-upload-complete-icon-show,ck-upload-complete-icon-hide;animation-fill-mode:forwards,forwards;animation-duration:.5s,.5s;font-size:var(--ck-image-upload-icon-size);animation-delay:0ms,3s}.ck-image-upload-complete-icon:after{left:25%;top:50%;opacity:0;height:0;width:0;transform:scaleX(-1) rotate(135deg);transform-origin:left top;border-top:var(--ck-image-upload-icon-width) solid var(--ck-color-image-upload-icon);border-right:var(--ck-image-upload-icon-width) solid var(--ck-color-image-upload-icon);animation-name:ck-upload-complete-icon-check;animation-duration:.5s;animation-delay:.5s;animation-fill-mode:forwards;box-sizing:border-box}@keyframes ck-upload-complete-icon-show{0%{opacity:0}to{opacity:1}}@keyframes ck-upload-complete-icon-hide{0%{opacity:1}to{opacity:0}}@keyframes ck-upload-complete-icon-check{0%{opacity:1;width:0;height:0}33%{width:.3em;height:0}to{opacity:1;width:.3em;height:.45em}}'},function(t,e,n){var r=n(1),i=n(72);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports='.ck .ck-upload-placeholder-loader{position:absolute;display:flex;align-items:center;justify-content:center;top:0;left:0}.ck .ck-upload-placeholder-loader:before{content:"";position:relative}:root{--ck-color-upload-placeholder-loader:#b3b3b3;--ck-upload-placeholder-loader-size:32px}.ck .ck-image-upload-placeholder{width:100%;margin:0}.ck .ck-upload-placeholder-loader{width:100%;height:100%}.ck .ck-upload-placeholder-loader:before{width:var(--ck-upload-placeholder-loader-size);height:var(--ck-upload-placeholder-loader-size);border-radius:50%;border-top:3px solid var(--ck-color-upload-placeholder-loader);border-right:2px solid transparent;animation:ck-upload-placeholder-loader 1s linear infinite}@keyframes ck-upload-placeholder-loader{to{transform:rotate(1turn)}}'},function(t,e){t.exports=".ck.ck-heading_heading1{font-size:20px}.ck.ck-heading_heading2{font-size:17px}.ck.ck-heading_heading3{font-size:14px}.ck[class*=ck-heading_heading]{font-weight:700}.ck.ck-dropdown.ck-heading-dropdown .ck-dropdown__button .ck-button__label{width:8em}.ck.ck-dropdown.ck-heading-dropdown .ck-dropdown__panel .ck-list__item{min-width:18em}"},function(t,e,n){var r=n(1),i=n(75);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck-content .image>figcaption{display:table-caption;caption-side:bottom;word-break:break-word;color:#333;background-color:#f7f7f7;padding:.6em;font-size:.75em;outline-offset:-1px}"},function(t,e,n){var r=n(1),i=n(77);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=":root{--ck-image-style-spacing:1.5em}.ck-content .image-style-side{float:right;margin-left:var(--ck-image-style-spacing);max-width:50%}.ck-content .image-style-align-left{float:left;margin-right:var(--ck-image-style-spacing)}.ck-content .image-style-align-center{margin-left:auto;margin-right:auto}.ck-content .image-style-align-right{float:right;margin-left:var(--ck-image-style-spacing)}"},function(t,e,n){var r=n(1),i=n(79);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-link-form{display:flex}.ck.ck-link-form .ck-label{display:none}@media screen and (max-width:600px){.ck.ck-link-form{flex-wrap:wrap}.ck.ck-link-form .ck-labeled-field-view{flex-basis:100%}.ck.ck-link-form .ck-button{flex-basis:50%}}.ck.ck-link-form_layout-vertical{display:block}.ck.ck-link-form_layout-vertical .ck-button.ck-button-cancel,.ck.ck-link-form_layout-vertical .ck-button.ck-button-save{margin-top:var(--ck-spacing-medium)}.ck.ck-link-form_layout-vertical{padding:0;min-width:var(--ck-input-text-width)}.ck.ck-link-form_layout-vertical .ck-labeled-field-view{margin:var(--ck-spacing-large) var(--ck-spacing-large) var(--ck-spacing-small)}.ck.ck-link-form_layout-vertical .ck-labeled-field-view .ck-input-text{min-width:0;width:100%}.ck.ck-link-form_layout-vertical .ck-button{padding:var(--ck-spacing-standard);margin:0;border-radius:0;border:0;border-top:1px solid var(--ck-color-base-border);width:50%}[dir=ltr] .ck.ck-link-form_layout-vertical .ck-button,[dir=rtl] .ck.ck-link-form_layout-vertical .ck-button{margin-left:0}[dir=rtl] .ck.ck-link-form_layout-vertical .ck-button:last-of-type{border-right:1px solid var(--ck-color-base-border)}.ck.ck-link-form_layout-vertical .ck.ck-list{margin:var(--ck-spacing-standard) var(--ck-spacing-large)}.ck.ck-link-form_layout-vertical .ck.ck-list .ck-button.ck-switchbutton{border:0;padding:0;width:100%}.ck.ck-link-form_layout-vertical .ck.ck-list .ck-button.ck-switchbutton:hover{background:none}"},function(t,e,n){var r=n(1),i=n(81);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-link-actions{display:flex;flex-direction:row;flex-wrap:nowrap}.ck.ck-link-actions .ck-link-actions__preview{display:inline-block}.ck.ck-link-actions .ck-link-actions__preview .ck-button__label{overflow:hidden}@media screen and (max-width:600px){.ck.ck-link-actions{flex-wrap:wrap}.ck.ck-link-actions .ck-link-actions__preview{flex-basis:100%}.ck.ck-link-actions .ck-button:not(.ck-link-actions__preview){flex-basis:50%}}.ck.ck-link-actions .ck-button.ck-link-actions__preview{padding-left:0;padding-right:0}.ck.ck-link-actions .ck-button.ck-link-actions__preview .ck-button__label{padding:0 var(--ck-spacing-medium);color:var(--ck-color-link-default);text-overflow:ellipsis;cursor:pointer;max-width:var(--ck-input-text-width);min-width:3em;text-align:center}.ck.ck-link-actions .ck-button.ck-link-actions__preview .ck-button__label:hover{text-decoration:underline}.ck.ck-link-actions .ck-button.ck-link-actions__preview,.ck.ck-link-actions .ck-button.ck-link-actions__preview:active,.ck.ck-link-actions .ck-button.ck-link-actions__preview:focus,.ck.ck-link-actions .ck-button.ck-link-actions__preview:hover{background:none}.ck.ck-link-actions .ck-button.ck-link-actions__preview:active{box-shadow:none}.ck.ck-link-actions .ck-button.ck-link-actions__preview:focus .ck-button__label{text-decoration:underline}[dir=ltr] .ck.ck-link-actions .ck-button:not(:first-child),[dir=rtl] .ck.ck-link-actions .ck-button:not(:last-child){margin-left:var(--ck-spacing-standard)}@media screen and (max-width:600px){.ck.ck-link-actions .ck-button.ck-link-actions__preview{margin:var(--ck-spacing-standard) var(--ck-spacing-standard) 0}.ck.ck-link-actions .ck-button.ck-link-actions__preview .ck-button__label{min-width:0;max-width:100%}[dir=ltr] .ck.ck-link-actions .ck-button:not(.ck-link-actions__preview),[dir=rtl] .ck.ck-link-actions .ck-button:not(.ck-link-actions__preview){margin-left:0}}"},function(t,e,n){var r=n(1),i=n(83);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports='.ck-media__wrapper .ck-media__placeholder{display:flex;flex-direction:column;align-items:center}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__url .ck-tooltip{display:block}@media (hover:none){.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__url .ck-tooltip{display:none}}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__url{max-width:100%;position:relative}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__url:hover .ck-tooltip{visibility:visible;opacity:1}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__url .ck-media__placeholder__url__text{overflow:hidden;display:block}.ck-media__wrapper[data-oembed-url*="facebook.com"] .ck-media__placeholder__icon *,.ck-media__wrapper[data-oembed-url*="google.com/maps"] .ck-media__placeholder__icon *,.ck-media__wrapper[data-oembed-url*="instagram.com"] .ck-media__placeholder__icon *,.ck-media__wrapper[data-oembed-url*="twitter.com"] .ck-media__placeholder__icon *{display:none}.ck-editor__editable:not(.ck-read-only) .ck-media__wrapper>:not(.ck-media__placeholder),.ck-editor__editable:not(.ck-read-only) .ck-widget:not(.ck-widget_selected) .ck-media__placeholder{pointer-events:none}:root{--ck-media-embed-placeholder-icon-size:3em;--ck-color-media-embed-placeholder-url-text:#757575;--ck-color-media-embed-placeholder-url-text-hover:var(--ck-color-base-text)}.ck-media__wrapper{margin:0 auto}.ck-media__wrapper .ck-media__placeholder{padding:calc(var(--ck-spacing-standard)*3);background:var(--ck-color-base-foreground)}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__icon{min-width:var(--ck-media-embed-placeholder-icon-size);height:var(--ck-media-embed-placeholder-icon-size);margin-bottom:var(--ck-spacing-large);background-position:50%;background-size:cover}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__icon .ck-icon{width:100%;height:100%}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__url__text{color:var(--ck-color-media-embed-placeholder-url-text);white-space:nowrap;text-align:center;font-style:italic;text-overflow:ellipsis}.ck-media__wrapper .ck-media__placeholder .ck-media__placeholder__url__text:hover{color:var(--ck-color-media-embed-placeholder-url-text-hover);cursor:pointer;text-decoration:underline}.ck-media__wrapper[data-oembed-url*="open.spotify.com"]{max-width:300px;max-height:380px}.ck-media__wrapper[data-oembed-url*="google.com/maps"] .ck-media__placeholder__icon{background-image:url(data:image/svg+xml;base64,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)}.ck-media__wrapper[data-oembed-url*="facebook.com"] .ck-media__placeholder{background:#4268b3}.ck-media__wrapper[data-oembed-url*="facebook.com"] .ck-media__placeholder .ck-media__placeholder__icon{background-image:url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTAyNCIgaGVpZ2h0PSIxMDI0IiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPjxwYXRoIGQ9Ik05NjcuNDg0IDBINTYuNTE3QzI1LjMwNCAwIDAgMjUuMzA0IDAgNTYuNTE3djkxMC45NjZDMCA5OTguNjk0IDI1LjI5NyAxMDI0IDU2LjUyMiAxMDI0SDU0N1Y2MjhINDE0VjQ3M2gxMzNWMzU5LjAyOWMwLTEzMi4yNjIgODAuNzczLTIwNC4yODIgMTk4Ljc1Ni0yMDQuMjgyIDU2LjUxMyAwIDEwNS4wODYgNC4yMDggMTE5LjI0NCA2LjA4OVYyOTlsLTgxLjYxNi4wMzdjLTYzLjk5MyAwLTc2LjM4NCAzMC40OTItNzYuMzg0IDc1LjIzNlY0NzNoMTUzLjQ4N2wtMTkuOTg2IDE1NUg3MDd2Mzk2aDI2MC40ODRjMzEuMjEzIDAgNTYuNTE2LTI1LjMwMyA1Ni41MTYtNTYuNTE2VjU2LjUxNUMxMDI0IDI1LjMwMyA5OTguNjk3IDAgOTY3LjQ4NCAwIiBmaWxsPSIjRkZGRkZFIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiLz48L3N2Zz4=)}.ck-media__wrapper[data-oembed-url*="facebook.com"] .ck-media__placeholder .ck-media__placeholder__url__text{color:#cdf}.ck-media__wrapper[data-oembed-url*="facebook.com"] .ck-media__placeholder .ck-media__placeholder__url__text:hover{color:#fff}.ck-media__wrapper[data-oembed-url*="instagram.com"] .ck-media__placeholder{background:linear-gradient(-135deg,#1400c7,#b800b1,#f50000)}.ck-media__wrapper[data-oembed-url*="instagram.com"] .ck-media__placeholder .ck-media__placeholder__icon{background-image:url(data:image/svg+xml;base64,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)}.ck-media__wrapper[data-oembed-url*="instagram.com"] .ck-media__placeholder .ck-media__placeholder__url__text{color:#ffe0fe}.ck-media__wrapper[data-oembed-url*="instagram.com"] .ck-media__placeholder .ck-media__placeholder__url__text:hover{color:#fff}.ck-media__wrapper[data-oembed-url*="twitter.com"] .ck.ck-media__placeholder{background:linear-gradient(90deg,#71c6f4,#0d70a5)}.ck-media__wrapper[data-oembed-url*="twitter.com"] .ck.ck-media__placeholder .ck-media__placeholder__icon{background-image:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA0MDAgNDAwIj48cGF0aCBkPSJNNDAwIDIwMGMwIDExMC41LTg5LjUgMjAwLTIwMCAyMDBTMCAzMTAuNSAwIDIwMCA4OS41IDAgMjAwIDBzMjAwIDg5LjUgMjAwIDIwMHpNMTYzLjQgMzA1LjVjODguNyAwIDEzNy4yLTczLjUgMTM3LjItMTM3LjIgMC0yLjEgMC00LjItLjEtNi4yIDkuNC02LjggMTcuNi0xNS4zIDI0LjEtMjUtOC42IDMuOC0xNy45IDYuNC0yNy43IDcuNiAxMC02IDE3LjYtMTUuNCAyMS4yLTI2LjctOS4zIDUuNS0xOS42IDkuNS0zMC42IDExLjctOC44LTkuNC0yMS4zLTE1LjItMzUuMi0xNS4yLTI2LjYgMC00OC4yIDIxLjYtNDguMiA0OC4yIDAgMy44LjQgNy41IDEuMyAxMS00MC4xLTItNzUuNi0yMS4yLTk5LjQtNTAuNC00LjEgNy4xLTYuNSAxNS40LTYuNSAyNC4yIDAgMTYuNyA4LjUgMzEuNSAyMS41IDQwLjEtNy45LS4yLTE1LjMtMi40LTIxLjgtNnYuNmMwIDIzLjQgMTYuNiA0Mi44IDM4LjcgNDcuMy00IDEuMS04LjMgMS43LTEyLjcgMS43LTMuMSAwLTYuMS0uMy05LjEtLjkgNi4xIDE5LjIgMjMuOSAzMy4xIDQ1IDMzLjUtMTYuNSAxMi45LTM3LjMgMjAuNi01OS45IDIwLjYtMy45IDAtNy43LS4yLTExLjUtLjcgMjEuMSAxMy44IDQ2LjUgMjEuOCA3My43IDIxLjgiIGZpbGw9IiNmZmYiLz48L3N2Zz4=)}.ck-media__wrapper[data-oembed-url*="twitter.com"] .ck.ck-media__placeholder .ck-media__placeholder__url__text{color:#b8e6ff}.ck-media__wrapper[data-oembed-url*="twitter.com"] .ck.ck-media__placeholder .ck-media__placeholder__url__text:hover{color:#fff}'},function(t,e,n){var r=n(1),i=n(85);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-media-form{display:flex;align-items:flex-start;flex-direction:row;flex-wrap:nowrap}.ck.ck-media-form .ck-labeled-field-view{display:inline-block}.ck.ck-media-form .ck-label{display:none}@media screen and (max-width:600px){.ck.ck-media-form{flex-wrap:wrap}.ck.ck-media-form .ck-labeled-field-view{flex-basis:100%}.ck.ck-media-form .ck-button{flex-basis:50%}}"},function(t,e,n){var r=n(1),i=n(87);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck-content .media{clear:both;margin:1em 0;display:block;min-width:15em}"},function(t,e,n){var r=n(1),i=n(89);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=":root{--ck-color-table-focused-cell-background:rgba(158,207,250,0.3)}.ck-widget.table td.ck-editor__nested-editable.ck-editor__nested-editable_focused,.ck-widget.table td.ck-editor__nested-editable:focus,.ck-widget.table th.ck-editor__nested-editable.ck-editor__nested-editable_focused,.ck-widget.table th.ck-editor__nested-editable:focus{background:var(--ck-color-table-focused-cell-background);border-style:none;outline:1px solid var(--ck-color-focus-border);outline-offset:-1px}"},function(t,e,n){var r=n(1),i=n(91);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck.ck-splitbutton{font-size:inherit}.ck.ck-splitbutton .ck-splitbutton__action:focus{z-index:calc(var(--ck-z-default) + 1)}.ck.ck-splitbutton.ck-splitbutton_open>.ck-button .ck-tooltip{display:none}:root{--ck-color-split-button-hover-background:#ebebeb;--ck-color-split-button-hover-border:#b3b3b3}[dir=ltr] .ck.ck-splitbutton>.ck-splitbutton__action{border-top-right-radius:unset;border-bottom-right-radius:unset}[dir=rtl] .ck.ck-splitbutton>.ck-splitbutton__action{border-top-left-radius:unset;border-bottom-left-radius:unset}.ck.ck-splitbutton>.ck-splitbutton__arrow{min-width:unset}[dir=ltr] .ck.ck-splitbutton>.ck-splitbutton__arrow{border-radius:0}.ck-rounded-corners [dir=ltr] .ck.ck-splitbutton>.ck-splitbutton__arrow,[dir=ltr] .ck.ck-splitbutton>.ck-splitbutton__arrow.ck-rounded-corners{border-radius:var(--ck-border-radius);border-top-left-radius:unset;border-bottom-left-radius:unset}[dir=rtl] .ck.ck-splitbutton>.ck-splitbutton__arrow{border-top-right-radius:unset;border-bottom-right-radius:unset}.ck.ck-splitbutton>.ck-splitbutton__arrow svg{width:var(--ck-dropdown-arrow-size)}.ck.ck-splitbutton.ck-splitbutton_open>.ck-button:not(.ck-on):not(.ck-disabled):not(:hover),.ck.ck-splitbutton:hover>.ck-button:not(.ck-on):not(.ck-disabled):not(:hover){background:var(--ck-color-split-button-hover-background)}[dir=ltr] .ck.ck-splitbutton.ck-splitbutton_open>.ck-splitbutton__arrow:not(.ck-disabled),[dir=ltr] .ck.ck-splitbutton:hover>.ck-splitbutton__arrow:not(.ck-disabled){border-left-color:var(--ck-color-split-button-hover-border)}[dir=rtl] .ck.ck-splitbutton.ck-splitbutton_open>.ck-splitbutton__arrow:not(.ck-disabled),[dir=rtl] .ck.ck-splitbutton:hover>.ck-splitbutton__arrow:not(.ck-disabled){border-right-color:var(--ck-color-split-button-hover-border)}.ck.ck-splitbutton.ck-splitbutton_open{border-radius:0}.ck-rounded-corners .ck.ck-splitbutton.ck-splitbutton_open,.ck.ck-splitbutton.ck-splitbutton_open.ck-rounded-corners{border-radius:var(--ck-border-radius)}.ck-rounded-corners .ck.ck-splitbutton.ck-splitbutton_open>.ck-splitbutton__action,.ck.ck-splitbutton.ck-splitbutton_open.ck-rounded-corners>.ck-splitbutton__action{border-bottom-left-radius:0}.ck-rounded-corners .ck.ck-splitbutton.ck-splitbutton_open>.ck-splitbutton__arrow,.ck.ck-splitbutton.ck-splitbutton_open.ck-rounded-corners>.ck-splitbutton__arrow{border-bottom-right-radius:0}"},function(t,e,n){var r=n(1),i=n(93);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck .ck-insert-table-dropdown__grid{display:flex;flex-direction:row;flex-wrap:wrap}:root{--ck-insert-table-dropdown-padding:10px;--ck-insert-table-dropdown-box-height:11px;--ck-insert-table-dropdown-box-width:12px;--ck-insert-table-dropdown-box-margin:1px}.ck .ck-insert-table-dropdown__grid{width:calc(var(--ck-insert-table-dropdown-box-width)*10 + var(--ck-insert-table-dropdown-box-margin)*20 + var(--ck-insert-table-dropdown-padding)*2);padding:var(--ck-insert-table-dropdown-padding) var(--ck-insert-table-dropdown-padding) 0}.ck .ck-insert-table-dropdown__label{text-align:center}.ck .ck-insert-table-dropdown-grid-box{width:var(--ck-insert-table-dropdown-box-width);height:var(--ck-insert-table-dropdown-box-height);margin:var(--ck-insert-table-dropdown-box-margin);border:1px solid var(--ck-color-base-border);border-radius:1px}.ck .ck-insert-table-dropdown-grid-box.ck-on{border-color:var(--ck-color-focus-border);background:var(--ck-color-focus-outer-shadow)}"},function(t,e,n){var r=n(1),i=n(95);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=':root{--ck-table-selected-cell-background:rgba(158,207,250,0.3)}.ck.ck-editor__editable .table table td.ck-editor__editable_selected,.ck.ck-editor__editable .table table th.ck-editor__editable_selected{position:relative;caret-color:transparent;outline:unset;box-shadow:unset}.ck.ck-editor__editable .table table td.ck-editor__editable_selected:after,.ck.ck-editor__editable .table table th.ck-editor__editable_selected:after{content:"";pointer-events:none;background-color:var(--ck-table-selected-cell-background);position:absolute;top:0;left:0;right:0;bottom:0}.ck.ck-editor__editable .table table td.ck-editor__editable_selected ::selection,.ck.ck-editor__editable .table table td.ck-editor__editable_selected:focus,.ck.ck-editor__editable .table table th.ck-editor__editable_selected ::selection,.ck.ck-editor__editable .table table th.ck-editor__editable_selected:focus{background-color:transparent}.ck.ck-editor__editable .table table td.ck-editor__editable_selected .ck-widget_selected,.ck.ck-editor__editable .table table th.ck-editor__editable_selected .ck-widget_selected{outline:unset}'},function(t,e,n){var r=n(1),i=n(97);"string"==typeof(i=i.__esModule?i.default:i)&&(i=[[t.i,i,""]]);var o={injectType:"singletonStyleTag",attributes:{"data-cke":!0},insert:"head",singleton:!0};r(i,o),t.exports=i.locals||{}},function(t,e){t.exports=".ck-content .table{margin:1em auto;display:table}.ck-content .table table{border-collapse:collapse;border-spacing:0;width:100%;height:100%;border:1px double #b3b3b3}.ck-content .table table td,.ck-content .table table th{min-width:2em;padding:.4em;border:1px solid #bfbfbf}.ck-content .table table th{font-weight:700;background:hsla(0,0%,0%,5%)}.ck-content[dir=rtl] .table th{text-align:right}.ck-content[dir=ltr] .table th{text-align:left}"},function(t,e,n){"use strict";n.r(e),n.d(e,"default",(function(){return Dg}));var r=n(3),i=r.a.Symbol,o=Object.prototype,a=o.hasOwnProperty,s=o.toString,c=i?i.toStringTag:void 0,l=function(t){var e=a.call(t,c),n=t[c];try{t[c]=void 0;var r=!0}catch(t){}var i=s.call(t);return r&&(e?t[c]=n:delete t[c]),i},u=Object.prototype.toString,d=function(t){return u.call(t)},h=i?i.toStringTag:void 0,f=function(t){return null==t?void 0===t?"[object Undefined]":"[object Null]":h&&h in Object(t)?l(t):d(t)},p=function(t,e){return function(n){return t(e(n))}},m=p(Object.getPrototypeOf,Object),b=function(t){return null!=t&&"object"==typeof t},g=Function.prototype,v=Object.prototype,w=g.toString,y=v.hasOwnProperty,k=w.call(Object),_=function(t){if(!b(t)||"[object Object]"!=f(t))return!1;var e=m(t);if(null===e)return!0;var n=y.call(e,"constructor")&&e.constructor;return"function"==typeof n&&n instanceof n&&w.call(n)==k},O=function(){this.__data__=[],this.size=0},z=function(t,e){return t===e||t!=t&&e!=e},A=function(t,e){for(var n=t.length;n--;)if(z(t[n][0],e))return n;return-1},j=Array.prototype.splice,M=function(t){var e=this.__data__,n=A(e,t);return!(n<0)&&(n==e.length-1?e.pop():j.call(e,n,1),--this.size,!0)},C=function(t){var e=this.__data__,n=A(e,t);return n<0?void 0:e[n][1]},V=function(t){return A(this.__data__,t)>-1},S=function(t,e){var n=this.__data__,r=A(n,t);return r<0?(++this.size,n.push([t,e])):n[r][1]=e,this};function x(t){var e=-1,n=null==t?0:t.length;for(this.clear();++e<n;){var r=t[e];this.set(r[0],r[1])}}x.prototype.clear=O,x.prototype.delete=M,x.prototype.get=C,x.prototype.has=V,x.prototype.set=S;var T,P=x,I=function(){this.__data__=new P,this.size=0},E=function(t){var e=this.__data__,n=e.delete(t);return this.size=e.size,n},L=function(t){return this.__data__.get(t)},B=function(t){return this.__data__.has(t)},H=function(t){var e=typeof t;return null!=t&&("object"==e||"function"==e)},F=function(t){if(!H(t))return!1;var e=f(t);return"[object Function]"==e||"[object GeneratorFunction]"==e||"[object AsyncFunction]"==e||"[object Proxy]"==e},D=r.a["__core-js_shared__"],R=(T=/[^.]+$/.exec(D&&D.keys&&D.keys.IE_PROTO||""))?"Symbol(src)_1."+T:"",N=function(t){return!!R&&R in t},$=Function.prototype.toString,U=function(t){if(null!=t){try{return $.call(t)}catch(t){}try{return t+""}catch(t){}}return""},q=/^\[object .+?Constructor\]$/,W=Function.prototype,G=Object.prototype,Y=W.toString,K=G.hasOwnProperty,Q=RegExp("^"+Y.call(K).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),X=function(t){return!(!H(t)||N(t))&&(F(t)?Q:q).test(U(t))},J=function(t,e){return null==t?void 0:t[e]},Z=function(t,e){var n=J(t,e);return X(n)?n:void 0},tt=Z(r.a,"Map"),et=Z(Object,"create"),nt=function(){this.__data__=et?et(null):{},this.size=0},rt=function(t){var e=this.has(t)&&delete this.__data__[t];return this.size-=e?1:0,e},it=Object.prototype.hasOwnProperty,ot=function(t){var e=this.__data__;if(et){var n=e[t];return"__lodash_hash_undefined__"===n?void 0:n}return it.call(e,t)?e[t]:void 0},at=Object.prototype.hasOwnProperty,st=function(t){var e=this.__data__;return et?void 0!==e[t]:at.call(e,t)},ct=function(t,e){var n=this.__data__;return this.size+=this.has(t)?0:1,n[t]=et&&void 0===e?"__lodash_hash_undefined__":e,this};function lt(t){var e=-1,n=null==t?0:t.length;for(this.clear();++e<n;){var r=t[e];this.set(r[0],r[1])}}lt.prototype.clear=nt,lt.prototype.delete=rt,lt.prototype.get=ot,lt.prototype.has=st,lt.prototype.set=ct;var ut=lt,dt=function(){this.size=0,this.__data__={hash:new ut,map:new(tt||P),string:new ut}},ht=function(t){var e=typeof t;return"string"==e||"number"==e||"symbol"==e||"boolean"==e?"__proto__"!==t:null===t},ft=function(t,e){var n=t.__data__;return ht(e)?n["string"==typeof e?"string":"hash"]:n.map},pt=function(t){var e=ft(this,t).delete(t);return this.size-=e?1:0,e},mt=function(t){return ft(this,t).get(t)},bt=function(t){return ft(this,t).has(t)},gt=function(t,e){var n=ft(this,t),r=n.size;return n.set(t,e),this.size+=n.size==r?0:1,this};function vt(t){var e=-1,n=null==t?0:t.length;for(this.clear();++e<n;){var r=t[e];this.set(r[0],r[1])}}vt.prototype.clear=dt,vt.prototype.delete=pt,vt.prototype.get=mt,vt.prototype.has=bt,vt.prototype.set=gt;var wt=vt,yt=function(t,e){var n=this.__data__;if(n instanceof P){var r=n.__data__;if(!tt||r.length<199)return r.push([t,e]),this.size=++n.size,this;n=this.__data__=new wt(r)}return n.set(t,e),this.size=n.size,this};function kt(t){var e=this.__data__=new P(t);this.size=e.size}kt.prototype.clear=I,kt.prototype.delete=E,kt.prototype.get=L,kt.prototype.has=B,kt.prototype.set=yt;var _t=kt,Ot=function(t,e){for(var n=-1,r=null==t?0:t.length;++n<r&&!1!==e(t[n],n,t););return t},zt=function(){try{var t=Z(Object,"defineProperty");return t({},"",{}),t}catch(t){}}(),At=function(t,e,n){"__proto__"==e&&zt?zt(t,e,{configurable:!0,enumerable:!0,value:n,writable:!0}):t[e]=n},jt=Object.prototype.hasOwnProperty,Mt=function(t,e,n){var r=t[e];jt.call(t,e)&&z(r,n)&&(void 0!==n||e in t)||At(t,e,n)},Ct=function(t,e,n,r){var i=!n;n||(n={});for(var o=-1,a=e.length;++o<a;){var s=e[o],c=r?r(n[s],t[s],s,n,t):void 0;void 0===c&&(c=t[s]),i?At(n,s,c):Mt(n,s,c)}return n},Vt=function(t,e){for(var n=-1,r=Array(t);++n<t;)r[n]=e(n);return r},St=function(t){return b(t)&&"[object Arguments]"==f(t)},xt=Object.prototype,Tt=xt.hasOwnProperty,Pt=xt.propertyIsEnumerable,It=St(function(){return arguments}())?St:function(t){return b(t)&&Tt.call(t,"callee")&&!Pt.call(t,"callee")},Et=Array.isArray,Lt=n(4),Bt=/^(?:0|[1-9]\d*)$/,Ht=function(t,e){var n=typeof t;return!!(e=null==e?9007199254740991:e)&&("number"==n||"symbol"!=n&&Bt.test(t))&&t>-1&&t%1==0&&t<e},Ft=function(t){return"number"==typeof t&&t>-1&&t%1==0&&t<=9007199254740991},Dt={};Dt["[object Float32Array]"]=Dt["[object Float64Array]"]=Dt["[object Int8Array]"]=Dt["[object Int16Array]"]=Dt["[object Int32Array]"]=Dt["[object Uint8Array]"]=Dt["[object Uint8ClampedArray]"]=Dt["[object Uint16Array]"]=Dt["[object Uint32Array]"]=!0,Dt["[object Arguments]"]=Dt["[object Array]"]=Dt["[object ArrayBuffer]"]=Dt["[object Boolean]"]=Dt["[object DataView]"]=Dt["[object Date]"]=Dt["[object Error]"]=Dt["[object Function]"]=Dt["[object Map]"]=Dt["[object Number]"]=Dt["[object Object]"]=Dt["[object RegExp]"]=Dt["[object Set]"]=Dt["[object String]"]=Dt["[object WeakMap]"]=!1;var Rt=function(t){return b(t)&&Ft(t.length)&&!!Dt[f(t)]},Nt=function(t){return function(e){return t(e)}},$t=n(5),Ut=$t.a&&$t.a.isTypedArray,qt=Ut?Nt(Ut):Rt,Wt=Object.prototype.hasOwnProperty,Gt=function(t,e){var n=Et(t),r=!n&&It(t),i=!n&&!r&&Object(Lt.a)(t),o=!n&&!r&&!i&&qt(t),a=n||r||i||o,s=a?Vt(t.length,String):[],c=s.length;for(var l in t)!e&&!Wt.call(t,l)||a&&("length"==l||i&&("offset"==l||"parent"==l)||o&&("buffer"==l||"byteLength"==l||"byteOffset"==l)||Ht(l,c))||s.push(l);return s},Yt=Object.prototype,Kt=function(t){var e=t&&t.constructor;return t===("function"==typeof e&&e.prototype||Yt)},Qt=p(Object.keys,Object),Xt=Object.prototype.hasOwnProperty,Jt=function(t){if(!Kt(t))return Qt(t);var e=[];for(var n in Object(t))Xt.call(t,n)&&"constructor"!=n&&e.push(n);return e},Zt=function(t){return null!=t&&Ft(t.length)&&!F(t)},te=function(t){return Zt(t)?Gt(t):Jt(t)},ee=function(t,e){return t&&Ct(e,te(e),t)},ne=function(t){var e=[];if(null!=t)for(var n in Object(t))e.push(n);return e},re=Object.prototype.hasOwnProperty,ie=function(t){if(!H(t))return ne(t);var e=Kt(t),n=[];for(var r in t)("constructor"!=r||!e&&re.call(t,r))&&n.push(r);return n},oe=function(t){return Zt(t)?Gt(t,!0):ie(t)},ae=function(t,e){return t&&Ct(e,oe(e),t)},se=n(9),ce=function(t,e){var n=-1,r=t.length;for(e||(e=Array(r));++n<r;)e[n]=t[n];return e},le=function(t,e){for(var n=-1,r=null==t?0:t.length,i=0,o=[];++n<r;){var a=t[n];e(a,n,t)&&(o[i++]=a)}return o},ue=function(){return[]},de=Object.prototype.propertyIsEnumerable,he=Object.getOwnPropertySymbols,fe=he?function(t){return null==t?[]:(t=Object(t),le(he(t),(function(e){return de.call(t,e)})))}:ue,pe=function(t,e){return Ct(t,fe(t),e)},me=function(t,e){for(var n=-1,r=e.length,i=t.length;++n<r;)t[i+n]=e[n];return t},be=Object.getOwnPropertySymbols?function(t){for(var e=[];t;)me(e,fe(t)),t=m(t);return e}:ue,ge=function(t,e){return Ct(t,be(t),e)},ve=function(t,e,n){var r=e(t);return Et(t)?r:me(r,n(t))},we=function(t){return ve(t,te,fe)},ye=function(t){return ve(t,oe,be)},ke=Z(r.a,"DataView"),_e=Z(r.a,"Promise"),Oe=Z(r.a,"Set"),ze=Z(r.a,"WeakMap"),Ae=U(ke),je=U(tt),Me=U(_e),Ce=U(Oe),Ve=U(ze),Se=f;(ke&&"[object DataView]"!=Se(new ke(new ArrayBuffer(1)))||tt&&"[object Map]"!=Se(new tt)||_e&&"[object Promise]"!=Se(_e.resolve())||Oe&&"[object Set]"!=Se(new Oe)||ze&&"[object WeakMap]"!=Se(new ze))&&(Se=function(t){var e=f(t),n="[object Object]"==e?t.constructor:void 0,r=n?U(n):"";if(r)switch(r){case Ae:return"[object DataView]";case je:return"[object Map]";case Me:return"[object Promise]";case Ce:return"[object Set]";case Ve:return"[object WeakMap]"}return e});var xe=Se,Te=Object.prototype.hasOwnProperty,Pe=function(t){var e=t.length,n=new t.constructor(e);return e&&"string"==typeof t[0]&&Te.call(t,"index")&&(n.index=t.index,n.input=t.input),n},Ie=r.a.Uint8Array,Ee=function(t){var e=new t.constructor(t.byteLength);return new Ie(e).set(new Ie(t)),e},Le=function(t,e){var n=e?Ee(t.buffer):t.buffer;return new t.constructor(n,t.byteOffset,t.byteLength)},Be=/\w*$/,He=function(t){var e=new t.constructor(t.source,Be.exec(t));return e.lastIndex=t.lastIndex,e},Fe=i?i.prototype:void 0,De=Fe?Fe.valueOf:void 0,Re=function(t){return De?Object(De.call(t)):{}},Ne=function(t,e){var n=e?Ee(t.buffer):t.buffer;return new t.constructor(n,t.byteOffset,t.length)},$e=function(t,e,n){var r=t.constructor;switch(e){case"[object ArrayBuffer]":return Ee(t);case"[object Boolean]":case"[object Date]":return new r(+t);case"[object DataView]":return Le(t,n);case"[object Float32Array]":case"[object Float64Array]":case"[object Int8Array]":case"[object Int16Array]":case"[object Int32Array]":case"[object Uint8Array]":case"[object Uint8ClampedArray]":case"[object Uint16Array]":case"[object Uint32Array]":return Ne(t,n);case"[object Map]":return new r;case"[object Number]":case"[object String]":return new r(t);case"[object RegExp]":return He(t);case"[object Set]":return new r;case"[object Symbol]":return Re(t)}},Ue=Object.create,qe=function(){function t(){}return function(e){if(!H(e))return{};if(Ue)return Ue(e);t.prototype=e;var n=new t;return t.prototype=void 0,n}}(),We=function(t){return"function"!=typeof t.constructor||Kt(t)?{}:qe(m(t))},Ge=function(t){return b(t)&&"[object Map]"==xe(t)},Ye=$t.a&&$t.a.isMap,Ke=Ye?Nt(Ye):Ge,Qe=function(t){return b(t)&&"[object Set]"==xe(t)},Xe=$t.a&&$t.a.isSet,Je=Xe?Nt(Xe):Qe,Ze={};Ze["[object Arguments]"]=Ze["[object Array]"]=Ze["[object ArrayBuffer]"]=Ze["[object DataView]"]=Ze["[object Boolean]"]=Ze["[object Date]"]=Ze["[object Float32Array]"]=Ze["[object Float64Array]"]=Ze["[object Int8Array]"]=Ze["[object Int16Array]"]=Ze["[object Int32Array]"]=Ze["[object Map]"]=Ze["[object Number]"]=Ze["[object Object]"]=Ze["[object RegExp]"]=Ze["[object Set]"]=Ze["[object String]"]=Ze["[object Symbol]"]=Ze["[object Uint8Array]"]=Ze["[object Uint8ClampedArray]"]=Ze["[object Uint16Array]"]=Ze["[object Uint32Array]"]=!0,Ze["[object Error]"]=Ze["[object Function]"]=Ze["[object WeakMap]"]=!1;var tn=function t(e,n,r,i,o,a){var s,c=1&n,l=2&n,u=4&n;if(r&&(s=o?r(e,i,o,a):r(e)),void 0!==s)return s;if(!H(e))return e;var d=Et(e);if(d){if(s=Pe(e),!c)return ce(e,s)}else{var h=xe(e),f="[object Function]"==h||"[object GeneratorFunction]"==h;if(Object(Lt.a)(e))return Object(se.a)(e,c);if("[object Object]"==h||"[object Arguments]"==h||f&&!o){if(s=l||f?{}:We(e),!c)return l?ge(e,ae(s,e)):pe(e,ee(s,e))}else{if(!Ze[h])return o?e:{};s=$e(e,h,c)}}a||(a=new _t);var p=a.get(e);if(p)return p;a.set(e,s),Je(e)?e.forEach((function(i){s.add(t(i,n,r,i,e,a))})):Ke(e)&&e.forEach((function(i,o){s.set(o,t(i,n,r,o,e,a))}));var m=d?void 0:(u?l?ye:we:l?oe:te)(e);return Ot(m||e,(function(i,o){m&&(i=e[o=i]),Mt(s,o,t(i,n,r,o,e,a))})),s},en=function(t,e){return tn(t,5,e="function"==typeof e?e:void 0)},nn=function(t){return b(t)&&1===t.nodeType&&!_(t)};class rn{constructor(t,e){this._config={},e&&this.define(on(e)),t&&this._setObjectToTarget(this._config,t)}set(t,e){this._setToTarget(this._config,t,e)}define(t,e){this._setToTarget(this._config,t,e,!0)}get(t){return this._getFromSource(this._config,t)}*names(){for(const t of Object.keys(this._config))yield t}_setToTarget(t,e,n,r=!1){if(_(e))return void this._setObjectToTarget(t,e,r);const i=e.split(".");e=i.pop();for(const o of i)_(t[o])||(t[o]={}),t=t[o];if(_(n))return _(t[e])||(t[e]={}),t=t[e],void this._setObjectToTarget(t,n,r);r&&void 0!==t[e]||(t[e]=n)}_getFromSource(t,e){const n=e.split(".");e=n.pop();for(const r of n){if(!_(t[r])){t=null;break}t=t[r]}return t?on(t[e]):void 0}_setObjectToTarget(t,e,n){Object.keys(e).forEach(r=>{this._setToTarget(t,r,e[r],n)})}}function on(t){return en(t,an)}function an(t){return nn(t)?t:void 0}var sn=function(){return function t(){t.called=!0}};class cn{constructor(t,e){this.source=t,this.name=e,this.path=[],this.stop=sn(),this.off=sn()}}const ln=new Array(256).fill().map((t,e)=>("0"+e.toString(16)).slice(-2));function un(){const t=4294967296*Math.random()>>>0,e=4294967296*Math.random()>>>0,n=4294967296*Math.random()>>>0,r=4294967296*Math.random()>>>0;return"e"+ln[t>>0&255]+ln[t>>8&255]+ln[t>>16&255]+ln[t>>24&255]+ln[e>>0&255]+ln[e>>8&255]+ln[e>>16&255]+ln[e>>24&255]+ln[n>>0&255]+ln[n>>8&255]+ln[n>>16&255]+ln[n>>24&255]+ln[r>>0&255]+ln[r>>8&255]+ln[r>>16&255]+ln[r>>24&255]}var dn={get(t){return"number"!=typeof t?this[t]||this.normal:t},highest:1e5,high:1e3,normal:0,low:-1e3,lowest:-1e5},hn=(n(6),n(0));const fn=Symbol("listeningTo"),pn=Symbol("emitterId");var mn={on(t,e,n={}){this.listenTo(this,t,e,n)},once(t,e,n){let r=!1;this.listenTo(this,t,(function(t,...n){r||(r=!0,t.off(),e.call(this,t,...n))}),n)},off(t,e){this.stopListening(this,t,e)},listenTo(t,e,n,r={}){let i,o;this[fn]||(this[fn]={});const a=this[fn];gn(t)||bn(t);const s=gn(t);(i=a[s])||(i=a[s]={emitter:t,callbacks:{}}),(o=i.callbacks[e])||(o=i.callbacks[e]=[]),o.push(n),function(t,e){const n=vn(t);if(n[e])return;let r=e,i=null;const o=[];for(;""!==r&&!n[r];)n[r]={callbacks:[],childEvents:[]},o.push(n[r]),i&&n[r].childEvents.push(i),i=r,r=r.substr(0,r.lastIndexOf(":"));if(""!==r){for(const t of o)t.callbacks=n[r].callbacks.slice();n[r].childEvents.push(i)}}(t,e);const c=wn(t,e),l=dn.get(r.priority),u={callback:n,priority:l};for(const d of c){let t=!1;for(let e=0;e<d.length;e++)if(d[e].priority<l){d.splice(e,0,u),t=!0;break}t||d.push(u)}},stopListening(t,e,n){const r=this[fn];let i=t&&gn(t);const o=r&&i&&r[i],a=o&&e&&o.callbacks[e];if(!(!r||t&&!o||e&&!a))if(n)kn(t,e,n),-1!==a.indexOf(n)&&(1===a.length?delete o.callbacks[e]:kn(t,e,n));else if(a){for(;n=a.pop();)kn(t,e,n);delete o.callbacks[e]}else if(o){for(e in o.callbacks)this.stopListening(t,e);delete r[i]}else{for(i in r)this.stopListening(r[i].emitter);delete this[fn]}},fire(t,...e){try{const n=t instanceof cn?t:new cn(this,t),r=n.name;let i=function t(e,n){let r;return e._events&&(r=e._events[n])&&r.callbacks.length?r.callbacks:n.indexOf(":")>-1?t(e,n.substr(0,n.lastIndexOf(":"))):null}(this,r);if(n.path.push(this),i){const t=[n,...e];i=Array.from(i);for(let e=0;e<i.length&&(i[e].callback.apply(this,t),n.off.called&&(delete n.off.called,kn(this,r,i[e].callback)),!n.stop.called);e++);}if(this._delegations){const t=this._delegations.get(r),i=this._delegations.get("*");t&&yn(t,n,e),i&&yn(i,n,e)}return n.return}catch(t){hn.a.rethrowUnexpectedError(t,this)}},delegate(...t){return{to:(e,n)=>{this._delegations||(this._delegations=new Map),t.forEach(t=>{const r=this._delegations.get(t);r?r.set(e,n):this._delegations.set(t,new Map([[e,n]]))})}}},stopDelegating(t,e){if(this._delegations)if(t)if(e){const n=this._delegations.get(t);n&&n.delete(e)}else this._delegations.delete(t);else this._delegations.clear()}};function bn(t,e){t[pn]||(t[pn]=e||un())}function gn(t){return t[pn]}function vn(t){return t._events||Object.defineProperty(t,"_events",{value:{}}),t._events}function wn(t,e){const n=vn(t)[e];if(!n)return[];let r=[n.callbacks];for(let i=0;i<n.childEvents.length;i++){const e=wn(t,n.childEvents[i]);r=r.concat(e)}return r}function yn(t,e,n){for(let[r,i]of t){i?"function"==typeof i&&(i=i(e.name)):i=e.name;const t=new cn(e.source,i);t.path=[...e.path],r.fire(t,...n)}}function kn(t,e,n){const r=wn(t,e);for(const i of r)for(let t=0;t<i.length;t++)i[t].callback==n&&(i.splice(t,1),t--)}function _n(t){return!(!t||!t[Symbol.iterator])}function On(t,...e){e.forEach(e=>{Object.getOwnPropertyNames(e).concat(Object.getOwnPropertySymbols(e)).forEach(n=>{if(n in t.prototype)return;const r=Object.getOwnPropertyDescriptor(e,n);r.enumerable=!1,Object.defineProperty(t.prototype,n,r)})})}class zn{constructor(t={},e={}){const n=_n(t);if(n||(e=t),this._items=[],this._itemMap=new Map,this._idProperty=e.idProperty||"id",this._bindToExternalToInternalMap=new WeakMap,this._bindToInternalToExternalMap=new WeakMap,this._skippedIndexesFromExternal=[],n)for(const r of t)this._items.push(r),this._itemMap.set(this._getItemIdBeforeAdding(r),r)}get length(){return this._items.length}get first(){return this._items[0]||null}get last(){return this._items[this.length-1]||null}add(t,e){return this.addMany([t],e)}addMany(t,e){if(void 0===e)e=this._items.length;else if(e>this._items.length||e<0)throw new hn.a("collection-add-item-invalid-index",this);for(let n=0;n<t.length;n++){const r=t[n],i=this._getItemIdBeforeAdding(r),o=e+n;this._items.splice(o,0,r),this._itemMap.set(i,r),this.fire("add",r,o)}return this.fire("change",{added:t,removed:[],index:e}),this}get(t){let e;if("string"==typeof t)e=this._itemMap.get(t);else{if("number"!=typeof t)throw new hn.a("collection-get-invalid-arg",this);e=this._items[t]}return e||null}has(t){if("string"==typeof t)return this._itemMap.has(t);{const e=t[this._idProperty];return this._itemMap.has(e)}}getIndex(t){let e;return e="string"==typeof t?this._itemMap.get(t):t,this._items.indexOf(e)}remove(t){const[e,n]=this._remove(t);return this.fire("change",{added:[],removed:[e],index:n}),e}map(t,e){return this._items.map(t,e)}find(t,e){return this._items.find(t,e)}filter(t,e){return this._items.filter(t,e)}clear(){this._bindToCollection&&(this.stopListening(this._bindToCollection),this._bindToCollection=null);const t=Array.from(this._items);for(;this.length;)this._remove(0);this.fire("change",{added:[],removed:t,index:0})}bindTo(t){if(this._bindToCollection)throw new hn.a("collection-bind-to-rebind",this);return this._bindToCollection=t,{as:t=>{this._setUpBindToBinding(e=>new t(e))},using:t=>{"function"==typeof t?this._setUpBindToBinding(e=>t(e)):this._setUpBindToBinding(e=>e[t])}}}_setUpBindToBinding(t){const e=this._bindToCollection,n=(n,r,i)=>{const o=e._bindToCollection==this,a=e._bindToInternalToExternalMap.get(r);if(o&&a)this._bindToExternalToInternalMap.set(r,a),this._bindToInternalToExternalMap.set(a,r);else{const n=t(r);if(!n)return void this._skippedIndexesFromExternal.push(i);let o=i;for(const t of this._skippedIndexesFromExternal)i>t&&o--;for(const t of e._skippedIndexesFromExternal)o>=t&&o++;this._bindToExternalToInternalMap.set(r,n),this._bindToInternalToExternalMap.set(n,r),this.add(n,o);for(let t=0;t<e._skippedIndexesFromExternal.length;t++)o<=e._skippedIndexesFromExternal[t]&&e._skippedIndexesFromExternal[t]++}};for(const r of e)n(0,r,e.getIndex(r));this.listenTo(e,"add",n),this.listenTo(e,"remove",(t,e,n)=>{const r=this._bindToExternalToInternalMap.get(e);r&&this.remove(r),this._skippedIndexesFromExternal=this._skippedIndexesFromExternal.reduce((t,e)=>(n<e&&t.push(e-1),n>e&&t.push(e),t),[])})}_getItemIdBeforeAdding(t){const e=this._idProperty;let n;if(e in t){if(n=t[e],"string"!=typeof n)throw new hn.a("collection-add-invalid-id",this);if(this.get(n))throw new hn.a("collection-add-item-already-exists",this)}else t[e]=n=un();return n}_remove(t){let e,n,r,i=!1;const o=this._idProperty;if("string"==typeof t?(n=t,r=this._itemMap.get(n),i=!r,r&&(e=this._items.indexOf(r))):"number"==typeof t?(e=t,r=this._items[e],i=!r,r&&(n=r[o])):(r=t,n=r[o],e=this._items.indexOf(r),i=-1==e||!this._itemMap.get(n)),i)throw new hn.a("collection-remove-404",this);this._items.splice(e,1),this._itemMap.delete(n);const a=this._bindToInternalToExternalMap.get(r);return this._bindToInternalToExternalMap.delete(r),this._bindToExternalToInternalMap.delete(a),this.fire("remove",r,e),[r,e]}[Symbol.iterator](){return this._items[Symbol.iterator]()}}On(zn,mn);class An{constructor(t,e=[],n=[]){this._context=t,this._plugins=new Map,this._availablePlugins=new Map;for(const r of e)r.pluginName&&this._availablePlugins.set(r.pluginName,r);this._contextPlugins=new Map;for(const[r,i]of n)this._contextPlugins.set(r,i),this._contextPlugins.set(i,r),r.pluginName&&this._availablePlugins.set(r.pluginName,r)}*[Symbol.iterator](){for(const t of this._plugins)"function"==typeof t[0]&&(yield t)}get(t){const e=this._plugins.get(t);if(!e){let e=t;throw"function"==typeof t&&(e=t.pluginName||t.name),new hn.a("plugincollection-plugin-not-loaded",this._context,{plugin:e})}return e}has(t){return this._plugins.has(t)}init(t,e=[]){const n=this,r=this._context,i=new Set,o=[],a=h(t),s=h(e),c=function(t){const e=[];for(const n of t)d(n)||e.push(n);return e.length?e:null}(t);if(c){const t="plugincollection-plugin-not-found";return Object(hn.b)(t,{plugins:c}),Promise.reject(new hn.a(t,r,{plugins:c}))}return Promise.all(a.map(l)).then(()=>u(o,"init")).then(()=>u(o,"afterInit")).then(()=>o);function l(t){if(!s.includes(t)&&!n._plugins.has(t)&&!i.has(t))return function(t){return new Promise(a=>{i.add(t),t.requires&&t.requires.forEach(n=>{const i=d(n);if(t.isContextPlugin&&!i.isContextPlugin)throw new hn.a("plugincollection-context-required",null,{plugin:i.name,requiredBy:t.name});if(e.includes(i))throw new hn.a("plugincollection-required",r,{plugin:i.name,requiredBy:t.name});l(i)});const s=n._contextPlugins.get(t)||new t(r);n._add(t,s),o.push(s),a()})}(t).catch(e=>{throw Object(hn.b)("plugincollection-load",{plugin:t}),e})}function u(t,e){return t.reduce((t,r)=>r[e]?n._contextPlugins.has(r)?t:t.then(r[e].bind(r)):t,Promise.resolve())}function d(t){return"function"==typeof t?t:n._availablePlugins.get(t)}function h(t){return t.map(t=>d(t)).filter(t=>!!t)}}destroy(){const t=[];for(const[,e]of this)"function"!=typeof e.destroy||this._contextPlugins.has(e)||t.push(e.destroy());return Promise.all(t)}_add(t,e){this._plugins.set(t,e);const n=t.pluginName;if(n){if(this._plugins.has(n))throw new hn.a("plugincollection-plugin-name-conflict",null,{pluginName:n,plugin1:this._plugins.get(n).constructor,plugin2:t});this._plugins.set(n,e)}}}function jn(t){return Array.isArray(t)?t:[t]}function Mn(t,e,n=1){if("number"!=typeof n)throw new hn.a("translation-service-quantity-not-a-number",null,{quantity:n});const r=Object.keys(window.CKEDITOR_TRANSLATIONS).length;1===r&&(t=Object.keys(window.CKEDITOR_TRANSLATIONS)[0]);const i=e.id||e.string;if(0===r||!function(t,e){return!!window.CKEDITOR_TRANSLATIONS[t]&&!!window.CKEDITOR_TRANSLATIONS[t].dictionary[e]}(t,i))return 1!==n?e.plural:e.string;const o=window.CKEDITOR_TRANSLATIONS[t].dictionary,a=window.CKEDITOR_TRANSLATIONS[t].getPluralForm||(t=>1===t?0:1);if("string"==typeof o[i])return o[i];const s=Number(a(n));return o[i][s]}On(An,mn),window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={});const Cn=["ar","fa","he","ku","ug"];class Vn{constructor(t={}){this.uiLanguage=t.uiLanguage||"en",this.contentLanguage=t.contentLanguage||this.uiLanguage,this.uiLanguageDirection=Sn(this.uiLanguage),this.contentLanguageDirection=Sn(this.contentLanguage),this.t=(t,e)=>this._t(t,e)}get language(){return console.warn("locale-deprecated-language-property: The Locale#language property has been deprecated and will be removed in the near future. Please use #uiLanguage and #contentLanguage properties instead."),this.uiLanguage}_t(t,e=[]){e=jn(e),"string"==typeof t&&(t={string:t});const n=t.plural?e[0]:1;return function(t,e){return t.replace(/%(\d+)/g,(t,n)=>n<e.length?e[n]:t)}(Mn(this.uiLanguage,t,n),e)}}function Sn(t){return Cn.includes(t)?"rtl":"ltr"}class xn{constructor(t){this.config=new rn(t,this.constructor.defaultConfig);const e=this.constructor.builtinPlugins;this.config.define("plugins",e),this.plugins=new An(this,e);const n=this.config.get("language")||{};this.locale=new Vn({uiLanguage:"string"==typeof n?n:n.ui,contentLanguage:this.config.get("language.content")}),this.t=this.locale.t,this.editors=new zn,this._contextOwner=null}initPlugins(){const t=this.config.get("plugins")||[];for(const e of t){if("function"!=typeof e)throw new hn.a("context-initplugins-constructor-only",null,{Plugin:e});if(!0!==e.isContextPlugin)throw new hn.a("context-initplugins-invalid-plugin",null,{Plugin:e})}return this.plugins.init(t)}destroy(){return Promise.all(Array.from(this.editors,t=>t.destroy())).then(()=>this.plugins.destroy())}_addEditor(t,e){if(this._contextOwner)throw new hn.a("context-addeditor-private-context");this.editors.add(t),e&&(this._contextOwner=t)}_removeEditor(t){return this.editors.has(t)&&this.editors.remove(t),this._contextOwner===t?this.destroy():Promise.resolve()}_getEditorConfig(){const t={};for(const e of this.config.names())["plugins","removePlugins","extraPlugins"].includes(e)||(t[e]=this.config.get(e));return t}static create(t){return new Promise(e=>{const n=new this(t);e(n.initPlugins().then(()=>n))})}}function Tn(t,e){const n=Math.min(t.length,e.length);for(let r=0;r<n;r++)if(t[r]!=e[r])return r;return t.length==e.length?"same":t.length<e.length?"prefix":"extension"}var Pn=function(t){return tn(t,4)};class In{constructor(t){this.document=t,this.parent=null}get index(){let t;if(!this.parent)return null;if(-1==(t=this.parent.getChildIndex(this)))throw new hn.a("view-node-not-found-in-parent",this);return t}get nextSibling(){const t=this.index;return null!==t&&this.parent.getChild(t+1)||null}get previousSibling(){const t=this.index;return null!==t&&this.parent.getChild(t-1)||null}get root(){let t=this;for(;t.parent;)t=t.parent;return t}isAttached(){return this.root.is("rootElement")}getPath(){const t=[];let e=this;for(;e.parent;)t.unshift(e.index),e=e.parent;return t}getAncestors(t={includeSelf:!1,parentFirst:!1}){const e=[];let n=t.includeSelf?this:this.parent;for(;n;)e[t.parentFirst?"push":"unshift"](n),n=n.parent;return e}getCommonAncestor(t,e={}){const n=this.getAncestors(e),r=t.getAncestors(e);let i=0;for(;n[i]==r[i]&&n[i];)i++;return 0===i?null:n[i-1]}isBefore(t){if(this==t)return!1;if(this.root!==t.root)return!1;const e=this.getPath(),n=t.getPath(),r=Tn(e,n);switch(r){case"prefix":return!0;case"extension":return!1;default:return e[r]<n[r]}}isAfter(t){return this!=t&&this.root===t.root&&!this.isBefore(t)}_remove(){this.parent._removeChildren(this.index)}_fireChange(t,e){this.fire("change:"+t,e),this.parent&&this.parent._fireChange(t,e)}toJSON(){const t=Pn(this);return delete t.parent,t}is(t){return"node"===t||"view:node"===t}}On(In,mn);class En extends In{constructor(t,e){super(t),this._textData=e}is(t){return"$text"===t||"view:$text"===t||"text"===t||"view:text"===t||"node"===t||"view:node"===t}get data(){return this._textData}get _data(){return this.data}set _data(t){this._fireChange("text",this),this._textData=t}isSimilar(t){return t instanceof En&&(this===t||this.data===t.data)}_clone(){return new En(this.document,this.data)}}class Ln{constructor(t,e,n){if(this.textNode=t,e<0||e>t.data.length)throw new hn.a("view-textproxy-wrong-offsetintext",this);if(n<0||e+n>t.data.length)throw new hn.a("view-textproxy-wrong-length",this);this.data=t.data.substring(e,e+n),this.offsetInText=e}get offsetSize(){return this.data.length}get isPartial(){return this.data.length!==this.textNode.data.length}get parent(){return this.textNode.parent}get root(){return this.textNode.root}get document(){return this.textNode.document}is(t){return"$textProxy"===t||"view:$textProxy"===t||"textProxy"===t||"view:textProxy"===t}getAncestors(t={includeSelf:!1,parentFirst:!1}){const e=[];let n=t.includeSelf?this.textNode:this.parent;for(;null!==n;)e[t.parentFirst?"push":"unshift"](n),n=n.parent;return e}}function Bn(t){return _n(t)?new Map(t):function(t){const e=new Map;for(const n in t)e.set(n,t[n]);return e}(t)}class Hn{constructor(...t){this._patterns=[],this.add(...t)}add(...t){for(let e of t)("string"==typeof e||e instanceof RegExp)&&(e={name:e}),e.classes&&("string"==typeof e.classes||e.classes instanceof RegExp)&&(e.classes=[e.classes]),this._patterns.push(e)}match(...t){for(const e of t)for(const t of this._patterns){const n=Fn(e,t);if(n)return{element:e,pattern:t,match:n}}return null}matchAll(...t){const e=[];for(const n of t)for(const t of this._patterns){const r=Fn(n,t);r&&e.push({element:n,pattern:t,match:r})}return e.length>0?e:null}getElementName(){if(1!==this._patterns.length)return null;const t=this._patterns[0],e=t.name;return"function"==typeof t||!e||e instanceof RegExp?null:e}}function Fn(t,e){if("function"==typeof e)return e(t);const n={};return e.name&&(n.name=function(t,e){return t instanceof RegExp?t.test(e):t===e}(e.name,t.name),!n.name)||e.attributes&&(n.attributes=function(t,e){const n=[];for(const r in t){const i=t[r];if(!e.hasAttribute(r))return null;{const t=e.getAttribute(r);if(!0===i)n.push(r);else if(i instanceof RegExp){if(!i.test(t))return null;n.push(r)}else{if(t!==i)return null;n.push(r)}}}return n}(e.attributes,t),!n.attributes)?null:!(e.classes&&(n.classes=function(t,e){const n=[];for(const r of t)if(r instanceof RegExp){const t=e.getClassNames();for(const e of t)r.test(e)&&n.push(e);if(0===n.length)return null}else{if(!e.hasClass(r))return null;n.push(r)}return n}(e.classes,t),!n.classes))&&!(e.styles&&(n.styles=function(t,e){const n=[];for(const r in t){const i=t[r];if(!e.hasStyle(r))return null;{const t=e.getStyle(r);if(i instanceof RegExp){if(!i.test(t))return null;n.push(r)}else{if(t!==i)return null;n.push(r)}}}return n}(e.styles,t),!n.styles))&&n}var Dn=function(t){return"symbol"==typeof t||b(t)&&"[object Symbol]"==f(t)},Rn=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,Nn=/^\w*$/,$n=function(t,e){if(Et(t))return!1;var n=typeof t;return!("number"!=n&&"symbol"!=n&&"boolean"!=n&&null!=t&&!Dn(t))||Nn.test(t)||!Rn.test(t)||null!=e&&t in Object(e)};function Un(t,e){if("function"!=typeof t||null!=e&&"function"!=typeof e)throw new TypeError("Expected a function");var n=function(){var r=arguments,i=e?e.apply(this,r):r[0],o=n.cache;if(o.has(i))return o.get(i);var a=t.apply(this,r);return n.cache=o.set(i,a)||o,a};return n.cache=new(Un.Cache||wt),n}Un.Cache=wt;var qn=Un,Wn=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g,Gn=/\\(\\)?/g,Yn=function(t){var e=qn(t,(function(t){return 500===n.size&&n.clear(),t})),n=e.cache;return e}((function(t){var e=[];return 46===t.charCodeAt(0)&&e.push(""),t.replace(Wn,(function(t,n,r,i){e.push(r?i.replace(Gn,"$1"):n||t)})),e})),Kn=function(t,e){for(var n=-1,r=null==t?0:t.length,i=Array(r);++n<r;)i[n]=e(t[n],n,t);return i},Qn=i?i.prototype:void 0,Xn=Qn?Qn.toString:void 0,Jn=function t(e){if("string"==typeof e)return e;if(Et(e))return Kn(e,t)+"";if(Dn(e))return Xn?Xn.call(e):"";var n=e+"";return"0"==n&&1/e==-1/0?"-0":n},Zn=function(t){return null==t?"":Jn(t)},tr=function(t,e){return Et(t)?t:$n(t,e)?[t]:Yn(Zn(t))},er=function(t){var e=null==t?0:t.length;return e?t[e-1]:void 0},nr=function(t){if("string"==typeof t||Dn(t))return t;var e=t+"";return"0"==e&&1/t==-1/0?"-0":e},rr=function(t,e){for(var n=0,r=(e=tr(e,t)).length;null!=t&&n<r;)t=t[nr(e[n++])];return n&&n==r?t:void 0},ir=function(t,e,n){var r=-1,i=t.length;e<0&&(e=-e>i?0:i+e),(n=n>i?i:n)<0&&(n+=i),i=e>n?0:n-e>>>0,e>>>=0;for(var o=Array(i);++r<i;)o[r]=t[r+e];return o},or=function(t,e){return e.length<2?t:rr(t,ir(e,0,-1))},ar=function(t,e){return e=tr(e,t),null==(t=or(t,e))||delete t[nr(er(e))]},sr=function(t,e){return null==t||ar(t,e)},cr=function(t,e,n){var r=null==t?void 0:rr(t,e);return void 0===r?n:r},lr=function(t,e,n){(void 0!==n&&!z(t[e],n)||void 0===n&&!(e in t))&&At(t,e,n)},ur=function(t){return function(e,n,r){for(var i=-1,o=Object(e),a=r(e),s=a.length;s--;){var c=a[t?s:++i];if(!1===n(o[c],c,o))break}return e}}(),dr=function(t){return b(t)&&Zt(t)},hr=function(t,e){if(("constructor"!==e||"function"!=typeof t[e])&&"__proto__"!=e)return t[e]},fr=function(t){return Ct(t,oe(t))},pr=function(t,e,n,r,i,o,a){var s=hr(t,n),c=hr(e,n),l=a.get(c);if(l)lr(t,n,l);else{var u=o?o(s,c,n+"",t,e,a):void 0,d=void 0===u;if(d){var h=Et(c),f=!h&&Object(Lt.a)(c),p=!h&&!f&&qt(c);u=c,h||f||p?Et(s)?u=s:dr(s)?u=ce(s):f?(d=!1,u=Object(se.a)(c,!0)):p?(d=!1,u=Ne(c,!0)):u=[]:_(c)||It(c)?(u=s,It(s)?u=fr(s):H(s)&&!F(s)||(u=We(c))):d=!1}d&&(a.set(c,u),i(u,c,r,o,a),a.delete(c)),lr(t,n,u)}},mr=function t(e,n,r,i,o){e!==n&&ur(n,(function(a,s){if(o||(o=new _t),H(a))pr(e,n,s,r,t,i,o);else{var c=i?i(hr(e,s),a,s+"",e,n,o):void 0;void 0===c&&(c=a),lr(e,s,c)}}),oe)},br=function(t){return t},gr=function(t,e,n){switch(n.length){case 0:return t.call(e);case 1:return t.call(e,n[0]);case 2:return t.call(e,n[0],n[1]);case 3:return t.call(e,n[0],n[1],n[2])}return t.apply(e,n)},vr=Math.max,wr=function(t,e,n){return e=vr(void 0===e?t.length-1:e,0),function(){for(var r=arguments,i=-1,o=vr(r.length-e,0),a=Array(o);++i<o;)a[i]=r[e+i];i=-1;for(var s=Array(e+1);++i<e;)s[i]=r[i];return s[e]=n(a),gr(t,this,s)}},yr=function(t){return function(){return t}},kr=zt?function(t,e){return zt(t,"toString",{configurable:!0,enumerable:!1,value:yr(e),writable:!0})}:br,_r=Date.now,Or=function(t){var e=0,n=0;return function(){var r=_r(),i=16-(r-n);if(n=r,i>0){if(++e>=800)return arguments[0]}else e=0;return t.apply(void 0,arguments)}}(kr),zr=function(t,e){return Or(wr(t,e,br),t+"")},Ar=function(t,e,n){if(!H(n))return!1;var r=typeof e;return!!("number"==r?Zt(n)&&Ht(e,n.length):"string"==r&&e in n)&&z(n[e],t)},jr=function(t){return zr((function(e,n){var r=-1,i=n.length,o=i>1?n[i-1]:void 0,a=i>2?n[2]:void 0;for(o=t.length>3&&"function"==typeof o?(i--,o):void 0,a&&Ar(n[0],n[1],a)&&(o=i<3?void 0:o,i=1),e=Object(e);++r<i;){var s=n[r];s&&t(e,s,r,o)}return e}))},Mr=jr((function(t,e,n){mr(t,e,n)})),Cr=function(t,e,n,r){if(!H(t))return t;for(var i=-1,o=(e=tr(e,t)).length,a=o-1,s=t;null!=s&&++i<o;){var c=nr(e[i]),l=n;if("__proto__"===c||"constructor"===c||"prototype"===c)return t;if(i!=a){var u=s[c];void 0===(l=r?r(u,c,s):void 0)&&(l=H(u)?u:Ht(e[i+1])?[]:{})}Mt(s,c,l),s=s[c]}return t},Vr=function(t,e,n){return null==t?t:Cr(t,e,n)};class Sr{constructor(t){this._styles={},this._styleProcessor=t}get isEmpty(){const t=Object.entries(this._styles);return!Array.from(t).length}get size(){return this.isEmpty?0:this.getStyleNames().length}setTo(t){this.clear();const e=Array.from(function(t){let e=null,n=0,r=0,i=null;const o=new Map;if(""===t)return o;";"!=t.charAt(t.length-1)&&(t+=";");for(let a=0;a<t.length;a++){const s=t.charAt(a);if(null===e)switch(s){case":":i||(i=t.substr(n,a-n),r=a+1);break;case'"':case"'":e=s;break;case";":{const e=t.substr(r,a-r);i&&o.set(i.trim(),e.trim()),i=null,n=a+1;break}}else s===e&&(e=null)}return o}(t).entries());for(const[n,r]of e)this._styleProcessor.toNormalizedForm(n,r,this._styles)}has(t){if(this.isEmpty)return!1;const e=this._styleProcessor.getReducedForm(t,this._styles).find(([e])=>e===t);return Array.isArray(e)}set(t,e){if(H(t))for(const[n,r]of Object.entries(t))this._styleProcessor.toNormalizedForm(n,r,this._styles);else this._styleProcessor.toNormalizedForm(t,e,this._styles)}remove(t){const e=Tr(t);sr(this._styles,e),delete this._styles[t],this._cleanEmptyObjectsOnPath(e)}getNormalized(t){return this._styleProcessor.getNormalized(t,this._styles)}toString(){return this.isEmpty?"":this._getStylesEntries().map(t=>t.join(":")).sort().join(";")+";"}getAsString(t){if(this.isEmpty)return;if(this._styles[t]&&!H(this._styles[t]))return this._styles[t];const e=this._styleProcessor.getReducedForm(t,this._styles).find(([e])=>e===t);return Array.isArray(e)?e[1]:void 0}getStyleNames(){return this.isEmpty?[]:this._getStylesEntries().map(([t])=>t)}clear(){this._styles={}}_getStylesEntries(){const t=[],e=Object.keys(this._styles);for(const n of e)t.push(...this._styleProcessor.getReducedForm(n,this._styles));return t}_cleanEmptyObjectsOnPath(t){const e=t.split(".");if(!(e.length>1))return;const n=e.splice(0,e.length-1).join("."),r=cr(this._styles,n);r&&!Array.from(Object.keys(r)).length&&this.remove(n)}}class xr{constructor(){this._normalizers=new Map,this._extractors=new Map,this._reducers=new Map,this._consumables=new Map}toNormalizedForm(t,e,n){if(H(e))Pr(n,Tr(t),e);else if(this._normalizers.has(t)){const r=this._normalizers.get(t),{path:i,value:o}=r(e);Pr(n,i,o)}else Pr(n,t,e)}getNormalized(t,e){if(!t)return Mr({},e);if(void 0!==e[t])return e[t];if(this._extractors.has(t)){const n=this._extractors.get(t);if("string"==typeof n)return cr(e,n);const r=n(t,e);if(r)return r}return cr(e,Tr(t))}getReducedForm(t,e){const n=this.getNormalized(t,e);return void 0===n?[]:this._reducers.has(t)?this._reducers.get(t)(n):[[t,n]]}getRelatedStyles(t){return this._consumables.get(t)||[]}setNormalizer(t,e){this._normalizers.set(t,e)}setExtractor(t,e){this._extractors.set(t,e)}setReducer(t,e){this._reducers.set(t,e)}setStyleRelation(t,e){this._mapStyleNames(t,e);for(const n of e)this._mapStyleNames(n,[t])}_mapStyleNames(t,e){this._consumables.has(t)||this._consumables.set(t,[]),this._consumables.get(t).push(...e)}}function Tr(t){return t.replace("-",".")}function Pr(t,e,n){let r=n;H(n)&&(r=Mr({},cr(t,e),n)),Vr(t,e,r)}class Ir extends In{constructor(t,e,n,r){if(super(t),this.name=e,this._attrs=function(t){t=Bn(t);for(const[e,n]of t)null===n?t.delete(e):"string"!=typeof n&&t.set(e,String(n));return t}(n),this._children=[],r&&this._insertChild(0,r),this._classes=new Set,this._attrs.has("class")){const t=this._attrs.get("class");Er(this._classes,t),this._attrs.delete("class")}this._styles=new Sr(this.document.stylesProcessor),this._attrs.has("style")&&(this._styles.setTo(this._attrs.get("style")),this._attrs.delete("style")),this._customProperties=new Map}get childCount(){return this._children.length}get isEmpty(){return 0===this._children.length}is(t,e=null){return e?e===this.name&&("element"===t||"view:element"===t):"element"===t||"view:element"===t||"node"===t||"view:node"===t}getChild(t){return this._children[t]}getChildIndex(t){return this._children.indexOf(t)}getChildren(){return this._children[Symbol.iterator]()}*getAttributeKeys(){this._classes.size>0&&(yield"class"),this._styles.isEmpty||(yield"style"),yield*this._attrs.keys()}*getAttributes(){yield*this._attrs.entries(),this._classes.size>0&&(yield["class",this.getAttribute("class")]),this._styles.isEmpty||(yield["style",this.getAttribute("style")])}getAttribute(t){if("class"==t)return this._classes.size>0?[...this._classes].join(" "):void 0;if("style"==t){const t=this._styles.toString();return""==t?void 0:t}return this._attrs.get(t)}hasAttribute(t){return"class"==t?this._classes.size>0:"style"==t?!this._styles.isEmpty:this._attrs.has(t)}isSimilar(t){if(!(t instanceof Ir))return!1;if(this===t)return!0;if(this.name!=t.name)return!1;if(this._attrs.size!==t._attrs.size||this._classes.size!==t._classes.size||this._styles.size!==t._styles.size)return!1;for(const[e,n]of this._attrs)if(!t._attrs.has(e)||t._attrs.get(e)!==n)return!1;for(const e of this._classes)if(!t._classes.has(e))return!1;for(const e of this._styles.getStyleNames())if(!t._styles.has(e)||t._styles.getAsString(e)!==this._styles.getAsString(e))return!1;return!0}hasClass(...t){for(const e of t)if(!this._classes.has(e))return!1;return!0}getClassNames(){return this._classes.keys()}getStyle(t){return this._styles.getAsString(t)}getNormalizedStyle(t){return this._styles.getNormalized(t)}getStyleNames(){return this._styles.getStyleNames()}hasStyle(...t){for(const e of t)if(!this._styles.has(e))return!1;return!0}findAncestor(...t){const e=new Hn(...t);let n=this.parent;for(;n;){if(e.match(n))return n;n=n.parent}return null}getCustomProperty(t){return this._customProperties.get(t)}*getCustomProperties(){yield*this._customProperties.entries()}getIdentity(){const t=Array.from(this._classes).sort().join(","),e=this._styles.toString(),n=Array.from(this._attrs).map(t=>`${t[0]}="${t[1]}"`).sort().join(" ");return this.name+(""==t?"":` class="${t}"`)+(e?` style="${e}"`:"")+(""==n?"":" "+n)}_clone(t=!1){const e=[];if(t)for(const r of this.getChildren())e.push(r._clone(t));const n=new this.constructor(this.document,this.name,this._attrs,e);return n._classes=new Set(this._classes),n._styles.set(this._styles.getNormalized()),n._customProperties=new Map(this._customProperties),n.getFillerOffset=this.getFillerOffset,n}_appendChild(t){return this._insertChild(this.childCount,t)}_insertChild(t,e){this._fireChange("children",this);let n=0;const r=function(t,e){return"string"==typeof e?[new En(t,e)]:(_n(e)||(e=[e]),Array.from(e).map(e=>"string"==typeof e?new En(t,e):e instanceof Ln?new En(t,e.data):e))}(this.document,e);for(const i of r)null!==i.parent&&i._remove(),i.parent=this,i.document=this.document,this._children.splice(t,0,i),t++,n++;return n}_removeChildren(t,e=1){this._fireChange("children",this);for(let n=t;n<t+e;n++)this._children[n].parent=null;return this._children.splice(t,e)}_setAttribute(t,e){e=String(e),this._fireChange("attributes",this),"class"==t?Er(this._classes,e):"style"==t?this._styles.setTo(e):this._attrs.set(t,e)}_removeAttribute(t){return this._fireChange("attributes",this),"class"==t?this._classes.size>0&&(this._classes.clear(),!0):"style"==t?!this._styles.isEmpty&&(this._styles.clear(),!0):this._attrs.delete(t)}_addClass(t){this._fireChange("attributes",this);for(const e of jn(t))this._classes.add(e)}_removeClass(t){this._fireChange("attributes",this);for(const e of jn(t))this._classes.delete(e)}_setStyle(t,e){this._fireChange("attributes",this),this._styles.set(t,e)}_removeStyle(t){this._fireChange("attributes",this);for(const e of jn(t))this._styles.remove(e)}_setCustomProperty(t,e){this._customProperties.set(t,e)}_removeCustomProperty(t){return this._customProperties.delete(t)}}function Er(t,e){const n=e.split(/\s+/);t.clear(),n.forEach(e=>t.add(e))}class Lr extends Ir{constructor(t,e,n,r){super(t,e,n,r),this.getFillerOffset=Br}is(t,e=null){return e?e===this.name&&("containerElement"===t||"view:containerElement"===t||"element"===t||"view:element"===t):"containerElement"===t||"view:containerElement"===t||"element"===t||"view:element"===t||"node"===t||"view:node"===t}}function Br(){const t=[...this.getChildren()],e=t[this.childCount-1];if(e&&e.is("element","br"))return this.childCount;for(const n of t)if(!n.is("uiElement"))return null;return this.childCount}var Hr=jr((function(t,e){Ct(e,oe(e),t)}));const Fr=Symbol("observableProperties"),Dr=Symbol("boundObservables"),Rr=Symbol("boundProperties"),Nr={set(t,e){if(H(t))return void Object.keys(t).forEach(e=>{this.set(e,t[e])},this);Ur(this);const n=this[Fr];if(t in this&&!n.has(t))throw new hn.a("observable-set-cannot-override",this);Object.defineProperty(this,t,{enumerable:!0,configurable:!0,get:()=>n.get(t),set(e){const r=n.get(t);let i=this.fire("set:"+t,t,e,r);void 0===i&&(i=e),r===i&&n.has(t)||(n.set(t,i),this.fire("change:"+t,t,i,r))}}),this[t]=e},bind(...t){if(!t.length||!Gr(t))throw new hn.a("observable-bind-wrong-properties",this);if(new Set(t).size!==t.length)throw new hn.a("observable-bind-duplicate-properties",this);Ur(this);const e=this[Rr];t.forEach(t=>{if(e.has(t))throw new hn.a("observable-bind-rebind",this)});const n=new Map;return t.forEach(t=>{const r={property:t,to:[]};e.set(t,r),n.set(t,r)}),{to:qr,toMany:Wr,_observable:this,_bindProperties:t,_to:[],_bindings:n}},unbind(...t){if(!this[Fr])return;const e=this[Rr],n=this[Dr];if(t.length){if(!Gr(t))throw new hn.a("observable-unbind-wrong-properties",this);t.forEach(t=>{const r=e.get(t);if(!r)return;let i,o,a,s;r.to.forEach(t=>{i=t[0],o=t[1],a=n.get(i),s=a[o],s.delete(r),s.size||delete a[o],Object.keys(a).length||(n.delete(i),this.stopListening(i,"change"))}),e.delete(t)})}else n.forEach((t,e)=>{this.stopListening(e,"change")}),n.clear(),e.clear()},decorate(t){const e=this[t];if(!e)throw new hn.a("observablemixin-cannot-decorate-undefined",this,{object:this,methodName:t});this.on(t,(t,n)=>{t.return=e.apply(this,n)}),this[t]=function(...e){return this.fire(t,e)}}};Hr(Nr,mn);var $r=Nr;function Ur(t){t[Fr]||(Object.defineProperty(t,Fr,{value:new Map}),Object.defineProperty(t,Dr,{value:new Map}),Object.defineProperty(t,Rr,{value:new Map}))}function qr(...t){const e=function(...t){if(!t.length)throw new hn.a("observable-bind-to-parse-error",null);const e={to:[]};let n;return"function"==typeof t[t.length-1]&&(e.callback=t.pop()),t.forEach(t=>{if("string"==typeof t)n.properties.push(t);else{if("object"!=typeof t)throw new hn.a("observable-bind-to-parse-error",null);n={observable:t,properties:[]},e.to.push(n)}}),e}(...t),n=Array.from(this._bindings.keys()),r=n.length;if(!e.callback&&e.to.length>1)throw new hn.a("observable-bind-to-no-callback",this);if(r>1&&e.callback)throw new hn.a("observable-bind-to-extra-callback",this);var i;e.to.forEach(t=>{if(t.properties.length&&t.properties.length!==r)throw new hn.a("observable-bind-to-properties-length",this);t.properties.length||(t.properties=this._bindProperties)}),this._to=e.to,e.callback&&(this._bindings.get(n[0]).callback=e.callback),i=this._observable,this._to.forEach(t=>{const e=i[Dr];let n;e.get(t.observable)||i.listenTo(t.observable,"change",(r,o)=>{n=e.get(t.observable)[o],n&&n.forEach(t=>{Yr(i,t.property)})})}),function(t){let e;t._bindings.forEach((n,r)=>{t._to.forEach(i=>{e=i.properties[n.callback?0:t._bindProperties.indexOf(r)],n.to.push([i.observable,e]),function(t,e,n,r){const i=t[Dr],o=i.get(n),a=o||{};a[r]||(a[r]=new Set),a[r].add(e),o||i.set(n,a)}(t._observable,n,i.observable,e)})})}(this),this._bindProperties.forEach(t=>{Yr(this._observable,t)})}function Wr(t,e,n){if(this._bindings.size>1)throw new hn.a("observable-bind-to-many-not-one-binding",this);this.to(...function(t,e){const n=t.map(t=>[t,e]);return Array.prototype.concat.apply([],n)}(t,e),n)}function Gr(t){return t.every(t=>"string"==typeof t)}function Yr(t,e){const n=t[Rr].get(e);let r;n.callback?r=n.callback.apply(t,n.to.map(t=>t[0][t[1]])):(r=n.to[0],r=r[0][r[1]]),Object.prototype.hasOwnProperty.call(t,e)?t[e]=r:t.set(e,r)}class Kr extends Lr{constructor(t,e,n,r){super(t,e,n,r),this.set("isReadOnly",!1),this.set("isFocused",!1),this.bind("isReadOnly").to(t),this.bind("isFocused").to(t,"isFocused",e=>e&&t.selection.editableElement==this),this.listenTo(t.selection,"change",()=>{this.isFocused=t.isFocused&&t.selection.editableElement==this})}is(t,e=null){return e?e===this.name&&("editableElement"===t||"view:editableElement"===t||"containerElement"===t||"view:containerElement"===t||"element"===t||"view:element"===t):"editableElement"===t||"view:editableElement"===t||"containerElement"===t||"view:containerElement"===t||"element"===t||"view:element"===t||"node"===t||"view:node"===t}destroy(){this.stopListening()}}On(Kr,$r);const Qr=Symbol("rootName");class Xr extends Kr{constructor(t,e){super(t,e),this.rootName="main"}is(t,e=null){return e?e===this.name&&("rootElement"===t||"view:rootElement"===t||"editableElement"===t||"view:editableElement"===t||"containerElement"===t||"view:containerElement"===t||"element"===t||"view:element"===t):"rootElement"===t||"view:rootElement"===t||"editableElement"===t||"view:editableElement"===t||"containerElement"===t||"view:containerElement"===t||"element"===t||"view:element"===t||"node"===t||"view:node"===t}get rootName(){return this.getCustomProperty(Qr)}set rootName(t){this._setCustomProperty(Qr,t)}set _name(t){this.name=t}}class Jr{constructor(t={}){if(!t.boundaries&&!t.startPosition)throw new hn.a("view-tree-walker-no-start-position",null);if(t.direction&&"forward"!=t.direction&&"backward"!=t.direction)throw new hn.a("view-tree-walker-unknown-direction",t.startPosition,{direction:t.direction});this.boundaries=t.boundaries||null,t.startPosition?this.position=Zr._createAt(t.startPosition):this.position=Zr._createAt(t.boundaries["backward"==t.direction?"end":"start"]),this.direction=t.direction||"forward",this.singleCharacters=!!t.singleCharacters,this.shallow=!!t.shallow,this.ignoreElementEnd=!!t.ignoreElementEnd,this._boundaryStartParent=this.boundaries?this.boundaries.start.parent:null,this._boundaryEndParent=this.boundaries?this.boundaries.end.parent:null}[Symbol.iterator](){return this}skip(t){let e,n,r;do{r=this.position,({done:e,value:n}=this.next())}while(!e&&t(n));e||(this.position=r)}next(){return"forward"==this.direction?this._next():this._previous()}_next(){let t=this.position.clone();const e=this.position,n=t.parent;if(null===n.parent&&t.offset===n.childCount)return{done:!0};if(n===this._boundaryEndParent&&t.offset==this.boundaries.end.offset)return{done:!0};let r;if(n instanceof En){if(t.isAtEnd)return this.position=Zr._createAfter(n),this._next();r=n.data[t.offset]}else r=n.getChild(t.offset);if(r instanceof Ir)return this.shallow?t.offset++:t=new Zr(r,0),this.position=t,this._formatReturnValue("elementStart",r,e,t,1);if(r instanceof En){if(this.singleCharacters)return t=new Zr(r,0),this.position=t,this._next();{let n,i=r.data.length;return r==this._boundaryEndParent?(i=this.boundaries.end.offset,n=new Ln(r,0,i),t=Zr._createAfter(n)):(n=new Ln(r,0,r.data.length),t.offset++),this.position=t,this._formatReturnValue("text",n,e,t,i)}}if("string"==typeof r){let r;r=this.singleCharacters?1:(n===this._boundaryEndParent?this.boundaries.end.offset:n.data.length)-t.offset;const i=new Ln(n,t.offset,r);return t.offset+=r,this.position=t,this._formatReturnValue("text",i,e,t,r)}return t=Zr._createAfter(n),this.position=t,this.ignoreElementEnd?this._next():this._formatReturnValue("elementEnd",n,e,t)}_previous(){let t=this.position.clone();const e=this.position,n=t.parent;if(null===n.parent&&0===t.offset)return{done:!0};if(n==this._boundaryStartParent&&t.offset==this.boundaries.start.offset)return{done:!0};let r;if(n instanceof En){if(t.isAtStart)return this.position=Zr._createBefore(n),this._previous();r=n.data[t.offset-1]}else r=n.getChild(t.offset-1);if(r instanceof Ir)return this.shallow?(t.offset--,this.position=t,this._formatReturnValue("elementStart",r,e,t,1)):(t=new Zr(r,r.childCount),this.position=t,this.ignoreElementEnd?this._previous():this._formatReturnValue("elementEnd",r,e,t));if(r instanceof En){if(this.singleCharacters)return t=new Zr(r,r.data.length),this.position=t,this._previous();{let n,i=r.data.length;if(r==this._boundaryStartParent){const e=this.boundaries.start.offset;n=new Ln(r,e,r.data.length-e),i=n.data.length,t=Zr._createBefore(n)}else n=new Ln(r,0,r.data.length),t.offset--;return this.position=t,this._formatReturnValue("text",n,e,t,i)}}if("string"==typeof r){let r;if(this.singleCharacters)r=1;else{const e=n===this._boundaryStartParent?this.boundaries.start.offset:0;r=t.offset-e}t.offset-=r;const i=new Ln(n,t.offset,r);return this.position=t,this._formatReturnValue("text",i,e,t,r)}return t=Zr._createBefore(n),this.position=t,this._formatReturnValue("elementStart",n,e,t,1)}_formatReturnValue(t,e,n,r,i){return e instanceof Ln&&(e.offsetInText+e.data.length==e.textNode.data.length&&("forward"!=this.direction||this.boundaries&&this.boundaries.end.isEqual(this.position)?n=Zr._createAfter(e.textNode):(r=Zr._createAfter(e.textNode),this.position=r)),0===e.offsetInText&&("backward"!=this.direction||this.boundaries&&this.boundaries.start.isEqual(this.position)?n=Zr._createBefore(e.textNode):(r=Zr._createBefore(e.textNode),this.position=r))),{done:!1,value:{type:t,item:e,previousPosition:n,nextPosition:r,length:i}}}}class Zr{constructor(t,e){this.parent=t,this.offset=e}get nodeAfter(){return this.parent.is("$text")?null:this.parent.getChild(this.offset)||null}get nodeBefore(){return this.parent.is("$text")?null:this.parent.getChild(this.offset-1)||null}get isAtStart(){return 0===this.offset}get isAtEnd(){const t=this.parent.is("$text")?this.parent.data.length:this.parent.childCount;return this.offset===t}get root(){return this.parent.root}get editableElement(){let t=this.parent;for(;!(t instanceof Kr);){if(!t.parent)return null;t=t.parent}return t}getShiftedBy(t){const e=Zr._createAt(this),n=e.offset+t;return e.offset=n<0?0:n,e}getLastMatchingPosition(t,e={}){e.startPosition=this;const n=new Jr(e);return n.skip(t),n.position}getAncestors(){return this.parent.is("documentFragment")?[this.parent]:this.parent.getAncestors({includeSelf:!0})}getCommonAncestor(t){const e=this.getAncestors(),n=t.getAncestors();let r=0;for(;e[r]==n[r]&&e[r];)r++;return 0===r?null:e[r-1]}is(t){return"position"===t||"view:position"===t}isEqual(t){return this.parent==t.parent&&this.offset==t.offset}isBefore(t){return"before"==this.compareWith(t)}isAfter(t){return"after"==this.compareWith(t)}compareWith(t){if(this.root!==t.root)return"different";if(this.isEqual(t))return"same";const e=this.parent.is("node")?this.parent.getPath():[],n=t.parent.is("node")?t.parent.getPath():[];e.push(this.offset),n.push(t.offset);const r=Tn(e,n);switch(r){case"prefix":return"before";case"extension":return"after";default:return e[r]<n[r]?"before":"after"}}getWalker(t={}){return t.startPosition=this,new Jr(t)}clone(){return new Zr(this.parent,this.offset)}static _createAt(t,e){if(t instanceof Zr)return new this(t.parent,t.offset);{const n=t;if("end"==e)e=n.is("$text")?n.data.length:n.childCount;else{if("before"==e)return this._createBefore(n);if("after"==e)return this._createAfter(n);if(0!==e&&!e)throw new hn.a("view-createpositionat-offset-required",n)}return new Zr(n,e)}}static _createAfter(t){if(t.is("$textProxy"))return new Zr(t.textNode,t.offsetInText+t.data.length);if(!t.parent)throw new hn.a("view-position-after-root",t,{root:t});return new Zr(t.parent,t.index+1)}static _createBefore(t){if(t.is("$textProxy"))return new Zr(t.textNode,t.offsetInText);if(!t.parent)throw new hn.a("view-position-before-root",t,{root:t});return new Zr(t.parent,t.index)}}class ti{constructor(t,e=null){this.start=t.clone(),this.end=e?e.clone():t.clone()}*[Symbol.iterator](){yield*new Jr({boundaries:this,ignoreElementEnd:!0})}get isCollapsed(){return this.start.isEqual(this.end)}get isFlat(){return this.start.parent===this.end.parent}get root(){return this.start.root}getEnlarged(){let t=this.start.getLastMatchingPosition(ei,{direction:"backward"}),e=this.end.getLastMatchingPosition(ei);return t.parent.is("$text")&&t.isAtStart&&(t=Zr._createBefore(t.parent)),e.parent.is("$text")&&e.isAtEnd&&(e=Zr._createAfter(e.parent)),new ti(t,e)}getTrimmed(){let t=this.start.getLastMatchingPosition(ei);if(t.isAfter(this.end)||t.isEqual(this.end))return new ti(t,t);let e=this.end.getLastMatchingPosition(ei,{direction:"backward"});const n=t.nodeAfter,r=e.nodeBefore;return n&&n.is("$text")&&(t=new Zr(n,0)),r&&r.is("$text")&&(e=new Zr(r,r.data.length)),new ti(t,e)}isEqual(t){return this==t||this.start.isEqual(t.start)&&this.end.isEqual(t.end)}containsPosition(t){return t.isAfter(this.start)&&t.isBefore(this.end)}containsRange(t,e=!1){t.isCollapsed&&(e=!1);const n=this.containsPosition(t.start)||e&&this.start.isEqual(t.start),r=this.containsPosition(t.end)||e&&this.end.isEqual(t.end);return n&&r}getDifference(t){const e=[];return this.isIntersecting(t)?(this.containsPosition(t.start)&&e.push(new ti(this.start,t.start)),this.containsPosition(t.end)&&e.push(new ti(t.end,this.end))):e.push(this.clone()),e}getIntersection(t){if(this.isIntersecting(t)){let e=this.start,n=this.end;return this.containsPosition(t.start)&&(e=t.start),this.containsPosition(t.end)&&(n=t.end),new ti(e,n)}return null}getWalker(t={}){return t.boundaries=this,new Jr(t)}getCommonAncestor(){return this.start.getCommonAncestor(this.end)}getContainedElement(){if(this.isCollapsed)return null;let t=this.start.nodeAfter,e=this.end.nodeBefore;return this.start.parent.is("$text")&&this.start.isAtEnd&&this.start.parent.nextSibling&&(t=this.start.parent.nextSibling),this.end.parent.is("$text")&&this.end.isAtStart&&this.end.parent.previousSibling&&(e=this.end.parent.previousSibling),t&&t.is("element")&&t===e?t:null}clone(){return new ti(this.start,this.end)}*getItems(t={}){t.boundaries=this,t.ignoreElementEnd=!0;const e=new Jr(t);for(const n of e)yield n.item}*getPositions(t={}){t.boundaries=this;const e=new Jr(t);yield e.position;for(const n of e)yield n.nextPosition}is(t){return"range"===t||"view:range"===t}isIntersecting(t){return this.start.isBefore(t.end)&&this.end.isAfter(t.start)}static _createFromParentsAndOffsets(t,e,n,r){return new this(new Zr(t,e),new Zr(n,r))}static _createFromPositionAndShift(t,e){const n=t,r=t.getShiftedBy(e);return e>0?new this(n,r):new this(r,n)}static _createIn(t){return this._createFromParentsAndOffsets(t,0,t,t.childCount)}static _createOn(t){const e=t.is("$textProxy")?t.offsetSize:1;return this._createFromPositionAndShift(Zr._createBefore(t),e)}}function ei(t){return!(!t.item.is("attributeElement")&&!t.item.is("uiElement"))}function ni(t){let e=0;for(const n of t)e++;return e}class ri{constructor(t=null,e,n){this._ranges=[],this._lastRangeBackward=!1,this._isFake=!1,this._fakeSelectionLabel="",this.setTo(t,e,n)}get isFake(){return this._isFake}get fakeSelectionLabel(){return this._fakeSelectionLabel}get anchor(){if(!this._ranges.length)return null;const t=this._ranges[this._ranges.length-1];return(this._lastRangeBackward?t.end:t.start).clone()}get focus(){if(!this._ranges.length)return null;const t=this._ranges[this._ranges.length-1];return(this._lastRangeBackward?t.start:t.end).clone()}get isCollapsed(){return 1===this.rangeCount&&this._ranges[0].isCollapsed}get rangeCount(){return this._ranges.length}get isBackward(){return!this.isCollapsed&&this._lastRangeBackward}get editableElement(){return this.anchor?this.anchor.editableElement:null}*getRanges(){for(const t of this._ranges)yield t.clone()}getFirstRange(){let t=null;for(const e of this._ranges)t&&!e.start.isBefore(t.start)||(t=e);return t?t.clone():null}getLastRange(){let t=null;for(const e of this._ranges)t&&!e.end.isAfter(t.end)||(t=e);return t?t.clone():null}getFirstPosition(){const t=this.getFirstRange();return t?t.start.clone():null}getLastPosition(){const t=this.getLastRange();return t?t.end.clone():null}isEqual(t){if(this.isFake!=t.isFake)return!1;if(this.isFake&&this.fakeSelectionLabel!=t.fakeSelectionLabel)return!1;if(this.rangeCount!=t.rangeCount)return!1;if(0===this.rangeCount)return!0;if(!this.anchor.isEqual(t.anchor)||!this.focus.isEqual(t.focus))return!1;for(const e of this._ranges){let n=!1;for(const r of t._ranges)if(e.isEqual(r)){n=!0;break}if(!n)return!1}return!0}isSimilar(t){if(this.isBackward!=t.isBackward)return!1;const e=ni(this.getRanges());if(e!=ni(t.getRanges()))return!1;if(0==e)return!0;for(let n of this.getRanges()){n=n.getTrimmed();let e=!1;for(let r of t.getRanges())if(r=r.getTrimmed(),n.start.isEqual(r.start)&&n.end.isEqual(r.end)){e=!0;break}if(!e)return!1}return!0}getSelectedElement(){return 1!==this.rangeCount?null:this.getFirstRange().getContainedElement()}setTo(t,e,n){if(null===t)this._setRanges([]),this._setFakeOptions(e);else if(t instanceof ri||t instanceof ii)this._setRanges(t.getRanges(),t.isBackward),this._setFakeOptions({fake:t.isFake,label:t.fakeSelectionLabel});else if(t instanceof ti)this._setRanges([t],e&&e.backward),this._setFakeOptions(e);else if(t instanceof Zr)this._setRanges([new ti(t)]),this._setFakeOptions(e);else if(t instanceof In){const r=!!n&&!!n.backward;let i;if(void 0===e)throw new hn.a("view-selection-setto-required-second-parameter",this);i="in"==e?ti._createIn(t):"on"==e?ti._createOn(t):new ti(Zr._createAt(t,e)),this._setRanges([i],r),this._setFakeOptions(n)}else{if(!_n(t))throw new hn.a("view-selection-setto-not-selectable",this);this._setRanges(t,e&&e.backward),this._setFakeOptions(e)}this.fire("change")}setFocus(t,e){if(null===this.anchor)throw new hn.a("view-selection-setfocus-no-ranges",this);const n=Zr._createAt(t,e);if("same"==n.compareWith(this.focus))return;const r=this.anchor;this._ranges.pop(),"before"==n.compareWith(r)?this._addRange(new ti(n,r),!0):this._addRange(new ti(r,n)),this.fire("change")}is(t){return"selection"===t||"view:selection"===t}_setRanges(t,e=!1){t=Array.from(t),this._ranges=[];for(const n of t)this._addRange(n);this._lastRangeBackward=!!e}_setFakeOptions(t={}){this._isFake=!!t.fake,this._fakeSelectionLabel=t.fake&&t.label||""}_addRange(t,e=!1){if(!(t instanceof ti))throw new hn.a("view-selection-add-range-not-range",this);this._pushRange(t),this._lastRangeBackward=!!e}_pushRange(t){for(const e of this._ranges)if(t.isIntersecting(e))throw new hn.a("view-selection-range-intersects",this,{addedRange:t,intersectingRange:e});this._ranges.push(new ti(t.start,t.end))}}On(ri,mn);class ii{constructor(t=null,e,n){this._selection=new ri,this._selection.delegate("change").to(this),this._selection.setTo(t,e,n)}get isFake(){return this._selection.isFake}get fakeSelectionLabel(){return this._selection.fakeSelectionLabel}get anchor(){return this._selection.anchor}get focus(){return this._selection.focus}get isCollapsed(){return this._selection.isCollapsed}get rangeCount(){return this._selection.rangeCount}get isBackward(){return this._selection.isBackward}get editableElement(){return this._selection.editableElement}get _ranges(){return this._selection._ranges}*getRanges(){yield*this._selection.getRanges()}getFirstRange(){return this._selection.getFirstRange()}getLastRange(){return this._selection.getLastRange()}getFirstPosition(){return this._selection.getFirstPosition()}getLastPosition(){return this._selection.getLastPosition()}getSelectedElement(){return this._selection.getSelectedElement()}isEqual(t){return this._selection.isEqual(t)}isSimilar(t){return this._selection.isSimilar(t)}is(t){return"selection"===t||"documentSelection"==t||"view:selection"==t||"view:documentSelection"==t}_setTo(t,e,n){this._selection.setTo(t,e,n)}_setFocus(t,e){this._selection.setFocus(t,e)}}On(ii,mn);class oi{constructor(t){this.selection=new ii,this.roots=new zn({idProperty:"rootName"}),this.stylesProcessor=t,this.set("isReadOnly",!1),this.set("isFocused",!1),this.set("isComposing",!1),this._postFixers=new Set}getRoot(t="main"){return this.roots.get(t)}registerPostFixer(t){this._postFixers.add(t)}destroy(){this.roots.map(t=>t.destroy()),this.stopListening()}_callPostFixers(t){let e=!1;do{for(const n of this._postFixers)if(e=n(t),e)break}while(e)}}On(oi,$r);class ai extends Ir{constructor(t,e,n,r){super(t,e,n,r),this.getFillerOffset=si,this._priority=10,this._id=null,this._clonesGroup=null}get priority(){return this._priority}get id(){return this._id}getElementsWithSameId(){if(null===this.id)throw new hn.a("attribute-element-get-elements-with-same-id-no-id",this);return new Set(this._clonesGroup)}is(t,e=null){return e?e===this.name&&("attributeElement"===t||"view:attributeElement"===t||"element"===t||"view:element"===t):"attributeElement"===t||"view:attributeElement"===t||"element"===t||"view:element"===t||"node"===t||"view:node"===t}isSimilar(t){return null!==this.id||null!==t.id?this.id===t.id:super.isSimilar(t)&&this.priority==t.priority}_clone(t){const e=super._clone(t);return e._priority=this._priority,e._id=this._id,e}}function si(){if(ci(this))return null;let t=this.parent;for(;t&&t.is("attributeElement");){if(ci(t)>1)return null;t=t.parent}return!t||ci(t)>1?null:this.childCount}function ci(t){return Array.from(t.getChildren()).filter(t=>!t.is("uiElement")).length}ai.DEFAULT_PRIORITY=10;class li extends Ir{constructor(t,e,n,r){super(t,e,n,r),this.getFillerOffset=ui}is(t,e=null){return e?e===this.name&&("emptyElement"===t||"view:emptyElement"===t||"element"===t||"view:element"===t):"emptyElement"===t||"view:emptyElement"===t||"element"===t||"view:element"===t||"node"===t||"view:node"===t}_insertChild(t,e){if(e&&(e instanceof In||Array.from(e).length>0))throw new hn.a("view-emptyelement-cannot-add",[this,e])}}function ui(){return null}const di=navigator.userAgent.toLowerCase();var hi={isMac:function(t){return t.indexOf("macintosh")>-1}(di),isGecko:function(t){return!!t.match(/gecko\/\d+/)}(di),isSafari:function(t){return t.indexOf(" applewebkit/")>-1&&-1===t.indexOf("chrome")}(di),isAndroid:function(t){return t.indexOf("android")>-1}(di),isBlink:function(t){return t.indexOf("chrome/")>-1&&t.indexOf("edge/")<0}(di),features:{isRegExpUnicodePropertySupported:function(){let t=!1;try{t=0==="ć".search(new RegExp("[\\p{L}]","u"))}catch(t){}return t}()}};const fi={"⌘":"ctrl","⇧":"shift","⌥":"alt"},pi={ctrl:"⌘",shift:"⇧",alt:"⌥"},mi=function(){const t={arrowleft:37,arrowup:38,arrowright:39,arrowdown:40,backspace:8,delete:46,enter:13,space:32,esc:27,tab:9,ctrl:1114112,cmd:1114112,shift:2228224,alt:4456448};for(let e=65;e<=90;e++){const n=String.fromCharCode(e);t[n.toLowerCase()]=e}for(let e=48;e<=57;e++)t[e-48]=e;for(let e=112;e<=123;e++)t["f"+(e-111)]=e;return t}();function bi(t){let e;if("string"==typeof t){if(e=mi[t.toLowerCase()],!e)throw new hn.a("keyboard-unknown-key",null,{key:t})}else e=t.keyCode+(t.altKey?mi.alt:0)+(t.ctrlKey?mi.ctrl:0)+(t.shiftKey?mi.shift:0);return e}function gi(t){return"string"==typeof t&&(t=_i(t)),t.map(t=>"string"==typeof t?bi(t):t).reduce((t,e)=>e+t,0)}function vi(t){return hi.isMac?_i(t).map(t=>pi[t.toLowerCase()]||t).reduce((t,e)=>t.slice(-1)in fi?t+e:t+"+"+e):t}function wi(t){return t==mi.arrowright||t==mi.arrowleft||t==mi.arrowup||t==mi.arrowdown}function yi(t,e){const n="ltr"===e;switch(t){case mi.arrowleft:return n?"left":"right";case mi.arrowright:return n?"right":"left";case mi.arrowup:return"up";case mi.arrowdown:return"down"}}function ki(t,e){const n=yi(t,e);return"down"===n||"right"===n}function _i(t){return t.split(/\s*\+\s*/)}class Oi extends Ir{constructor(t,e,n,r){super(t,e,n,r),this.getFillerOffset=Ai}is(t,e=null){return e?e===this.name&&("uiElement"===t||"view:uiElement"===t||"element"===t||"view:element"===t):"uiElement"===t||"view:uiElement"===t||"element"===t||"view:element"===t||"node"===t||"view:node"===t}_insertChild(t,e){if(e&&(e instanceof In||Array.from(e).length>0))throw new hn.a("view-uielement-cannot-add",this)}render(t){return this.toDomElement(t)}toDomElement(t){const e=t.createElement(this.name);for(const n of this.getAttributeKeys())e.setAttribute(n,this.getAttribute(n));return e}}function zi(t){t.document.on("keydown",(e,n)=>function(t,e,n){if(e.keyCode==mi.arrowright){const t=e.domTarget.ownerDocument.defaultView.getSelection(),r=1==t.rangeCount&&t.getRangeAt(0).collapsed;if(r||e.shiftKey){const e=t.focusNode,i=t.focusOffset,o=n.domPositionToView(e,i);if(null===o)return;let a=!1;const s=o.getLastMatchingPosition(t=>(t.item.is("uiElement")&&(a=!0),!(!t.item.is("uiElement")&&!t.item.is("attributeElement"))));if(a){const e=n.viewPositionToDom(s);r?t.collapse(e.parent,e.offset):t.extend(e.parent,e.offset)}}}}(0,n,t.domConverter))}function Ai(){return null}class ji extends Ir{constructor(t,e,n,r){super(t,e,n,r),this.getFillerOffset=Mi}is(t,e=null){return e?e===this.name&&("rawElement"===t||"view:rawElement"===t||"element"===t||"view:element"===t):"rawElement"===t||"view:rawElement"===t||t===this.name||t==="view:"+this.name||"element"===t||"view:element"===t||"node"===t||"view:node"===t}_insertChild(t,e){if(e&&(e instanceof In||Array.from(e).length>0))throw new hn.a("view-rawelement-cannot-add",[this,e])}}function Mi(){return null}class Ci{constructor(t,e){this.document=t,this._children=[],e&&this._insertChild(0,e)}[Symbol.iterator](){return this._children[Symbol.iterator]()}get childCount(){return this._children.length}get isEmpty(){return 0===this.childCount}get root(){return this}get parent(){return null}is(t){return"documentFragment"===t||"view:documentFragment"===t}_appendChild(t){return this._insertChild(this.childCount,t)}getChild(t){return this._children[t]}getChildIndex(t){return this._children.indexOf(t)}getChildren(){return this._children[Symbol.iterator]()}_insertChild(t,e){this._fireChange("children",this);let n=0;const r=function(t,e){return"string"==typeof e?[new En(t,e)]:(_n(e)||(e=[e]),Array.from(e).map(e=>"string"==typeof e?new En(t,e):e instanceof Ln?new En(t,e.data):e))}(this.document,e);for(const i of r)null!==i.parent&&i._remove(),i.parent=this,this._children.splice(t,0,i),t++,n++;return n}_removeChildren(t,e=1){this._fireChange("children",this);for(let n=t;n<t+e;n++)this._children[n].parent=null;return this._children.splice(t,e)}_fireChange(t,e){this.fire("change:"+t,e)}}On(Ci,mn);class Vi{constructor(t){this.document=t,this._cloneGroups=new Map}setSelection(t,e,n){this.document.selection._setTo(t,e,n)}setSelectionFocus(t,e){this.document.selection._setFocus(t,e)}createText(t){return new En(this.document,t)}createAttributeElement(t,e,n={}){const r=new ai(this.document,t,e);return n.priority&&(r._priority=n.priority),n.id&&(r._id=n.id),r}createContainerElement(t,e){return new Lr(this.document,t,e)}createEditableElement(t,e){const n=new Kr(this.document,t,e);return n._document=this.document,n}createEmptyElement(t,e){return new li(this.document,t,e)}createUIElement(t,e,n){const r=new Oi(this.document,t,e);return n&&(r.render=n),r}createRawElement(t,e,n){const r=new ji(this.document,t,e);return r.render=n||(()=>{}),r}setAttribute(t,e,n){n._setAttribute(t,e)}removeAttribute(t,e){e._removeAttribute(t)}addClass(t,e){e._addClass(t)}removeClass(t,e){e._removeClass(t)}setStyle(t,e,n){_(t)&&void 0===n&&(n=e),n._setStyle(t,e)}removeStyle(t,e){e._removeStyle(t)}setCustomProperty(t,e,n){n._setCustomProperty(t,e)}removeCustomProperty(t,e){return e._removeCustomProperty(t)}breakAttributes(t){return t instanceof Zr?this._breakAttributes(t):this._breakAttributesRange(t)}breakContainer(t){const e=t.parent;if(!e.is("containerElement"))throw new hn.a("view-writer-break-non-container-element",this.document);if(!e.parent)throw new hn.a("view-writer-break-root",this.document);if(t.isAtStart)return Zr._createBefore(e);if(!t.isAtEnd){const n=e._clone(!1);this.insert(Zr._createAfter(e),n);const r=new ti(t,Zr._createAt(e,"end")),i=new Zr(n,0);this.move(r,i)}return Zr._createAfter(e)}mergeAttributes(t){const e=t.offset,n=t.parent;if(n.is("$text"))return t;if(n.is("attributeElement")&&0===n.childCount){const t=n.parent,e=n.index;return n._remove(),this._removeFromClonedElementsGroup(n),this.mergeAttributes(new Zr(t,e))}const r=n.getChild(e-1),i=n.getChild(e);if(!r||!i)return t;if(r.is("$text")&&i.is("$text"))return Ii(r,i);if(r.is("attributeElement")&&i.is("attributeElement")&&r.isSimilar(i)){const t=r.childCount;return r._appendChild(i.getChildren()),i._remove(),this._removeFromClonedElementsGroup(i),this.mergeAttributes(new Zr(r,t))}return t}mergeContainers(t){const e=t.nodeBefore,n=t.nodeAfter;if(!(e&&n&&e.is("containerElement")&&n.is("containerElement")))throw new hn.a("view-writer-merge-containers-invalid-position",this.document);const r=e.getChild(e.childCount-1),i=r instanceof En?Zr._createAt(r,"end"):Zr._createAt(e,"end");return this.move(ti._createIn(n),Zr._createAt(e,"end")),this.remove(ti._createOn(n)),i}insert(t,e){(function t(e,n){for(const r of e){if(!Ei.some(t=>r instanceof t))throw new hn.a("view-writer-insert-invalid-node-type",n);r.is("$text")||t(r.getChildren(),n)}})(e=_n(e)?[...e]:[e],this.document);const n=Si(t);if(!n)throw new hn.a("view-writer-invalid-position-container",this.document);const r=this._breakAttributes(t,!0),i=n._insertChild(r.offset,e);for(const s of e)this._addToClonedElementsGroup(s);const o=r.getShiftedBy(i),a=this.mergeAttributes(r);if(0===i)return new ti(a,a);{a.isEqual(r)||o.offset--;const t=this.mergeAttributes(o);return new ti(a,t)}}remove(t){const e=t instanceof ti?t:ti._createOn(t);if(Bi(e,this.document),e.isCollapsed)return new Ci(this.document);const{start:n,end:r}=this._breakAttributesRange(e,!0),i=n.parent,o=r.offset-n.offset,a=i._removeChildren(n.offset,o);for(const c of a)this._removeFromClonedElementsGroup(c);const s=this.mergeAttributes(n);return e.start=s,e.end=s.clone(),new Ci(this.document,a)}clear(t,e){Bi(t,this.document);const n=t.getWalker({direction:"backward",ignoreElementEnd:!0});for(const r of n){const n=r.item;let i;if(n.is("element")&&e.isSimilar(n))i=ti._createOn(n);else if(!r.nextPosition.isAfter(t.start)&&n.is("$textProxy")){const t=n.getAncestors().find(t=>t.is("element")&&e.isSimilar(t));t&&(i=ti._createIn(t))}i&&(i.end.isAfter(t.end)&&(i.end=t.end),i.start.isBefore(t.start)&&(i.start=t.start),this.remove(i))}}move(t,e){let n;if(e.isAfter(t.end)){const r=(e=this._breakAttributes(e,!0)).parent,i=r.childCount;t=this._breakAttributesRange(t,!0),n=this.remove(t),e.offset+=r.childCount-i}else n=this.remove(t);return this.insert(e,n)}wrap(t,e){if(!(e instanceof ai))throw new hn.a("view-writer-wrap-invalid-attribute",this.document);if(Bi(t,this.document),t.isCollapsed){let r=t.start;r.parent.is("element")&&(n=r.parent,!Array.from(n.getChildren()).some(t=>!t.is("uiElement")))&&(r=r.getLastMatchingPosition(t=>t.item.is("uiElement"))),r=this._wrapPosition(r,e);const i=this.document.selection;return i.isCollapsed&&i.getFirstPosition().isEqual(t.start)&&this.setSelection(r),new ti(r)}return this._wrapRange(t,e);var n}unwrap(t,e){if(!(e instanceof ai))throw new hn.a("view-writer-unwrap-invalid-attribute",this.document);if(Bi(t,this.document),t.isCollapsed)return t;const{start:n,end:r}=this._breakAttributesRange(t,!0),i=n.parent,o=this._unwrapChildren(i,n.offset,r.offset,e),a=this.mergeAttributes(o.start);a.isEqual(o.start)||o.end.offset--;const s=this.mergeAttributes(o.end);return new ti(a,s)}rename(t,e){const n=new Lr(this.document,t,e.getAttributes());return this.insert(Zr._createAfter(e),n),this.move(ti._createIn(e),Zr._createAt(n,0)),this.remove(ti._createOn(e)),n}clearClonedElementsGroup(t){this._cloneGroups.delete(t)}createPositionAt(t,e){return Zr._createAt(t,e)}createPositionAfter(t){return Zr._createAfter(t)}createPositionBefore(t){return Zr._createBefore(t)}createRange(t,e){return new ti(t,e)}createRangeOn(t){return ti._createOn(t)}createRangeIn(t){return ti._createIn(t)}createSelection(t,e,n){return new ri(t,e,n)}_wrapChildren(t,e,n,r){let i=e;const o=[];for(;i<n;){const e=t.getChild(i),n=e.is("$text"),a=e.is("attributeElement"),s=e.is("emptyElement"),c=e.is("uiElement"),l=e.is("rawElement");if(a&&this._wrapAttributeElement(r,e))o.push(new Zr(t,i));else if(n||s||c||l||a&&xi(r,e)){const n=r._clone();e._remove(),n._appendChild(e),t._insertChild(i,n),this._addToClonedElementsGroup(n),o.push(new Zr(t,i))}else a&&this._wrapChildren(e,0,e.childCount,r);i++}let a=0;for(const s of o)s.offset-=a,s.offset!=e&&(this.mergeAttributes(s).isEqual(s)||(a++,n--));return ti._createFromParentsAndOffsets(t,e,t,n)}_unwrapChildren(t,e,n,r){let i=e;const o=[];for(;i<n;){const e=t.getChild(i);if(e.is("attributeElement"))if(e.isSimilar(r)){const r=e.getChildren(),a=e.childCount;e._remove(),t._insertChild(i,r),this._removeFromClonedElementsGroup(e),o.push(new Zr(t,i),new Zr(t,i+a)),i+=a,n+=a-1}else this._unwrapAttributeElement(r,e)?(o.push(new Zr(t,i),new Zr(t,i+1)),i++):(this._unwrapChildren(e,0,e.childCount,r),i++);else i++}let a=0;for(const s of o)s.offset-=a,s.offset!=e&&s.offset!=n&&(this.mergeAttributes(s).isEqual(s)||(a++,n--));return ti._createFromParentsAndOffsets(t,e,t,n)}_wrapRange(t,e){const{start:n,end:r}=this._breakAttributesRange(t,!0),i=n.parent,o=this._wrapChildren(i,n.offset,r.offset,e),a=this.mergeAttributes(o.start);a.isEqual(o.start)||o.end.offset--;const s=this.mergeAttributes(o.end);return new ti(a,s)}_wrapPosition(t,e){if(e.isSimilar(t.parent))return Ti(t.clone());t.parent.is("$text")&&(t=Pi(t));const n=this.createAttributeElement();n._priority=Number.POSITIVE_INFINITY,n.isSimilar=()=>!1,t.parent._insertChild(t.offset,n);const r=new ti(t,t.getShiftedBy(1));this.wrap(r,e);const i=new Zr(n.parent,n.index);n._remove();const o=i.nodeBefore,a=i.nodeAfter;return o instanceof En&&a instanceof En?Ii(o,a):Ti(i)}_wrapAttributeElement(t,e){if(!Hi(t,e))return!1;if(t.name!==e.name||t.priority!==e.priority)return!1;for(const n of t.getAttributeKeys())if("class"!==n&&"style"!==n&&e.hasAttribute(n)&&e.getAttribute(n)!==t.getAttribute(n))return!1;for(const n of t.getStyleNames())if(e.hasStyle(n)&&e.getStyle(n)!==t.getStyle(n))return!1;for(const n of t.getAttributeKeys())"class"!==n&&"style"!==n&&(e.hasAttribute(n)||this.setAttribute(n,t.getAttribute(n),e));for(const n of t.getStyleNames())e.hasStyle(n)||this.setStyle(n,t.getStyle(n),e);for(const n of t.getClassNames())e.hasClass(n)||this.addClass(n,e);return!0}_unwrapAttributeElement(t,e){if(!Hi(t,e))return!1;if(t.name!==e.name||t.priority!==e.priority)return!1;for(const n of t.getAttributeKeys())if("class"!==n&&"style"!==n&&(!e.hasAttribute(n)||e.getAttribute(n)!==t.getAttribute(n)))return!1;if(!e.hasClass(...t.getClassNames()))return!1;for(const n of t.getStyleNames())if(!e.hasStyle(n)||e.getStyle(n)!==t.getStyle(n))return!1;for(const n of t.getAttributeKeys())"class"!==n&&"style"!==n&&this.removeAttribute(n,e);return this.removeClass(Array.from(t.getClassNames()),e),this.removeStyle(Array.from(t.getStyleNames()),e),!0}_breakAttributesRange(t,e=!1){const n=t.start,r=t.end;if(Bi(t,this.document),t.isCollapsed){const n=this._breakAttributes(t.start,e);return new ti(n,n)}const i=this._breakAttributes(r,e),o=i.parent.childCount,a=this._breakAttributes(n,e);return i.offset+=i.parent.childCount-o,new ti(a,i)}_breakAttributes(t,e=!1){const n=t.offset,r=t.parent;if(t.parent.is("emptyElement"))throw new hn.a("view-writer-cannot-break-empty-element",this.document);if(t.parent.is("uiElement"))throw new hn.a("view-writer-cannot-break-ui-element",this.document);if(t.parent.is("rawElement"))throw new hn.a("view-writer-cannot-break-raw-element",this.document);if(!e&&r.is("$text")&&Li(r.parent))return t.clone();if(Li(r))return t.clone();if(r.is("$text"))return this._breakAttributes(Pi(t),e);if(n==r.childCount){const t=new Zr(r.parent,r.index+1);return this._breakAttributes(t,e)}if(0===n){const t=new Zr(r.parent,r.index);return this._breakAttributes(t,e)}{const t=r.index+1,i=r._clone();r.parent._insertChild(t,i),this._addToClonedElementsGroup(i);const o=r.childCount-n,a=r._removeChildren(n,o);i._appendChild(a);const s=new Zr(r.parent,t);return this._breakAttributes(s,e)}}_addToClonedElementsGroup(t){if(!t.root.is("rootElement"))return;if(t.is("element"))for(const r of t.getChildren())this._addToClonedElementsGroup(r);const e=t.id;if(!e)return;let n=this._cloneGroups.get(e);n||(n=new Set,this._cloneGroups.set(e,n)),n.add(t),t._clonesGroup=n}_removeFromClonedElementsGroup(t){if(t.is("element"))for(const r of t.getChildren())this._removeFromClonedElementsGroup(r);const e=t.id;if(!e)return;const n=this._cloneGroups.get(e);n&&n.delete(t)}}function Si(t){let e=t.parent;for(;!Li(e);){if(!e)return;e=e.parent}return e}function xi(t,e){return t.priority<e.priority||!(t.priority>e.priority)&&t.getIdentity()<e.getIdentity()}function Ti(t){const e=t.nodeBefore;if(e&&e.is("$text"))return new Zr(e,e.data.length);const n=t.nodeAfter;return n&&n.is("$text")?new Zr(n,0):t}function Pi(t){if(t.offset==t.parent.data.length)return new Zr(t.parent.parent,t.parent.index+1);if(0===t.offset)return new Zr(t.parent.parent,t.parent.index);const e=t.parent.data.slice(t.offset);return t.parent._data=t.parent.data.slice(0,t.offset),t.parent.parent._insertChild(t.parent.index+1,new En(t.root.document,e)),new Zr(t.parent.parent,t.parent.index+1)}function Ii(t,e){const n=t.data.length;return t._data+=e.data,e._remove(),new Zr(t,n)}const Ei=[En,ai,Lr,li,ji,Oi];function Li(t){return t&&(t.is("containerElement")||t.is("documentFragment"))}function Bi(t,e){const n=Si(t.start),r=Si(t.end);if(!n||!r||n!==r)throw new hn.a("view-writer-invalid-range-container",e)}function Hi(t,e){return null===t.id&&null===e.id}function Fi(t){return"[object Text]"==Object.prototype.toString.call(t)}const Di=t=>t.createTextNode(" "),Ri=t=>{const e=t.createElement("br");return e.dataset.ckeFiller=!0,e},Ni=(()=>{let t="";for(let e=0;e<7;e++)t+="​";return t})();function $i(t){return Fi(t)&&t.data.substr(0,7)===Ni}function Ui(t){return 7==t.data.length&&$i(t)}function qi(t){return $i(t)?t.data.slice(7):t.data}function Wi(t,e){if(e.keyCode==mi.arrowleft){const t=e.domTarget.ownerDocument.defaultView.getSelection();if(1==t.rangeCount&&t.getRangeAt(0).collapsed){const e=t.getRangeAt(0).startContainer,n=t.getRangeAt(0).startOffset;$i(e)&&n<=7&&t.collapse(e,0)}}}function Gi(t,e,n,r=!1){n=n||function(t,e){return t===e},Array.isArray(t)||(t=Array.prototype.slice.call(t)),Array.isArray(e)||(e=Array.prototype.slice.call(e));const i=function(t,e,n){const r=Yi(t,e,n);if(-1===r)return{firstIndex:-1,lastIndexOld:-1,lastIndexNew:-1};const i=Ki(t,r),o=Ki(e,r),a=Yi(i,o,n),s=t.length-a,c=e.length-a;return{firstIndex:r,lastIndexOld:s,lastIndexNew:c}}(t,e,n);return r?function(t,e){const{firstIndex:n,lastIndexOld:r,lastIndexNew:i}=t;if(-1===n)return Array(e).fill("equal");let o=[];return n>0&&(o=o.concat(Array(n).fill("equal"))),i-n>0&&(o=o.concat(Array(i-n).fill("insert"))),r-n>0&&(o=o.concat(Array(r-n).fill("delete"))),i<e&&(o=o.concat(Array(e-i).fill("equal"))),o}(i,e.length):function(t,e){const n=[],{firstIndex:r,lastIndexOld:i,lastIndexNew:o}=e;return o-r>0&&n.push({index:r,type:"insert",values:t.slice(r,o)}),i-r>0&&n.push({index:r+(o-r),type:"delete",howMany:i-r}),n}(e,i)}function Yi(t,e,n){for(let r=0;r<Math.max(t.length,e.length);r++)if(void 0===t[r]||void 0===e[r]||!n(t[r],e[r]))return r;return-1}function Ki(t,e){return t.slice(e).reverse()}function Qi(t,e,n){n=n||function(t,e){return t===e};const r=t.length,i=e.length;if(r>200||i>200||r+i>300)return Qi.fastDiff(t,e,n,!0);let o,a;if(i<r){const n=t;t=e,e=n,o="delete",a="insert"}else o="insert",a="delete";const s=t.length,c=e.length,l=c-s,u={},d={};function h(r){const i=(void 0!==d[r-1]?d[r-1]:-1)+1,l=void 0!==d[r+1]?d[r+1]:-1,h=i>l?-1:1;u[r+h]&&(u[r]=u[r+h].slice(0)),u[r]||(u[r]=[]),u[r].push(i>l?o:a);let f=Math.max(i,l),p=f-r;for(;p<s&&f<c&&n(t[p],e[f]);)p++,f++,u[r].push("equal");return f}let f,p=0;do{for(f=-p;f<l;f++)d[f]=h(f);for(f=l+p;f>l;f--)d[f]=h(f);d[l]=h(l),p++}while(d[l]!==c);return u[l].slice(1)}function Xi(t,e,n){t.insertBefore(n,t.childNodes[e]||null)}function Ji(t){const e=t.parentNode;e&&e.removeChild(t)}function Zi(t){if(t){if(t.defaultView)return t instanceof t.defaultView.Document;if(t.ownerDocument&&t.ownerDocument.defaultView)return t instanceof t.ownerDocument.defaultView.Node}return!1}Qi.fastDiff=Gi;class to{constructor(t,e){this.domDocuments=new Set,this.domConverter=t,this.markedAttributes=new Set,this.markedChildren=new Set,this.markedTexts=new Set,this.selection=e,this.isFocused=!1,this._inlineFiller=null,this._fakeSelectionContainer=null}markToSync(t,e){if("text"===t)this.domConverter.mapViewToDom(e.parent)&&this.markedTexts.add(e);else{if(!this.domConverter.mapViewToDom(e))return;if("attributes"===t)this.markedAttributes.add(e);else{if("children"!==t)throw new hn.a("view-renderer-unknown-type",this);this.markedChildren.add(e)}}}render(){let t;for(const e of this.markedChildren)this._updateChildrenMappings(e);this._inlineFiller&&!this._isSelectionInInlineFiller()&&this._removeInlineFiller(),this._inlineFiller?t=this._getInlineFillerPosition():this._needsInlineFillerAtSelection()&&(t=this.selection.getFirstPosition(),this.markedChildren.add(t.parent));for(const e of this.markedAttributes)this._updateAttrs(e);for(const e of this.markedChildren)this._updateChildren(e,{inlineFillerPosition:t});for(const e of this.markedTexts)!this.markedChildren.has(e.parent)&&this.domConverter.mapViewToDom(e.parent)&&this._updateText(e,{inlineFillerPosition:t});if(t){const e=this.domConverter.viewPositionToDom(t),n=e.parent.ownerDocument;$i(e.parent)?this._inlineFiller=e.parent:this._inlineFiller=eo(n,e.parent,e.offset)}else this._inlineFiller=null;this._updateSelection(),this._updateFocus(),this.markedTexts.clear(),this.markedAttributes.clear(),this.markedChildren.clear()}_updateChildrenMappings(t){const e=this.domConverter.mapViewToDom(t);if(!e)return;const n=this.domConverter.mapViewToDom(t).childNodes,r=Array.from(this.domConverter.viewChildrenToDom(t,e.ownerDocument,{withChildren:!1})),i=this._diffNodeLists(n,r),o=this._findReplaceActions(i,n,r);if(-1!==o.indexOf("replace")){const e={equal:0,insert:0,delete:0};for(const i of o)if("replace"===i){const i=e.equal+e.insert,o=e.equal+e.delete,a=t.getChild(i);!a||a.is("uiElement")||a.is("rawElement")||this._updateElementMappings(a,n[o]),Ji(r[i]),e.equal++}else e[i]++}}_updateElementMappings(t,e){this.domConverter.unbindDomElement(e),this.domConverter.bindElements(e,t),this.markedChildren.add(t),this.markedAttributes.add(t)}_getInlineFillerPosition(){const t=this.selection.getFirstPosition();return t.parent.is("$text")?Zr._createBefore(this.selection.getFirstPosition().parent):t}_isSelectionInInlineFiller(){if(1!=this.selection.rangeCount||!this.selection.isCollapsed)return!1;const t=this.selection.getFirstPosition(),e=this.domConverter.viewPositionToDom(t);return!!(e&&Fi(e.parent)&&$i(e.parent))}_removeInlineFiller(){const t=this._inlineFiller;if(!$i(t))throw new hn.a("view-renderer-filler-was-lost",this);Ui(t)?t.parentNode.removeChild(t):t.data=t.data.substr(7),this._inlineFiller=null}_needsInlineFillerAtSelection(){if(1!=this.selection.rangeCount||!this.selection.isCollapsed)return!1;const t=this.selection.getFirstPosition(),e=t.parent,n=t.offset;if(!this.domConverter.mapViewToDom(e.root))return!1;if(!e.is("element"))return!1;if(!function(t){if("false"==t.getAttribute("contenteditable"))return!1;const e=t.findAncestor(t=>t.hasAttribute("contenteditable"));return!e||"true"==e.getAttribute("contenteditable")}(e))return!1;if(n===e.getFillerOffset())return!1;const r=t.nodeBefore,i=t.nodeAfter;return!(r instanceof En||i instanceof En)}_updateText(t,e){const n=this.domConverter.findCorrespondingDomText(t),r=this.domConverter.viewToDom(t,n.ownerDocument),i=n.data;let o=r.data;const a=e.inlineFillerPosition;if(a&&a.parent==t.parent&&a.offset==t.index&&(o=Ni+o),i!=o){const t=Gi(i,o);for(const e of t)"insert"===e.type?n.insertData(e.index,e.values.join("")):n.deleteData(e.index,e.howMany)}}_updateAttrs(t){const e=this.domConverter.mapViewToDom(t);if(!e)return;const n=Array.from(e.attributes).map(t=>t.name),r=t.getAttributeKeys();for(const i of r)e.setAttribute(i,t.getAttribute(i));for(const i of n)t.hasAttribute(i)||e.removeAttribute(i)}_updateChildren(t,e){const n=this.domConverter.mapViewToDom(t);if(!n)return;const r=e.inlineFillerPosition,i=this.domConverter.mapViewToDom(t).childNodes,o=Array.from(this.domConverter.viewChildrenToDom(t,n.ownerDocument,{bind:!0,inlineFillerPosition:r}));r&&r.parent===t&&eo(n.ownerDocument,o,r.offset);const a=this._diffNodeLists(i,o);let s=0;const c=new Set;for(const l of a)"delete"===l?(c.add(i[s]),Ji(i[s])):"equal"===l&&s++;s=0;for(const l of a)"insert"===l?(Xi(n,s,o[s]),s++):"equal"===l&&(this._markDescendantTextToSync(this.domConverter.domToView(o[s])),s++);for(const l of c)l.parentNode||this.domConverter.unbindDomElement(l)}_diffNodeLists(t,e){return Qi(t=function(t,e){const n=Array.from(t);return 0!=n.length&&e?(n[n.length-1]==e&&n.pop(),n):n}(t,this._fakeSelectionContainer),e,ro.bind(null,this.domConverter))}_findReplaceActions(t,e,n){if(-1===t.indexOf("insert")||-1===t.indexOf("delete"))return t;let r=[],i=[],o=[];const a={equal:0,insert:0,delete:0};for(const s of t)"insert"===s?o.push(n[a.equal+a.insert]):"delete"===s?i.push(e[a.equal+a.delete]):(r=r.concat(Qi(i,o,no).map(t=>"equal"===t?"replace":t)),r.push("equal"),i=[],o=[]),a[s]++;return r.concat(Qi(i,o,no).map(t=>"equal"===t?"replace":t))}_markDescendantTextToSync(t){if(t)if(t.is("$text"))this.markedTexts.add(t);else if(t.is("element"))for(const e of t.getChildren())this._markDescendantTextToSync(e)}_updateSelection(){if(0===this.selection.rangeCount)return this._removeDomSelection(),void this._removeFakeSelection();const t=this.domConverter.mapViewToDom(this.selection.editableElement);this.isFocused&&t&&(this.selection.isFake?this._updateFakeSelection(t):(this._removeFakeSelection(),this._updateDomSelection(t)))}_updateFakeSelection(t){const e=t.ownerDocument;this._fakeSelectionContainer||(this._fakeSelectionContainer=function(t){const e=t.createElement("div");return e.className="ck-fake-selection-container",Object.assign(e.style,{position:"fixed",top:0,left:"-9999px",width:"42px"}),e.textContent=" ",e}(e));const n=this._fakeSelectionContainer;if(this.domConverter.bindFakeSelection(n,this.selection),!this._fakeSelectionNeedsUpdate(t))return;n.parentElement&&n.parentElement==t||t.appendChild(n),n.textContent=this.selection.fakeSelectionLabel||" ";const r=e.getSelection(),i=e.createRange();r.removeAllRanges(),i.selectNodeContents(n),r.addRange(i)}_updateDomSelection(t){const e=t.ownerDocument.defaultView.getSelection();if(!this._domSelectionNeedsUpdate(e))return;const n=this.domConverter.viewPositionToDom(this.selection.anchor),r=this.domConverter.viewPositionToDom(this.selection.focus);t.focus(),e.collapse(n.parent,n.offset),e.extend(r.parent,r.offset),hi.isGecko&&function(t,e){const n=t.parent;if(n.nodeType!=Node.ELEMENT_NODE||t.offset!=n.childNodes.length-1)return;const r=n.childNodes[t.offset];r&&"BR"==r.tagName&&e.addRange(e.getRangeAt(0))}(r,e)}_domSelectionNeedsUpdate(t){if(!this.domConverter.isDomSelectionCorrect(t))return!0;const e=t&&this.domConverter.domSelectionToView(t);return(!e||!this.selection.isEqual(e))&&!(!this.selection.isCollapsed&&this.selection.isSimilar(e))}_fakeSelectionNeedsUpdate(t){const e=this._fakeSelectionContainer,n=t.ownerDocument.getSelection();return!e||e.parentElement!==t||n.anchorNode!==e&&!e.contains(n.anchorNode)||e.textContent!==this.selection.fakeSelectionLabel}_removeDomSelection(){for(const t of this.domDocuments)if(t.getSelection().rangeCount){const e=t.activeElement,n=this.domConverter.mapDomToView(e);e&&n&&t.getSelection().removeAllRanges()}}_removeFakeSelection(){const t=this._fakeSelectionContainer;t&&t.remove()}_updateFocus(){if(this.isFocused){const t=this.selection.editableElement;t&&this.domConverter.focus(t)}}}function eo(t,e,n){const r=e instanceof Array?e:e.childNodes,i=r[n];if(Fi(i))return i.data=Ni+i.data,i;{const i=t.createTextNode(Ni);return Array.isArray(e)?r.splice(n,0,i):Xi(e,n,i),i}}function no(t,e){return Zi(t)&&Zi(e)&&!Fi(t)&&!Fi(e)&&t.nodeType!==Node.COMMENT_NODE&&e.nodeType!==Node.COMMENT_NODE&&t.tagName.toLowerCase()===e.tagName.toLowerCase()}function ro(t,e,n){return e===n||(Fi(e)&&Fi(n)?e.data===n.data:!(!t.isBlockFiller(e)||!t.isBlockFiller(n)))}On(to,$r);var io={window:window,document:document};function oo(t){let e=0;for(;t.previousSibling;)t=t.previousSibling,e++;return e}function ao(t){const e=[];for(;t&&t.nodeType!=Node.DOCUMENT_NODE;)e.unshift(t),t=t.parentNode;return e}const so=Ri(document);class co{constructor(t,e={}){this.document=t,this.blockFillerMode=e.blockFillerMode||"br",this.preElements=["pre"],this.blockElements=["p","div","h1","h2","h3","h4","h5","h6","li","dd","dt","figcaption","td","th"],this._blockFiller="br"==this.blockFillerMode?Ri:Di,this._domToViewMapping=new WeakMap,this._viewToDomMapping=new WeakMap,this._fakeSelectionMapping=new WeakMap,this._rawContentElementMatcher=new Hn,this._encounteredRawContentDomNodes=new WeakSet}bindFakeSelection(t,e){this._fakeSelectionMapping.set(t,new ri(e))}fakeSelectionToView(t){return this._fakeSelectionMapping.get(t)}bindElements(t,e){this._domToViewMapping.set(t,e),this._viewToDomMapping.set(e,t)}unbindDomElement(t){const e=this._domToViewMapping.get(t);if(e){this._domToViewMapping.delete(t),this._viewToDomMapping.delete(e);for(const e of t.childNodes)this.unbindDomElement(e)}}bindDocumentFragments(t,e){this._domToViewMapping.set(t,e),this._viewToDomMapping.set(e,t)}viewToDom(t,e,n={}){if(t.is("$text")){const n=this._processDataFromViewText(t);return e.createTextNode(n)}{if(this.mapViewToDom(t))return this.mapViewToDom(t);let r;if(t.is("documentFragment"))r=e.createDocumentFragment(),n.bind&&this.bindDocumentFragments(r,t);else{if(t.is("uiElement"))return r=t.render(e),n.bind&&this.bindElements(r,t),r;r=t.hasAttribute("xmlns")?e.createElementNS(t.getAttribute("xmlns"),t.name):e.createElement(t.name),t.is("rawElement")&&t.render(r),n.bind&&this.bindElements(r,t);for(const e of t.getAttributeKeys())r.setAttribute(e,t.getAttribute(e))}if(!1!==n.withChildren)for(const i of this.viewChildrenToDom(t,e,n))r.appendChild(i);return r}}*viewChildrenToDom(t,e,n={}){const r=t.getFillerOffset&&t.getFillerOffset();let i=0;for(const o of t.getChildren())r===i&&(yield this._blockFiller(e)),yield this.viewToDom(o,e,n),i++;r===i&&(yield this._blockFiller(e))}viewRangeToDom(t){const e=this.viewPositionToDom(t.start),n=this.viewPositionToDom(t.end),r=document.createRange();return r.setStart(e.parent,e.offset),r.setEnd(n.parent,n.offset),r}viewPositionToDom(t){const e=t.parent;if(e.is("$text")){const n=this.findCorrespondingDomText(e);if(!n)return null;let r=t.offset;return $i(n)&&(r+=7),{parent:n,offset:r}}{let n,r,i;if(0===t.offset){if(n=this.mapViewToDom(e),!n)return null;i=n.childNodes[0]}else{const e=t.nodeBefore;if(r=e.is("$text")?this.findCorrespondingDomText(e):this.mapViewToDom(t.nodeBefore),!r)return null;n=r.parentNode,i=r.nextSibling}return Fi(i)&&$i(i)?{parent:i,offset:7}:{parent:n,offset:r?oo(r)+1:0}}}domToView(t,e={}){if(this.isBlockFiller(t,this.blockFillerMode))return null;const n=this.getHostViewElement(t);if(n)return n;if(Fi(t)){if(Ui(t))return null;{const e=this._processDataFromDomText(t);return""===e?null:new En(this.document,e)}}if(this.isComment(t))return null;{if(this.mapDomToView(t))return this.mapDomToView(t);let n;if(this.isDocumentFragment(t))n=new Ci(this.document),e.bind&&this.bindDocumentFragments(t,n);else{const r=e.keepOriginalCase?t.tagName:t.tagName.toLowerCase();n=new Ir(this.document,r),e.bind&&this.bindElements(t,n);const i=t.attributes;for(let t=i.length-1;t>=0;t--)n._setAttribute(i[t].name,i[t].value);if(!1!==e.withChildren&&this._rawContentElementMatcher.match(n))return n._setCustomProperty("$rawContent",t.innerHTML),this._encounteredRawContentDomNodes.add(t),n}if(!1!==e.withChildren)for(const r of this.domChildrenToView(t,e))n._appendChild(r);return n}}*domChildrenToView(t,e={}){for(let n=0;n<t.childNodes.length;n++){const r=t.childNodes[n],i=this.domToView(r,e);null!==i&&(yield i)}}domSelectionToView(t){if(1===t.rangeCount){let e=t.getRangeAt(0).startContainer;Fi(e)&&(e=e.parentNode);const n=this.fakeSelectionToView(e);if(n)return n}const e=this.isDomSelectionBackward(t),n=[];for(let r=0;r<t.rangeCount;r++){const e=t.getRangeAt(r),i=this.domRangeToView(e);i&&n.push(i)}return new ri(n,{backward:e})}domRangeToView(t){const e=this.domPositionToView(t.startContainer,t.startOffset),n=this.domPositionToView(t.endContainer,t.endOffset);return e&&n?new ti(e,n):null}domPositionToView(t,e){if(this.isBlockFiller(t,this.blockFillerMode))return this.domPositionToView(t.parentNode,oo(t));const n=this.mapDomToView(t);if(n&&(n.is("uiElement")||n.is("rawElement")))return Zr._createBefore(n);if(Fi(t)){if(Ui(t))return this.domPositionToView(t.parentNode,oo(t));const n=this.findCorrespondingViewText(t);let r=e;return n?($i(t)&&(r-=7,r=r<0?0:r),new Zr(n,r)):null}if(0===e){const e=this.mapDomToView(t);if(e)return new Zr(e,0)}else{const n=t.childNodes[e-1],r=Fi(n)?this.findCorrespondingViewText(n):this.mapDomToView(n);if(r&&r.parent)return new Zr(r.parent,r.index+1)}return null}mapDomToView(t){return this.getHostViewElement(t)||this._domToViewMapping.get(t)}findCorrespondingViewText(t){if(Ui(t))return null;const e=this.getHostViewElement(t);if(e)return e;const n=t.previousSibling;if(n){if(!this.isElement(n))return null;const t=this.mapDomToView(n);if(t)return t.nextSibling instanceof En?t.nextSibling:null}else{const e=this.mapDomToView(t.parentNode);if(e){const t=e.getChild(0);return t instanceof En?t:null}}return null}mapViewToDom(t){return this._viewToDomMapping.get(t)}findCorrespondingDomText(t){const e=t.previousSibling;return e&&this.mapViewToDom(e)?this.mapViewToDom(e).nextSibling:!e&&t.parent&&this.mapViewToDom(t.parent)?this.mapViewToDom(t.parent).childNodes[0]:null}focus(t){const e=this.mapViewToDom(t);if(e&&e.ownerDocument.activeElement!==e){const{scrollX:t,scrollY:n}=io.window,r=[];uo(e,t=>{const{scrollLeft:e,scrollTop:n}=t;r.push([e,n])}),e.focus(),uo(e,t=>{const[e,n]=r.shift();t.scrollLeft=e,t.scrollTop=n}),io.window.scrollTo(t,n)}}isElement(t){return t&&t.nodeType==Node.ELEMENT_NODE}isDocumentFragment(t){return t&&t.nodeType==Node.DOCUMENT_FRAGMENT_NODE}isComment(t){return t&&t.nodeType==Node.COMMENT_NODE}isBlockFiller(t){return"br"==this.blockFillerMode?t.isEqualNode(so):!("BR"!==t.tagName||!ho(t,this.blockElements)||1!==t.parentNode.childNodes.length)||function(t,e){return Fi(t)&&" "==t.data&&ho(t,e)&&1===t.parentNode.childNodes.length}(t,this.blockElements)}isDomSelectionBackward(t){if(t.isCollapsed)return!1;const e=document.createRange();e.setStart(t.anchorNode,t.anchorOffset),e.setEnd(t.focusNode,t.focusOffset);const n=e.collapsed;return e.detach(),n}getHostViewElement(t){const e=ao(t);for(e.pop();e.length;){const t=e.pop(),n=this._domToViewMapping.get(t);if(n&&(n.is("uiElement")||n.is("rawElement")))return n}return null}isDomSelectionCorrect(t){return this._isDomSelectionPositionCorrect(t.anchorNode,t.anchorOffset)&&this._isDomSelectionPositionCorrect(t.focusNode,t.focusOffset)}registerRawContentMatcher(t){this._rawContentElementMatcher.add(t)}_isDomSelectionPositionCorrect(t,e){if(Fi(t)&&$i(t)&&e<7)return!1;if(this.isElement(t)&&$i(t.childNodes[e]))return!1;const n=this.mapDomToView(t);return!n||!n.is("uiElement")&&!n.is("rawElement")}_processDataFromViewText(t){let e=t.data;if(t.getAncestors().some(t=>this.preElements.includes(t.name)))return e;if(" "==e.charAt(0)){const n=this._getTouchingViewTextNode(t,!1);(!n||!this._nodeEndsWithSpace(n))&&n||(e=" "+e.substr(1))}if(" "==e.charAt(e.length-1)){const n=this._getTouchingViewTextNode(t,!0);" "!=e.charAt(e.length-2)&&n&&" "!=n.data.charAt(0)||(e=e.substr(0,e.length-1)+" ")}return e.replace(/ {2}/g,"  ")}_nodeEndsWithSpace(t){if(t.getAncestors().some(t=>this.preElements.includes(t.name)))return!1;const e=this._processDataFromViewText(t);return" "==e.charAt(e.length-1)}_processDataFromDomText(t){let e=t.data;if(lo(t,this.preElements))return qi(t);e=e.replace(/[ \n\t\r]{1,}/g," ");const n=this._getTouchingInlineDomNode(t,!1),r=this._getTouchingInlineDomNode(t,!0),i=this._checkShouldLeftTrimDomText(t,n),o=this._checkShouldRightTrimDomText(t,r);return i&&(e=e.replace(/^ /,"")),o&&(e=e.replace(/ $/,"")),e=qi(new Text(e)),e=e.replace(/ \u00A0/g,"  "),(/( |\u00A0)\u00A0$/.test(e)||!r||r.data&&" "==r.data.charAt(0))&&(e=e.replace(/\u00A0$/," ")),i&&(e=e.replace(/^\u00A0/," ")),e}_checkShouldLeftTrimDomText(t,e){return!e||!!nn(e)||!this._encounteredRawContentDomNodes.has(t.previousSibling)&&/[^\S\u00A0]/.test(e.data.charAt(e.data.length-1))}_checkShouldRightTrimDomText(t,e){return!e&&!$i(t)}_getTouchingViewTextNode(t,e){const n=new Jr({startPosition:e?Zr._createAfter(t):Zr._createBefore(t),direction:e?"forward":"backward"});for(const r of n){if(r.item.is("containerElement"))return null;if(r.item.is("element","br"))return null;if(r.item.is("$textProxy"))return r.item}return null}_getTouchingInlineDomNode(t,e){if(!t.parentNode)return null;const n=e?"nextNode":"previousNode",r=t.ownerDocument,i=ao(t)[0],o=r.createTreeWalker(i,NodeFilter.SHOW_TEXT|NodeFilter.SHOW_ELEMENT,{acceptNode:t=>Fi(t)||"BR"==t.tagName?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP});o.currentNode=t;const a=o[n]();if(null!==a){const e=function(t,e){const n=ao(t),r=ao(e);let i=0;for(;n[i]==r[i]&&n[i];)i++;return 0===i?null:n[i-1]}(t,a);if(e&&!lo(t,this.blockElements,e)&&!lo(a,this.blockElements,e))return a}return null}}function lo(t,e,n){let r=ao(t);return n&&(r=r.slice(r.indexOf(n)+1)),r.some(t=>t.tagName&&e.includes(t.tagName.toLowerCase()))}function uo(t,e){for(;t&&t!=io.document;)e(t),t=t.parentNode}function ho(t,e){const n=t.parentNode;return n&&n.tagName&&e.includes(n.tagName.toLowerCase())}function fo(t){const e=Object.prototype.toString.apply(t);return"[object Window]"==e||"[object global]"==e}var po=Hr({},mn,{listenTo(t,...e){if(Zi(t)||fo(t)){const n=this._getProxyEmitter(t)||new mo(t);n.attach(...e),t=n}mn.listenTo.call(this,t,...e)},stopListening(t,e,n){if(Zi(t)||fo(t)){const e=this._getProxyEmitter(t);if(!e)return;t=e}mn.stopListening.call(this,t,e,n),t instanceof mo&&t.detach(e)},_getProxyEmitter(t){return e=this,n=bo(t),e[fn]&&e[fn][n]?e[fn][n].emitter:null;var e,n}});class mo{constructor(t){bn(this,bo(t)),this._domNode=t}}function bo(t){return t["data-ck-expando"]||(t["data-ck-expando"]=un())}Hr(mo.prototype,mn,{attach(t,e,n={}){if(this._domListeners&&this._domListeners[t])return;const r={capture:!!n.useCapture,passive:!!n.usePassive},i=this._createDomListener(t,r);this._domNode.addEventListener(t,i,r),this._domListeners||(this._domListeners={}),this._domListeners[t]=i},detach(t){let e;!this._domListeners[t]||(e=this._events[t])&&e.callbacks.length||this._domListeners[t].removeListener()},_createDomListener(t,e){const n=e=>{this.fire(t,e)};return n.removeListener=()=>{this._domNode.removeEventListener(t,n,e),delete this._domListeners[t]},n}});class go{constructor(t){this.view=t,this.document=t.document,this.isEnabled=!1}enable(){this.isEnabled=!0}disable(){this.isEnabled=!1}destroy(){this.disable(),this.stopListening()}checkShouldIgnoreEventFromTarget(t){return t&&3===t.nodeType&&(t=t.parentNode),!(!t||1!==t.nodeType)&&t.matches("[data-cke-ignore-events], [data-cke-ignore-events] *")}}On(go,po);var vo=function(t){return this.__data__.set(t,"__lodash_hash_undefined__"),this},wo=function(t){return this.__data__.has(t)};function yo(t){var e=-1,n=null==t?0:t.length;for(this.__data__=new wt;++e<n;)this.add(t[e])}yo.prototype.add=yo.prototype.push=vo,yo.prototype.has=wo;var ko=yo,_o=function(t,e){for(var n=-1,r=null==t?0:t.length;++n<r;)if(e(t[n],n,t))return!0;return!1},Oo=function(t,e){return t.has(e)},zo=function(t,e,n,r,i,o){var a=1&n,s=t.length,c=e.length;if(s!=c&&!(a&&c>s))return!1;var l=o.get(t),u=o.get(e);if(l&&u)return l==e&&u==t;var d=-1,h=!0,f=2&n?new ko:void 0;for(o.set(t,e),o.set(e,t);++d<s;){var p=t[d],m=e[d];if(r)var b=a?r(m,p,d,e,t,o):r(p,m,d,t,e,o);if(void 0!==b){if(b)continue;h=!1;break}if(f){if(!_o(e,(function(t,e){if(!Oo(f,e)&&(p===t||i(p,t,n,r,o)))return f.push(e)}))){h=!1;break}}else if(p!==m&&!i(p,m,n,r,o)){h=!1;break}}return o.delete(t),o.delete(e),h},Ao=function(t){var e=-1,n=Array(t.size);return t.forEach((function(t,r){n[++e]=[r,t]})),n},jo=function(t){var e=-1,n=Array(t.size);return t.forEach((function(t){n[++e]=t})),n},Mo=i?i.prototype:void 0,Co=Mo?Mo.valueOf:void 0,Vo=function(t,e,n,r,i,o,a){switch(n){case"[object DataView]":if(t.byteLength!=e.byteLength||t.byteOffset!=e.byteOffset)return!1;t=t.buffer,e=e.buffer;case"[object ArrayBuffer]":return!(t.byteLength!=e.byteLength||!o(new Ie(t),new Ie(e)));case"[object Boolean]":case"[object Date]":case"[object Number]":return z(+t,+e);case"[object Error]":return t.name==e.name&&t.message==e.message;case"[object RegExp]":case"[object String]":return t==e+"";case"[object Map]":var s=Ao;case"[object Set]":var c=1&r;if(s||(s=jo),t.size!=e.size&&!c)return!1;var l=a.get(t);if(l)return l==e;r|=2,a.set(t,e);var u=zo(s(t),s(e),r,i,o,a);return a.delete(t),u;case"[object Symbol]":if(Co)return Co.call(t)==Co.call(e)}return!1},So=Object.prototype.hasOwnProperty,xo=function(t,e,n,r,i,o){var a=1&n,s=we(t),c=s.length;if(c!=we(e).length&&!a)return!1;for(var l=c;l--;){var u=s[l];if(!(a?u in e:So.call(e,u)))return!1}var d=o.get(t),h=o.get(e);if(d&&h)return d==e&&h==t;var f=!0;o.set(t,e),o.set(e,t);for(var p=a;++l<c;){var m=t[u=s[l]],b=e[u];if(r)var g=a?r(b,m,u,e,t,o):r(m,b,u,t,e,o);if(!(void 0===g?m===b||i(m,b,n,r,o):g)){f=!1;break}p||(p="constructor"==u)}if(f&&!p){var v=t.constructor,w=e.constructor;v==w||!("constructor"in t)||!("constructor"in e)||"function"==typeof v&&v instanceof v&&"function"==typeof w&&w instanceof w||(f=!1)}return o.delete(t),o.delete(e),f},To=Object.prototype.hasOwnProperty,Po=function(t,e,n,r,i,o){var a=Et(t),s=Et(e),c=a?"[object Array]":xe(t),l=s?"[object Array]":xe(e),u="[object Object]"==(c="[object Arguments]"==c?"[object Object]":c),d="[object Object]"==(l="[object Arguments]"==l?"[object Object]":l),h=c==l;if(h&&Object(Lt.a)(t)){if(!Object(Lt.a)(e))return!1;a=!0,u=!1}if(h&&!u)return o||(o=new _t),a||qt(t)?zo(t,e,n,r,i,o):Vo(t,e,c,n,r,i,o);if(!(1&n)){var f=u&&To.call(t,"__wrapped__"),p=d&&To.call(e,"__wrapped__");if(f||p){var m=f?t.value():t,b=p?e.value():e;return o||(o=new _t),i(m,b,n,r,o)}}return!!h&&(o||(o=new _t),xo(t,e,n,r,i,o))},Io=function t(e,n,r,i,o){return e===n||(null==e||null==n||!b(e)&&!b(n)?e!=e&&n!=n:Po(e,n,r,i,t,o))},Eo=function(t,e,n){var r=(n="function"==typeof n?n:void 0)?n(t,e):void 0;return void 0===r?Io(t,e,void 0,n):!!r};class Lo extends go{constructor(t){super(t),this._config={childList:!0,characterData:!0,characterDataOldValue:!0,subtree:!0},this.domConverter=t.domConverter,this.renderer=t._renderer,this._domElements=[],this._mutationObserver=new window.MutationObserver(this._onMutations.bind(this))}flush(){this._onMutations(this._mutationObserver.takeRecords())}observe(t){this._domElements.push(t),this.isEnabled&&this._mutationObserver.observe(t,this._config)}enable(){super.enable();for(const t of this._domElements)this._mutationObserver.observe(t,this._config)}disable(){super.disable(),this._mutationObserver.disconnect()}destroy(){super.destroy(),this._mutationObserver.disconnect()}_onMutations(t){if(0===t.length)return;const e=this.domConverter,n=new Map,r=new Set;for(const c of t)if("childList"===c.type){const t=e.mapDomToView(c.target);if(t&&(t.is("uiElement")||t.is("rawElement")))continue;t&&!this._isBogusBrMutation(c)&&r.add(t)}for(const c of t){const t=e.mapDomToView(c.target);if((!t||!t.is("uiElement")&&!t.is("rawElement"))&&"characterData"===c.type){const t=e.findCorrespondingViewText(c.target);t&&!r.has(t.parent)?n.set(t,{type:"text",oldText:t.data,newText:qi(c.target),node:t}):!t&&$i(c.target)&&r.add(e.mapDomToView(c.target.parentNode))}}const i=[];for(const c of n.values())this.renderer.markToSync("text",c.node),i.push(c);for(const c of r){const t=e.mapViewToDom(c),n=Array.from(c.getChildren()),r=Array.from(e.domChildrenToView(t,{withChildren:!1}));Eo(n,r,s)||(this.renderer.markToSync("children",c),i.push({type:"children",oldChildren:n,newChildren:r,node:c}))}const o=t[0].target.ownerDocument.getSelection();let a=null;if(o&&o.anchorNode){const t=e.domPositionToView(o.anchorNode,o.anchorOffset),n=e.domPositionToView(o.focusNode,o.focusOffset);t&&n&&(a=new ri(t),a.setFocus(n))}function s(t,e){if(!Array.isArray(t))return t===e||!(!t.is("$text")||!e.is("$text"))&&t.data===e.data}i.length&&(this.document.fire("mutations",i,a),this.view.forceRender())}_isBogusBrMutation(t){let e=null;return null===t.nextSibling&&0===t.removedNodes.length&&1==t.addedNodes.length&&(e=this.domConverter.domToView(t.addedNodes[0],{withChildren:!1})),e&&e.is("element","br")}}class Bo{constructor(t,e,n){this.view=t,this.document=t.document,this.domEvent=e,this.domTarget=e.target,Hr(this,n)}get target(){return this.view.domConverter.mapDomToView(this.domTarget)}preventDefault(){this.domEvent.preventDefault()}stopPropagation(){this.domEvent.stopPropagation()}}class Ho extends go{constructor(t){super(t),this.useCapture=!1}observe(t){("string"==typeof this.domEventType?[this.domEventType]:this.domEventType).forEach(e=>{this.listenTo(t,e,(t,e)=>{this.isEnabled&&!this.checkShouldIgnoreEventFromTarget(e.target)&&this.onDomEvent(e)},{useCapture:this.useCapture})})}fire(t,e,n){this.isEnabled&&this.document.fire(t,new Bo(this.view,e,n))}}class Fo extends Ho{constructor(t){super(t),this.domEventType=["keydown","keyup"]}onDomEvent(t){this.fire(t.type,t,{keyCode:t.keyCode,altKey:t.altKey,ctrlKey:t.ctrlKey||t.metaKey,shiftKey:t.shiftKey,get keystroke(){return bi(this)}})}}var Do=function(){return r.a.Date.now()},Ro=/^\s+|\s+$/g,No=/^[-+]0x[0-9a-f]+$/i,$o=/^0b[01]+$/i,Uo=/^0o[0-7]+$/i,qo=parseInt,Wo=function(t){if("number"==typeof t)return t;if(Dn(t))return NaN;if(H(t)){var e="function"==typeof t.valueOf?t.valueOf():t;t=H(e)?e+"":e}if("string"!=typeof t)return 0===t?t:+t;t=t.replace(Ro,"");var n=$o.test(t);return n||Uo.test(t)?qo(t.slice(2),n?2:8):No.test(t)?NaN:+t},Go=Math.max,Yo=Math.min,Ko=function(t,e,n){var r,i,o,a,s,c,l=0,u=!1,d=!1,h=!0;if("function"!=typeof t)throw new TypeError("Expected a function");function f(e){var n=r,o=i;return r=i=void 0,l=e,a=t.apply(o,n)}function p(t){return l=t,s=setTimeout(b,e),u?f(t):a}function m(t){var n=t-c;return void 0===c||n>=e||n<0||d&&t-l>=o}function b(){var t=Do();if(m(t))return g(t);s=setTimeout(b,function(t){var n=e-(t-c);return d?Yo(n,o-(t-l)):n}(t))}function g(t){return s=void 0,h&&r?f(t):(r=i=void 0,a)}function v(){var t=Do(),n=m(t);if(r=arguments,i=this,c=t,n){if(void 0===s)return p(c);if(d)return clearTimeout(s),s=setTimeout(b,e),f(c)}return void 0===s&&(s=setTimeout(b,e)),a}return e=Wo(e)||0,H(n)&&(u=!!n.leading,o=(d="maxWait"in n)?Go(Wo(n.maxWait)||0,e):o,h="trailing"in n?!!n.trailing:h),v.cancel=function(){void 0!==s&&clearTimeout(s),l=0,r=c=i=s=void 0},v.flush=function(){return void 0===s?a:g(Do())},v};class Qo extends go{constructor(t){super(t),this._fireSelectionChangeDoneDebounced=Ko(t=>this.document.fire("selectionChangeDone",t),200)}observe(){const t=this.document;t.on("keydown",(e,n)=>{t.selection.isFake&&wi(n.keyCode)&&this.isEnabled&&(n.preventDefault(),this._handleSelectionMove(n.keyCode))},{priority:"lowest"})}destroy(){super.destroy(),this._fireSelectionChangeDoneDebounced.cancel()}_handleSelectionMove(t){const e=this.document.selection,n=new ri(e.getRanges(),{backward:e.isBackward,fake:!1});t!=mi.arrowleft&&t!=mi.arrowup||n.setTo(n.getFirstPosition()),t!=mi.arrowright&&t!=mi.arrowdown||n.setTo(n.getLastPosition());const r={oldSelection:e,newSelection:n,domSelection:null};this.document.fire("selectionChange",r),this._fireSelectionChangeDoneDebounced(r)}}class Xo extends go{constructor(t){super(t),this.mutationObserver=t.getObserver(Lo),this.selection=this.document.selection,this.domConverter=t.domConverter,this._documents=new WeakSet,this._fireSelectionChangeDoneDebounced=Ko(t=>this.document.fire("selectionChangeDone",t),200),this._clearInfiniteLoopInterval=setInterval(()=>this._clearInfiniteLoop(),1e3),this._loopbackCounter=0}observe(t){const e=t.ownerDocument;this._documents.has(e)||(this.listenTo(e,"selectionchange",(t,n)=>{this._handleSelectionChange(n,e)}),this._documents.add(e))}destroy(){super.destroy(),clearInterval(this._clearInfiniteLoopInterval),this._fireSelectionChangeDoneDebounced.cancel()}_handleSelectionChange(t,e){if(!this.isEnabled)return;const n=e.defaultView.getSelection();if(this.checkShouldIgnoreEventFromTarget(n.anchorNode))return;this.mutationObserver.flush();const r=this.domConverter.domSelectionToView(n);if(0!=r.rangeCount){if(this.view.hasDomSelection=!0,!(this.selection.isEqual(r)&&this.domConverter.isDomSelectionCorrect(n)||++this._loopbackCounter>60))if(this.selection.isSimilar(r))this.view.forceRender();else{const t={oldSelection:this.selection,newSelection:r,domSelection:n};this.document.fire("selectionChange",t),this._fireSelectionChangeDoneDebounced(t)}}else this.view.hasDomSelection=!1}_clearInfiniteLoop(){this._loopbackCounter=0}}class Jo extends Ho{constructor(t){super(t),this.domEventType=["focus","blur"],this.useCapture=!0;const e=this.document;e.on("focus",()=>{e.isFocused=!0,this._renderTimeoutId=setTimeout(()=>t.forceRender(),50)}),e.on("blur",(n,r)=>{const i=e.selection.editableElement;null!==i&&i!==r.target||(e.isFocused=!1,t.forceRender())})}onDomEvent(t){this.fire(t.type,t)}destroy(){this._renderTimeoutId&&clearTimeout(this._renderTimeoutId),super.destroy()}}class Zo extends Ho{constructor(t){super(t),this.domEventType=["compositionstart","compositionupdate","compositionend"];const e=this.document;e.on("compositionstart",()=>{e.isComposing=!0}),e.on("compositionend",()=>{e.isComposing=!1})}onDomEvent(t){this.fire(t.type,t)}}class ta extends Ho{constructor(t){super(t),this.domEventType=["beforeinput"]}onDomEvent(t){this.fire(t.type,t)}}function ea(t){return"[object Range]"==Object.prototype.toString.apply(t)}function na(t){const e=t.ownerDocument.defaultView.getComputedStyle(t);return{top:parseInt(e.borderTopWidth,10),right:parseInt(e.borderRightWidth,10),bottom:parseInt(e.borderBottomWidth,10),left:parseInt(e.borderLeftWidth,10)}}const ra=["top","right","bottom","left","width","height"];class ia{constructor(t){const e=ea(t);if(Object.defineProperty(this,"_source",{value:t._source||t,writable:!0,enumerable:!1}),nn(t)||e)if(e){const e=ia.getDomRangeRects(t);oa(this,ia.getBoundingRect(e))}else oa(this,t.getBoundingClientRect());else if(fo(t)){const{innerWidth:e,innerHeight:n}=t;oa(this,{top:0,right:e,bottom:n,left:0,width:e,height:n})}else oa(this,t)}clone(){return new ia(this)}moveTo(t,e){return this.top=e,this.right=t+this.width,this.bottom=e+this.height,this.left=t,this}moveBy(t,e){return this.top+=e,this.right+=t,this.left+=t,this.bottom+=e,this}getIntersection(t){const e={top:Math.max(this.top,t.top),right:Math.min(this.right,t.right),bottom:Math.min(this.bottom,t.bottom),left:Math.max(this.left,t.left)};return e.width=e.right-e.left,e.height=e.bottom-e.top,e.width<0||e.height<0?null:new ia(e)}getIntersectionArea(t){const e=this.getIntersection(t);return e?e.getArea():0}getArea(){return this.width*this.height}getVisible(){const t=this._source;let e=this.clone();if(!aa(t)){let n=t.parentNode||t.commonAncestorContainer;for(;n&&!aa(n);){const t=new ia(n),r=e.getIntersection(t);if(!r)return null;r.getArea()<e.getArea()&&(e=r),n=n.parentNode}}return e}isEqual(t){for(const e of ra)if(this[e]!==t[e])return!1;return!0}contains(t){const e=this.getIntersection(t);return!(!e||!e.isEqual(t))}excludeScrollbarsAndBorders(){const t=this._source;let e,n,r;if(fo(t))e=t.innerWidth-t.document.documentElement.clientWidth,n=t.innerHeight-t.document.documentElement.clientHeight,r=t.getComputedStyle(t.document.documentElement).direction;else{const i=na(this._source);e=t.offsetWidth-t.clientWidth-i.left-i.right,n=t.offsetHeight-t.clientHeight-i.top-i.bottom,r=t.ownerDocument.defaultView.getComputedStyle(t).direction,this.left+=i.left,this.top+=i.top,this.right-=i.right,this.bottom-=i.bottom,this.width=this.right-this.left,this.height=this.bottom-this.top}return this.width-=e,"ltr"===r?this.right-=e:this.left+=e,this.height-=n,this.bottom-=n,this}static getDomRangeRects(t){const e=[],n=Array.from(t.getClientRects());if(n.length)for(const r of n)e.push(new ia(r));else{let n=t.startContainer;Fi(n)&&(n=n.parentNode);const r=new ia(n.getBoundingClientRect());r.right=r.left,r.width=0,e.push(r)}return e}static getBoundingRect(t){const e={left:Number.POSITIVE_INFINITY,top:Number.POSITIVE_INFINITY,right:Number.NEGATIVE_INFINITY,bottom:Number.NEGATIVE_INFINITY};let n=0;for(const r of t)n++,e.left=Math.min(e.left,r.left),e.top=Math.min(e.top,r.top),e.right=Math.max(e.right,r.right),e.bottom=Math.max(e.bottom,r.bottom);return 0==n?null:(e.width=e.right-e.left,e.height=e.bottom-e.top,new ia(e))}}function oa(t,e){for(const n of ra)t[n]=e[n]}function aa(t){return!!nn(t)&&t===t.ownerDocument.body}function sa({target:t,viewportOffset:e=0}){const n=pa(t);let r=n,i=null;for(;r;){let o;o=ma(r==n?t:i),la(o,()=>ba(t,r));const a=ba(t,r);if(ca(r,a,e),r.parent!=r){if(i=r.frameElement,r=r.parent,!i)return}else r=null}}function ca(t,e,n){const r=e.clone().moveBy(0,n),i=e.clone().moveBy(0,-n),o=new ia(t).excludeScrollbarsAndBorders();if(![i,r].every(t=>o.contains(t))){let{scrollX:a,scrollY:s}=t;da(i,o)?s-=o.top-e.top+n:ua(r,o)&&(s+=e.bottom-o.bottom+n),ha(e,o)?a-=o.left-e.left+n:fa(e,o)&&(a+=e.right-o.right+n),t.scrollTo(a,s)}}function la(t,e){const n=pa(t);let r,i;for(;t!=n.document.body;)i=e(),r=new ia(t).excludeScrollbarsAndBorders(),r.contains(i)||(da(i,r)?t.scrollTop-=r.top-i.top:ua(i,r)&&(t.scrollTop+=i.bottom-r.bottom),ha(i,r)?t.scrollLeft-=r.left-i.left:fa(i,r)&&(t.scrollLeft+=i.right-r.right)),t=t.parentNode}function ua(t,e){return t.bottom>e.bottom}function da(t,e){return t.top<e.top}function ha(t,e){return t.left<e.left}function fa(t,e){return t.right>e.right}function pa(t){return ea(t)?t.startContainer.ownerDocument.defaultView:t.ownerDocument.defaultView}function ma(t){if(ea(t)){let e=t.commonAncestorContainer;return Fi(e)&&(e=e.parentNode),e}return t.parentNode}function ba(t,e){const n=pa(t),r=new ia(t);if(n===e)return r;{let t=n;for(;t!=e;){const e=t.frameElement,n=new ia(e).excludeScrollbarsAndBorders();r.moveBy(n.left,n.top),t=t.parent}}return r}Object.assign({},{scrollViewportToShowTarget:sa,scrollAncestorsToShowTarget:function(t){la(ma(t),()=>new ia(t))}});class ga{constructor(t){this.document=new oi(t),this.domConverter=new co(this.document),this.domRoots=new Map,this.set("isRenderingInProgress",!1),this.set("hasDomSelection",!1),this._renderer=new to(this.domConverter,this.document.selection),this._renderer.bind("isFocused").to(this.document),this._initialDomRootAttributes=new WeakMap,this._observers=new Map,this._ongoingChange=!1,this._postFixersInProgress=!1,this._renderingDisabled=!1,this._hasChangedSinceTheLastRendering=!1,this._writer=new Vi(this.document),this.addObserver(Lo),this.addObserver(Xo),this.addObserver(Jo),this.addObserver(Fo),this.addObserver(Qo),this.addObserver(Zo),hi.isAndroid&&this.addObserver(ta),this.document.on("keydown",Wi),zi(this),this.on("render",()=>{this._render(),this.document.fire("layoutChanged"),this._hasChangedSinceTheLastRendering=!1}),this.listenTo(this.document.selection,"change",()=>{this._hasChangedSinceTheLastRendering=!0})}attachDomRoot(t,e="main"){const n=this.document.getRoot(e);n._name=t.tagName.toLowerCase();const r={};for(const{name:o,value:a}of Array.from(t.attributes))r[o]=a,"class"===o?this._writer.addClass(a.split(" "),n):this._writer.setAttribute(o,a,n);this._initialDomRootAttributes.set(t,r);const i=()=>{this._writer.setAttribute("contenteditable",!n.isReadOnly,n),n.isReadOnly?this._writer.addClass("ck-read-only",n):this._writer.removeClass("ck-read-only",n)};i(),this.domRoots.set(e,t),this.domConverter.bindElements(t,n),this._renderer.markToSync("children",n),this._renderer.markToSync("attributes",n),this._renderer.domDocuments.add(t.ownerDocument),n.on("change:children",(t,e)=>this._renderer.markToSync("children",e)),n.on("change:attributes",(t,e)=>this._renderer.markToSync("attributes",e)),n.on("change:text",(t,e)=>this._renderer.markToSync("text",e)),n.on("change:isReadOnly",()=>this.change(i)),n.on("change",()=>{this._hasChangedSinceTheLastRendering=!0});for(const o of this._observers.values())o.observe(t,e)}detachDomRoot(t){const e=this.domRoots.get(t);Array.from(e.attributes).forEach(({name:t})=>e.removeAttribute(t));const n=this._initialDomRootAttributes.get(e);for(const r in n)e.setAttribute(r,n[r]);this.domRoots.delete(t),this.domConverter.unbindDomElement(e)}getDomRoot(t="main"){return this.domRoots.get(t)}addObserver(t){let e=this._observers.get(t);if(e)return e;e=new t(this),this._observers.set(t,e);for(const[n,r]of this.domRoots)e.observe(r,n);return e.enable(),e}getObserver(t){return this._observers.get(t)}disableObservers(){for(const t of this._observers.values())t.disable()}enableObservers(){for(const t of this._observers.values())t.enable()}scrollToTheSelection(){const t=this.document.selection.getFirstRange();t&&sa({target:this.domConverter.viewRangeToDom(t),viewportOffset:20})}focus(){if(!this.document.isFocused){const t=this.document.selection.editableElement;t&&(this.domConverter.focus(t),this.forceRender())}}change(t){if(this.isRenderingInProgress||this._postFixersInProgress)throw new hn.a("cannot-change-view-tree",this);try{if(this._ongoingChange)return t(this._writer);this._ongoingChange=!0;const e=t(this._writer);return this._ongoingChange=!1,!this._renderingDisabled&&this._hasChangedSinceTheLastRendering&&(this._postFixersInProgress=!0,this.document._callPostFixers(this._writer),this._postFixersInProgress=!1,this.fire("render")),e}catch(t){hn.a.rethrowUnexpectedError(t,this)}}forceRender(){this._hasChangedSinceTheLastRendering=!0,this.change(()=>{})}destroy(){for(const t of this._observers.values())t.destroy();this.document.destroy(),this.stopListening()}createPositionAt(t,e){return Zr._createAt(t,e)}createPositionAfter(t){return Zr._createAfter(t)}createPositionBefore(t){return Zr._createBefore(t)}createRange(t,e){return new ti(t,e)}createRangeOn(t){return ti._createOn(t)}createRangeIn(t){return ti._createIn(t)}createSelection(t,e,n){return new ri(t,e,n)}_disableRendering(t){this._renderingDisabled=t,0==t&&this.change(()=>{})}_render(){this.isRenderingInProgress=!0,this.disableObservers(),this._renderer.render(),this.enableObservers(),this.isRenderingInProgress=!1}}On(ga,$r);class va{constructor(t){this.parent=null,this._attrs=Bn(t)}get index(){let t;if(!this.parent)return null;if(null===(t=this.parent.getChildIndex(this)))throw new hn.a("model-node-not-found-in-parent",this);return t}get startOffset(){let t;if(!this.parent)return null;if(null===(t=this.parent.getChildStartOffset(this)))throw new hn.a("model-node-not-found-in-parent",this);return t}get offsetSize(){return 1}get endOffset(){return this.parent?this.startOffset+this.offsetSize:null}get nextSibling(){const t=this.index;return null!==t&&this.parent.getChild(t+1)||null}get previousSibling(){const t=this.index;return null!==t&&this.parent.getChild(t-1)||null}get root(){let t=this;for(;t.parent;)t=t.parent;return t}isAttached(){return this.root.is("rootElement")}getPath(){const t=[];let e=this;for(;e.parent;)t.unshift(e.startOffset),e=e.parent;return t}getAncestors(t={includeSelf:!1,parentFirst:!1}){const e=[];let n=t.includeSelf?this:this.parent;for(;n;)e[t.parentFirst?"push":"unshift"](n),n=n.parent;return e}getCommonAncestor(t,e={}){const n=this.getAncestors(e),r=t.getAncestors(e);let i=0;for(;n[i]==r[i]&&n[i];)i++;return 0===i?null:n[i-1]}isBefore(t){if(this==t)return!1;if(this.root!==t.root)return!1;const e=this.getPath(),n=t.getPath(),r=Tn(e,n);switch(r){case"prefix":return!0;case"extension":return!1;default:return e[r]<n[r]}}isAfter(t){return this!=t&&this.root===t.root&&!this.isBefore(t)}hasAttribute(t){return this._attrs.has(t)}getAttribute(t){return this._attrs.get(t)}getAttributes(){return this._attrs.entries()}getAttributeKeys(){return this._attrs.keys()}toJSON(){const t={};return this._attrs.size&&(t.attributes=Array.from(this._attrs).reduce((t,e)=>(t[e[0]]=e[1],t),{})),t}is(t){return"node"===t||"model:node"===t}_clone(){return new va(this._attrs)}_remove(){this.parent._removeChildren(this.index)}_setAttribute(t,e){this._attrs.set(t,e)}_setAttributesTo(t){this._attrs=Bn(t)}_removeAttribute(t){return this._attrs.delete(t)}_clearAttributes(){this._attrs.clear()}}class wa extends va{constructor(t,e){super(e),this._data=t||""}get offsetSize(){return this.data.length}get data(){return this._data}is(t){return"$text"===t||"model:$text"===t||"text"===t||"model:text"===t||"node"===t||"model:node"===t}toJSON(){const t=super.toJSON();return t.data=this.data,t}_clone(){return new wa(this.data,this.getAttributes())}static fromJSON(t){return new wa(t.data,t.attributes)}}class ya{constructor(t,e,n){if(this.textNode=t,e<0||e>t.offsetSize)throw new hn.a("model-textproxy-wrong-offsetintext",this);if(n<0||e+n>t.offsetSize)throw new hn.a("model-textproxy-wrong-length",this);this.data=t.data.substring(e,e+n),this.offsetInText=e}get startOffset(){return null!==this.textNode.startOffset?this.textNode.startOffset+this.offsetInText:null}get offsetSize(){return this.data.length}get endOffset(){return null!==this.startOffset?this.startOffset+this.offsetSize:null}get isPartial(){return this.offsetSize!==this.textNode.offsetSize}get parent(){return this.textNode.parent}get root(){return this.textNode.root}is(t){return"$textProxy"===t||"model:$textProxy"===t||"textProxy"===t||"model:textProxy"===t}getPath(){const t=this.textNode.getPath();return t.length>0&&(t[t.length-1]+=this.offsetInText),t}getAncestors(t={includeSelf:!1,parentFirst:!1}){const e=[];let n=t.includeSelf?this:this.parent;for(;n;)e[t.parentFirst?"push":"unshift"](n),n=n.parent;return e}hasAttribute(t){return this.textNode.hasAttribute(t)}getAttribute(t){return this.textNode.getAttribute(t)}getAttributes(){return this.textNode.getAttributes()}getAttributeKeys(){return this.textNode.getAttributeKeys()}}class ka{constructor(t){this._nodes=[],t&&this._insertNodes(0,t)}[Symbol.iterator](){return this._nodes[Symbol.iterator]()}get length(){return this._nodes.length}get maxOffset(){return this._nodes.reduce((t,e)=>t+e.offsetSize,0)}getNode(t){return this._nodes[t]||null}getNodeIndex(t){const e=this._nodes.indexOf(t);return-1==e?null:e}getNodeStartOffset(t){const e=this.getNodeIndex(t);return null===e?null:this._nodes.slice(0,e).reduce((t,e)=>t+e.offsetSize,0)}indexToOffset(t){if(t==this._nodes.length)return this.maxOffset;const e=this._nodes[t];if(!e)throw new hn.a("model-nodelist-index-out-of-bounds",this);return this.getNodeStartOffset(e)}offsetToIndex(t){let e=0;for(const n of this._nodes){if(t>=e&&t<e+n.offsetSize)return this.getNodeIndex(n);e+=n.offsetSize}if(e!=t)throw new hn.a("model-nodelist-offset-out-of-bounds",this,{offset:t,nodeList:this});return this.length}_insertNodes(t,e){for(const n of e)if(!(n instanceof va))throw new hn.a("model-nodelist-insertnodes-not-node",this);this._nodes.splice(t,0,...e)}_removeNodes(t,e=1){return this._nodes.splice(t,e)}toJSON(){return this._nodes.map(t=>t.toJSON())}}class _a extends va{constructor(t,e,n){super(e),this.name=t,this._children=new ka,n&&this._insertChild(0,n)}get childCount(){return this._children.length}get maxOffset(){return this._children.maxOffset}get isEmpty(){return 0===this.childCount}is(t,e=null){return e?e===this.name&&("element"===t||"model:element"===t):"element"===t||"model:element"===t||"node"===t||"model:node"===t}getChild(t){return this._children.getNode(t)}getChildren(){return this._children[Symbol.iterator]()}getChildIndex(t){return this._children.getNodeIndex(t)}getChildStartOffset(t){return this._children.getNodeStartOffset(t)}offsetToIndex(t){return this._children.offsetToIndex(t)}getNodeByPath(t){let e=this;for(const n of t)e=e.getChild(e.offsetToIndex(n));return e}findAncestor(t,e={includeSelf:!1}){let n=e.includeSelf?this:this.parent;for(;n;){if(n.name===t)return n;n=n.parent}return null}toJSON(){const t=super.toJSON();if(t.name=this.name,this._children.length>0){t.children=[];for(const e of this._children)t.children.push(e.toJSON())}return t}_clone(t=!1){const e=t?Array.from(this._children).map(t=>t._clone(!0)):null;return new _a(this.name,this.getAttributes(),e)}_appendChild(t){this._insertChild(this.childCount,t)}_insertChild(t,e){const n=function(t){return"string"==typeof t?[new wa(t)]:(_n(t)||(t=[t]),Array.from(t).map(t=>"string"==typeof t?new wa(t):t instanceof ya?new wa(t.data,t.getAttributes()):t))}(e);for(const r of n)null!==r.parent&&r._remove(),r.parent=this;this._children._insertNodes(t,n)}_removeChildren(t,e=1){const n=this._children._removeNodes(t,e);for(const r of n)r.parent=null;return n}static fromJSON(t){let e=null;if(t.children){e=[];for(const n of t.children)n.name?e.push(_a.fromJSON(n)):e.push(wa.fromJSON(n))}return new _a(t.name,t.attributes,e)}}class Oa{constructor(t={}){if(!t.boundaries&&!t.startPosition)throw new hn.a("model-tree-walker-no-start-position",null);const e=t.direction||"forward";if("forward"!=e&&"backward"!=e)throw new hn.a("model-tree-walker-unknown-direction",t,{direction:e});this.direction=e,this.boundaries=t.boundaries||null,t.startPosition?this.position=t.startPosition.clone():this.position=Aa._createAt(this.boundaries["backward"==this.direction?"end":"start"]),this.position.stickiness="toNone",this.singleCharacters=!!t.singleCharacters,this.shallow=!!t.shallow,this.ignoreElementEnd=!!t.ignoreElementEnd,this._boundaryStartParent=this.boundaries?this.boundaries.start.parent:null,this._boundaryEndParent=this.boundaries?this.boundaries.end.parent:null,this._visitedParent=this.position.parent}[Symbol.iterator](){return this}skip(t){let e,n,r,i;do{r=this.position,i=this._visitedParent,({done:e,value:n}=this.next())}while(!e&&t(n));e||(this.position=r,this._visitedParent=i)}next(){return"forward"==this.direction?this._next():this._previous()}_next(){const t=this.position,e=this.position.clone(),n=this._visitedParent;if(null===n.parent&&e.offset===n.maxOffset)return{done:!0};if(n===this._boundaryEndParent&&e.offset==this.boundaries.end.offset)return{done:!0};const r=e.parent,i=ja(e,r),o=i||Ma(e,r,i);if(o instanceof _a)return this.shallow?e.offset++:(e.path.push(0),this._visitedParent=o),this.position=e,za("elementStart",o,t,e,1);if(o instanceof wa){let r;if(this.singleCharacters)r=1;else{let t=o.endOffset;this._boundaryEndParent==n&&this.boundaries.end.offset<t&&(t=this.boundaries.end.offset),r=t-e.offset}const i=e.offset-o.startOffset,a=new ya(o,i,r);return e.offset+=r,this.position=e,za("text",a,t,e,r)}return e.path.pop(),e.offset++,this.position=e,this._visitedParent=n.parent,this.ignoreElementEnd?this._next():za("elementEnd",n,t,e)}_previous(){const t=this.position,e=this.position.clone(),n=this._visitedParent;if(null===n.parent&&0===e.offset)return{done:!0};if(n==this._boundaryStartParent&&e.offset==this.boundaries.start.offset)return{done:!0};const r=e.parent,i=ja(e,r),o=i||Ca(e,r,i);if(o instanceof _a)return e.offset--,this.shallow?(this.position=e,za("elementStart",o,t,e,1)):(e.path.push(o.maxOffset),this.position=e,this._visitedParent=o,this.ignoreElementEnd?this._previous():za("elementEnd",o,t,e));if(o instanceof wa){let r;if(this.singleCharacters)r=1;else{let t=o.startOffset;this._boundaryStartParent==n&&this.boundaries.start.offset>t&&(t=this.boundaries.start.offset),r=e.offset-t}const i=e.offset-o.startOffset,a=new ya(o,i-r,r);return e.offset-=r,this.position=e,za("text",a,t,e,r)}return e.path.pop(),this.position=e,this._visitedParent=n.parent,za("elementStart",n,t,e,1)}}function za(t,e,n,r,i){return{done:!1,value:{type:t,item:e,previousPosition:n,nextPosition:r,length:i}}}class Aa{constructor(t,e,n="toNone"){if(!t.is("element")&&!t.is("documentFragment"))throw new hn.a("model-position-root-invalid",t);if(!(e instanceof Array)||0===e.length)throw new hn.a("model-position-path-incorrect-format",t,{path:e});t.is("rootElement")?e=e.slice():(e=[...t.getPath(),...e],t=t.root),this.root=t,this.path=e,this.stickiness=n}get offset(){return this.path[this.path.length-1]}set offset(t){this.path[this.path.length-1]=t}get parent(){let t=this.root;for(let e=0;e<this.path.length-1;e++)if(t=t.getChild(t.offsetToIndex(this.path[e])),!t)throw new hn.a("model-position-path-incorrect",this,{position:this});if(t.is("$text"))throw new hn.a("model-position-path-incorrect",this,{position:this});return t}get index(){return this.parent.offsetToIndex(this.offset)}get textNode(){return ja(this,this.parent)}get nodeAfter(){const t=this.parent;return Ma(this,t,ja(this,t))}get nodeBefore(){const t=this.parent;return Ca(this,t,ja(this,t))}get isAtStart(){return 0===this.offset}get isAtEnd(){return this.offset==this.parent.maxOffset}compareWith(t){if(this.root!=t.root)return"different";const e=Tn(this.path,t.path);switch(e){case"same":return"same";case"prefix":return"before";case"extension":return"after";default:return this.path[e]<t.path[e]?"before":"after"}}getLastMatchingPosition(t,e={}){e.startPosition=this;const n=new Oa(e);return n.skip(t),n.position}getParentPath(){return this.path.slice(0,-1)}getAncestors(){const t=this.parent;return t.is("documentFragment")?[t]:t.getAncestors({includeSelf:!0})}findAncestor(t){const e=this.parent;return e.is("element")?e.findAncestor(t,{includeSelf:!0}):null}getCommonPath(t){if(this.root!=t.root)return[];const e=Tn(this.path,t.path),n="string"==typeof e?Math.min(this.path.length,t.path.length):e;return this.path.slice(0,n)}getCommonAncestor(t){const e=this.getAncestors(),n=t.getAncestors();let r=0;for(;e[r]==n[r]&&e[r];)r++;return 0===r?null:e[r-1]}getShiftedBy(t){const e=this.clone(),n=e.offset+t;return e.offset=n<0?0:n,e}isAfter(t){return"after"==this.compareWith(t)}isBefore(t){return"before"==this.compareWith(t)}isEqual(t){return"same"==this.compareWith(t)}isTouching(t){let e=null,n=null;switch(this.compareWith(t)){case"same":return!0;case"before":e=Aa._createAt(this),n=Aa._createAt(t);break;case"after":e=Aa._createAt(t),n=Aa._createAt(this);break;default:return!1}let r=e.parent;for(;e.path.length+n.path.length;){if(e.isEqual(n))return!0;if(e.path.length>n.path.length){if(e.offset!==r.maxOffset)return!1;e.path=e.path.slice(0,-1),r=r.parent,e.offset++}else{if(0!==n.offset)return!1;n.path=n.path.slice(0,-1)}}}is(t){return"position"===t||"model:position"===t}hasSameParentAs(t){return this.root===t.root&&"same"==Tn(this.getParentPath(),t.getParentPath())}getTransformedByOperation(t){let e;switch(t.type){case"insert":e=this._getTransformedByInsertOperation(t);break;case"move":case"remove":case"reinsert":e=this._getTransformedByMoveOperation(t);break;case"split":e=this._getTransformedBySplitOperation(t);break;case"merge":e=this._getTransformedByMergeOperation(t);break;default:e=Aa._createAt(this)}return e}_getTransformedByInsertOperation(t){return this._getTransformedByInsertion(t.position,t.howMany)}_getTransformedByMoveOperation(t){return this._getTransformedByMove(t.sourcePosition,t.targetPosition,t.howMany)}_getTransformedBySplitOperation(t){const e=t.movedRange;return e.containsPosition(this)||e.start.isEqual(this)&&"toNext"==this.stickiness?this._getCombined(t.splitPosition,t.moveTargetPosition):t.graveyardPosition?this._getTransformedByMove(t.graveyardPosition,t.insertionPosition,1):this._getTransformedByInsertion(t.insertionPosition,1)}_getTransformedByMergeOperation(t){const e=t.movedRange;let n;return e.containsPosition(this)||e.start.isEqual(this)?(n=this._getCombined(t.sourcePosition,t.targetPosition),t.sourcePosition.isBefore(t.targetPosition)&&(n=n._getTransformedByDeletion(t.deletionPosition,1))):n=this.isEqual(t.deletionPosition)?Aa._createAt(t.deletionPosition):this._getTransformedByMove(t.deletionPosition,t.graveyardPosition,1),n}_getTransformedByDeletion(t,e){const n=Aa._createAt(this);if(this.root!=t.root)return n;if("same"==Tn(t.getParentPath(),this.getParentPath())){if(t.offset<this.offset){if(t.offset+e>this.offset)return null;n.offset-=e}}else if("prefix"==Tn(t.getParentPath(),this.getParentPath())){const r=t.path.length-1;if(t.offset<=this.path[r]){if(t.offset+e>this.path[r])return null;n.path[r]-=e}}return n}_getTransformedByInsertion(t,e){const n=Aa._createAt(this);if(this.root!=t.root)return n;if("same"==Tn(t.getParentPath(),this.getParentPath()))(t.offset<this.offset||t.offset==this.offset&&"toPrevious"!=this.stickiness)&&(n.offset+=e);else if("prefix"==Tn(t.getParentPath(),this.getParentPath())){const r=t.path.length-1;t.offset<=this.path[r]&&(n.path[r]+=e)}return n}_getTransformedByMove(t,e,n){if(e=e._getTransformedByDeletion(t,n),t.isEqual(e))return Aa._createAt(this);const r=this._getTransformedByDeletion(t,n);return null===r||t.isEqual(this)&&"toNext"==this.stickiness||t.getShiftedBy(n).isEqual(this)&&"toPrevious"==this.stickiness?this._getCombined(t,e):r._getTransformedByInsertion(e,n)}_getCombined(t,e){const n=t.path.length-1,r=Aa._createAt(e);return r.stickiness=this.stickiness,r.offset=r.offset+this.path[n]-t.offset,r.path=[...r.path,...this.path.slice(n+1)],r}toJSON(){return{root:this.root.toJSON(),path:Array.from(this.path),stickiness:this.stickiness}}clone(){return new this.constructor(this.root,this.path,this.stickiness)}static _createAt(t,e,n="toNone"){if(t instanceof Aa)return new Aa(t.root,t.path,t.stickiness);{const r=t;if("end"==e)e=r.maxOffset;else{if("before"==e)return this._createBefore(r,n);if("after"==e)return this._createAfter(r,n);if(0!==e&&!e)throw new hn.a("model-createpositionat-offset-required",[this,t])}if(!r.is("element")&&!r.is("documentFragment"))throw new hn.a("model-position-parent-incorrect",[this,t]);const i=r.getPath();return i.push(e),new this(r.root,i,n)}}static _createAfter(t,e){if(!t.parent)throw new hn.a("model-position-after-root",[this,t],{root:t});return this._createAt(t.parent,t.endOffset,e)}static _createBefore(t,e){if(!t.parent)throw new hn.a("model-position-before-root",t,{root:t});return this._createAt(t.parent,t.startOffset,e)}static fromJSON(t,e){if("$graveyard"===t.root){const n=new Aa(e.graveyard,t.path);return n.stickiness=t.stickiness,n}if(!e.getRoot(t.root))throw new hn.a("model-position-fromjson-no-root",e,{rootName:t.root});return new Aa(e.getRoot(t.root),t.path,t.stickiness)}}function ja(t,e){const n=e.getChild(e.offsetToIndex(t.offset));return n&&n.is("$text")&&n.startOffset<t.offset?n:null}function Ma(t,e,n){return null!==n?null:e.getChild(e.offsetToIndex(t.offset))}function Ca(t,e,n){return null!==n?null:e.getChild(e.offsetToIndex(t.offset)-1)}class Va{constructor(t,e=null){this.start=Aa._createAt(t),this.end=e?Aa._createAt(e):Aa._createAt(t),this.start.stickiness=this.isCollapsed?"toNone":"toNext",this.end.stickiness=this.isCollapsed?"toNone":"toPrevious"}*[Symbol.iterator](){yield*new Oa({boundaries:this,ignoreElementEnd:!0})}get isCollapsed(){return this.start.isEqual(this.end)}get isFlat(){return"same"==Tn(this.start.getParentPath(),this.end.getParentPath())}get root(){return this.start.root}containsPosition(t){return t.isAfter(this.start)&&t.isBefore(this.end)}containsRange(t,e=!1){t.isCollapsed&&(e=!1);const n=this.containsPosition(t.start)||e&&this.start.isEqual(t.start),r=this.containsPosition(t.end)||e&&this.end.isEqual(t.end);return n&&r}containsItem(t){const e=Aa._createBefore(t);return this.containsPosition(e)||this.start.isEqual(e)}is(t){return"range"===t||"model:range"===t}isEqual(t){return this.start.isEqual(t.start)&&this.end.isEqual(t.end)}isIntersecting(t){return this.start.isBefore(t.end)&&this.end.isAfter(t.start)}getDifference(t){const e=[];return this.isIntersecting(t)?(this.containsPosition(t.start)&&e.push(new Va(this.start,t.start)),this.containsPosition(t.end)&&e.push(new Va(t.end,this.end))):e.push(new Va(this.start,this.end)),e}getIntersection(t){if(this.isIntersecting(t)){let e=this.start,n=this.end;return this.containsPosition(t.start)&&(e=t.start),this.containsPosition(t.end)&&(n=t.end),new Va(e,n)}return null}getJoined(t,e=!1){let n=this.isIntersecting(t);if(n||(n=this.start.isBefore(t.start)?e?this.end.isTouching(t.start):this.end.isEqual(t.start):e?t.end.isTouching(this.start):t.end.isEqual(this.start)),!n)return null;let r=this.start,i=this.end;return t.start.isBefore(r)&&(r=t.start),t.end.isAfter(i)&&(i=t.end),new Va(r,i)}getMinimalFlatRanges(){const t=[],e=this.start.getCommonPath(this.end).length,n=Aa._createAt(this.start);let r=n.parent;for(;n.path.length>e+1;){const e=r.maxOffset-n.offset;0!==e&&t.push(new Va(n,n.getShiftedBy(e))),n.path=n.path.slice(0,-1),n.offset++,r=r.parent}for(;n.path.length<=this.end.path.length;){const e=this.end.path[n.path.length-1],r=e-n.offset;0!==r&&t.push(new Va(n,n.getShiftedBy(r))),n.offset=e,n.path.push(0)}return t}getWalker(t={}){return t.boundaries=this,new Oa(t)}*getItems(t={}){t.boundaries=this,t.ignoreElementEnd=!0;const e=new Oa(t);for(const n of e)yield n.item}*getPositions(t={}){t.boundaries=this;const e=new Oa(t);yield e.position;for(const n of e)yield n.nextPosition}getTransformedByOperation(t){switch(t.type){case"insert":return this._getTransformedByInsertOperation(t);case"move":case"remove":case"reinsert":return this._getTransformedByMoveOperation(t);case"split":return[this._getTransformedBySplitOperation(t)];case"merge":return[this._getTransformedByMergeOperation(t)]}return[new Va(this.start,this.end)]}getTransformedByOperations(t){const e=[new Va(this.start,this.end)];for(const n of t)for(let t=0;t<e.length;t++){const r=e[t].getTransformedByOperation(n);e.splice(t,1,...r),t+=r.length-1}for(let n=0;n<e.length;n++){const t=e[n];for(let r=n+1;r<e.length;r++){const n=e[r];(t.containsRange(n)||n.containsRange(t)||t.isEqual(n))&&e.splice(r,1)}}return e}getCommonAncestor(){return this.start.getCommonAncestor(this.end)}getContainedElement(){if(this.isCollapsed)return null;const t=this.start.nodeAfter,e=this.end.nodeBefore;return t&&t.is("element")&&t===e?t:null}toJSON(){return{start:this.start.toJSON(),end:this.end.toJSON()}}clone(){return new this.constructor(this.start,this.end)}_getTransformedByInsertOperation(t,e=!1){return this._getTransformedByInsertion(t.position,t.howMany,e)}_getTransformedByMoveOperation(t,e=!1){const n=t.sourcePosition,r=t.howMany,i=t.targetPosition;return this._getTransformedByMove(n,i,r,e)}_getTransformedBySplitOperation(t){const e=this.start._getTransformedBySplitOperation(t);let n=this.end._getTransformedBySplitOperation(t);return this.end.isEqual(t.insertionPosition)&&(n=this.end.getShiftedBy(1)),e.root!=n.root&&(n=this.end.getShiftedBy(-1)),new Va(e,n)}_getTransformedByMergeOperation(t){if(this.start.isEqual(t.targetPosition)&&this.end.isEqual(t.deletionPosition))return new Va(this.start);let e=this.start._getTransformedByMergeOperation(t),n=this.end._getTransformedByMergeOperation(t);return e.root!=n.root&&(n=this.end.getShiftedBy(-1)),e.isAfter(n)?(t.sourcePosition.isBefore(t.targetPosition)?(e=Aa._createAt(n),e.offset=0):(t.deletionPosition.isEqual(e)||(n=t.deletionPosition),e=t.targetPosition),new Va(e,n)):new Va(e,n)}_getTransformedByInsertion(t,e,n=!1){if(n&&this.containsPosition(t))return[new Va(this.start,t),new Va(t.getShiftedBy(e),this.end._getTransformedByInsertion(t,e))];{const n=new Va(this.start,this.end);return n.start=n.start._getTransformedByInsertion(t,e),n.end=n.end._getTransformedByInsertion(t,e),[n]}}_getTransformedByMove(t,e,n,r=!1){if(this.isCollapsed){const r=this.start._getTransformedByMove(t,e,n);return[new Va(r)]}const i=Va._createFromPositionAndShift(t,n),o=e._getTransformedByDeletion(t,n);if(this.containsPosition(e)&&!r&&(i.containsPosition(this.start)||i.containsPosition(this.end))){const r=this.start._getTransformedByMove(t,e,n),i=this.end._getTransformedByMove(t,e,n);return[new Va(r,i)]}let a;const s=this.getDifference(i);let c=null;const l=this.getIntersection(i);if(1==s.length?c=new Va(s[0].start._getTransformedByDeletion(t,n),s[0].end._getTransformedByDeletion(t,n)):2==s.length&&(c=new Va(this.start,this.end._getTransformedByDeletion(t,n))),a=c?c._getTransformedByInsertion(o,n,null!==l||r):[],l){const t=new Va(l.start._getCombined(i.start,o),l.end._getCombined(i.start,o));2==a.length?a.splice(1,0,t):a.push(t)}return a}_getTransformedByDeletion(t,e){let n=this.start._getTransformedByDeletion(t,e),r=this.end._getTransformedByDeletion(t,e);return null==n&&null==r?null:(null==n&&(n=t),null==r&&(r=t),new Va(n,r))}static _createFromPositionAndShift(t,e){const n=t,r=t.getShiftedBy(e);return e>0?new this(n,r):new this(r,n)}static _createIn(t){return new this(Aa._createAt(t,0),Aa._createAt(t,t.maxOffset))}static _createOn(t){return this._createFromPositionAndShift(Aa._createBefore(t),t.offsetSize)}static _createFromRanges(t){if(0===t.length)throw new hn.a("range-create-from-ranges-empty-array",null);if(1==t.length)return t[0].clone();const e=t[0];t.sort((t,e)=>t.start.isAfter(e.start)?1:-1);const n=t.indexOf(e),r=new this(e.start,e.end);if(n>0)for(let i=n-1;t[i].end.isEqual(r.start);i++)r.start=Aa._createAt(t[i].start);for(let i=n+1;i<t.length&&t[i].start.isEqual(r.end);i++)r.end=Aa._createAt(t[i].end);return r}static fromJSON(t,e){return new this(Aa.fromJSON(t.start,e),Aa.fromJSON(t.end,e))}}class Sa{constructor(){this._modelToViewMapping=new WeakMap,this._viewToModelMapping=new WeakMap,this._viewToModelLengthCallbacks=new Map,this._markerNameToElements=new Map,this._elementToMarkerNames=new Map,this._unboundMarkerNames=new Set,this.on("modelToViewPosition",(t,e)=>{if(e.viewPosition)return;const n=this._modelToViewMapping.get(e.modelPosition.parent);e.viewPosition=this.findPositionIn(n,e.modelPosition.offset)},{priority:"low"}),this.on("viewToModelPosition",(t,e)=>{if(e.modelPosition)return;const n=this.findMappedViewAncestor(e.viewPosition),r=this._viewToModelMapping.get(n),i=this._toModelOffset(e.viewPosition.parent,e.viewPosition.offset,n);e.modelPosition=Aa._createAt(r,i)},{priority:"low"})}bindElements(t,e){this._modelToViewMapping.set(t,e),this._viewToModelMapping.set(e,t)}unbindViewElement(t){const e=this.toModelElement(t);if(this._viewToModelMapping.delete(t),this._elementToMarkerNames.has(t))for(const n of this._elementToMarkerNames.get(t))this._unboundMarkerNames.add(n);this._modelToViewMapping.get(e)==t&&this._modelToViewMapping.delete(e)}unbindModelElement(t){const e=this.toViewElement(t);this._modelToViewMapping.delete(t),this._viewToModelMapping.get(e)==t&&this._viewToModelMapping.delete(e)}bindElementToMarker(t,e){const n=this._markerNameToElements.get(e)||new Set;n.add(t);const r=this._elementToMarkerNames.get(t)||new Set;r.add(e),this._markerNameToElements.set(e,n),this._elementToMarkerNames.set(t,r)}unbindElementFromMarkerName(t,e){const n=this._markerNameToElements.get(e);n&&(n.delete(t),0==n.size&&this._markerNameToElements.delete(e));const r=this._elementToMarkerNames.get(t);r&&(r.delete(e),0==r.size&&this._elementToMarkerNames.delete(t))}flushUnboundMarkerNames(){const t=Array.from(this._unboundMarkerNames);return this._unboundMarkerNames.clear(),t}clearBindings(){this._modelToViewMapping=new WeakMap,this._viewToModelMapping=new WeakMap,this._markerNameToElements=new Map,this._elementToMarkerNames=new Map,this._unboundMarkerNames=new Set}toModelElement(t){return this._viewToModelMapping.get(t)}toViewElement(t){return this._modelToViewMapping.get(t)}toModelRange(t){return new Va(this.toModelPosition(t.start),this.toModelPosition(t.end))}toViewRange(t){return new ti(this.toViewPosition(t.start),this.toViewPosition(t.end))}toModelPosition(t){const e={viewPosition:t,mapper:this};return this.fire("viewToModelPosition",e),e.modelPosition}toViewPosition(t,e={isPhantom:!1}){const n={modelPosition:t,mapper:this,isPhantom:e.isPhantom};return this.fire("modelToViewPosition",n),n.viewPosition}markerNameToElements(t){const e=this._markerNameToElements.get(t);if(!e)return null;const n=new Set;for(const r of e)if(r.is("attributeElement"))for(const t of r.getElementsWithSameId())n.add(t);else n.add(r);return n}registerViewToModelLength(t,e){this._viewToModelLengthCallbacks.set(t,e)}findMappedViewAncestor(t){let e=t.parent;for(;!this._viewToModelMapping.has(e);)e=e.parent;return e}_toModelOffset(t,e,n){if(n!=t)return this._toModelOffset(t.parent,t.index,n)+this._toModelOffset(t,e,t);if(t.is("$text"))return e;let r=0;for(let i=0;i<e;i++)r+=this.getModelLength(t.getChild(i));return r}getModelLength(t){if(this._viewToModelLengthCallbacks.get(t.name))return this._viewToModelLengthCallbacks.get(t.name)(t);if(this._viewToModelMapping.has(t))return 1;if(t.is("$text"))return t.data.length;if(t.is("uiElement"))return 0;{let e=0;for(const n of t.getChildren())e+=this.getModelLength(n);return e}}findPositionIn(t,e){let n,r=0,i=0,o=0;if(t.is("$text"))return new Zr(t,e);for(;i<e;)n=t.getChild(o),r=this.getModelLength(n),i+=r,o++;return i==e?this._moveViewPositionToTextNode(new Zr(t,o)):this.findPositionIn(n,e-(i-r))}_moveViewPositionToTextNode(t){const e=t.nodeBefore,n=t.nodeAfter;return e instanceof En?new Zr(e,e.data.length):n instanceof En?new Zr(n,0):t}}On(Sa,mn);class xa{constructor(){this._consumable=new Map,this._textProxyRegistry=new Map}add(t,e){e=Ta(e),t instanceof ya&&(t=this._getSymbolForTextProxy(t)),this._consumable.has(t)||this._consumable.set(t,new Map),this._consumable.get(t).set(e,!0)}consume(t,e){return e=Ta(e),t instanceof ya&&(t=this._getSymbolForTextProxy(t)),!!this.test(t,e)&&(this._consumable.get(t).set(e,!1),!0)}test(t,e){e=Ta(e),t instanceof ya&&(t=this._getSymbolForTextProxy(t));const n=this._consumable.get(t);if(void 0===n)return null;const r=n.get(e);return void 0===r?null:r}revert(t,e){e=Ta(e),t instanceof ya&&(t=this._getSymbolForTextProxy(t));const n=this.test(t,e);return!1===n?(this._consumable.get(t).set(e,!0),!0):!0!==n&&null}_getSymbolForTextProxy(t){let e=null;const n=this._textProxyRegistry.get(t.startOffset);if(n){const r=n.get(t.endOffset);r&&(e=r.get(t.parent))}return e||(e=this._addSymbolForTextProxy(t.startOffset,t.endOffset,t.parent)),e}_addSymbolForTextProxy(t,e,n){const r=Symbol("textProxySymbol");let i,o;return i=this._textProxyRegistry.get(t),i||(i=new Map,this._textProxyRegistry.set(t,i)),o=i.get(e),o||(o=new Map,i.set(e,o)),o.set(n,r),r}}function Ta(t){const e=t.split(":");return e.length>1?e[0]+":"+e[1]:e[0]}class Pa{constructor(t){this.conversionApi=Object.assign({dispatcher:this},t),this._reconversionEventsMapping=new Map}convertChanges(t,e,n){for(const i of t.getMarkersToRemove())this.convertMarkerRemove(i.name,i.range,n);const r=this._mapChangesWithAutomaticReconversion(t);for(const i of r)"insert"===i.type?this.convertInsert(Va._createFromPositionAndShift(i.position,i.length),n):"remove"===i.type?this.convertRemove(i.position,i.length,i.name,n):"reconvert"===i.type?this.reconvertElement(i.element,n):this.convertAttribute(i.range,i.attributeKey,i.attributeOldValue,i.attributeNewValue,n);for(const i of this.conversionApi.mapper.flushUnboundMarkerNames()){const t=e.get(i).getRange();this.convertMarkerRemove(i,t,n),this.convertMarkerAdd(i,t,n)}for(const i of t.getMarkersToAdd())this.convertMarkerAdd(i.name,i.range,n)}convertInsert(t,e){this.conversionApi.writer=e,this.conversionApi.consumable=this._createInsertConsumable(t);for(const n of Array.from(t).map(Ea))this._convertInsertWithAttributes(n);this._clearConversionApi()}convertRemove(t,e,n,r){this.conversionApi.writer=r,this.fire("remove:"+n,{position:t,length:e},this.conversionApi),this._clearConversionApi()}convertAttribute(t,e,n,r,i){this.conversionApi.writer=i,this.conversionApi.consumable=this._createConsumableForRange(t,"attribute:"+e);for(const o of t){const t={item:o.item,range:Va._createFromPositionAndShift(o.previousPosition,o.length),attributeKey:e,attributeOldValue:n,attributeNewValue:r};this._testAndFire("attribute:"+e,t)}this._clearConversionApi()}reconvertElement(t,e){const n=Va._createOn(t);this.conversionApi.writer=e,this.conversionApi.consumable=this._createInsertConsumable(n);const r=this.conversionApi.mapper,i=r.toViewElement(t);e.remove(i),this._convertInsertWithAttributes({item:t,range:n});const o=r.toViewElement(t);for(const a of Va._createIn(t)){const{item:t}=a,n=La(t,r);n?n.root!==o.root&&e.move(e.createRangeOn(n),r.toViewPosition(Aa._createBefore(t))):this._convertInsertWithAttributes(Ea(a))}r.unbindViewElement(i),this._clearConversionApi()}convertSelection(t,e,n){const r=Array.from(e.getMarkersAtPosition(t.getFirstPosition()));if(this.conversionApi.writer=n,this.conversionApi.consumable=this._createSelectionConsumable(t,r),this.fire("selection",{selection:t},this.conversionApi),t.isCollapsed){for(const e of r){const n=e.getRange();if(!Ia(t.getFirstPosition(),e,this.conversionApi.mapper))continue;const r={item:t,markerName:e.name,markerRange:n};this.conversionApi.consumable.test(t,"addMarker:"+e.name)&&this.fire("addMarker:"+e.name,r,this.conversionApi)}for(const e of t.getAttributeKeys()){const n={item:t,range:t.getFirstRange(),attributeKey:e,attributeOldValue:null,attributeNewValue:t.getAttribute(e)};this.conversionApi.consumable.test(t,"attribute:"+n.attributeKey)&&this.fire("attribute:"+n.attributeKey+":$text",n,this.conversionApi)}this._clearConversionApi()}}convertMarkerAdd(t,e,n){if(!e.root.document||"$graveyard"==e.root.rootName)return;this.conversionApi.writer=n;const r="addMarker:"+t,i=new xa;if(i.add(e,r),this.conversionApi.consumable=i,this.fire(r,{markerName:t,markerRange:e},this.conversionApi),i.test(e,r)){this.conversionApi.consumable=this._createConsumableForRange(e,r);for(const n of e.getItems()){if(!this.conversionApi.consumable.test(n,r))continue;const i={item:n,range:Va._createOn(n),markerName:t,markerRange:e};this.fire(r,i,this.conversionApi)}this._clearConversionApi()}}convertMarkerRemove(t,e,n){e.root.document&&"$graveyard"!=e.root.rootName&&(this.conversionApi.writer=n,this.fire("removeMarker:"+t,{markerName:t,markerRange:e},this.conversionApi),this._clearConversionApi())}_mapReconversionTriggerEvent(t,e){this._reconversionEventsMapping.set(e,t)}_createInsertConsumable(t){const e=new xa;for(const n of t){const t=n.item;e.add(t,"insert");for(const n of t.getAttributeKeys())e.add(t,"attribute:"+n)}return e}_createConsumableForRange(t,e){const n=new xa;for(const r of t.getItems())n.add(r,e);return n}_createSelectionConsumable(t,e){const n=new xa;n.add(t,"selection");for(const r of e)n.add(t,"addMarker:"+r.name);for(const r of t.getAttributeKeys())n.add(t,"attribute:"+r);return n}_testAndFire(t,e){this.conversionApi.consumable.test(e.item,t)&&this.fire(function(t,e){const n=e.item.name||"$text";return`${t}:${n}`}(t,e),e,this.conversionApi)}_clearConversionApi(){delete this.conversionApi.writer,delete this.conversionApi.consumable}_convertInsertWithAttributes(t){this._testAndFire("insert",t);for(const e of t.item.getAttributeKeys())t.attributeKey=e,t.attributeOldValue=null,t.attributeNewValue=t.item.getAttribute(e),this._testAndFire("attribute:"+e,t)}_mapChangesWithAutomaticReconversion(t){const e=new Set,n=[];for(const r of t.getChanges()){const t=r.position||r.range.start,i=t.parent;if(ja(t,i)){n.push(r);continue}const o="attribute"===r.type?Ma(t,i,null):i;if(o.is("$text")){n.push(r);continue}let a;if(a="attribute"===r.type?`attribute:${r.attributeKey}:${o.name}`:`${r.type}:${r.name}`,this._isReconvertTriggerEvent(a,o.name)){if(e.has(o))continue;e.add(o),n.push({type:"reconvert",element:o})}else n.push(r)}return n}_isReconvertTriggerEvent(t,e){return this._reconversionEventsMapping.get(t)===e}}function Ia(t,e,n){const r=e.getRange(),i=Array.from(t.getAncestors());return i.shift(),i.reverse(),!i.some(t=>{if(r.containsItem(t))return!!n.toViewElement(t).getCustomProperty("addHighlight")})}function Ea(t){return{item:t.item,range:Va._createFromPositionAndShift(t.previousPosition,t.length)}}function La(t,e){if(t.is("textProxy")){const n=e.toViewPosition(Aa._createBefore(t)).parent;return n.is("$text")?n:null}return e.toViewElement(t)}On(Pa,mn);class Ba{constructor(t,e,n){this._lastRangeBackward=!1,this._ranges=[],this._attrs=new Map,t&&this.setTo(t,e,n)}get anchor(){if(this._ranges.length>0){const t=this._ranges[this._ranges.length-1];return this._lastRangeBackward?t.end:t.start}return null}get focus(){if(this._ranges.length>0){const t=this._ranges[this._ranges.length-1];return this._lastRangeBackward?t.start:t.end}return null}get isCollapsed(){return 1===this._ranges.length&&this._ranges[0].isCollapsed}get rangeCount(){return this._ranges.length}get isBackward(){return!this.isCollapsed&&this._lastRangeBackward}isEqual(t){if(this.rangeCount!=t.rangeCount)return!1;if(0===this.rangeCount)return!0;if(!this.anchor.isEqual(t.anchor)||!this.focus.isEqual(t.focus))return!1;for(const e of this._ranges){let n=!1;for(const r of t._ranges)if(e.isEqual(r)){n=!0;break}if(!n)return!1}return!0}*getRanges(){for(const t of this._ranges)yield new Va(t.start,t.end)}getFirstRange(){let t=null;for(const e of this._ranges)t&&!e.start.isBefore(t.start)||(t=e);return t?new Va(t.start,t.end):null}getLastRange(){let t=null;for(const e of this._ranges)t&&!e.end.isAfter(t.end)||(t=e);return t?new Va(t.start,t.end):null}getFirstPosition(){const t=this.getFirstRange();return t?t.start.clone():null}getLastPosition(){const t=this.getLastRange();return t?t.end.clone():null}setTo(t,e,n){if(null===t)this._setRanges([]);else if(t instanceof Ba)this._setRanges(t.getRanges(),t.isBackward);else if(t&&"function"==typeof t.getRanges)this._setRanges(t.getRanges(),t.isBackward);else if(t instanceof Va)this._setRanges([t],!!e&&!!e.backward);else if(t instanceof Aa)this._setRanges([new Va(t)]);else if(t instanceof va){const r=!!n&&!!n.backward;let i;if("in"==e)i=Va._createIn(t);else if("on"==e)i=Va._createOn(t);else{if(void 0===e)throw new hn.a("model-selection-setto-required-second-parameter",[this,t]);i=new Va(Aa._createAt(t,e))}this._setRanges([i],r)}else{if(!_n(t))throw new hn.a("model-selection-setto-not-selectable",[this,t]);this._setRanges(t,e&&!!e.backward)}}_setRanges(t,e=!1){const n=(t=Array.from(t)).some(e=>{if(!(e instanceof Va))throw new hn.a("model-selection-set-ranges-not-range",[this,t]);return this._ranges.every(t=>!t.isEqual(e))});if(t.length!==this._ranges.length||n){this._removeAllRanges();for(const e of t)this._pushRange(e);this._lastRangeBackward=!!e,this.fire("change:range",{directChange:!0})}}setFocus(t,e){if(null===this.anchor)throw new hn.a("model-selection-setfocus-no-ranges",[this,t]);const n=Aa._createAt(t,e);if("same"==n.compareWith(this.focus))return;const r=this.anchor;this._ranges.length&&this._popRange(),"before"==n.compareWith(r)?(this._pushRange(new Va(n,r)),this._lastRangeBackward=!0):(this._pushRange(new Va(r,n)),this._lastRangeBackward=!1),this.fire("change:range",{directChange:!0})}getAttribute(t){return this._attrs.get(t)}getAttributes(){return this._attrs.entries()}getAttributeKeys(){return this._attrs.keys()}hasAttribute(t){return this._attrs.has(t)}removeAttribute(t){this.hasAttribute(t)&&(this._attrs.delete(t),this.fire("change:attribute",{attributeKeys:[t],directChange:!0}))}setAttribute(t,e){this.getAttribute(t)!==e&&(this._attrs.set(t,e),this.fire("change:attribute",{attributeKeys:[t],directChange:!0}))}getSelectedElement(){return 1!==this.rangeCount?null:this.getFirstRange().getContainedElement()}is(t){return"selection"===t||"model:selection"===t}*getSelectedBlocks(){const t=new WeakSet;for(const e of this.getRanges()){const n=Da(e.start,t);n&&Ra(n,e)&&(yield n);for(const i of e.getWalker()){const n=i.item;"elementEnd"==i.type&&Fa(n,t,e)&&(yield n)}const r=Da(e.end,t);r&&!e.end.isTouching(Aa._createAt(r,0))&&Ra(r,e)&&(yield r)}}containsEntireContent(t=this.anchor.root){const e=Aa._createAt(t,0),n=Aa._createAt(t,"end");return e.isTouching(this.getFirstPosition())&&n.isTouching(this.getLastPosition())}_pushRange(t){this._checkRange(t),this._ranges.push(new Va(t.start,t.end))}_checkRange(t){for(let e=0;e<this._ranges.length;e++)if(t.isIntersecting(this._ranges[e]))throw new hn.a("model-selection-range-intersects",[this,t],{addedRange:t,intersectingRange:this._ranges[e]})}_removeAllRanges(){for(;this._ranges.length>0;)this._popRange()}_popRange(){this._ranges.pop()}}function Ha(t,e){return!e.has(t)&&(e.add(t),t.root.document.model.schema.isBlock(t)&&t.parent)}function Fa(t,e,n){return Ha(t,e)&&Ra(t,n)}function Da(t,e){const n=t.parent.root.document.model.schema,r=t.parent.getAncestors({parentFirst:!0,includeSelf:!0});let i=!1;const o=r.find(t=>!i&&(i=n.isLimit(t),!i&&Ha(t,e)));return r.forEach(t=>e.add(t)),o}function Ra(t,e){const n=function(t){const e=t.root.document.model.schema;let n=t.parent;for(;n;){if(e.isBlock(n))return n;n=n.parent}}(t);return!n||!e.containsRange(Va._createOn(n),!0)}On(Ba,mn);class Na extends Va{constructor(t,e){super(t,e),$a.call(this)}detach(){this.stopListening()}is(t){return"liveRange"===t||"model:liveRange"===t||"range"==t||"model:range"===t}toRange(){return new Va(this.start,this.end)}static fromRange(t){return new Na(t.start,t.end)}}function $a(){this.listenTo(this.root.document.model,"applyOperation",(t,e)=>{const n=e[0];n.isDocumentOperation&&Ua.call(this,n)},{priority:"low"})}function Ua(t){const e=this.getTransformedByOperation(t),n=Va._createFromRanges(e),r=!n.isEqual(this),i=function(t,e){switch(e.type){case"insert":return t.containsPosition(e.position);case"move":case"remove":case"reinsert":case"merge":return t.containsPosition(e.sourcePosition)||t.start.isEqual(e.sourcePosition)||t.containsPosition(e.targetPosition);case"split":return t.containsPosition(e.splitPosition)||t.containsPosition(e.insertionPosition)}return!1}(this,t);let o=null;if(r){"$graveyard"==n.root.rootName&&(o="remove"==t.type?t.sourcePosition:t.deletionPosition);const e=this.toRange();this.start=n.start,this.end=n.end,this.fire("change:range",e,{deletionPosition:o})}else i&&this.fire("change:content",this.toRange(),{deletionPosition:o})}On(Na,mn);class qa{constructor(t){this._selection=new Wa(t),this._selection.delegate("change:range").to(this),this._selection.delegate("change:attribute").to(this),this._selection.delegate("change:marker").to(this)}get isCollapsed(){return this._selection.isCollapsed}get anchor(){return this._selection.anchor}get focus(){return this._selection.focus}get rangeCount(){return this._selection.rangeCount}get hasOwnRange(){return this._selection.hasOwnRange}get isBackward(){return this._selection.isBackward}get isGravityOverridden(){return this._selection.isGravityOverridden}get markers(){return this._selection.markers}get _ranges(){return this._selection._ranges}getRanges(){return this._selection.getRanges()}getFirstPosition(){return this._selection.getFirstPosition()}getLastPosition(){return this._selection.getLastPosition()}getFirstRange(){return this._selection.getFirstRange()}getLastRange(){return this._selection.getLastRange()}getSelectedBlocks(){return this._selection.getSelectedBlocks()}getSelectedElement(){return this._selection.getSelectedElement()}containsEntireContent(t){return this._selection.containsEntireContent(t)}destroy(){this._selection.destroy()}getAttributeKeys(){return this._selection.getAttributeKeys()}getAttributes(){return this._selection.getAttributes()}getAttribute(t){return this._selection.getAttribute(t)}hasAttribute(t){return this._selection.hasAttribute(t)}refresh(){this._selection._updateMarkers(),this._selection._updateAttributes(!1)}observeMarkers(t){this._selection.observeMarkers(t)}is(t){return"selection"===t||"model:selection"==t||"documentSelection"==t||"model:documentSelection"==t}_setFocus(t,e){this._selection.setFocus(t,e)}_setTo(t,e,n){this._selection.setTo(t,e,n)}_setAttribute(t,e){this._selection.setAttribute(t,e)}_removeAttribute(t){this._selection.removeAttribute(t)}_getStoredAttributes(){return this._selection._getStoredAttributes()}_overrideGravity(){return this._selection.overrideGravity()}_restoreGravity(t){this._selection.restoreGravity(t)}static _getStoreAttributeKey(t){return"selection:"+t}static _isStoreAttributeKey(t){return t.startsWith("selection:")}}On(qa,mn);class Wa extends Ba{constructor(t){super(),this.markers=new zn({idProperty:"name"}),this._model=t.model,this._document=t,this._attributePriority=new Map,this._selectionRestorePosition=null,this._hasChangedRange=!1,this._overriddenGravityRegister=new Set,this._observedMarkers=new Set,this.listenTo(this._model,"applyOperation",(t,e)=>{const n=e[0];n.isDocumentOperation&&"marker"!=n.type&&"rename"!=n.type&&"noop"!=n.type&&(0==this._ranges.length&&this._selectionRestorePosition&&this._fixGraveyardSelection(this._selectionRestorePosition),this._selectionRestorePosition=null,this._hasChangedRange&&(this._hasChangedRange=!1,this.fire("change:range",{directChange:!1})))},{priority:"lowest"}),this.on("change:range",()=>{for(const t of this.getRanges())if(!this._document._validateSelectionRange(t))throw new hn.a("document-selection-wrong-position",this,{range:t})}),this.listenTo(this._model.markers,"update",(t,e,n,r)=>{this._updateMarker(e,r)}),this.listenTo(this._document,"change",(t,e)=>{!function(t,e){const n=t.document.differ;for(const r of n.getChanges()){if("insert"!=r.type)continue;const n=r.position.parent;r.length===n.maxOffset&&t.enqueueChange(e,t=>{const e=Array.from(n.getAttributeKeys()).filter(t=>t.startsWith("selection:"));for(const r of e)t.removeAttribute(r,n)})}}(this._model,e)})}get isCollapsed(){return 0===this._ranges.length?this._document._getDefaultRange().isCollapsed:super.isCollapsed}get anchor(){return super.anchor||this._document._getDefaultRange().start}get focus(){return super.focus||this._document._getDefaultRange().end}get rangeCount(){return this._ranges.length?this._ranges.length:1}get hasOwnRange(){return this._ranges.length>0}get isGravityOverridden(){return!!this._overriddenGravityRegister.size}destroy(){for(let t=0;t<this._ranges.length;t++)this._ranges[t].detach();this.stopListening()}*getRanges(){this._ranges.length?yield*super.getRanges():yield this._document._getDefaultRange()}getFirstRange(){return super.getFirstRange()||this._document._getDefaultRange()}getLastRange(){return super.getLastRange()||this._document._getDefaultRange()}setTo(t,e,n){super.setTo(t,e,n),this._updateAttributes(!0),this._updateMarkers()}setFocus(t,e){super.setFocus(t,e),this._updateAttributes(!0),this._updateMarkers()}setAttribute(t,e){if(this._setAttribute(t,e)){const e=[t];this.fire("change:attribute",{attributeKeys:e,directChange:!0})}}removeAttribute(t){if(this._removeAttribute(t)){const e=[t];this.fire("change:attribute",{attributeKeys:e,directChange:!0})}}overrideGravity(){const t=un();return this._overriddenGravityRegister.add(t),1===this._overriddenGravityRegister.size&&this._updateAttributes(!0),t}restoreGravity(t){if(!this._overriddenGravityRegister.has(t))throw new hn.a("document-selection-gravity-wrong-restore",this,{uid:t});this._overriddenGravityRegister.delete(t),this.isGravityOverridden||this._updateAttributes(!0)}observeMarkers(t){this._observedMarkers.add(t),this._updateMarkers()}_popRange(){this._ranges.pop().detach()}_pushRange(t){const e=this._prepareRange(t);e&&this._ranges.push(e)}_prepareRange(t){if(this._checkRange(t),t.root==this._document.graveyard)return;const e=Na.fromRange(t);return e.on("change:range",(t,n,r)=>{if(this._hasChangedRange=!0,e.root==this._document.graveyard){this._selectionRestorePosition=r.deletionPosition;const t=this._ranges.indexOf(e);this._ranges.splice(t,1),e.detach()}}),e}_updateMarkers(){if(!this._observedMarkers.size)return;const t=[];let e=!1;for(const r of this._model.markers){const e=r.name.split(":",1)[0];if(!this._observedMarkers.has(e))continue;const n=r.getRange();for(const i of this.getRanges())n.containsRange(i,!i.isCollapsed)&&t.push(r)}const n=Array.from(this.markers);for(const r of t)this.markers.has(r)||(this.markers.add(r),e=!0);for(const r of Array.from(this.markers))t.includes(r)||(this.markers.remove(r),e=!0);e&&this.fire("change:marker",{oldMarkers:n,directChange:!1})}_updateMarker(t,e){const n=t.name.split(":",1)[0];if(!this._observedMarkers.has(n))return;let r=!1;const i=Array.from(this.markers),o=this.markers.has(t);if(e){let n=!1;for(const t of this.getRanges())if(e.containsRange(t,!t.isCollapsed)){n=!0;break}n&&!o?(this.markers.add(t),r=!0):!n&&o&&(this.markers.remove(t),r=!0)}else o&&(this.markers.remove(t),r=!0);r&&this.fire("change:marker",{oldMarkers:i,directChange:!1})}_updateAttributes(t){const e=Bn(this._getSurroundingAttributes()),n=Bn(this.getAttributes());if(t)this._attributePriority=new Map,this._attrs=new Map;else for(const[i,o]of this._attributePriority)"low"==o&&(this._attrs.delete(i),this._attributePriority.delete(i));this._setAttributesTo(e);const r=[];for(const[i,o]of this.getAttributes())n.has(i)&&n.get(i)===o||r.push(i);for(const[i]of n)this.hasAttribute(i)||r.push(i);r.length>0&&this.fire("change:attribute",{attributeKeys:r,directChange:!1})}_setAttribute(t,e,n=!0){const r=n?"normal":"low";return("low"!=r||"normal"!=this._attributePriority.get(t))&&(super.getAttribute(t)!==e&&(this._attrs.set(t,e),this._attributePriority.set(t,r),!0))}_removeAttribute(t,e=!0){const n=e?"normal":"low";return("low"!=n||"normal"!=this._attributePriority.get(t))&&(this._attributePriority.set(t,n),!!super.hasAttribute(t)&&(this._attrs.delete(t),!0))}_setAttributesTo(t){const e=new Set;for(const[n,r]of this.getAttributes())t.get(n)!==r&&this._removeAttribute(n,!1);for(const[n,r]of t)this._setAttribute(n,r,!1)&&e.add(n);return e}*_getStoredAttributes(){const t=this.getFirstPosition().parent;if(this.isCollapsed&&t.isEmpty)for(const e of t.getAttributeKeys())if(e.startsWith("selection:")){const n=e.substr("selection:".length);yield[n,t.getAttribute(e)]}}_getSurroundingAttributes(){const t=this.getFirstPosition(),e=this._model.schema;let n=null;if(this.isCollapsed){const r=t.textNode?t.textNode:t.nodeBefore,i=t.textNode?t.textNode:t.nodeAfter;if(this.isGravityOverridden||(n=Ga(r)),n||(n=Ga(i)),!this.isGravityOverridden&&!n){let t=r;for(;t&&!e.isInline(t)&&!n;)t=t.previousSibling,n=Ga(t)}if(!n){let t=i;for(;t&&!e.isInline(t)&&!n;)t=t.nextSibling,n=Ga(t)}n||(n=this._getStoredAttributes())}else{const t=this.getFirstRange();for(const r of t){if(r.item.is("element")&&e.isObject(r.item))break;if("text"==r.type){n=r.item.getAttributes();break}}}return n}_fixGraveyardSelection(t){const e=this._model.schema.getNearestSelectionRange(t);e&&this._pushRange(e)}}function Ga(t){return t instanceof ya||t instanceof wa?t.getAttributes():null}class Ya{constructor(t){this._dispatchers=t}add(t){for(const e of this._dispatchers)t(e);return this}}var Ka=function(t){return tn(t,5)};class Qa extends Ya{elementToElement(t){return this.add(function(t){return(t=Ka(t)).view=Za(t.view,"container"),e=>{var n;if(e.on("insert:"+t.model,(n=t.view,(t,e,r)=>{const i=n(e.item,r);if(!i)return;if(!r.consumable.consume(e.item,"insert"))return;const o=r.mapper.toViewPosition(e.range.start);r.mapper.bindElements(e.item,i),r.writer.insert(o,i)}),{priority:t.converterPriority||"normal"}),t.triggerBy){if(t.triggerBy.attributes)for(const n of t.triggerBy.attributes)e._mapReconversionTriggerEvent(t.model,`attribute:${n}:${t.model}`);if(t.triggerBy.children)for(const n of t.triggerBy.children)e._mapReconversionTriggerEvent(t.model,"insert:"+n),e._mapReconversionTriggerEvent(t.model,"remove:"+n)}}}(t))}attributeToElement(t){return this.add(function(t){t=Ka(t);let e="attribute:"+(t.model.key?t.model.key:t.model);if(t.model.name&&(e+=":"+t.model.name),t.model.values)for(const r of t.model.values)t.view[r]=Za(t.view[r],"attribute");else t.view=Za(t.view,"attribute");const n=ts(t);return r=>{r.on(e,function(t){return(e,n,r)=>{const i=t(n.attributeOldValue,r),o=t(n.attributeNewValue,r);if(!i&&!o)return;if(!r.consumable.consume(n.item,e.name))return;const a=r.writer,s=a.document.selection;if(n.item instanceof Ba||n.item instanceof qa)a.wrap(s.getFirstRange(),o);else{let t=r.mapper.toViewRange(n.range);null!==n.attributeOldValue&&i&&(t=a.unwrap(t,i)),null!==n.attributeNewValue&&o&&a.wrap(t,o)}}}(n),{priority:t.converterPriority||"normal"})}}(t))}attributeToAttribute(t){return this.add(function(t){t=Ka(t);let e="attribute:"+(t.model.key?t.model.key:t.model);if(t.model.name&&(e+=":"+t.model.name),t.model.values)for(const r of t.model.values)t.view[r]=es(t.view[r]);else t.view=es(t.view);const n=ts(t);return r=>{var i;r.on(e,(i=n,(t,e,n)=>{const r=i(e.attributeOldValue,n),o=i(e.attributeNewValue,n);if(!r&&!o)return;if(!n.consumable.consume(e.item,t.name))return;const a=n.mapper.toViewElement(e.item),s=n.writer;if(!a)throw new hn.a("conversion-attribute-to-attribute-on-text",[e,n]);if(null!==e.attributeOldValue&&r)if("class"==r.key){const t=jn(r.value);for(const e of t)s.removeClass(e,a)}else if("style"==r.key){const t=Object.keys(r.value);for(const e of t)s.removeStyle(e,a)}else s.removeAttribute(r.key,a);if(null!==e.attributeNewValue&&o)if("class"==o.key){const t=jn(o.value);for(const e of t)s.addClass(e,a)}else if("style"==o.key){const t=Object.keys(o.value);for(const e of t)s.setStyle(e,o.value[e],a)}else s.setAttribute(o.key,o.value,a)}),{priority:t.converterPriority||"normal"})}}(t))}markerToElement(t){return this.add(function(t){return(t=Ka(t)).view=Za(t.view,"ui"),e=>{var n;e.on("addMarker:"+t.model,(n=t.view,(t,e,r)=>{e.isOpening=!0;const i=n(e,r);e.isOpening=!1;const o=n(e,r);if(!i||!o)return;const a=e.markerRange;if(a.isCollapsed&&!r.consumable.consume(a,t.name))return;for(const n of a)if(!r.consumable.consume(n.item,t.name))return;const s=r.mapper,c=r.writer;c.insert(s.toViewPosition(a.start),i),r.mapper.bindElementToMarker(i,e.markerName),a.isCollapsed||(c.insert(s.toViewPosition(a.end),o),r.mapper.bindElementToMarker(o,e.markerName)),t.stop()}),{priority:t.converterPriority||"normal"}),e.on("removeMarker:"+t.model,(t.view,(t,e,n)=>{const r=n.mapper.markerNameToElements(e.markerName);if(r){for(const t of r)n.mapper.unbindElementFromMarkerName(t,e.markerName),n.writer.clear(n.writer.createRangeOn(t),t);n.writer.clearClonedElementsGroup(e.markerName),t.stop()}}),{priority:t.converterPriority||"normal"})}}(t))}markerToHighlight(t){return this.add(function(t){return e=>{var n;e.on("addMarker:"+t.model,(n=t.view,(t,e,r)=>{if(!e.item)return;if(!(e.item instanceof Ba||e.item instanceof qa||e.item.is("$textProxy")))return;const i=ns(n,e,r);if(!i)return;if(!r.consumable.consume(e.item,t.name))return;const o=r.writer,a=Xa(o,i),s=o.document.selection;if(e.item instanceof Ba||e.item instanceof qa)o.wrap(s.getFirstRange(),a,s);else{const t=r.mapper.toViewRange(e.range),n=o.wrap(t,a);for(const i of n.getItems())if(i.is("attributeElement")&&i.isSimilar(a)){r.mapper.bindElementToMarker(i,e.markerName);break}}}),{priority:t.converterPriority||"normal"}),e.on("addMarker:"+t.model,function(t){return(e,n,r)=>{if(!n.item)return;if(!(n.item instanceof _a))return;const i=ns(t,n,r);if(!i)return;if(!r.consumable.test(n.item,e.name))return;const o=r.mapper.toViewElement(n.item);if(o&&o.getCustomProperty("addHighlight")){r.consumable.consume(n.item,e.name);for(const t of Va._createIn(n.item))r.consumable.consume(t.item,e.name);o.getCustomProperty("addHighlight")(o,i,r.writer),r.mapper.bindElementToMarker(o,n.markerName)}}}(t.view),{priority:t.converterPriority||"normal"}),e.on("removeMarker:"+t.model,function(t){return(e,n,r)=>{if(n.markerRange.isCollapsed)return;const i=ns(t,n,r);if(!i)return;const o=Xa(r.writer,i),a=r.mapper.markerNameToElements(n.markerName);if(a){for(const t of a)r.mapper.unbindElementFromMarkerName(t,n.markerName),t.is("attributeElement")?r.writer.unwrap(r.writer.createRangeOn(t),o):t.getCustomProperty("removeHighlight")(t,i.id,r.writer);r.writer.clearClonedElementsGroup(n.markerName),e.stop()}}}(t.view),{priority:t.converterPriority||"normal"})}}(t))}markerToData(t){return this.add(function(t){const e=(t=Ka(t)).model;return t.view||(t.view=n=>({group:e,name:n.substr(t.model.length+1)})),n=>{var r;n.on("addMarker:"+e,(r=t.view,(t,e,n)=>{const i=r(e.markerName,n);if(!i)return;const o=e.markerRange;n.consumable.consume(o,t.name)&&(Ja(o,!1,n,e,i),Ja(o,!0,n,e,i),t.stop())}),{priority:t.converterPriority||"normal"}),n.on("removeMarker:"+e,function(t){return(e,n,r)=>{const i=t(n.markerName,r);if(!i)return;const o=r.mapper.markerNameToElements(n.markerName);if(o){for(const t of o)r.mapper.unbindElementFromMarkerName(t,n.markerName),t.is("containerElement")?(a(`data-${i.group}-start-before`,t),a(`data-${i.group}-start-after`,t),a(`data-${i.group}-end-before`,t),a(`data-${i.group}-end-after`,t)):r.writer.clear(r.writer.createRangeOn(t),t);r.writer.clearClonedElementsGroup(n.markerName),e.stop()}function a(t,e){if(e.hasAttribute(t)){const n=new Set(e.getAttribute(t).split(","));n.delete(i.name),0==n.size?r.writer.removeAttribute(t,e):r.writer.setAttribute(t,Array.from(n).join(","),e)}}}}(t.view),{priority:t.converterPriority||"normal"})}}(t))}}function Xa(t,e){const n=t.createAttributeElement("span",e.attributes);return e.classes&&n._addClass(e.classes),e.priority&&(n._priority=e.priority),n._id=e.id,n}function Ja(t,e,n,r,i){const o=e?t.start:t.end;if(n.schema.checkChild(o,"$text"))!function(t,e,n,r,i){const o=`${i.group}-${e?"start":"end"}`,a=i.name?{name:i.name}:null,s=n.writer.createUIElement(o,a);n.writer.insert(t,s),n.mapper.bindElementToMarker(s,r.markerName)}(n.mapper.toViewPosition(o),e,n,r,i);else{let t,a;e&&o.nodeAfter||!e&&!o.nodeBefore?(t=o.nodeAfter,a=!0):(t=o.nodeBefore,a=!1),function(t,e,n,r,i,o){const a=`data-${o.group}-${e?"start":"end"}-${n?"before":"after"}`,s=t.hasAttribute(a)?t.getAttribute(a).split(","):[];s.unshift(o.name),r.writer.setAttribute(a,s.join(","),t),r.mapper.bindElementToMarker(t,i.markerName)}(n.mapper.toViewElement(t),e,a,n,r,i)}}function Za(t,e){return"function"==typeof t?t:(n,r)=>function(t,e,n){let r;"string"==typeof t&&(t={name:t});const i=e.writer,o=Object.assign({},t.attributes);if("container"==n)r=i.createContainerElement(t.name,o);else if("attribute"==n){const e={priority:t.priority||ai.DEFAULT_PRIORITY};r=i.createAttributeElement(t.name,o,e)}else r=i.createUIElement(t.name,o);if(t.styles){const e=Object.keys(t.styles);for(const n of e)i.setStyle(n,t.styles[n],r)}if(t.classes){const e=t.classes;if("string"==typeof e)i.addClass(e,r);else for(const t of e)i.addClass(t,r)}return r}(t,r,e)}function ts(t){return t.model.values?(e,n)=>{const r=t.view[e];return r?r(e,n):null}:t.view}function es(t){return"string"==typeof t?e=>({key:t,value:e}):"object"==typeof t?t.value?()=>t:e=>({key:t.key,value:e}):t}function ns(t,e,n){const r="function"==typeof t?t(e,n):t;return r?(r.priority||(r.priority=10),r.id||(r.id=e.markerName),r):null}function rs(t){const{schema:e,document:n}=t.model;for(const r of n.getRootNames()){const i=n.getRoot(r);if(i.isEmpty&&!e.checkChild(i,"$text")&&e.checkChild(i,"paragraph"))return t.insertElement("paragraph",i),!0}return!1}function is(t,e,n){const r=n.createContext(t);return!!n.checkChild(r,"paragraph")&&!!n.checkChild(r.push("paragraph"),e)}function os(t,e){const n=e.createElement("paragraph");return e.insert(n,t),e.createPositionAt(n,0)}class as extends Ya{elementToElement(t){return this.add(ss(t))}elementToAttribute(t){return this.add(function(t){us(t=Ka(t));const e=ds(t,!1),n=cs(t.view),r=n?"element:"+n:"element";return n=>{n.on(r,e,{priority:t.converterPriority||"low"})}}(t))}attributeToAttribute(t){return this.add(function(t){t=Ka(t);let e=null;("string"==typeof t.view||t.view.key)&&(e=function(t){"string"==typeof t.view&&(t.view={key:t.view});const e=t.view.key;let n;if("class"==e||"style"==e)n={["class"==e?"classes":"styles"]:t.view.value};else{const r=void 0===t.view.value?/[\s\S]*/:t.view.value;n={attributes:{[e]:r}}}return t.view.name&&(n.name=t.view.name),t.view=n,e}(t)),us(t,e);const n=ds(t,!0);return e=>{e.on("element",n,{priority:t.converterPriority||"low"})}}(t))}elementToMarker(t){return Object(hn.c)("upcast-helpers-element-to-marker-deprecated"),this.add(function(t){return function(t){const e=t.model;t.model=(t,n)=>{const r="string"==typeof e?e:e(t,n);return n.writer.createElement("$marker",{"data-name":r})}}(t=Ka(t)),ss(t)}(t))}dataToMarker(t){return this.add(function(t){(t=Ka(t)).model||(t.model=e=>e?t.view+":"+e:t.view);const e=ls(hs(t,"start")),n=ls(hs(t,"end"));return r=>{r.on("element:"+t.view+"-start",e,{priority:t.converterPriority||"normal"}),r.on("element:"+t.view+"-end",n,{priority:t.converterPriority||"normal"});const i=dn.get("low"),o=dn.get("highest"),a=dn.get(t.converterPriority)/o;r.on("element",function(t){return(e,n,r)=>{const i="data-"+t.view;function o(e,i){for(const o of i){const i=t.model(o,r),a=r.writer.createElement("$marker",{"data-name":i});r.writer.insert(a,e),n.modelCursor.isEqual(e)?n.modelCursor=n.modelCursor.getShiftedBy(1):n.modelCursor=n.modelCursor._getTransformedByInsertion(e,1),n.modelRange=n.modelRange._getTransformedByInsertion(e,1)[0]}}n.modelRange||(n=Object.assign(n,r.convertChildren(n.viewItem,n.modelCursor))),r.consumable.consume(n.viewItem,{attributes:i+"-end-after"})&&o(n.modelRange.end,n.viewItem.getAttribute(i+"-end-after").split(",")),r.consumable.consume(n.viewItem,{attributes:i+"-start-after"})&&o(n.modelRange.end,n.viewItem.getAttribute(i+"-start-after").split(",")),r.consumable.consume(n.viewItem,{attributes:i+"-end-before"})&&o(n.modelRange.start,n.viewItem.getAttribute(i+"-end-before").split(",")),r.consumable.consume(n.viewItem,{attributes:i+"-start-before"})&&o(n.modelRange.start,n.viewItem.getAttribute(i+"-start-before").split(","))}}(t),{priority:i+a})}}(t))}}function ss(t){const e=ls(t=Ka(t)),n=cs(t.view),r=n?"element:"+n:"element";return n=>{n.on(r,e,{priority:t.converterPriority||"normal"})}}function cs(t){return"string"==typeof t?t:"object"==typeof t&&"string"==typeof t.name?t.name:null}function ls(t){const e=new Hn(t.view);return(n,r,i)=>{const o=e.match(r.viewItem);if(!o)return;const a=o.match;if(a.name=!0,!i.consumable.test(r.viewItem,a))return;const s=function(t,e,n){return t instanceof Function?t(e,n):n.writer.createElement(t)}(t.model,r.viewItem,i);s&&i.safeInsert(s,r.modelCursor)&&(i.consumable.consume(r.viewItem,a),i.convertChildren(r.viewItem,s),i.updateConversionResult(s,r))}}function us(t,e=null){const n=null===e||(t=>t.getAttribute(e)),r="object"!=typeof t.model?t.model:t.model.key,i="object"!=typeof t.model||void 0===t.model.value?n:t.model.value;t.model={key:r,value:i}}function ds(t,e){const n=new Hn(t.view);return(r,i,o)=>{const a=n.match(i.viewItem);if(!a)return;const s=t.model.key,c="function"==typeof t.model.value?t.model.value(i.viewItem,o):t.model.value;null!==c&&(function(t,e){const n="function"==typeof t?t(e):t;return!("object"==typeof n&&!cs(n))&&(!n.classes&&!n.attributes&&!n.styles)}(t.view,i.viewItem)?a.match.name=!0:delete a.match.name,o.consumable.test(i.viewItem,a.match)&&(i.modelRange||(i=Object.assign(i,o.convertChildren(i.viewItem,i.modelCursor))),function(t,e,n,r){let i=!1;for(const o of Array.from(t.getItems({shallow:n})))r.schema.checkAttribute(o,e.key)&&(r.writer.setAttribute(e.key,e.value,o),i=!0);return i}(i.modelRange,{key:s,value:c},e,o)&&o.consumable.consume(i.viewItem,a.match)))}}function hs(t,e){const n={};return n.view=t.view+"-"+e,n.model=(e,n)=>{const r=e.getAttribute("name"),i=t.model(r,n);return n.writer.createElement("$marker",{"data-name":i})},n}class fs{constructor(t,e){this.model=t,this.view=new ga(e),this.mapper=new Sa,this.downcastDispatcher=new Pa({mapper:this.mapper,schema:t.schema});const n=this.model.document,r=n.selection,i=this.model.markers;this.listenTo(this.model,"_beforeChanges",()=>{this.view._disableRendering(!0)},{priority:"highest"}),this.listenTo(this.model,"_afterChanges",()=>{this.view._disableRendering(!1)},{priority:"lowest"}),this.listenTo(n,"change",()=>{this.view.change(t=>{this.downcastDispatcher.convertChanges(n.differ,i,t),this.downcastDispatcher.convertSelection(r,i,t)})},{priority:"low"}),this.listenTo(this.view.document,"selectionChange",function(t,e){return(n,r)=>{const i=r.newSelection,o=[];for(const t of i.getRanges())o.push(e.toModelRange(t));const a=t.createSelection(o,{backward:i.isBackward});a.isEqual(t.document.selection)||t.change(t=>{t.setSelection(a)})}}(this.model,this.mapper)),this.downcastDispatcher.on("insert:$text",(t,e,n)=>{if(!n.consumable.consume(e.item,"insert"))return;const r=n.writer,i=n.mapper.toViewPosition(e.range.start),o=r.createText(e.item.data);r.insert(i,o)},{priority:"lowest"}),this.downcastDispatcher.on("remove",(t,e,n)=>{const r=n.mapper.toViewPosition(e.position),i=e.position.getShiftedBy(e.length),o=n.mapper.toViewPosition(i,{isPhantom:!0}),a=n.writer.createRange(r,o),s=n.writer.remove(a.getTrimmed());for(const c of n.writer.createRangeIn(s).getItems())n.mapper.unbindViewElement(c)},{priority:"low"}),this.downcastDispatcher.on("selection",(t,e,n)=>{const r=n.writer,i=r.document.selection;for(const o of i.getRanges())o.isCollapsed&&o.end.parent.isAttached()&&n.writer.mergeAttributes(o.start);r.setSelection(null)},{priority:"low"}),this.downcastDispatcher.on("selection",(t,e,n)=>{const r=e.selection;if(r.isCollapsed)return;if(!n.consumable.consume(r,"selection"))return;const i=[];for(const o of r.getRanges()){const t=n.mapper.toViewRange(o);i.push(t)}n.writer.setSelection(i,{backward:r.isBackward})},{priority:"low"}),this.downcastDispatcher.on("selection",(t,e,n)=>{const r=e.selection;if(!r.isCollapsed)return;if(!n.consumable.consume(r,"selection"))return;const i=n.writer,o=r.getFirstPosition(),a=n.mapper.toViewPosition(o),s=i.breakAttributes(a);i.setSelection(s)},{priority:"low"}),this.view.document.roots.bindTo(this.model.document.roots).using(t=>{if("$graveyard"==t.rootName)return null;const e=new Xr(this.view.document,t.name);return e.rootName=t.rootName,this.mapper.bindElements(t,e),e})}destroy(){this.view.destroy(),this.stopListening()}}On(fs,$r);class ps{constructor(){this._commands=new Map}add(t,e){this._commands.set(t,e)}get(t){return this._commands.get(t)}execute(t,...e){const n=this.get(t);if(!n)throw new hn.a("commandcollection-command-not-found",this,{commandName:t});return n.execute(...e)}*names(){yield*this._commands.keys()}*commands(){yield*this._commands.values()}[Symbol.iterator](){return this._commands[Symbol.iterator]()}destroy(){for(const t of this.commands())t.destroy()}}class ms{constructor(){this._consumables=new Map}add(t,e){let n;t.is("$text")||t.is("documentFragment")?this._consumables.set(t,!0):(this._consumables.has(t)?n=this._consumables.get(t):(n=new bs(t),this._consumables.set(t,n)),n.add(e))}test(t,e){const n=this._consumables.get(t);return void 0===n?null:t.is("$text")||t.is("documentFragment")?n:n.test(e)}consume(t,e){return!!this.test(t,e)&&(t.is("$text")||t.is("documentFragment")?this._consumables.set(t,!1):this._consumables.get(t).consume(e),!0)}revert(t,e){const n=this._consumables.get(t);void 0!==n&&(t.is("$text")||t.is("documentFragment")?this._consumables.set(t,!0):n.revert(e))}static consumablesFromElement(t){const e={element:t,name:!0,attributes:[],classes:[],styles:[]},n=t.getAttributeKeys();for(const o of n)"style"!=o&&"class"!=o&&e.attributes.push(o);const r=t.getClassNames();for(const o of r)e.classes.push(o);const i=t.getStyleNames();for(const o of i)e.styles.push(o);return e}static createFrom(t,e){if(e||(e=new ms(t)),t.is("$text"))return e.add(t),e;t.is("element")&&e.add(t,ms.consumablesFromElement(t)),t.is("documentFragment")&&e.add(t);for(const n of t.getChildren())e=ms.createFrom(n,e);return e}}class bs{constructor(t){this.element=t,this._canConsumeName=null,this._consumables={attributes:new Map,styles:new Map,classes:new Map}}add(t){t.name&&(this._canConsumeName=!0);for(const e in this._consumables)e in t&&this._add(e,t[e])}test(t){if(t.name&&!this._canConsumeName)return this._canConsumeName;for(const e in this._consumables)if(e in t){const n=this._test(e,t[e]);if(!0!==n)return n}return!0}consume(t){t.name&&(this._canConsumeName=!1);for(const e in this._consumables)e in t&&this._consume(e,t[e])}revert(t){t.name&&(this._canConsumeName=!0);for(const e in this._consumables)e in t&&this._revert(e,t[e])}_add(t,e){const n=Et(e)?e:[e],r=this._consumables[t];for(const i of n){if("attributes"===t&&("class"===i||"style"===i))throw new hn.a("viewconsumable-invalid-attribute",this);if(r.set(i,!0),"styles"===t)for(const t of this.element.document.stylesProcessor.getRelatedStyles(i))r.set(t,!0)}}_test(t,e){const n=Et(e)?e:[e],r=this._consumables[t];for(const i of n)if("attributes"!==t||"class"!==i&&"style"!==i){const t=r.get(i);if(void 0===t)return null;if(!t)return!1}else{const t="class"==i?"classes":"styles",e=this._test(t,[...this._consumables[t].keys()]);if(!0!==e)return e}return!0}_consume(t,e){const n=Et(e)?e:[e],r=this._consumables[t];for(const i of n)if("attributes"!==t||"class"!==i&&"style"!==i){if(r.set(i,!1),"styles"==t)for(const t of this.element.document.stylesProcessor.getRelatedStyles(i))r.set(t,!1)}else{const t="class"==i?"classes":"styles";this._consume(t,[...this._consumables[t].keys()])}}_revert(t,e){const n=Et(e)?e:[e],r=this._consumables[t];for(const i of n)if("attributes"!==t||"class"!==i&&"style"!==i)!1===r.get(i)&&r.set(i,!0);else{const t="class"==i?"classes":"styles";this._revert(t,[...this._consumables[t].keys()])}}}class gs{constructor(){this._sourceDefinitions={},this._attributeProperties={},this.decorate("checkChild"),this.decorate("checkAttribute"),this.on("checkAttribute",(t,e)=>{e[0]=new vs(e[0])},{priority:"highest"}),this.on("checkChild",(t,e)=>{e[0]=new vs(e[0]),e[1]=this.getDefinition(e[1])},{priority:"highest"})}register(t,e){if(this._sourceDefinitions[t])throw new hn.a("schema-cannot-register-item-twice",this,{itemName:t});this._sourceDefinitions[t]=[Object.assign({},e)],this._clearCache()}extend(t,e){if(!this._sourceDefinitions[t])throw new hn.a("schema-cannot-extend-missing-item",this,{itemName:t});this._sourceDefinitions[t].push(Object.assign({},e)),this._clearCache()}getDefinitions(){return this._compiledDefinitions||this._compile(),this._compiledDefinitions}getDefinition(t){let e;return e="string"==typeof t?t:t.is&&(t.is("$text")||t.is("$textProxy"))?"$text":t.name,this.getDefinitions()[e]}isRegistered(t){return!!this.getDefinition(t)}isBlock(t){const e=this.getDefinition(t);return!(!e||!e.isBlock)}isLimit(t){const e=this.getDefinition(t);return!!e&&!(!e.isLimit&&!e.isObject)}isObject(t){const e=this.getDefinition(t);return!!e&&!!(e.isObject||e.isLimit&&e.isSelectable&&e.isContent)}isInline(t){const e=this.getDefinition(t);return!(!e||!e.isInline)}isSelectable(t){const e=this.getDefinition(t);return!!e&&!(!e.isSelectable&&!e.isObject)}isContent(t){const e=this.getDefinition(t);return!!e&&!(!e.isContent&&!e.isObject)}checkChild(t,e){return!!e&&this._checkContextMatch(e,t)}checkAttribute(t,e){const n=this.getDefinition(t.last);return!!n&&n.allowAttributes.includes(e)}checkMerge(t,e=null){if(t instanceof Aa){const e=t.nodeBefore,n=t.nodeAfter;if(!(e instanceof _a))throw new hn.a("schema-check-merge-no-element-before",this);if(!(n instanceof _a))throw new hn.a("schema-check-merge-no-element-after",this);return this.checkMerge(e,n)}for(const n of e.getChildren())if(!this.checkChild(t,n))return!1;return!0}addChildCheck(t){this.on("checkChild",(e,[n,r])=>{if(!r)return;const i=t(n,r);"boolean"==typeof i&&(e.stop(),e.return=i)},{priority:"high"})}addAttributeCheck(t){this.on("checkAttribute",(e,[n,r])=>{const i=t(n,r);"boolean"==typeof i&&(e.stop(),e.return=i)},{priority:"high"})}setAttributeProperties(t,e){this._attributeProperties[t]=Object.assign(this.getAttributeProperties(t),e)}getAttributeProperties(t){return this._attributeProperties[t]||{}}getLimitElement(t){let e;for(e=t instanceof Aa?t.parent:(t instanceof Va?[t]:Array.from(t.getRanges())).reduce((t,e)=>{const n=e.getCommonAncestor();return t?t.getCommonAncestor(n,{includeSelf:!0}):n},null);!this.isLimit(e)&&e.parent;)e=e.parent;return e}checkAttributeInSelection(t,e){if(t.isCollapsed){const n=[...t.getFirstPosition().getAncestors(),new wa("",t.getAttributes())];return this.checkAttribute(n,e)}{const n=t.getRanges();for(const t of n)for(const n of t)if(this.checkAttribute(n.item,e))return!0}return!1}*getValidRanges(t,e){t=function*(t){for(const e of t)yield*e.getMinimalFlatRanges()}(t);for(const n of t)yield*this._getValidRangesForRange(n,e)}getNearestSelectionRange(t,e="both"){if(this.checkChild(t,"$text"))return new Va(t);let n,r;const i=t.getAncestors().reverse().find(t=>this.isLimit(t))||t.root;"both"!=e&&"backward"!=e||(n=new Oa({boundaries:Va._createIn(i),startPosition:t,direction:"backward"})),"both"!=e&&"forward"!=e||(r=new Oa({boundaries:Va._createIn(i),startPosition:t}));for(const o of function*(t,e){let n=!1;for(;!n;){if(n=!0,t){const e=t.next();e.done||(n=!1,yield{walker:t,value:e.value})}if(e){const t=e.next();t.done||(n=!1,yield{walker:e,value:t.value})}}}(n,r)){const t=o.walker==n?"elementEnd":"elementStart",e=o.value;if(e.type==t&&this.isObject(e.item))return Va._createOn(e.item);if(this.checkChild(e.nextPosition,"$text"))return new Va(e.nextPosition)}return null}findAllowedParent(t,e){let n=t.parent;for(;n;){if(this.checkChild(n,e))return n;if(this.isLimit(n))return null;n=n.parent}return null}removeDisallowedAttributes(t,e){for(const n of t)if(n.is("$text"))Vs(this,n,e);else{const t=Va._createIn(n).getPositions();for(const n of t)Vs(this,n.nodeBefore||n.parent,e)}}createContext(t){return new vs(t)}_clearCache(){this._compiledDefinitions=null}_compile(){const t={},e=this._sourceDefinitions,n=Object.keys(e);for(const r of n)t[r]=ws(e[r],r);for(const r of n)ys(t,r);for(const r of n)ks(t,r);for(const r of n)_s(t,r),Os(t,r);for(const r of n)zs(t,r),As(t,r);this._compiledDefinitions=t}_checkContextMatch(t,e,n=e.length-1){const r=e.getItem(n);if(t.allowIn.includes(r.name)){if(0==n)return!0;{const t=this.getDefinition(r);return this._checkContextMatch(t,e,n-1)}}return!1}*_getValidRangesForRange(t,e){let n=t.start,r=t.start;for(const i of t.getItems({shallow:!0}))i.is("element")&&(yield*this._getValidRangesForRange(Va._createIn(i),e)),this.checkAttribute(i,e)||(n.isEqual(r)||(yield new Va(n,r)),n=Aa._createAfter(i)),r=Aa._createAfter(i);n.isEqual(r)||(yield new Va(n,r))}}On(gs,$r);class vs{constructor(t){if(t instanceof vs)return t;"string"==typeof t?t=[t]:Array.isArray(t)||(t=t.getAncestors({includeSelf:!0})),t[0]&&"string"!=typeof t[0]&&t[0].is("documentFragment")&&t.shift(),this._items=t.map(Cs)}get length(){return this._items.length}get last(){return this._items[this._items.length-1]}[Symbol.iterator](){return this._items[Symbol.iterator]()}push(t){const e=new vs([t]);return e._items=[...this._items,...e._items],e}getItem(t){return this._items[t]}*getNames(){yield*this._items.map(t=>t.name)}endsWith(t){return Array.from(this.getNames()).join(" ").endsWith(t)}startsWith(t){return Array.from(this.getNames()).join(" ").startsWith(t)}}function ws(t,e){const n={name:e,allowIn:[],allowContentOf:[],allowWhere:[],allowAttributes:[],allowAttributesOf:[],inheritTypesFrom:[]};return function(t,e){for(const n of t){const t=Object.keys(n).filter(t=>t.startsWith("is"));for(const r of t)e[r]=n[r]}}(t,n),js(t,n,"allowIn"),js(t,n,"allowContentOf"),js(t,n,"allowWhere"),js(t,n,"allowAttributes"),js(t,n,"allowAttributesOf"),js(t,n,"inheritTypesFrom"),function(t,e){for(const n of t){const t=n.inheritAllFrom;t&&(e.allowContentOf.push(t),e.allowWhere.push(t),e.allowAttributesOf.push(t),e.inheritTypesFrom.push(t))}}(t,n),n}function ys(t,e){for(const n of t[e].allowContentOf)t[n]&&Ms(t,n).forEach(t=>{t.allowIn.push(e)});delete t[e].allowContentOf}function ks(t,e){for(const n of t[e].allowWhere){const r=t[n];if(r){const n=r.allowIn;t[e].allowIn.push(...n)}}delete t[e].allowWhere}function _s(t,e){for(const n of t[e].allowAttributesOf){const r=t[n];if(r){const n=r.allowAttributes;t[e].allowAttributes.push(...n)}}delete t[e].allowAttributesOf}function Os(t,e){const n=t[e];for(const r of n.inheritTypesFrom){const e=t[r];if(e){const t=Object.keys(e).filter(t=>t.startsWith("is"));for(const r of t)r in n||(n[r]=e[r])}}delete n.inheritTypesFrom}function zs(t,e){const n=t[e],r=n.allowIn.filter(e=>t[e]);n.allowIn=Array.from(new Set(r))}function As(t,e){const n=t[e];n.allowAttributes=Array.from(new Set(n.allowAttributes))}function js(t,e,n){for(const r of t)"string"==typeof r[n]?e[n].push(r[n]):Array.isArray(r[n])&&e[n].push(...r[n])}function Ms(t,e){const n=t[e];return(r=t,Object.keys(r).map(t=>r[t])).filter(t=>t.allowIn.includes(n.name));var r}function Cs(t){return"string"==typeof t?{name:t,*getAttributeKeys(){},getAttribute(){}}:{name:t.is("element")?t.name:"$text",*getAttributeKeys(){yield*t.getAttributeKeys()},getAttribute:e=>t.getAttribute(e)}}function Vs(t,e,n){for(const r of e.getAttributeKeys())t.checkAttribute(e,r)||n.removeAttribute(r,e)}class Ss{constructor(t={}){this._splitParts=new Map,this._cursorParents=new Map,this._modelCursor=null,this.conversionApi=Object.assign({},t),this.conversionApi.convertItem=this._convertItem.bind(this),this.conversionApi.convertChildren=this._convertChildren.bind(this),this.conversionApi.safeInsert=this._safeInsert.bind(this),this.conversionApi.updateConversionResult=this._updateConversionResult.bind(this),this.conversionApi.splitToAllowedParent=this._splitToAllowedParent.bind(this),this.conversionApi.getSplitParts=this._getSplitParts.bind(this)}convert(t,e,n=["$root"]){this.fire("viewCleanup",t),this._modelCursor=function(t,e){let n;for(const r of new vs(t)){const t={};for(const e of r.getAttributeKeys())t[e]=r.getAttribute(e);const i=e.createElement(r.name,t);n&&e.append(i,n),n=Aa._createAt(i,0)}return n}(n,e),this.conversionApi.writer=e,this.conversionApi.consumable=ms.createFrom(t),this.conversionApi.store={};const{modelRange:r}=this._convertItem(t,this._modelCursor),i=e.createDocumentFragment();if(r){this._removeEmptyElements();for(const t of Array.from(this._modelCursor.parent.getChildren()))e.append(t,i);i.markers=function(t,e){const n=new Set,r=new Map,i=Va._createIn(t).getItems();for(const o of i)"$marker"==o.name&&n.add(o);for(const o of n){const t=o.getAttribute("data-name"),n=e.createPositionBefore(o);r.has(t)?r.get(t).end=n.clone():r.set(t,new Va(n.clone())),e.remove(o)}return r}(i,e)}return this._modelCursor=null,this._splitParts.clear(),this._cursorParents.clear(),this.conversionApi.writer=null,this.conversionApi.store=null,i}_convertItem(t,e){const n=Object.assign({viewItem:t,modelCursor:e,modelRange:null});if(t.is("element")?this.fire("element:"+t.name,n,this.conversionApi):t.is("$text")?this.fire("text",n,this.conversionApi):this.fire("documentFragment",n,this.conversionApi),n.modelRange&&!(n.modelRange instanceof Va))throw new hn.a("view-conversion-dispatcher-incorrect-result",this);return{modelRange:n.modelRange,modelCursor:n.modelCursor}}_convertChildren(t,e){let n=e.is("position")?e:Aa._createAt(e,0);const r=new Va(n);for(const i of Array.from(t.getChildren())){const t=this._convertItem(i,n);t.modelRange instanceof Va&&(r.end=t.modelRange.end,n=t.modelCursor)}return{modelRange:r,modelCursor:n}}_safeInsert(t,e){const n=this._splitToAllowedParent(t,e);return!!n&&(this.conversionApi.writer.insert(t,n.position),!0)}_updateConversionResult(t,e){const n=this._getSplitParts(t),r=this.conversionApi.writer;e.modelRange||(e.modelRange=r.createRange(r.createPositionBefore(t),r.createPositionAfter(n[n.length-1])));const i=this._cursorParents.get(t);e.modelCursor=i?r.createPositionAt(i,0):e.modelRange.end}_splitToAllowedParent(t,e){const{schema:n,writer:r}=this.conversionApi;let i=n.findAllowedParent(e,t);if(i){if(i===e.parent)return{position:e};this._modelCursor.parent.getAncestors().includes(i)&&(i=null)}if(!i)return is(e,t,n)?{position:os(e,r)}:null;const o=this.conversionApi.writer.split(e,i),a=[];for(const c of o.range.getWalker())if("elementEnd"==c.type)a.push(c.item);else{const t=a.pop(),e=c.item;this._registerSplitPair(t,e)}const s=o.range.end.parent;return this._cursorParents.set(t,s),{position:o.position,cursorParent:s}}_registerSplitPair(t,e){this._splitParts.has(t)||this._splitParts.set(t,[t]);const n=this._splitParts.get(t);this._splitParts.set(e,n),n.push(e)}_getSplitParts(t){let e;return e=this._splitParts.has(t)?this._splitParts.get(t):[t],e}_removeEmptyElements(){let t=!1;for(const e of this._splitParts.keys())e.isEmpty&&(this.conversionApi.writer.remove(e),this._splitParts.delete(e),t=!0);t&&this._removeEmptyElements()}}On(Ss,mn);class xs{getHtml(t){const e=document.implementation.createHTMLDocument("").createElement("div");return e.appendChild(t),e.innerHTML}}class Ts{constructor(t){this._domParser=new DOMParser,this._domConverter=new co(t,{blockFillerMode:"nbsp"}),this._htmlWriter=new xs}toData(t){const e=this._domConverter.viewToDom(t,document);return this._htmlWriter.getHtml(e)}toView(t){const e=this._toDom(t);return this._domConverter.domToView(e)}registerRawContentMatcher(t){this._domConverter.registerRawContentMatcher(t)}_toDom(t){const e=this._domParser.parseFromString(t,"text/html"),n=e.createDocumentFragment(),r=e.body.childNodes;for(;r.length>0;)n.appendChild(r[0]);return n}}class Ps{constructor(t,e){this.model=t,this.mapper=new Sa,this.downcastDispatcher=new Pa({mapper:this.mapper,schema:t.schema}),this.downcastDispatcher.on("insert:$text",(t,e,n)=>{if(!n.consumable.consume(e.item,"insert"))return;const r=n.writer,i=n.mapper.toViewPosition(e.range.start),o=r.createText(e.item.data);r.insert(i,o)},{priority:"lowest"}),this.upcastDispatcher=new Ss({schema:t.schema}),this.viewDocument=new oi(e),this.stylesProcessor=e,this.htmlProcessor=new Ts(this.viewDocument),this.processor=this.htmlProcessor,this._viewWriter=new Vi(this.viewDocument),this.upcastDispatcher.on("text",(t,e,{schema:n,consumable:r,writer:i})=>{let o=e.modelCursor;if(!r.test(e.viewItem))return;if(!n.checkChild(o,"$text")){if(!is(o,"$text",n))return;o=os(o,i)}r.consume(e.viewItem);const a=i.createText(e.viewItem.data);i.insert(a,o),e.modelRange=i.createRange(o,o.getShiftedBy(a.offsetSize)),e.modelCursor=e.modelRange.end},{priority:"lowest"}),this.upcastDispatcher.on("element",(t,e,n)=>{if(!e.modelRange&&n.consumable.consume(e.viewItem,{name:!0})){const{modelRange:t,modelCursor:r}=n.convertChildren(e.viewItem,e.modelCursor);e.modelRange=t,e.modelCursor=r}},{priority:"lowest"}),this.upcastDispatcher.on("documentFragment",(t,e,n)=>{if(!e.modelRange&&n.consumable.consume(e.viewItem,{name:!0})){const{modelRange:t,modelCursor:r}=n.convertChildren(e.viewItem,e.modelCursor);e.modelRange=t,e.modelCursor=r}},{priority:"lowest"}),this.decorate("init"),this.decorate("set"),this.on("init",()=>{this.fire("ready")},{priority:"lowest"}),this.on("ready",()=>{this.model.enqueueChange("transparent",rs)},{priority:"lowest"})}get(t={}){const{rootName:e="main",trim:n="empty"}=t;if(!this._checkIfRootsExists([e]))throw new hn.a("datacontroller-get-non-existent-root",this);const r=this.model.document.getRoot(e);return"empty"!==n||this.model.hasContent(r,{ignoreWhitespaces:!0})?this.stringify(r,t):""}stringify(t,e){const n=this.toView(t,e);return this.processor.toData(n)}toView(t,e){const n=this.viewDocument,r=this._viewWriter;this.mapper.clearBindings();const i=Va._createIn(t),o=new Ci(n);if(this.mapper.bindElements(t,o),this.downcastDispatcher.conversionApi.options=e,this.downcastDispatcher.convertInsert(i,r),!t.is("documentFragment")){const e=function(t){const e=[],n=t.root.document;if(!n)return[];const r=Va._createIn(t);for(const i of n.model.markers){const t=r.getIntersection(i.getRange());t&&e.push([i.name,t])}return e}(t);for(const[t,n]of e)this.downcastDispatcher.convertMarkerAdd(t,n,r)}return delete this.downcastDispatcher.conversionApi.options,o}init(t){if(this.model.document.version)throw new hn.a("datacontroller-init-document-not-empty",this);let e={};if("string"==typeof t?e.main=t:e=t,!this._checkIfRootsExists(Object.keys(e)))throw new hn.a("datacontroller-init-non-existent-root",this);return this.model.enqueueChange("transparent",t=>{for(const n of Object.keys(e)){const r=this.model.document.getRoot(n);t.insert(this.parse(e[n],r),r,0)}}),Promise.resolve()}set(t){let e={};if("string"==typeof t?e.main=t:e=t,!this._checkIfRootsExists(Object.keys(e)))throw new hn.a("datacontroller-set-non-existent-root",this);this.model.enqueueChange("transparent",t=>{t.setSelection(null),t.removeSelectionAttribute(this.model.document.selection.getAttributeKeys());for(const n of Object.keys(e)){const r=this.model.document.getRoot(n);t.remove(t.createRangeIn(r)),t.insert(this.parse(e[n],r),r,0)}})}parse(t,e="$root"){const n=this.processor.toView(t);return this.toModel(n,e)}toModel(t,e="$root"){return this.model.change(n=>this.upcastDispatcher.convert(t,n,e))}addStyleProcessorRules(t){t(this.stylesProcessor)}registerRawContentMatcher(t){this.processor&&this.processor!==this.htmlProcessor&&this.processor.registerRawContentMatcher(t),this.htmlProcessor.registerRawContentMatcher(t)}destroy(){this.stopListening()}_checkIfRootsExists(t){for(const e of t)if(!this.model.document.getRootNames().includes(e))return!1;return!0}}On(Ps,$r);class Is{constructor(t,e){this._helpers=new Map,this._downcast=jn(t),this._createConversionHelpers({name:"downcast",dispatchers:this._downcast,isDowncast:!0}),this._upcast=jn(e),this._createConversionHelpers({name:"upcast",dispatchers:this._upcast,isDowncast:!1})}addAlias(t,e){const n=this._downcast.includes(e);if(!this._upcast.includes(e)&&!n)throw new hn.a("conversion-add-alias-dispatcher-not-registered",this);this._createConversionHelpers({name:t,dispatchers:[e],isDowncast:n})}for(t){if(!this._helpers.has(t))throw new hn.a("conversion-for-unknown-group",this);return this._helpers.get(t)}elementToElement(t){this.for("downcast").elementToElement(t);for(const{model:e,view:n}of Es(t))this.for("upcast").elementToElement({model:e,view:n,converterPriority:t.converterPriority})}attributeToElement(t){this.for("downcast").attributeToElement(t);for(const{model:e,view:n}of Es(t))this.for("upcast").elementToAttribute({view:n,model:e,converterPriority:t.converterPriority})}attributeToAttribute(t){this.for("downcast").attributeToAttribute(t);for(const{model:e,view:n}of Es(t))this.for("upcast").attributeToAttribute({view:n,model:e})}_createConversionHelpers({name:t,dispatchers:e,isDowncast:n}){if(this._helpers.has(t))throw new hn.a("conversion-group-exists",this);const r=n?new Qa(e):new as(e);this._helpers.set(t,r)}}function*Es(t){if(t.model.values)for(const e of t.model.values){const n={key:t.model.key,value:e},r=t.view[e],i=t.upcastAlso?t.upcastAlso[e]:void 0;yield*Ls(n,r,i)}else yield*Ls(t.model,t.view,t.upcastAlso)}function*Ls(t,e,n){if(yield{model:t,view:e},n)for(const r of jn(n))yield{model:t,view:r}}class Bs{constructor(t="default"){this.operations=[],this.type=t}get baseVersion(){for(const t of this.operations)if(null!==t.baseVersion)return t.baseVersion;return null}addOperation(t){return t.batch=this,this.operations.push(t),t}}class Hs{constructor(t){this.baseVersion=t,this.isDocumentOperation=null!==this.baseVersion,this.batch=null}_validate(){}toJSON(){const t=Object.assign({},this);return t.__className=this.constructor.className,delete t.batch,delete t.isDocumentOperation,t}static get className(){return"Operation"}static fromJSON(t){return new this(t.baseVersion)}}class Fs{constructor(t){this.markers=new Map,this._children=new ka,t&&this._insertChild(0,t)}[Symbol.iterator](){return this.getChildren()}get childCount(){return this._children.length}get maxOffset(){return this._children.maxOffset}get isEmpty(){return 0===this.childCount}get root(){return this}get parent(){return null}is(t){return"documentFragment"===t||"model:documentFragment"===t}getChild(t){return this._children.getNode(t)}getChildren(){return this._children[Symbol.iterator]()}getChildIndex(t){return this._children.getNodeIndex(t)}getChildStartOffset(t){return this._children.getNodeStartOffset(t)}getPath(){return[]}getNodeByPath(t){let e=this;for(const n of t)e=e.getChild(e.offsetToIndex(n));return e}offsetToIndex(t){return this._children.offsetToIndex(t)}toJSON(){const t=[];for(const e of this._children)t.push(e.toJSON());return t}static fromJSON(t){const e=[];for(const n of t)n.name?e.push(_a.fromJSON(n)):e.push(wa.fromJSON(n));return new Fs(e)}_appendChild(t){this._insertChild(this.childCount,t)}_insertChild(t,e){const n=function(t){return"string"==typeof t?[new wa(t)]:(_n(t)||(t=[t]),Array.from(t).map(t=>"string"==typeof t?new wa(t):t instanceof ya?new wa(t.data,t.getAttributes()):t))}(e);for(const r of n)null!==r.parent&&r._remove(),r.parent=this;this._children._insertNodes(t,n)}_removeChildren(t,e=1){const n=this._children._removeNodes(t,e);for(const r of n)r.parent=null;return n}}function Ds(t,e){const n=(e=$s(e)).reduce((t,e)=>t+e.offsetSize,0),r=t.parent;qs(t);const i=t.index;return r._insertChild(i,e),Us(r,i+e.length),Us(r,i),new Va(t,t.getShiftedBy(n))}function Rs(t){if(!t.isFlat)throw new hn.a("operation-utils-remove-range-not-flat",this);const e=t.start.parent;qs(t.start),qs(t.end);const n=e._removeChildren(t.start.index,t.end.index-t.start.index);return Us(e,t.start.index),n}function Ns(t,e){if(!t.isFlat)throw new hn.a("operation-utils-move-range-not-flat",this);const n=Rs(t);return Ds(e=e._getTransformedByDeletion(t.start,t.end.offset-t.start.offset),n)}function $s(t){const e=[];t instanceof Array||(t=[t]);for(let n=0;n<t.length;n++)if("string"==typeof t[n])e.push(new wa(t[n]));else if(t[n]instanceof ya)e.push(new wa(t[n].data,t[n].getAttributes()));else if(t[n]instanceof Fs||t[n]instanceof ka)for(const r of t[n])e.push(r);else t[n]instanceof va&&e.push(t[n]);for(let n=1;n<e.length;n++){const t=e[n],r=e[n-1];t instanceof wa&&r instanceof wa&&Ws(t,r)&&(e.splice(n-1,2,new wa(r.data+t.data,r.getAttributes())),n--)}return e}function Us(t,e){const n=t.getChild(e-1),r=t.getChild(e);if(n&&r&&n.is("$text")&&r.is("$text")&&Ws(n,r)){const i=new wa(n.data+r.data,n.getAttributes());t._removeChildren(e-1,2),t._insertChild(e-1,i)}}function qs(t){const e=t.textNode,n=t.parent;if(e){const r=t.offset-e.startOffset,i=e.index;n._removeChildren(i,1);const o=new wa(e.data.substr(0,r),e.getAttributes()),a=new wa(e.data.substr(r),e.getAttributes());n._insertChild(i,[o,a])}}function Ws(t,e){const n=t.getAttributes(),r=e.getAttributes();for(const i of n){if(i[1]!==e.getAttribute(i[0]))return!1;r.next()}return r.next().done}var Gs=function(t,e){return Io(t,e)};class Ys extends Hs{constructor(t,e,n,r,i){super(i),this.range=t.clone(),this.key=e,this.oldValue=void 0===n?null:n,this.newValue=void 0===r?null:r}get type(){return null===this.oldValue?"addAttribute":null===this.newValue?"removeAttribute":"changeAttribute"}clone(){return new Ys(this.range,this.key,this.oldValue,this.newValue,this.baseVersion)}getReversed(){return new Ys(this.range,this.key,this.newValue,this.oldValue,this.baseVersion+1)}toJSON(){const t=super.toJSON();return t.range=this.range.toJSON(),t}_validate(){if(!this.range.isFlat)throw new hn.a("attribute-operation-range-not-flat",this);for(const t of this.range.getItems({shallow:!0})){if(null!==this.oldValue&&!Gs(t.getAttribute(this.key),this.oldValue))throw new hn.a("attribute-operation-wrong-old-value",this,{item:t,key:this.key,value:this.oldValue});if(null===this.oldValue&&null!==this.newValue&&t.hasAttribute(this.key))throw new hn.a("attribute-operation-attribute-exists",this,{node:t,key:this.key})}}_execute(){Gs(this.oldValue,this.newValue)||function(t,e,n){qs(t.start),qs(t.end);for(const r of t.getItems({shallow:!0})){const t=r.is("$textProxy")?r.textNode:r;null!==n?t._setAttribute(e,n):t._removeAttribute(e),Us(t.parent,t.index)}Us(t.end.parent,t.end.index)}(this.range,this.key,this.newValue)}static get className(){return"AttributeOperation"}static fromJSON(t,e){return new Ys(Va.fromJSON(t.range,e),t.key,t.oldValue,t.newValue,t.baseVersion)}}class Ks extends Hs{constructor(t,e){super(null),this.sourcePosition=t.clone(),this.howMany=e}get type(){return"detach"}toJSON(){const t=super.toJSON();return t.sourcePosition=this.sourcePosition.toJSON(),t}_validate(){if(this.sourcePosition.root.document)throw new hn.a("detach-operation-on-document-node",this)}_execute(){Rs(Va._createFromPositionAndShift(this.sourcePosition,this.howMany))}static get className(){return"DetachOperation"}}class Qs extends Hs{constructor(t,e,n,r){super(r),this.sourcePosition=t.clone(),this.sourcePosition.stickiness="toNext",this.howMany=e,this.targetPosition=n.clone(),this.targetPosition.stickiness="toNone"}get type(){return"$graveyard"==this.targetPosition.root.rootName?"remove":"$graveyard"==this.sourcePosition.root.rootName?"reinsert":"move"}clone(){return new this.constructor(this.sourcePosition,this.howMany,this.targetPosition,this.baseVersion)}getMovedRangeStart(){return this.targetPosition._getTransformedByDeletion(this.sourcePosition,this.howMany)}getReversed(){const t=this.sourcePosition._getTransformedByInsertion(this.targetPosition,this.howMany);return new this.constructor(this.getMovedRangeStart(),this.howMany,t,this.baseVersion+1)}_validate(){const t=this.sourcePosition.parent,e=this.targetPosition.parent,n=this.sourcePosition.offset,r=this.targetPosition.offset;if(n+this.howMany>t.maxOffset)throw new hn.a("move-operation-nodes-do-not-exist",this);if(t===e&&n<r&&r<n+this.howMany)throw new hn.a("move-operation-range-into-itself",this);if(this.sourcePosition.root==this.targetPosition.root&&"prefix"==Tn(this.sourcePosition.getParentPath(),this.targetPosition.getParentPath())){const t=this.sourcePosition.path.length-1;if(this.targetPosition.path[t]>=n&&this.targetPosition.path[t]<n+this.howMany)throw new hn.a("move-operation-node-into-itself",this)}}_execute(){Ns(Va._createFromPositionAndShift(this.sourcePosition,this.howMany),this.targetPosition)}toJSON(){const t=super.toJSON();return t.sourcePosition=this.sourcePosition.toJSON(),t.targetPosition=this.targetPosition.toJSON(),t}static get className(){return"MoveOperation"}static fromJSON(t,e){const n=Aa.fromJSON(t.sourcePosition,e),r=Aa.fromJSON(t.targetPosition,e);return new this(n,t.howMany,r,t.baseVersion)}}class Xs extends Hs{constructor(t,e,n){super(n),this.position=t.clone(),this.position.stickiness="toNone",this.nodes=new ka($s(e)),this.shouldReceiveAttributes=!1}get type(){return"insert"}get howMany(){return this.nodes.maxOffset}clone(){const t=new ka([...this.nodes].map(t=>t._clone(!0))),e=new Xs(this.position,t,this.baseVersion);return e.shouldReceiveAttributes=this.shouldReceiveAttributes,e}getReversed(){const t=this.position.root.document.graveyard,e=new Aa(t,[0]);return new Qs(this.position,this.nodes.maxOffset,e,this.baseVersion+1)}_validate(){const t=this.position.parent;if(!t||t.maxOffset<this.position.offset)throw new hn.a("insert-operation-position-invalid",this)}_execute(){const t=this.nodes;this.nodes=new ka([...t].map(t=>t._clone(!0))),Ds(this.position,t)}toJSON(){const t=super.toJSON();return t.position=this.position.toJSON(),t.nodes=this.nodes.toJSON(),t}static get className(){return"InsertOperation"}static fromJSON(t,e){const n=[];for(const i of t.nodes)i.name?n.push(_a.fromJSON(i)):n.push(wa.fromJSON(i));const r=new Xs(Aa.fromJSON(t.position,e),n,t.baseVersion);return r.shouldReceiveAttributes=t.shouldReceiveAttributes,r}}class Js extends Hs{constructor(t,e,n,r,i,o){super(o),this.name=t,this.oldRange=e?e.clone():null,this.newRange=n?n.clone():null,this.affectsData=i,this._markers=r}get type(){return"marker"}clone(){return new Js(this.name,this.oldRange,this.newRange,this._markers,this.affectsData,this.baseVersion)}getReversed(){return new Js(this.name,this.newRange,this.oldRange,this._markers,this.affectsData,this.baseVersion+1)}_execute(){const t=this.newRange?"_set":"_remove";this._markers[t](this.name,this.newRange,!0,this.affectsData)}toJSON(){const t=super.toJSON();return this.oldRange&&(t.oldRange=this.oldRange.toJSON()),this.newRange&&(t.newRange=this.newRange.toJSON()),delete t._markers,t}static get className(){return"MarkerOperation"}static fromJSON(t,e){return new Js(t.name,t.oldRange?Va.fromJSON(t.oldRange,e):null,t.newRange?Va.fromJSON(t.newRange,e):null,e.model.markers,t.affectsData,t.baseVersion)}}class Zs extends Hs{constructor(t,e,n,r){super(r),this.position=t,this.position.stickiness="toNext",this.oldName=e,this.newName=n}get type(){return"rename"}clone(){return new Zs(this.position.clone(),this.oldName,this.newName,this.baseVersion)}getReversed(){return new Zs(this.position.clone(),this.newName,this.oldName,this.baseVersion+1)}_validate(){const t=this.position.nodeAfter;if(!(t instanceof _a))throw new hn.a("rename-operation-wrong-position",this);if(t.name!==this.oldName)throw new hn.a("rename-operation-wrong-name",this)}_execute(){this.position.nodeAfter.name=this.newName}toJSON(){const t=super.toJSON();return t.position=this.position.toJSON(),t}static get className(){return"RenameOperation"}static fromJSON(t,e){return new Zs(Aa.fromJSON(t.position,e),t.oldName,t.newName,t.baseVersion)}}class tc extends Hs{constructor(t,e,n,r,i){super(i),this.root=t,this.key=e,this.oldValue=n,this.newValue=r}get type(){return null===this.oldValue?"addRootAttribute":null===this.newValue?"removeRootAttribute":"changeRootAttribute"}clone(){return new tc(this.root,this.key,this.oldValue,this.newValue,this.baseVersion)}getReversed(){return new tc(this.root,this.key,this.newValue,this.oldValue,this.baseVersion+1)}_validate(){if(this.root!=this.root.root||this.root.is("documentFragment"))throw new hn.a("rootattribute-operation-not-a-root",this,{root:this.root,key:this.key});if(null!==this.oldValue&&this.root.getAttribute(this.key)!==this.oldValue)throw new hn.a("rootattribute-operation-wrong-old-value",this,{root:this.root,key:this.key});if(null===this.oldValue&&null!==this.newValue&&this.root.hasAttribute(this.key))throw new hn.a("rootattribute-operation-attribute-exists",this,{root:this.root,key:this.key})}_execute(){null!==this.newValue?this.root._setAttribute(this.key,this.newValue):this.root._removeAttribute(this.key)}toJSON(){const t=super.toJSON();return t.root=this.root.toJSON(),t}static get className(){return"RootAttributeOperation"}static fromJSON(t,e){if(!e.getRoot(t.root))throw new hn.a("rootattribute-operation-fromjson-no-root",this,{rootName:t.root});return new tc(e.getRoot(t.root),t.key,t.oldValue,t.newValue,t.baseVersion)}}class ec extends Hs{constructor(t,e,n,r,i){super(i),this.sourcePosition=t.clone(),this.sourcePosition.stickiness="toPrevious",this.howMany=e,this.targetPosition=n.clone(),this.targetPosition.stickiness="toNext",this.graveyardPosition=r.clone()}get type(){return"merge"}get deletionPosition(){return new Aa(this.sourcePosition.root,this.sourcePosition.path.slice(0,-1))}get movedRange(){const t=this.sourcePosition.getShiftedBy(Number.POSITIVE_INFINITY);return new Va(this.sourcePosition,t)}clone(){return new this.constructor(this.sourcePosition,this.howMany,this.targetPosition,this.graveyardPosition,this.baseVersion)}getReversed(){const t=this.targetPosition._getTransformedByMergeOperation(this),e=this.sourcePosition.path.slice(0,-1),n=new Aa(this.sourcePosition.root,e)._getTransformedByMergeOperation(this),r=new nc(t,this.howMany,this.graveyardPosition,this.baseVersion+1);return r.insertionPosition=n,r}_validate(){const t=this.sourcePosition.parent,e=this.targetPosition.parent;if(!t.parent)throw new hn.a("merge-operation-source-position-invalid",this);if(!e.parent)throw new hn.a("merge-operation-target-position-invalid",this);if(this.howMany!=t.maxOffset)throw new hn.a("merge-operation-how-many-invalid",this)}_execute(){const t=this.sourcePosition.parent;Ns(Va._createIn(t),this.targetPosition),Ns(Va._createOn(t),this.graveyardPosition)}toJSON(){const t=super.toJSON();return t.sourcePosition=t.sourcePosition.toJSON(),t.targetPosition=t.targetPosition.toJSON(),t.graveyardPosition=t.graveyardPosition.toJSON(),t}static get className(){return"MergeOperation"}static fromJSON(t,e){const n=Aa.fromJSON(t.sourcePosition,e),r=Aa.fromJSON(t.targetPosition,e),i=Aa.fromJSON(t.graveyardPosition,e);return new this(n,t.howMany,r,i,t.baseVersion)}}class nc extends Hs{constructor(t,e,n,r){super(r),this.splitPosition=t.clone(),this.splitPosition.stickiness="toNext",this.howMany=e,this.insertionPosition=nc.getInsertionPosition(t),this.insertionPosition.stickiness="toNone",this.graveyardPosition=n?n.clone():null,this.graveyardPosition&&(this.graveyardPosition.stickiness="toNext")}get type(){return"split"}get moveTargetPosition(){const t=this.insertionPosition.path.slice();return t.push(0),new Aa(this.insertionPosition.root,t)}get movedRange(){const t=this.splitPosition.getShiftedBy(Number.POSITIVE_INFINITY);return new Va(this.splitPosition,t)}clone(){const t=new this.constructor(this.splitPosition,this.howMany,this.graveyardPosition,this.baseVersion);return t.insertionPosition=this.insertionPosition,t}getReversed(){const t=this.splitPosition.root.document.graveyard,e=new Aa(t,[0]);return new ec(this.moveTargetPosition,this.howMany,this.splitPosition,e,this.baseVersion+1)}_validate(){const t=this.splitPosition.parent,e=this.splitPosition.offset;if(!t||t.maxOffset<e)throw new hn.a("split-operation-position-invalid",this);if(!t.parent)throw new hn.a("split-operation-split-in-root",this);if(this.howMany!=t.maxOffset-this.splitPosition.offset)throw new hn.a("split-operation-how-many-invalid",this);if(this.graveyardPosition&&!this.graveyardPosition.nodeAfter)throw new hn.a("split-operation-graveyard-position-invalid",this)}_execute(){const t=this.splitPosition.parent;if(this.graveyardPosition)Ns(Va._createFromPositionAndShift(this.graveyardPosition,1),this.insertionPosition);else{const e=t._clone();Ds(this.insertionPosition,e)}Ns(new Va(Aa._createAt(t,this.splitPosition.offset),Aa._createAt(t,t.maxOffset)),this.moveTargetPosition)}toJSON(){const t=super.toJSON();return t.splitPosition=this.splitPosition.toJSON(),t.insertionPosition=this.insertionPosition.toJSON(),this.graveyardPosition&&(t.graveyardPosition=this.graveyardPosition.toJSON()),t}static get className(){return"SplitOperation"}static getInsertionPosition(t){const e=t.path.slice(0,-1);return e[e.length-1]++,new Aa(t.root,e)}static fromJSON(t,e){const n=Aa.fromJSON(t.splitPosition,e),r=Aa.fromJSON(t.insertionPosition,e),i=t.graveyardPosition?Aa.fromJSON(t.graveyardPosition,e):null,o=new this(n,t.howMany,i,t.baseVersion);return o.insertionPosition=r,o}}class rc extends _a{constructor(t,e,n="main"){super(e),this._document=t,this.rootName=n}get document(){return this._document}is(t,e){return e?e===this.name&&("rootElement"===t||"model:rootElement"===t||"element"===t||"model:element"===t):"rootElement"===t||"model:rootElement"===t||"element"===t||"model:element"===t||"node"===t||"model:node"===t}toJSON(){return this.rootName}}class ic{constructor(t,e){this.model=t,this.batch=e}createText(t,e){return new wa(t,e)}createElement(t,e){return new _a(t,e)}createDocumentFragment(){return new Fs}cloneElement(t,e=!0){return t._clone(e)}insert(t,e,n=0){if(this._assertWriterUsedCorrectly(),t instanceof wa&&""==t.data)return;const r=Aa._createAt(e,n);if(t.parent){if(lc(t.root,r.root))return void this.move(Va._createOn(t),r);if(t.root.document)throw new hn.a("model-writer-insert-forbidden-move",this);this.remove(t)}const i=r.root.document?r.root.document.version:null,o=new Xs(r,t,i);if(t instanceof wa&&(o.shouldReceiveAttributes=!0),this.batch.addOperation(o),this.model.applyOperation(o),t instanceof Fs)for(const[a,s]of t.markers){const t=Aa._createAt(s.root,0),e={range:new Va(s.start._getCombined(t,r),s.end._getCombined(t,r)),usingOperation:!0,affectsData:!0};this.model.markers.has(a)?this.updateMarker(a,e):this.addMarker(a,e)}}insertText(t,e,n,r){e instanceof Fs||e instanceof _a||e instanceof Aa?this.insert(this.createText(t),e,n):this.insert(this.createText(t,e),n,r)}insertElement(t,e,n,r){e instanceof Fs||e instanceof _a||e instanceof Aa?this.insert(this.createElement(t),e,n):this.insert(this.createElement(t,e),n,r)}append(t,e){this.insert(t,e,"end")}appendText(t,e,n){e instanceof Fs||e instanceof _a?this.insert(this.createText(t),e,"end"):this.insert(this.createText(t,e),n,"end")}appendElement(t,e,n){e instanceof Fs||e instanceof _a?this.insert(this.createElement(t),e,"end"):this.insert(this.createElement(t,e),n,"end")}setAttribute(t,e,n){if(this._assertWriterUsedCorrectly(),n instanceof Va){const r=n.getMinimalFlatRanges();for(const n of r)oc(this,t,e,n)}else ac(this,t,e,n)}setAttributes(t,e){for(const[n,r]of Bn(t))this.setAttribute(n,r,e)}removeAttribute(t,e){if(this._assertWriterUsedCorrectly(),e instanceof Va){const n=e.getMinimalFlatRanges();for(const e of n)oc(this,t,null,e)}else ac(this,t,null,e)}clearAttributes(t){this._assertWriterUsedCorrectly();const e=t=>{for(const e of t.getAttributeKeys())this.removeAttribute(e,t)};if(t instanceof Va)for(const n of t.getItems())e(n);else e(t)}move(t,e,n){if(this._assertWriterUsedCorrectly(),!(t instanceof Va))throw new hn.a("writer-move-invalid-range",this);if(!t.isFlat)throw new hn.a("writer-move-range-not-flat",this);const r=Aa._createAt(e,n);if(r.isEqual(t.start))return;if(this._addOperationForAffectedMarkers("move",t),!lc(t.root,r.root))throw new hn.a("writer-move-different-document",this);const i=t.root.document?t.root.document.version:null,o=new Qs(t.start,t.end.offset-t.start.offset,r,i);this.batch.addOperation(o),this.model.applyOperation(o)}remove(t){this._assertWriterUsedCorrectly();const e=(t instanceof Va?t:Va._createOn(t)).getMinimalFlatRanges().reverse();for(const n of e)this._addOperationForAffectedMarkers("move",n),cc(n.start,n.end.offset-n.start.offset,this.batch,this.model)}merge(t){this._assertWriterUsedCorrectly();const e=t.nodeBefore,n=t.nodeAfter;if(this._addOperationForAffectedMarkers("merge",t),!(e instanceof _a))throw new hn.a("writer-merge-no-element-before",this);if(!(n instanceof _a))throw new hn.a("writer-merge-no-element-after",this);t.root.document?this._merge(t):this._mergeDetached(t)}createPositionFromPath(t,e,n){return this.model.createPositionFromPath(t,e,n)}createPositionAt(t,e){return this.model.createPositionAt(t,e)}createPositionAfter(t){return this.model.createPositionAfter(t)}createPositionBefore(t){return this.model.createPositionBefore(t)}createRange(t,e){return this.model.createRange(t,e)}createRangeIn(t){return this.model.createRangeIn(t)}createRangeOn(t){return this.model.createRangeOn(t)}createSelection(t,e,n){return this.model.createSelection(t,e,n)}_mergeDetached(t){const e=t.nodeBefore,n=t.nodeAfter;this.move(Va._createIn(n),Aa._createAt(e,"end")),this.remove(n)}_merge(t){const e=Aa._createAt(t.nodeBefore,"end"),n=Aa._createAt(t.nodeAfter,0),r=t.root.document.graveyard,i=new Aa(r,[0]),o=t.root.document.version,a=new ec(n,t.nodeAfter.maxOffset,e,i,o);this.batch.addOperation(a),this.model.applyOperation(a)}rename(t,e){if(this._assertWriterUsedCorrectly(),!(t instanceof _a))throw new hn.a("writer-rename-not-element-instance",this);const n=t.root.document?t.root.document.version:null,r=new Zs(Aa._createBefore(t),t.name,e,n);this.batch.addOperation(r),this.model.applyOperation(r)}split(t,e){this._assertWriterUsedCorrectly();let n,r,i=t.parent;if(!i.parent)throw new hn.a("writer-split-element-no-parent",this);if(e||(e=i.parent),!t.parent.getAncestors({includeSelf:!0}).includes(e))throw new hn.a("writer-split-invalid-limit-element",this);do{const e=i.root.document?i.root.document.version:null,o=i.maxOffset-t.offset,a=new nc(t,o,null,e);this.batch.addOperation(a),this.model.applyOperation(a),n||r||(n=i,r=t.parent.nextSibling),i=(t=this.createPositionAfter(t.parent)).parent}while(i!==e);return{position:t,range:new Va(Aa._createAt(n,"end"),Aa._createAt(r,0))}}wrap(t,e){if(this._assertWriterUsedCorrectly(),!t.isFlat)throw new hn.a("writer-wrap-range-not-flat",this);const n=e instanceof _a?e:new _a(e);if(n.childCount>0)throw new hn.a("writer-wrap-element-not-empty",this);if(null!==n.parent)throw new hn.a("writer-wrap-element-attached",this);this.insert(n,t.start);const r=new Va(t.start.getShiftedBy(1),t.end.getShiftedBy(1));this.move(r,Aa._createAt(n,0))}unwrap(t){if(this._assertWriterUsedCorrectly(),null===t.parent)throw new hn.a("writer-unwrap-element-no-parent",this);this.move(Va._createIn(t),this.createPositionAfter(t)),this.remove(t)}addMarker(t,e){if(this._assertWriterUsedCorrectly(),!e||"boolean"!=typeof e.usingOperation)throw new hn.a("writer-addmarker-no-usingoperation",this);const n=e.usingOperation,r=e.range,i=void 0!==e.affectsData&&e.affectsData;if(this.model.markers.has(t))throw new hn.a("writer-addmarker-marker-exists",this);if(!r)throw new hn.a("writer-addmarker-no-range",this);return n?(sc(this,t,null,r,i),this.model.markers.get(t)):this.model.markers._set(t,r,n,i)}updateMarker(t,e){this._assertWriterUsedCorrectly();const n="string"==typeof t?t:t.name,r=this.model.markers.get(n);if(!r)throw new hn.a("writer-updatemarker-marker-not-exists",this);if(!e)return void this.model.markers._refresh(r);const i="boolean"==typeof e.usingOperation,o="boolean"==typeof e.affectsData,a=o?e.affectsData:r.affectsData;if(!i&&!e.range&&!o)throw new hn.a("writer-updatemarker-wrong-options",this);const s=r.getRange(),c=e.range?e.range:s;i&&e.usingOperation!==r.managedUsingOperations?e.usingOperation?sc(this,n,null,c,a):(sc(this,n,s,null,a),this.model.markers._set(n,c,void 0,a)):r.managedUsingOperations?sc(this,n,s,c,a):this.model.markers._set(n,c,void 0,a)}removeMarker(t){this._assertWriterUsedCorrectly();const e="string"==typeof t?t:t.name;if(!this.model.markers.has(e))throw new hn.a("writer-removemarker-no-marker",this);const n=this.model.markers.get(e);n.managedUsingOperations?sc(this,e,n.getRange(),null,n.affectsData):this.model.markers._remove(e)}setSelection(t,e,n){this._assertWriterUsedCorrectly(),this.model.document.selection._setTo(t,e,n)}setSelectionFocus(t,e){this._assertWriterUsedCorrectly(),this.model.document.selection._setFocus(t,e)}setSelectionAttribute(t,e){if(this._assertWriterUsedCorrectly(),"string"==typeof t)this._setSelectionAttribute(t,e);else for(const[n,r]of Bn(t))this._setSelectionAttribute(n,r)}removeSelectionAttribute(t){if(this._assertWriterUsedCorrectly(),"string"==typeof t)this._removeSelectionAttribute(t);else for(const e of t)this._removeSelectionAttribute(e)}overrideSelectionGravity(){return this.model.document.selection._overrideGravity()}restoreSelectionGravity(t){this.model.document.selection._restoreGravity(t)}_setSelectionAttribute(t,e){const n=this.model.document.selection;if(n.isCollapsed&&n.anchor.parent.isEmpty){const r=qa._getStoreAttributeKey(t);this.setAttribute(r,e,n.anchor.parent)}n._setAttribute(t,e)}_removeSelectionAttribute(t){const e=this.model.document.selection;if(e.isCollapsed&&e.anchor.parent.isEmpty){const n=qa._getStoreAttributeKey(t);this.removeAttribute(n,e.anchor.parent)}e._removeAttribute(t)}_assertWriterUsedCorrectly(){if(this.model._currentWriter!==this)throw new hn.a("writer-incorrect-use",this)}_addOperationForAffectedMarkers(t,e){for(const n of this.model.markers){if(!n.managedUsingOperations)continue;const r=n.getRange();let i=!1;if("move"===t)i=e.containsPosition(r.start)||e.start.isEqual(r.start)||e.containsPosition(r.end)||e.end.isEqual(r.end);else{const t=e.nodeBefore,n=e.nodeAfter,o=r.start.parent==t&&r.start.isAtEnd,a=r.end.parent==n&&0==r.end.offset,s=r.end.nodeAfter==n,c=r.start.nodeAfter==n;i=o||a||s||c}i&&this.updateMarker(n.name,{range:r})}}}function oc(t,e,n,r){const i=t.model,o=i.document;let a,s,c,l=r.start;for(const d of r.getWalker({shallow:!0}))c=d.item.getAttribute(e),a&&s!=c&&(s!=n&&u(),l=a),a=d.nextPosition,s=c;function u(){const r=new Va(l,a),c=r.root.document?o.version:null,u=new Ys(r,e,s,n,c);t.batch.addOperation(u),i.applyOperation(u)}a instanceof Aa&&a!=l&&s!=n&&u()}function ac(t,e,n,r){const i=t.model,o=i.document,a=r.getAttribute(e);let s,c;if(a!=n){if(r.root===r){const t=r.document?o.version:null;c=new tc(r,e,a,n,t)}else{s=new Va(Aa._createBefore(r),t.createPositionAfter(r));const i=s.root.document?o.version:null;c=new Ys(s,e,a,n,i)}t.batch.addOperation(c),i.applyOperation(c)}}function sc(t,e,n,r,i){const o=t.model,a=o.document,s=new Js(e,n,r,o.markers,i,a.version);t.batch.addOperation(s),o.applyOperation(s)}function cc(t,e,n,r){let i;if(t.root.document){const n=r.document,o=new Aa(n.graveyard,[0]);i=new Qs(t,e,o,n.version)}else i=new Ks(t,e);n.addOperation(i),r.applyOperation(i)}function lc(t,e){return t===e||t instanceof rc&&e instanceof rc}class uc{constructor(t){this._markerCollection=t,this._changesInElement=new Map,this._elementSnapshots=new Map,this._changedMarkers=new Map,this._changeCount=0,this._cachedChanges=null,this._cachedChangesWithGraveyard=null}get isEmpty(){return 0==this._changesInElement.size&&0==this._changedMarkers.size}refreshItem(t){if(this._isInInsertedElement(t.parent))return;this._markRemove(t.parent,t.startOffset,t.offsetSize),this._markInsert(t.parent,t.startOffset,t.offsetSize);const e=Va._createOn(t);for(const n of this._markerCollection.getMarkersIntersectingRange(e)){const t=n.getRange();this.bufferMarkerChange(n.name,t,t,n.affectsData)}this._cachedChanges=null}bufferOperation(t){switch(t.type){case"insert":if(this._isInInsertedElement(t.position.parent))return;this._markInsert(t.position.parent,t.position.offset,t.nodes.maxOffset);break;case"addAttribute":case"removeAttribute":case"changeAttribute":for(const e of t.range.getItems({shallow:!0}))this._isInInsertedElement(e.parent)||this._markAttribute(e);break;case"remove":case"move":case"reinsert":{if(t.sourcePosition.isEqual(t.targetPosition)||t.sourcePosition.getShiftedBy(t.howMany).isEqual(t.targetPosition))return;const e=this._isInInsertedElement(t.sourcePosition.parent),n=this._isInInsertedElement(t.targetPosition.parent);e||this._markRemove(t.sourcePosition.parent,t.sourcePosition.offset,t.howMany),n||this._markInsert(t.targetPosition.parent,t.getMovedRangeStart().offset,t.howMany);break}case"rename":{if(this._isInInsertedElement(t.position.parent))return;this._markRemove(t.position.parent,t.position.offset,1),this._markInsert(t.position.parent,t.position.offset,1);const e=Va._createFromPositionAndShift(t.position,1);for(const t of this._markerCollection.getMarkersIntersectingRange(e)){const e=t.getRange();this.bufferMarkerChange(t.name,e,e,t.affectsData)}break}case"split":{const e=t.splitPosition.parent;this._isInInsertedElement(e)||this._markRemove(e,t.splitPosition.offset,t.howMany),this._isInInsertedElement(t.insertionPosition.parent)||this._markInsert(t.insertionPosition.parent,t.insertionPosition.offset,1),t.graveyardPosition&&this._markRemove(t.graveyardPosition.parent,t.graveyardPosition.offset,1);break}case"merge":{const e=t.sourcePosition.parent;this._isInInsertedElement(e.parent)||this._markRemove(e.parent,e.startOffset,1);const n=t.graveyardPosition.parent;this._markInsert(n,t.graveyardPosition.offset,1);const r=t.targetPosition.parent;this._isInInsertedElement(r)||this._markInsert(r,t.targetPosition.offset,e.maxOffset);break}}this._cachedChanges=null}bufferMarkerChange(t,e,n,r){const i=this._changedMarkers.get(t);i?(i.newRange=n,i.affectsData=r,null==i.oldRange&&null==i.newRange&&this._changedMarkers.delete(t)):this._changedMarkers.set(t,{oldRange:e,newRange:n,affectsData:r})}getMarkersToRemove(){const t=[];for(const[e,n]of this._changedMarkers)null!=n.oldRange&&t.push({name:e,range:n.oldRange});return t}getMarkersToAdd(){const t=[];for(const[e,n]of this._changedMarkers)null!=n.newRange&&t.push({name:e,range:n.newRange});return t}getChangedMarkers(){return Array.from(this._changedMarkers).map(t=>({name:t[0],data:{oldRange:t[1].oldRange,newRange:t[1].newRange}}))}hasDataChanges(){for(const[,t]of this._changedMarkers)if(t.affectsData)return!0;return this._changesInElement.size>0}getChanges(t={includeChangesInGraveyard:!1}){if(this._cachedChanges)return t.includeChangesInGraveyard?this._cachedChangesWithGraveyard.slice():this._cachedChanges.slice();let e=[];for(const n of this._changesInElement.keys()){const t=this._changesInElement.get(n).sort((t,e)=>t.offset===e.offset?t.type!=e.type?"remove"==t.type?-1:1:0:t.offset<e.offset?-1:1),r=this._elementSnapshots.get(n),i=dc(n.getChildren()),o=hc(r.length,t);let a=0,s=0;for(const c of o)if("i"===c)e.push(this._getInsertDiff(n,a,i[a].name)),a++;else if("r"===c)e.push(this._getRemoveDiff(n,a,r[s].name)),s++;else if("a"===c){const t=i[a].attributes,o=r[s].attributes;let c;if("$text"==i[a].name)c=new Va(Aa._createAt(n,a),Aa._createAt(n,a+1));else{const t=n.offsetToIndex(a);c=new Va(Aa._createAt(n,a),Aa._createAt(n.getChild(t),0))}e.push(...this._getAttributesDiff(c,o,t)),a++,s++}else a++,s++}e.sort((t,e)=>t.position.root!=e.position.root?t.position.root.rootName<e.position.root.rootName?-1:1:t.position.isEqual(e.position)?t.changeCount-e.changeCount:t.position.isBefore(e.position)?-1:1);for(let n=1,r=0;n<e.length;n++){const t=e[r],i=e[n],o="remove"==t.type&&"remove"==i.type&&"$text"==t.name&&"$text"==i.name&&t.position.isEqual(i.position),a="insert"==t.type&&"insert"==i.type&&"$text"==t.name&&"$text"==i.name&&t.position.parent==i.position.parent&&t.position.offset+t.length==i.position.offset,s="attribute"==t.type&&"attribute"==i.type&&t.position.parent==i.position.parent&&t.range.isFlat&&i.range.isFlat&&t.position.offset+t.length==i.position.offset&&t.attributeKey==i.attributeKey&&t.attributeOldValue==i.attributeOldValue&&t.attributeNewValue==i.attributeNewValue;o||a||s?(t.length++,s&&(t.range.end=t.range.end.getShiftedBy(1)),e[n]=null):r=n}e=e.filter(t=>t);for(const n of e)delete n.changeCount,"attribute"==n.type&&(delete n.position,delete n.length);return this._changeCount=0,this._cachedChangesWithGraveyard=e.slice(),this._cachedChanges=e.filter(fc),t.includeChangesInGraveyard?this._cachedChangesWithGraveyard:this._cachedChanges}reset(){this._changesInElement.clear(),this._elementSnapshots.clear(),this._changedMarkers.clear(),this._cachedChanges=null}_markInsert(t,e,n){const r={type:"insert",offset:e,howMany:n,count:this._changeCount++};this._markChange(t,r)}_markRemove(t,e,n){const r={type:"remove",offset:e,howMany:n,count:this._changeCount++};this._markChange(t,r),this._removeAllNestedChanges(t,e,n)}_markAttribute(t){const e={type:"attribute",offset:t.startOffset,howMany:t.offsetSize,count:this._changeCount++};this._markChange(t.parent,e)}_markChange(t,e){this._makeSnapshot(t);const n=this._getChangesForElement(t);this._handleChange(e,n),n.push(e);for(let r=0;r<n.length;r++)n[r].howMany<1&&(n.splice(r,1),r--)}_getChangesForElement(t){let e;return this._changesInElement.has(t)?e=this._changesInElement.get(t):(e=[],this._changesInElement.set(t,e)),e}_makeSnapshot(t){this._elementSnapshots.has(t)||this._elementSnapshots.set(t,dc(t.getChildren()))}_handleChange(t,e){t.nodesToHandle=t.howMany;for(const n of e){const r=t.offset+t.howMany,i=n.offset+n.howMany;if("insert"==t.type&&("insert"==n.type&&(t.offset<=n.offset?n.offset+=t.howMany:t.offset<i&&(n.howMany+=t.nodesToHandle,t.nodesToHandle=0)),"remove"==n.type&&t.offset<n.offset&&(n.offset+=t.howMany),"attribute"==n.type))if(t.offset<=n.offset)n.offset+=t.howMany;else if(t.offset<i){const i=n.howMany;n.howMany=t.offset-n.offset,e.unshift({type:"attribute",offset:r,howMany:i-n.howMany,count:this._changeCount++})}if("remove"==t.type){if("insert"==n.type)if(r<=n.offset)n.offset-=t.howMany;else if(r<=i)if(t.offset<n.offset){const e=r-n.offset;n.offset=t.offset,n.howMany-=e,t.nodesToHandle-=e}else n.howMany-=t.nodesToHandle,t.nodesToHandle=0;else if(t.offset<=n.offset)t.nodesToHandle-=n.howMany,n.howMany=0;else if(t.offset<i){const e=i-t.offset;n.howMany-=e,t.nodesToHandle-=e}if("remove"==n.type&&(r<=n.offset?n.offset-=t.howMany:t.offset<n.offset&&(t.nodesToHandle+=n.howMany,n.howMany=0)),"attribute"==n.type)if(r<=n.offset)n.offset-=t.howMany;else if(t.offset<n.offset){const e=r-n.offset;n.offset=t.offset,n.howMany-=e}else if(t.offset<i)if(r<=i){const r=n.howMany;n.howMany=t.offset-n.offset;const i=r-n.howMany-t.nodesToHandle;e.unshift({type:"attribute",offset:t.offset,howMany:i,count:this._changeCount++})}else n.howMany-=i-t.offset}if("attribute"==t.type){if("insert"==n.type)if(t.offset<n.offset&&r>n.offset){if(r>i){const t={type:"attribute",offset:i,howMany:r-i,count:this._changeCount++};this._handleChange(t,e),e.push(t)}t.nodesToHandle=n.offset-t.offset,t.howMany=t.nodesToHandle}else t.offset>=n.offset&&t.offset<i&&(r>i?(t.nodesToHandle=r-i,t.offset=i):t.nodesToHandle=0);if("remove"==n.type&&t.offset<n.offset&&r>n.offset){const i={type:"attribute",offset:n.offset,howMany:r-n.offset,count:this._changeCount++};this._handleChange(i,e),e.push(i),t.nodesToHandle=n.offset-t.offset,t.howMany=t.nodesToHandle}"attribute"==n.type&&(t.offset>=n.offset&&r<=i?(t.nodesToHandle=0,t.howMany=0,t.offset=0):t.offset<=n.offset&&r>=i&&(n.howMany=0))}}t.howMany=t.nodesToHandle,delete t.nodesToHandle}_getInsertDiff(t,e,n){return{type:"insert",position:Aa._createAt(t,e),name:n,length:1,changeCount:this._changeCount++}}_getRemoveDiff(t,e,n){return{type:"remove",position:Aa._createAt(t,e),name:n,length:1,changeCount:this._changeCount++}}_getAttributesDiff(t,e,n){const r=[];n=new Map(n);for(const[i,o]of e){const e=n.has(i)?n.get(i):null;e!==o&&r.push({type:"attribute",position:t.start,range:t.clone(),length:1,attributeKey:i,attributeOldValue:o,attributeNewValue:e,changeCount:this._changeCount++}),n.delete(i)}for(const[i,o]of n)r.push({type:"attribute",position:t.start,range:t.clone(),length:1,attributeKey:i,attributeOldValue:null,attributeNewValue:o,changeCount:this._changeCount++});return r}_isInInsertedElement(t){const e=t.parent;if(!e)return!1;const n=this._changesInElement.get(e),r=t.startOffset;if(n)for(const i of n)if("insert"==i.type&&r>=i.offset&&r<i.offset+i.howMany)return!0;return this._isInInsertedElement(e)}_removeAllNestedChanges(t,e,n){const r=new Va(Aa._createAt(t,e),Aa._createAt(t,e+n));for(const i of r.getItems({shallow:!0}))i.is("element")&&(this._elementSnapshots.delete(i),this._changesInElement.delete(i),this._removeAllNestedChanges(i,0,i.maxOffset))}}function dc(t){const e=[];for(const n of t)if(n.is("$text"))for(let t=0;t<n.data.length;t++)e.push({name:"$text",attributes:new Map(n.getAttributes())});else e.push({name:n.name,attributes:new Map(n.getAttributes())});return e}function hc(t,e){const n=[];let r=0,i=0;for(const o of e){if(o.offset>r){for(let t=0;t<o.offset-r;t++)n.push("e");i+=o.offset-r}if("insert"==o.type){for(let t=0;t<o.howMany;t++)n.push("i");r=o.offset+o.howMany}else if("remove"==o.type){for(let t=0;t<o.howMany;t++)n.push("r");r=o.offset,i+=o.howMany}else n.push(..."a".repeat(o.howMany).split("")),r=o.offset+o.howMany,i+=o.howMany}if(i<t)for(let o=0;o<t-i-r;o++)n.push("e");return n}function fc(t){const e=t.position&&"$graveyard"==t.position.root.rootName,n=t.range&&"$graveyard"==t.range.root.rootName;return!e&&!n}class pc{constructor(){this._operations=[],this._undoPairs=new Map,this._undoneOperations=new Set}addOperation(t){this._operations.includes(t)||this._operations.push(t)}getOperations(t=Number.NEGATIVE_INFINITY,e=Number.POSITIVE_INFINITY){const n=[];for(const r of this._operations)r.baseVersion>=t&&r.baseVersion<e&&n.push(r);return n}getOperation(t){for(const e of this._operations)if(e.baseVersion==t)return e}setOperationAsUndone(t,e){this._undoPairs.set(e,t),this._undoneOperations.add(t)}isUndoingOperation(t){return this._undoPairs.has(t)}isUndoneOperation(t){return this._undoneOperations.has(t)}getUndoneOperation(t){return this._undoPairs.get(t)}}function mc(t,e){return!!(n=t.charAt(e-1))&&1==n.length&&/[\ud800-\udbff]/.test(n)&&function(t){return!!t&&1==t.length&&/[\udc00-\udfff]/.test(t)}(t.charAt(e));var n}function bc(t,e){return!!(n=t.charAt(e))&&1==n.length&&/[\u0300-\u036f\u1ab0-\u1aff\u1dc0-\u1dff\u20d0-\u20ff\ufe20-\ufe2f]/.test(n);var n}class gc{constructor(t){this.model=t,this.version=0,this.history=new pc(this),this.selection=new qa(this),this.roots=new zn({idProperty:"rootName"}),this.differ=new uc(t.markers),this._postFixers=new Set,this._hasSelectionChangedFromTheLastChangeBlock=!1,this.createRoot("$root","$graveyard"),this.listenTo(t,"applyOperation",(t,e)=>{const n=e[0];if(n.isDocumentOperation&&n.baseVersion!==this.version)throw new hn.a("model-document-applyoperation-wrong-version",this,{operation:n})},{priority:"highest"}),this.listenTo(t,"applyOperation",(t,e)=>{const n=e[0];n.isDocumentOperation&&this.differ.bufferOperation(n)},{priority:"high"}),this.listenTo(t,"applyOperation",(t,e)=>{const n=e[0];n.isDocumentOperation&&(this.version++,this.history.addOperation(n))},{priority:"low"}),this.listenTo(this.selection,"change",()=>{this._hasSelectionChangedFromTheLastChangeBlock=!0}),this.listenTo(t.markers,"update",(t,e,n,r)=>{this.differ.bufferMarkerChange(e.name,n,r,e.affectsData),null===n&&e.on("change",(t,n)=>{this.differ.bufferMarkerChange(e.name,n,e.getRange(),e.affectsData)})})}get graveyard(){return this.getRoot("$graveyard")}createRoot(t="$root",e="main"){if(this.roots.get(e))throw new hn.a("model-document-createroot-name-exists",this,{name:e});const n=new rc(this,t,e);return this.roots.add(n),n}destroy(){this.selection.destroy(),this.stopListening()}getRoot(t="main"){return this.roots.get(t)}getRootNames(){return Array.from(this.roots,t=>t.rootName).filter(t=>"$graveyard"!=t)}registerPostFixer(t){this._postFixers.add(t)}toJSON(){const t=Pn(this);return t.selection="[engine.model.DocumentSelection]",t.model="[engine.model.Model]",t}_handleChangeBlock(t){this._hasDocumentChangedFromTheLastChangeBlock()&&(this._callPostFixers(t),this.selection.refresh(),this.differ.hasDataChanges()?this.fire("change:data",t.batch):this.fire("change",t.batch),this.selection.refresh(),this.differ.reset()),this._hasSelectionChangedFromTheLastChangeBlock=!1}_hasDocumentChangedFromTheLastChangeBlock(){return!this.differ.isEmpty||this._hasSelectionChangedFromTheLastChangeBlock}_getDefaultRoot(){for(const t of this.roots)if(t!==this.graveyard)return t;return this.graveyard}_getDefaultRange(){const t=this._getDefaultRoot(),e=this.model,n=e.schema,r=e.createPositionFromPath(t,[0]);return n.getNearestSelectionRange(r)||e.createRange(r)}_validateSelectionRange(t){return vc(t.start)&&vc(t.end)}_callPostFixers(t){let e=!1;do{for(const n of this._postFixers)if(this.selection.refresh(),e=n(t),e)break}while(e)}}function vc(t){const e=t.textNode;if(e){const n=e.data,r=t.offset-e.startOffset;return!mc(n,r)&&!bc(n,r)}return!0}On(gc,mn);class wc{constructor(){this._markers=new Map}[Symbol.iterator](){return this._markers.values()}has(t){return this._markers.has(t)}get(t){return this._markers.get(t)||null}_set(t,e,n=!1,r=!1){const i=t instanceof yc?t.name:t;if(i.includes(","))throw new hn.a("markercollection-incorrect-marker-name",this);const o=this._markers.get(i);if(o){const t=o.getRange();let a=!1;return t.isEqual(e)||(o._attachLiveRange(Na.fromRange(e)),a=!0),n!=o.managedUsingOperations&&(o._managedUsingOperations=n,a=!0),"boolean"==typeof r&&r!=o.affectsData&&(o._affectsData=r,a=!0),a&&this.fire("update:"+i,o,t,e),o}const a=Na.fromRange(e),s=new yc(i,a,n,r);return this._markers.set(i,s),this.fire("update:"+i,s,null,e),s}_remove(t){const e=t instanceof yc?t.name:t,n=this._markers.get(e);return!!n&&(this._markers.delete(e),this.fire("update:"+e,n,n.getRange(),null),this._destroyMarker(n),!0)}_refresh(t){const e=t instanceof yc?t.name:t,n=this._markers.get(e);if(!n)throw new hn.a("markercollection-refresh-marker-not-exists",this);const r=n.getRange();this.fire("update:"+e,n,r,r,n.managedUsingOperations,n.affectsData)}*getMarkersAtPosition(t){for(const e of this)e.getRange().containsPosition(t)&&(yield e)}*getMarkersIntersectingRange(t){for(const e of this)null!==e.getRange().getIntersection(t)&&(yield e)}destroy(){for(const t of this._markers.values())this._destroyMarker(t);this._markers=null,this.stopListening()}*getMarkersGroup(t){for(const e of this._markers.values())e.name.startsWith(t+":")&&(yield e)}_destroyMarker(t){t.stopListening(),t._detachLiveRange()}}On(wc,mn);class yc{constructor(t,e,n,r){this.name=t,this._liveRange=this._attachLiveRange(e),this._managedUsingOperations=n,this._affectsData=r}get managedUsingOperations(){if(!this._liveRange)throw new hn.a("marker-destroyed",this);return this._managedUsingOperations}get affectsData(){if(!this._liveRange)throw new hn.a("marker-destroyed",this);return this._affectsData}getStart(){if(!this._liveRange)throw new hn.a("marker-destroyed",this);return this._liveRange.start.clone()}getEnd(){if(!this._liveRange)throw new hn.a("marker-destroyed",this);return this._liveRange.end.clone()}getRange(){if(!this._liveRange)throw new hn.a("marker-destroyed",this);return this._liveRange.toRange()}is(t){return"marker"===t||"model:marker"===t}_attachLiveRange(t){return this._liveRange&&this._detachLiveRange(),t.delegate("change:range").to(this),t.delegate("change:content").to(this),this._liveRange=t,t}_detachLiveRange(){this._liveRange.stopDelegating("change:range",this),this._liveRange.stopDelegating("change:content",this),this._liveRange.detach(),this._liveRange=null}}On(yc,mn);class kc extends Hs{get type(){return"noop"}clone(){return new kc(this.baseVersion)}getReversed(){return new kc(this.baseVersion+1)}_execute(){}static get className(){return"NoOperation"}}const _c={};_c[Ys.className]=Ys,_c[Xs.className]=Xs,_c[Js.className]=Js,_c[Qs.className]=Qs,_c[kc.className]=kc,_c[Hs.className]=Hs,_c[Zs.className]=Zs,_c[tc.className]=tc,_c[nc.className]=nc,_c[ec.className]=ec;class Oc extends Aa{constructor(t,e,n="toNone"){if(super(t,e,n),!this.root.is("rootElement"))throw new hn.a("model-liveposition-root-not-rootelement",t);zc.call(this)}detach(){this.stopListening()}is(t){return"livePosition"===t||"model:livePosition"===t||"position"==t||"model:position"===t}toPosition(){return new Aa(this.root,this.path.slice(),this.stickiness)}static fromPosition(t,e){return new this(t.root,t.path.slice(),e||t.stickiness)}}function zc(){this.listenTo(this.root.document.model,"applyOperation",(t,e)=>{const n=e[0];n.isDocumentOperation&&Ac.call(this,n)},{priority:"low"})}function Ac(t){const e=this.getTransformedByOperation(t);if(!this.isEqual(e)){const t=this.toPosition();this.path=e.path,this.root=e.root,this.fire("change",t)}}On(Oc,mn);class jc{constructor(t,e,n){this.model=t,this.writer=e,this.position=n,this.canMergeWith=new Set([this.position.parent]),this.schema=t.schema,this._documentFragment=e.createDocumentFragment(),this._documentFragmentPosition=e.createPositionAt(this._documentFragment,0),this._firstNode=null,this._lastNode=null,this._filterAttributesOf=[],this._affectedStart=null,this._affectedEnd=null}handleNodes(t){for(const e of Array.from(t))this._handleNode(e);this._insertPartialFragment(),this._mergeOnRight(),this.schema.removeDisallowedAttributes(this._filterAttributesOf,this.writer),this._filterAttributesOf=[]}getSelectionRange(){return this.nodeToSelect?Va._createOn(this.nodeToSelect):this.model.schema.getNearestSelectionRange(this.position)}getAffectedRange(){return this._affectedStart?new Va(this._affectedStart,this._affectedEnd):null}destroy(){this._affectedStart&&this._affectedStart.detach(),this._affectedEnd&&this._affectedEnd.detach()}_handleNode(t){this.schema.isObject(t)?this._handleObject(t):this._checkAndSplitToAllowedPosition(t)?(this._appendToFragment(t),this._firstNode||(this._firstNode=t),this._lastNode=t):this._handleDisallowedNode(t)}_insertPartialFragment(){if(this._documentFragment.isEmpty)return;const t=Oc.fromPosition(this.position,"toNext");this._setAffectedBoundaries(this.position),this._documentFragment.getChild(0)==this._firstNode&&(this.writer.insert(this._firstNode,this.position),this._mergeOnLeft(),this.position=t.toPosition()),this._documentFragment.isEmpty||this.writer.insert(this._documentFragment,this.position),this._documentFragmentPosition=this.writer.createPositionAt(this._documentFragment,0),this.position=t.toPosition(),t.detach()}_handleObject(t){this._checkAndSplitToAllowedPosition(t)?this._appendToFragment(t):this._tryAutoparagraphing(t)}_handleDisallowedNode(t){t.is("element")?this.handleNodes(t.getChildren()):this._tryAutoparagraphing(t)}_appendToFragment(t){if(!this.schema.checkChild(this.position,t))throw new hn.a("insertcontent-wrong-position",this,{node:t,position:this.position});this.writer.insert(t,this._documentFragmentPosition),this._documentFragmentPosition=this._documentFragmentPosition.getShiftedBy(t.offsetSize),this.schema.isObject(t)&&!this.schema.checkChild(this.position,"$text")?this.nodeToSelect=t:this.nodeToSelect=null,this._filterAttributesOf.push(t)}_setAffectedBoundaries(t){this._affectedStart||(this._affectedStart=Oc.fromPosition(t,"toPrevious")),this._affectedEnd&&!this._affectedEnd.isBefore(t)||(this._affectedEnd&&this._affectedEnd.detach(),this._affectedEnd=Oc.fromPosition(t,"toNext"))}_mergeOnLeft(){const t=this._firstNode;if(!(t instanceof _a))return;if(!this._canMergeLeft(t))return;const e=Oc._createBefore(t);e.stickiness="toNext";const n=Oc.fromPosition(this.position,"toNext");this._affectedStart.isEqual(e)&&(this._affectedStart.detach(),this._affectedStart=Oc._createAt(e.nodeBefore,"end","toPrevious")),this._firstNode===this._lastNode&&(this._firstNode=e.nodeBefore,this._lastNode=e.nodeBefore),this.writer.merge(e),e.isEqual(this._affectedEnd)&&this._firstNode===this._lastNode&&(this._affectedEnd.detach(),this._affectedEnd=Oc._createAt(e.nodeBefore,"end","toNext")),this.position=n.toPosition(),n.detach(),this._filterAttributesOf.push(this.position.parent),e.detach()}_mergeOnRight(){const t=this._lastNode;if(!(t instanceof _a))return;if(!this._canMergeRight(t))return;const e=Oc._createAfter(t);if(e.stickiness="toNext",!this.position.isEqual(e))throw new hn.a("insertcontent-invalid-insertion-position",this);this.position=Aa._createAt(e.nodeBefore,"end");const n=Oc.fromPosition(this.position,"toPrevious");this._affectedEnd.isEqual(e)&&(this._affectedEnd.detach(),this._affectedEnd=Oc._createAt(e.nodeBefore,"end","toNext")),this._firstNode===this._lastNode&&(this._firstNode=e.nodeBefore,this._lastNode=e.nodeBefore),this.writer.merge(e),e.getShiftedBy(-1).isEqual(this._affectedStart)&&this._firstNode===this._lastNode&&(this._affectedStart.detach(),this._affectedStart=Oc._createAt(e.nodeBefore,0,"toPrevious")),this.position=n.toPosition(),n.detach(),this._filterAttributesOf.push(this.position.parent),e.detach()}_canMergeLeft(t){const e=t.previousSibling;return e instanceof _a&&this.canMergeWith.has(e)&&this.model.schema.checkMerge(e,t)}_canMergeRight(t){const e=t.nextSibling;return e instanceof _a&&this.canMergeWith.has(e)&&this.model.schema.checkMerge(t,e)}_tryAutoparagraphing(t){const e=this.writer.createElement("paragraph");this._getAllowedIn(e,this.position.parent)&&this.schema.checkChild(e,t)&&(e._appendChild(t),this._handleNode(e))}_checkAndSplitToAllowedPosition(t){const e=this._getAllowedIn(t,this.position.parent);if(!e)return!1;for(e!=this.position.parent&&this._insertPartialFragment();e!=this.position.parent;){if(this.schema.isLimit(this.position.parent))return!1;if(this.position.isAtStart){const t=this.position.parent;this.position=this.writer.createPositionBefore(t),t.isEmpty&&t.parent===e&&this.writer.remove(t)}else if(this.position.isAtEnd)this.position=this.writer.createPositionAfter(this.position.parent);else{const t=this.writer.createPositionAfter(this.position.parent);this._setAffectedBoundaries(this.position),this.writer.split(this.position),this.position=t,this.canMergeWith.add(this.position.nodeAfter)}}return!0}_getAllowedIn(t,e){return this.schema.checkChild(e,t)?e:e.parent?this._getAllowedIn(t,e.parent):null}}function Mc(t,e,n={}){if(e.isCollapsed)return;const r=e.getFirstRange();if("$graveyard"==r.root.rootName)return;const i=t.schema;t.change(t=>{if(!n.doNotResetEntireContent&&function(t,e){const n=t.getLimitElement(e);if(!e.containsEntireContent(n))return!1;const r=e.getFirstRange();return r.start.parent!=r.end.parent&&t.checkChild(n,"paragraph")}(i,e))return void function(t,e){const n=t.model.schema.getLimitElement(e);t.remove(t.createRangeIn(n)),Vc(t,t.createPositionAt(n,0),e)}(t,e);const[o,a]=function(t){const e=t.root.document.model,n=t.start;let r=t.end;if(e.hasContent(t,{ignoreMarkers:!0})){const n=function(t){const e=t.parent,n=e.root.document.model.schema,r=e.getAncestors({parentFirst:!0,includeSelf:!0});for(const i of r){if(n.isLimit(i))return null;if(n.isBlock(i))return i}}(r);if(n&&r.isTouching(e.createPositionAt(n,0))){const n=e.createSelection(t);e.modifySelection(n,{direction:"backward"}),r=n.getLastPosition()}}return[Oc.fromPosition(n,"toPrevious"),Oc.fromPosition(r,"toNext")]}(r);o.isTouching(a)||t.remove(t.createRange(o,a)),n.leaveUnmerged||(function(t,e,n){const r=t.model;if(!Cc(t.model.schema,e,n))return;const[i,o]=function(t,e){const n=t.getAncestors(),r=e.getAncestors();let i=0;for(;n[i]&&n[i]==r[i];)i++;return[n[i],r[i]]}(e,n);i&&o&&(!r.hasContent(i,{ignoreMarkers:!0})&&r.hasContent(o,{ignoreMarkers:!0})?function t(e,n,r,i){const o=n.parent,a=r.parent;if(o!=i&&a!=i){for(n=e.createPositionAfter(o),(r=e.createPositionBefore(a)).isEqual(n)||e.insert(o,r);n.parent.isEmpty;){const t=n.parent;n=e.createPositionBefore(t),e.remove(t)}r=e.createPositionBefore(a),function(t,e){const n=e.nodeBefore,r=e.nodeAfter;n.name!=r.name&&t.rename(n,r.name),t.clearAttributes(n),t.setAttributes(Object.fromEntries(r.getAttributes()),n),t.merge(e)}(e,r),Cc(e.model.schema,n,r)&&t(e,n,r,i)}}(t,e,n,i.parent):function t(e,n,r,i){const o=n.parent,a=r.parent;if(o!=i&&a!=i){for(n=e.createPositionAfter(o),(r=e.createPositionBefore(a)).isEqual(n)||e.insert(a,n),e.merge(n);r.parent.isEmpty;){const t=r.parent;r=e.createPositionBefore(t),e.remove(t)}Cc(e.model.schema,n,r)&&t(e,n,r,i)}}(t,e,n,i.parent))}(t,o,a),i.removeDisallowedAttributes(o.parent.getChildren(),t)),Sc(t,e,o),!n.doNotAutoparagraph&&function(t,e){const n=t.checkChild(e,"$text"),r=t.checkChild(e,"paragraph");return!n&&r}(i,o)&&Vc(t,o,e),o.detach(),a.detach()})}function Cc(t,e,n){const r=e.parent,i=n.parent;return r!=i&&!t.isLimit(r)&&!t.isLimit(i)&&function(t,e,n){const r=new Va(t,e);for(const i of r.getWalker())if(n.isLimit(i.item))return!1;return!0}(e,n,t)}function Vc(t,e,n){const r=t.createElement("paragraph");t.insert(r,e),Sc(t,n,t.createPositionAt(r,0))}function Sc(t,e,n){e instanceof qa?t.setSelection(n):e.setTo(n)}function xc(t,e){const{isForward:n,walker:r,unit:i,schema:o}=t,{type:a,item:s,nextPosition:c}=e;if("text"==a)return"word"===t.unit?function(t,e){let n=t.position.textNode;if(n){let r=t.position.offset-n.startOffset;for(;!Pc(n.data,r,e)&&!Ic(n,r,e);){t.next();const i=e?t.position.nodeAfter:t.position.nodeBefore;if(i&&i.is("$text")){const r=i.data.charAt(e?0:i.data.length-1);' ,.?!:;"-()'.includes(r)||(t.next(),n=t.position.textNode)}r=t.position.offset-n.startOffset}}return t.position}(r,n):function(t,e){const n=t.position.textNode;if(n){const r=n.data;let i=t.position.offset-n.startOffset;for(;mc(r,i)||"character"==e&&bc(r,i);)t.next(),i=t.position.offset-n.startOffset}return t.position}(r,i);if(a==(n?"elementStart":"elementEnd")){if(o.isSelectable(s))return Aa._createAt(s,n?"after":"before");if(o.checkChild(c,"$text"))return c}else{if(o.isLimit(s))return void r.skip(()=>!0);if(o.checkChild(c,"$text"))return c}}function Tc(t,e){const n=t.root,r=Aa._createAt(n,e?"end":0);return e?new Va(t,r):new Va(r,t)}function Pc(t,e,n){const r=e+(n?0:-1);return' ,.?!:;"-()'.includes(t.charAt(r))}function Ic(t,e,n){return e===(n?t.endOffset:0)}function Ec(t,e){const n=[];Array.from(t.getItems({direction:"backward"})).map(t=>e.createRangeOn(t)).filter(e=>(e.start.isAfter(t.start)||e.start.isEqual(t.start))&&(e.end.isBefore(t.end)||e.end.isEqual(t.end))).forEach(t=>{n.push(t.start.parent),e.remove(t)}),n.forEach(t=>{let n=t;for(;n.parent&&n.isEmpty;){const t=e.createRangeOn(n);n=n.parent,e.remove(t)}})}function Lc(t){t.document.registerPostFixer(e=>function(t,e){const n=e.document.selection,r=e.schema,i=[];let o=!1;for(const a of n.getRanges()){const t=Bc(a,r);t&&!t.isEqual(a)?(i.push(t),o=!0):i.push(a)}o&&t.setSelection(function(t){const e=[];e.push(t.shift());for(const n of t){const t=e.pop();if(n.isEqual(t))e.push(t);else if(n.isIntersecting(t)){const r=t.start.isAfter(n.start)?n.start:t.start,i=t.end.isAfter(n.end)?t.end:n.end,o=new Va(r,i);e.push(o)}else e.push(t),e.push(n)}return e}(i),{backward:n.isBackward})}(e,t))}function Bc(t,e){return t.isCollapsed?function(t,e){const n=t.start,r=e.getNearestSelectionRange(n);if(!r)return null;if(!r.isCollapsed)return r;const i=r.start;return n.isEqual(i)?null:new Va(i)}(t,e):function(t,e){const{start:n,end:r}=t,i=e.checkChild(n,"$text"),o=e.checkChild(r,"$text"),a=e.getLimitElement(n),s=e.getLimitElement(r);if(a===s){if(i&&o)return null;if(function(t,e,n){const r=t.nodeAfter&&!n.isLimit(t.nodeAfter)||n.checkChild(t,"$text"),i=e.nodeBefore&&!n.isLimit(e.nodeBefore)||n.checkChild(e,"$text");return r||i}(n,r,e)){const t=n.nodeAfter&&e.isSelectable(n.nodeAfter)?null:e.getNearestSelectionRange(n,"forward"),i=r.nodeBefore&&e.isSelectable(r.nodeBefore)?null:e.getNearestSelectionRange(r,"backward"),o=t?t.start:n,a=i?i.end:r;return new Va(o,a)}}const c=a&&!a.is("rootElement"),l=s&&!s.is("rootElement");if(c||l){const t=n.nodeAfter&&r.nodeBefore&&n.nodeAfter.parent===r.nodeBefore.parent,i=c&&(!t||!Fc(n.nodeAfter,e)),o=l&&(!t||!Fc(r.nodeBefore,e));let u=n,d=r;return i&&(u=Aa._createBefore(Hc(a,e))),o&&(d=Aa._createAfter(Hc(s,e))),new Va(u,d)}return null}(t,e)}function Hc(t,e){let n=t,r=n;for(;e.isLimit(r)&&r.parent;)n=r,r=r.parent;return n}function Fc(t,e){return t&&e.isSelectable(t)}class Dc{constructor(){this.markers=new wc,this.document=new gc(this),this.schema=new gs,this._pendingChanges=[],this._currentWriter=null,["insertContent","deleteContent","modifySelection","getSelectedContent","applyOperation"].forEach(t=>this.decorate(t)),this.on("applyOperation",(t,e)=>{e[0]._validate()},{priority:"highest"}),this.schema.register("$root",{isLimit:!0}),this.schema.register("$block",{allowIn:"$root",isBlock:!0}),this.schema.register("$text",{allowIn:"$block",isInline:!0,isContent:!0}),this.schema.register("$clipboardHolder",{allowContentOf:"$root",isLimit:!0}),this.schema.extend("$text",{allowIn:"$clipboardHolder"}),this.schema.register("$marker"),this.schema.addChildCheck((t,e)=>{if("$marker"===e.name)return!0}),Lc(this),this.document.registerPostFixer(rs)}change(t){try{return 0===this._pendingChanges.length?(this._pendingChanges.push({batch:new Bs,callback:t}),this._runPendingChanges()[0]):t(this._currentWriter)}catch(t){hn.a.rethrowUnexpectedError(t,this)}}enqueueChange(t,e){try{"string"==typeof t?t=new Bs(t):"function"==typeof t&&(e=t,t=new Bs),this._pendingChanges.push({batch:t,callback:e}),1==this._pendingChanges.length&&this._runPendingChanges()}catch(t){hn.a.rethrowUnexpectedError(t,this)}}applyOperation(t){t._execute()}insertContent(t,e,n){return function(t,e,n,r){return t.change(i=>{let o;o=n?n instanceof Ba||n instanceof qa?n:i.createSelection(n,r):t.document.selection,o.isCollapsed||t.deleteContent(o,{doNotAutoparagraph:!0});const a=new jc(t,i,o.anchor);let s;s=e.is("documentFragment")?e.getChildren():[e],a.handleNodes(s);const c=a.getSelectionRange();c&&(o instanceof qa?i.setSelection(c):o.setTo(c));const l=a.getAffectedRange()||t.createRange(o.anchor);return a.destroy(),l})}(this,t,e,n)}deleteContent(t,e){Mc(this,t,e)}modifySelection(t,e){!function(t,e,n={}){const r=t.schema,i="backward"!=n.direction,o=n.unit?n.unit:"character",a=e.focus,s=new Oa({boundaries:Tc(a,i),singleCharacters:!0,direction:i?"forward":"backward"}),c={walker:s,schema:r,isForward:i,unit:o};let l;for(;l=s.next();){if(l.done)return;const n=xc(c,l.value);if(n)return void(e instanceof qa?t.change(t=>{t.setSelectionFocus(n)}):e.setFocus(n))}}(this,t,e)}getSelectedContent(t){return function(t,e){return t.change(t=>{const n=t.createDocumentFragment(),r=e.getFirstRange();if(!r||r.isCollapsed)return n;const i=r.start.root,o=r.start.getCommonPath(r.end),a=i.getNodeByPath(o);let s;s=r.start.parent==r.end.parent?r:t.createRange(t.createPositionAt(a,r.start.path[o.length]),t.createPositionAt(a,r.end.path[o.length]+1));const c=s.end.offset-s.start.offset;for(const e of s.getItems({shallow:!0}))e.is("$textProxy")?t.appendText(e.data,e.getAttributes(),n):t.append(t.cloneElement(e,!0),n);if(s!=r){const e=r._getTransformedByMove(s.start,t.createPositionAt(n,0),c)[0],i=t.createRange(t.createPositionAt(n,0),e.start);Ec(t.createRange(e.end,t.createPositionAt(n,"end")),t),Ec(i,t)}return n})}(this,t)}hasContent(t,e={}){const n=t instanceof _a?Va._createIn(t):t;if(n.isCollapsed)return!1;const{ignoreWhitespaces:r=!1,ignoreMarkers:i=!1}=e;if(!i)for(const o of this.markers.getMarkersIntersectingRange(n))if(o.affectsData)return!0;for(const o of n.getItems())if(this.schema.isContent(o)){if(!o.is("$textProxy"))return!0;if(!r)return!0;if(-1!==o.data.search(/\S/))return!0}return!1}createPositionFromPath(t,e,n){return new Aa(t,e,n)}createPositionAt(t,e){return Aa._createAt(t,e)}createPositionAfter(t){return Aa._createAfter(t)}createPositionBefore(t){return Aa._createBefore(t)}createRange(t,e){return new Va(t,e)}createRangeIn(t){return Va._createIn(t)}createRangeOn(t){return Va._createOn(t)}createSelection(t,e,n){return new Ba(t,e,n)}createBatch(t){return new Bs(t)}createOperationFromJSON(t){return class{static fromJSON(t,e){return _c[t.__className].fromJSON(t,e)}}.fromJSON(t,this.document)}destroy(){this.document.destroy(),this.stopListening()}_runPendingChanges(){const t=[];for(this.fire("_beforeChanges");this._pendingChanges.length;){const e=this._pendingChanges[0].batch;this._currentWriter=new ic(this,e);const n=this._pendingChanges[0].callback(this._currentWriter);t.push(n),this.document._handleChangeBlock(this._currentWriter),this._pendingChanges.shift(),this._currentWriter=null}return this.fire("_afterChanges"),t}}On(Dc,$r);class Rc{constructor(){this._listener=Object.create(po)}listenTo(t){this._listener.listenTo(t,"keydown",(t,e)=>{this._listener.fire("_keydown:"+bi(e),e)})}set(t,e,n={}){const r=gi(t),i=n.priority;this._listener.listenTo(this._listener,"_keydown:"+r,(t,n)=>{e(n,()=>{n.preventDefault(),n.stopPropagation(),t.stop()}),t.return=!0},{priority:i})}press(t){return!!this._listener.fire("_keydown:"+bi(t),t)}destroy(){this._listener.stopListening()}}class Nc extends Rc{constructor(t){super(),this.editor=t}set(t,e,n={}){if("string"==typeof e){const t=e;e=(e,n)=>{this.editor.execute(t),n()}}super.set(t,e,n)}}class $c{constructor(t={}){this._context=t.context||new xn({language:t.language}),this._context._addEditor(this,!t.context);const e=Array.from(this.constructor.builtinPlugins||[]);this.config=new rn(t,this.constructor.defaultConfig),this.config.define("plugins",e),this.config.define(this._context._getEditorConfig()),this.plugins=new An(this,e,this._context.plugins),this.locale=this._context.locale,this.t=this.locale.t,this.commands=new ps,this.set("state","initializing"),this.once("ready",()=>this.state="ready",{priority:"high"}),this.once("destroy",()=>this.state="destroyed",{priority:"high"}),this.set("isReadOnly",!1),this.model=new Dc;const n=new xr;this.data=new Ps(this.model,n),this.editing=new fs(this.model,n),this.editing.view.document.bind("isReadOnly").to(this),this.conversion=new Is([this.editing.downcastDispatcher,this.data.downcastDispatcher],this.data.upcastDispatcher),this.conversion.addAlias("dataDowncast",this.data.downcastDispatcher),this.conversion.addAlias("editingDowncast",this.editing.downcastDispatcher),this.keystrokes=new Nc(this),this.keystrokes.listenTo(this.editing.view.document)}initPlugins(){const t=this.config,e=t.get("plugins"),n=t.get("removePlugins")||[],r=t.get("extraPlugins")||[];return this.plugins.init(e.concat(r),n)}destroy(){let t=Promise.resolve();return"initializing"==this.state&&(t=new Promise(t=>this.once("ready",t))),t.then(()=>{this.fire("destroy"),this.stopListening(),this.commands.destroy()}).then(()=>this.plugins.destroy()).then(()=>{this.model.destroy(),this.data.destroy(),this.editing.destroy(),this.keystrokes.destroy()}).then(()=>this._context._removeEditor(this))}execute(...t){try{return this.commands.execute(...t)}catch(t){hn.a.rethrowUnexpectedError(t,this)}}focus(){this.editing.view.focus()}}On($c,$r);var Uc={setData(t){this.data.set(t)},getData(t){return this.data.get(t)}},qc={updateSourceElement(){if(!this.sourceElement)throw new hn.a("editor-missing-sourceelement",this);var t,e;t=this.sourceElement,e=this.data.get(),t instanceof HTMLTextAreaElement&&(t.value=e),t.innerHTML=e}};class Wc{constructor(t){this.editor=t,this._components=new Map}*names(){for(const t of this._components.values())yield t.originalName}add(t,e){this._components.set(Gc(t),{callback:e,originalName:t})}create(t){if(!this.has(t))throw new hn.a("componentfactory-item-missing",this,{name:t});return this._components.get(Gc(t)).callback(this.editor.locale)}has(t){return this._components.has(Gc(t))}}function Gc(t){return String(t).toLowerCase()}class Yc{constructor(){this.set("isFocused",!1),this.set("focusedElement",null),this._elements=new Set,this._nextEventLoopTimeout=null}add(t){if(this._elements.has(t))throw new hn.a("focustracker-add-element-already-exist",this);this.listenTo(t,"focus",()=>this._focus(t),{useCapture:!0}),this.listenTo(t,"blur",()=>this._blur(),{useCapture:!0}),this._elements.add(t)}remove(t){t===this.focusedElement&&this._blur(t),this._elements.has(t)&&(this.stopListening(t),this._elements.delete(t))}destroy(){this.stopListening()}_focus(t){clearTimeout(this._nextEventLoopTimeout),this.focusedElement=t,this.isFocused=!0}_blur(){clearTimeout(this._nextEventLoopTimeout),this._nextEventLoopTimeout=setTimeout(()=>{this.focusedElement=null,this.isFocused=!1},0)}}On(Yc,po),On(Yc,$r);class Kc{constructor(t){this.editor=t,this.componentFactory=new Wc(t),this.focusTracker=new Yc,this._editableElementsMap=new Map,this.listenTo(t.editing.view.document,"layoutChanged",()=>this.update())}get element(){return null}update(){this.fire("update")}destroy(){this.stopListening(),this.focusTracker.destroy();for(const t of this._editableElementsMap.values())t.ckeditorInstance=null;this._editableElementsMap=new Map}setEditableElement(t,e){this._editableElementsMap.set(t,e),e.ckeditorInstance||(e.ckeditorInstance=this.editor)}getEditableElement(t="main"){return this._editableElementsMap.get(t)}getEditableElementsNames(){return this._editableElementsMap.keys()}get _editableElements(){return console.warn("editor-ui-deprecated-editable-elements: The EditorUI#_editableElements property has been deprecated and will be removed in the near future.",{editorUI:this}),this._editableElementsMap}}function Qc(t){return Array.isArray(t)?{items:t,removeItems:[]}:t?Object.assign({items:[],removeItems:[]},t):{items:[],removeItems:[]}}On(Kc,mn),n(14);const Xc=new WeakMap;function Jc(t){const{view:e,element:n,text:r,isDirectHost:i=!0}=t,o=e.document;Xc.has(o)||(Xc.set(o,new Map),o.registerPostFixer(t=>tl(o,t))),Xc.get(o).set(n,{text:r,isDirectHost:i}),e.change(t=>tl(o,t))}function Zc(t,e){return!!e.hasClass("ck-placeholder")&&(t.removeClass("ck-placeholder",e),!0)}function tl(t,e){const n=Xc.get(t);let r=!1;for(const[i,o]of n)el(e,i,o)&&(r=!0);return r}function el(t,e,n){const{text:r,isDirectHost:i}=n,o=i?e:function(t){if(1===t.childCount){const e=t.getChild(0);if(e.is("element")&&!e.is("uiElement"))return e}return null}(e);let a=!1;return!!o&&(n.hostElement=o,o.getAttribute("data-placeholder")!==r&&(t.setAttribute("data-placeholder",r,o),a=!0),function(t){if(!t.isAttached())return!1;const e=!Array.from(t.getChildren()).some(t=>!t.is("uiElement")),n=t.document;if(!n.isFocused&&e)return!0;const r=n.selection.anchor;return!(!e||!r||r.parent===t)}(o)?function(t,e){return!e.hasClass("ck-placeholder")&&(t.addClass("ck-placeholder",e),!0)}(t,o)&&(a=!0):Zc(t,o)&&(a=!0),a)}class nl{constructor(){this._replacedElements=[]}replace(t,e){this._replacedElements.push({element:t,newElement:e}),t.style.display="none",e&&t.parentNode.insertBefore(e,t.nextSibling)}restore(){this._replacedElements.forEach(({element:t,newElement:e})=>{t.style.display="",e&&e.remove()}),this._replacedElements=[]}}class rl extends Kc{constructor(t,e){super(t),this.view=e,this._toolbarConfig=Qc(t.config.get("toolbar")),this._elementReplacer=new nl}get element(){return this.view.element}init(t){const e=this.editor,n=this.view,r=e.editing.view,i=n.editable,o=r.document.getRoot();i.name=o.rootName,n.render();const a=i.element;this.setEditableElement(i.name,a),this.focusTracker.add(a),n.editable.bind("isFocused").to(this.focusTracker),r.attachDomRoot(a),t&&this._elementReplacer.replace(t,this.element),this._initPlaceholder(),this._initToolbar(),this.fire("ready")}destroy(){const t=this.view,e=this.editor.editing.view;this._elementReplacer.restore(),e.detachDomRoot(t.editable.name),t.destroy(),super.destroy()}_initToolbar(){const t=this.editor,e=this.view,n=t.editing.view;e.stickyPanel.bind("isActive").to(this.focusTracker,"isFocused"),e.stickyPanel.limiterElement=e.element,this._toolbarConfig.viewportTopOffset&&(e.stickyPanel.viewportTopOffset=this._toolbarConfig.viewportTopOffset),e.toolbar.fillFromConfig(this._toolbarConfig,this.componentFactory),function({origin:t,originKeystrokeHandler:e,originFocusTracker:n,toolbar:r,beforeFocus:i,afterBlur:o}){n.add(r.element),e.set("Alt+F10",(t,e)=>{n.isFocused&&!r.focusTracker.isFocused&&(i&&i(),r.focus(),e())}),r.keystrokes.set("Esc",(e,n)=>{r.focusTracker.isFocused&&(t.focus(),o&&o(),n())})}({origin:n,originFocusTracker:this.focusTracker,originKeystrokeHandler:t.keystrokes,toolbar:e.toolbar})}_initPlaceholder(){const t=this.editor,e=t.editing.view,n=e.document.getRoot(),r=t.sourceElement,i=t.config.get("placeholder")||r&&"textarea"===r.tagName.toLowerCase()&&r.getAttribute("placeholder");i&&Jc({view:e,element:n,text:i,isDirectHost:!1})}}class il extends zn{constructor(t=[]){super(t,{idProperty:"viewUid"}),this.on("add",(t,e,n)=>{this._renderViewIntoCollectionParent(e,n)}),this.on("remove",(t,e)=>{e.element&&this._parentElement&&e.element.remove()}),this._parentElement=null}destroy(){this.map(t=>t.destroy())}setParent(t){this._parentElement=t;for(const e of this)this._renderViewIntoCollectionParent(e)}delegate(...t){if(!t.length||!t.every(t=>"string"==typeof t))throw new hn.a("ui-viewcollection-delegate-wrong-events",this);return{to:e=>{for(const n of this)for(const r of t)n.delegate(r).to(e);this.on("add",(n,r)=>{for(const i of t)r.delegate(i).to(e)}),this.on("remove",(n,r)=>{for(const i of t)r.stopDelegating(i,e)})}}}_renderViewIntoCollectionParent(t,e){t.isRendered||t.render(),t.element&&this._parentElement&&this._parentElement.insertBefore(t.element,this._parentElement.children[e])}}class ol{constructor(t){Object.assign(this,ml(pl(t))),this._isRendered=!1,this._revertData=null}render(){const t=this._renderNode({intoFragment:!0});return this._isRendered=!0,t}apply(t){return this._revertData={children:[],bindings:[],attributes:{}},this._renderNode({node:t,isApplying:!0,revertData:this._revertData}),t}revert(t){if(!this._revertData)throw new hn.a("ui-template-revert-not-applied",[this,t]);this._revertTemplateFromNode(t,this._revertData)}*getViews(){yield*function*t(e){if(e.children)for(const n of e.children)yl(n)?yield n:kl(n)&&(yield*t(n))}(this)}static bind(t,e){return{to:(n,r)=>new sl({eventNameOrFunction:n,attribute:n,observable:t,emitter:e,callback:r}),if:(n,r,i)=>new cl({observable:t,emitter:e,attribute:n,valueIfTrue:r,callback:i})}}static extend(t,e){if(t._isRendered)throw new hn.a("template-extend-render",[this,t]);!function t(e,n){if(n.attributes&&(e.attributes||(e.attributes={}),vl(e.attributes,n.attributes)),n.eventListeners&&(e.eventListeners||(e.eventListeners={}),vl(e.eventListeners,n.eventListeners)),n.text&&e.text.push(...n.text),n.children&&n.children.length){if(e.children.length!=n.children.length)throw new hn.a("ui-template-extend-children-mismatch",e);let r=0;for(const i of n.children)t(e.children[r++],i)}}(t,ml(pl(e)))}_renderNode(t){let e;if(e=t.node?this.tag&&this.text:this.tag?this.text:!this.text,e)throw new hn.a("ui-template-wrong-syntax",this);return this.text?this._renderText(t):this._renderElement(t)}_renderElement(t){let e=t.node;return e||(e=t.node=document.createElementNS(this.ns||"http://www.w3.org/1999/xhtml",this.tag)),this._renderAttributes(t),this._renderElementChildren(t),this._setUpListeners(t),e}_renderText(t){let e=t.node;return e?t.revertData.text=e.textContent:e=t.node=document.createTextNode(""),ll(this.text)?this._bindToObservable({schema:this.text,updater:dl(e),data:t}):e.textContent=this.text.join(""),e}_renderAttributes(t){let e,n,r,i;if(!this.attributes)return;const o=t.node,a=t.revertData;for(e in this.attributes)if(r=o.getAttribute(e),n=this.attributes[e],a&&(a.attributes[e]=r),i=H(n[0])&&n[0].ns?n[0].ns:null,ll(n)){const s=i?n[0].value:n;a&&Ol(e)&&s.unshift(r),this._bindToObservable({schema:s,updater:hl(o,e,i),data:t})}else"style"==e&&"string"!=typeof n[0]?this._renderStyleAttribute(n[0],t):(a&&r&&Ol(e)&&n.unshift(r),n=n.map(t=>t&&t.value||t).reduce((t,e)=>t.concat(e),[]).reduce(gl,""),wl(n)||o.setAttributeNS(i,e,n))}_renderStyleAttribute(t,e){const n=e.node;for(const r in t){const i=t[r];ll(i)?this._bindToObservable({schema:[i],updater:fl(n,r),data:e}):n.style[r]=i}}_renderElementChildren(t){const e=t.node,n=t.intoFragment?document.createDocumentFragment():e,r=t.isApplying;let i=0;for(const o of this.children)if(_l(o)){if(!r){o.setParent(e);for(const t of o)n.appendChild(t.element)}}else if(yl(o))r||(o.isRendered||o.render(),n.appendChild(o.element));else if(Zi(o))n.appendChild(o);else if(r){const e={children:[],bindings:[],attributes:{}};t.revertData.children.push(e),o._renderNode({node:n.childNodes[i++],isApplying:!0,revertData:e})}else n.appendChild(o.render());t.intoFragment&&e.appendChild(n)}_setUpListeners(t){if(this.eventListeners)for(const e in this.eventListeners){const n=this.eventListeners[e].map(n=>{const[r,i]=e.split("@");return n.activateDomEventListener(r,i,t)});t.revertData&&t.revertData.bindings.push(n)}}_bindToObservable({schema:t,updater:e,data:n}){const r=n.revertData;ul(t,e,n);const i=t.filter(t=>!wl(t)).filter(t=>t.observable).map(r=>r.activateAttributeListener(t,e,n));r&&r.bindings.push(i)}_revertTemplateFromNode(t,e){for(const n of e.bindings)for(const t of n)t();if(e.text)t.textContent=e.text;else{for(const n in e.attributes){const r=e.attributes[n];null===r?t.removeAttribute(n):t.setAttribute(n,r)}for(let n=0;n<e.children.length;++n)this._revertTemplateFromNode(t.childNodes[n],e.children[n])}}}On(ol,mn);class al{constructor(t){Object.assign(this,t)}getValue(t){const e=this.observable[this.attribute];return this.callback?this.callback(e,t):e}activateAttributeListener(t,e,n){const r=()=>ul(t,e,n);return this.emitter.listenTo(this.observable,"change:"+this.attribute,r),()=>{this.emitter.stopListening(this.observable,"change:"+this.attribute,r)}}}class sl extends al{activateDomEventListener(t,e,n){const r=(t,n)=>{e&&!n.target.matches(e)||("function"==typeof this.eventNameOrFunction?this.eventNameOrFunction(n):this.observable.fire(this.eventNameOrFunction,n))};return this.emitter.listenTo(n.node,t,r),()=>{this.emitter.stopListening(n.node,t,r)}}}class cl extends al{getValue(t){return!wl(super.getValue(t))&&(this.valueIfTrue||!0)}}function ll(t){return!!t&&(t.value&&(t=t.value),Array.isArray(t)?t.some(ll):t instanceof al)}function ul(t,e,{node:n}){let r=function(t,e){return t.map(t=>t instanceof al?t.getValue(e):t)}(t,n);r=1==t.length&&t[0]instanceof cl?r[0]:r.reduce(gl,""),wl(r)?e.remove():e.set(r)}function dl(t){return{set(e){t.textContent=e},remove(){t.textContent=""}}}function hl(t,e,n){return{set(r){t.setAttributeNS(n,e,r)},remove(){t.removeAttributeNS(n,e)}}}function fl(t,e){return{set(n){t.style[e]=n},remove(){t.style[e]=null}}}function pl(t){return en(t,t=>{if(t&&(t instanceof al||kl(t)||yl(t)||_l(t)))return t})}function ml(t){if("string"==typeof t?t=function(t){return{text:[t]}}(t):t.text&&function(t){t.text=jn(t.text)}(t),t.on&&(t.eventListeners=function(t){for(const e in t)bl(t,e);return t}(t.on),delete t.on),!t.text){t.attributes&&function(t){for(const e in t)t[e].value&&(t[e].value=jn(t[e].value)),bl(t,e)}(t.attributes);const e=[];if(t.children)if(_l(t.children))e.push(t.children);else for(const n of t.children)kl(n)||yl(n)||Zi(n)?e.push(n):e.push(new ol(n));t.children=e}return t}function bl(t,e){t[e]=jn(t[e])}function gl(t,e){return wl(e)?t:wl(t)?e:`${t} ${e}`}function vl(t,e){for(const n in e)t[n]?t[n].push(...e[n]):t[n]=e[n]}function wl(t){return!t&&0!==t}function yl(t){return t instanceof zl}function kl(t){return t instanceof ol}function _l(t){return t instanceof il}function Ol(t){return"class"==t||"style"==t}n(16);class zl{constructor(t){this.element=null,this.isRendered=!1,this.locale=t,this.t=t&&t.t,this._viewCollections=new zn,this._unboundChildren=this.createCollection(),this._viewCollections.on("add",(e,n)=>{n.locale=t}),this.decorate("render")}get bindTemplate(){return this._bindTemplate?this._bindTemplate:this._bindTemplate=ol.bind(this,this)}createCollection(t){const e=new il(t);return this._viewCollections.add(e),e}registerChild(t){_n(t)||(t=[t]);for(const e of t)this._unboundChildren.add(e)}deregisterChild(t){_n(t)||(t=[t]);for(const e of t)this._unboundChildren.remove(e)}setTemplate(t){this.template=new ol(t)}extendTemplate(t){ol.extend(this.template,t)}render(){if(this.isRendered)throw new hn.a("ui-view-render-already-rendered",this);this.template&&(this.element=this.template.render(),this.registerChild(this.template.getViews())),this.isRendered=!0}destroy(){this.stopListening(),this._viewCollections.map(t=>t.destroy()),this.template&&this.template._revertData&&this.template.revert(this.element)}}On(zl,po),On(zl,$r);var Al=function(t){return"string"==typeof t||!Et(t)&&b(t)&&"[object String]"==f(t)};class jl extends il{constructor(t,e=[]){super(e),this.locale=t}attachToDom(){this._bodyCollectionContainer=new ol({tag:"div",attributes:{class:["ck","ck-reset_all","ck-body","ck-rounded-corners"],dir:this.locale.uiLanguageDirection},children:this}).render();let t=document.querySelector(".ck-body-wrapper");t||(t=function(t,e,n={},r=[]){const i=n&&n.xmlns,o=i?t.createElementNS(i,e):t.createElement(e);for(const a in n)o.setAttribute(a,n[a]);!Al(r)&&_n(r)||(r=[r]);for(let a of r)Al(a)&&(a=t.createTextNode(a)),o.appendChild(a);return o}(document,"div",{class:"ck-body-wrapper"}),document.body.appendChild(t)),t.appendChild(this._bodyCollectionContainer)}detachFromDom(){super.destroy(),this._bodyCollectionContainer&&this._bodyCollectionContainer.remove();const t=document.querySelector(".ck-body-wrapper");t&&0==t.childElementCount&&t.remove()}}n(18);class Ml extends zl{constructor(t){super(t),this.body=new jl(t)}render(){super.render(),this.body.attachToDom()}destroy(){return this.body.detachFromDom(),super.destroy()}}n(20);class Cl extends zl{constructor(t){super(t),this.set("text"),this.set("for"),this.id="ck-editor__label_"+un();const e=this.bindTemplate;this.setTemplate({tag:"label",attributes:{class:["ck","ck-label"],id:this.id,for:e.to("for")},children:[{text:e.to("text")}]})}}class Vl extends Ml{constructor(t){super(t),this.top=this.createCollection(),this.main=this.createCollection(),this._voiceLabelView=this._createVoiceLabel(),this.setTemplate({tag:"div",attributes:{class:["ck","ck-reset","ck-editor","ck-rounded-corners"],role:"application",dir:t.uiLanguageDirection,lang:t.uiLanguage,"aria-labelledby":this._voiceLabelView.id},children:[this._voiceLabelView,{tag:"div",attributes:{class:["ck","ck-editor__top","ck-reset_all"],role:"presentation"},children:this.top},{tag:"div",attributes:{class:["ck","ck-editor__main"],role:"presentation"},children:this.main}]})}_createVoiceLabel(){const t=this.t,e=new Cl;return e.text=t("Rich Text Editor"),e.extendTemplate({attributes:{class:"ck-voice-label"}}),e}}class Sl extends zl{constructor(t,e,n){super(t),this.setTemplate({tag:"div",attributes:{class:["ck","ck-content","ck-editor__editable","ck-rounded-corners"],lang:t.contentLanguage,dir:t.contentLanguageDirection}}),this.name=null,this.set("isFocused",!1),this._editableElement=n,this._hasExternalElement=!!this._editableElement,this._editingView=e}render(){super.render(),this._hasExternalElement?this.template.apply(this.element=this._editableElement):this._editableElement=this.element,this.on("change:isFocused",()=>this._updateIsFocusedClasses()),this._updateIsFocusedClasses()}destroy(){this._hasExternalElement&&this.template.revert(this._editableElement),super.destroy()}_updateIsFocusedClasses(){const t=this._editingView;function e(e){t.change(n=>{const r=t.document.getRoot(e.name);n.addClass(e.isFocused?"ck-focused":"ck-blurred",r),n.removeClass(e.isFocused?"ck-blurred":"ck-focused",r)})}t.isRenderingInProgress?function n(r){t.once("change:isRenderingInProgress",(t,i,o)=>{o?n(r):e(r)})}(this):e(this)}}class xl extends Sl{constructor(t,e,n){super(t,e,n),this.extendTemplate({attributes:{role:"textbox",class:"ck-editor__editable_inline"}})}render(){super.render();const t=this._editingView,e=this.t;t.change(n=>{const r=t.document.getRoot(this.name);n.setAttribute("aria-label",e("Rich Text Editor, %0",this.name),r)})}}function Tl(t){return e=>e+t}n(22);const Pl=Tl("px");class Il extends zl{constructor(t){super(t);const e=this.bindTemplate;this.set("isActive",!1),this.set("isSticky",!1),this.set("limiterElement",null),this.set("limiterBottomOffset",50),this.set("viewportTopOffset",0),this.set("_marginLeft",null),this.set("_isStickyToTheLimiter",!1),this.set("_hasViewportTopOffset",!1),this.content=this.createCollection(),this._contentPanelPlaceholder=new ol({tag:"div",attributes:{class:["ck","ck-sticky-panel__placeholder"],style:{display:e.to("isSticky",t=>t?"block":"none"),height:e.to("isSticky",t=>t?Pl(this._panelRect.height):null)}}}).render(),this._contentPanel=new ol({tag:"div",attributes:{class:["ck","ck-sticky-panel__content",e.if("isSticky","ck-sticky-panel__content_sticky"),e.if("_isStickyToTheLimiter","ck-sticky-panel__content_sticky_bottom-limit")],style:{width:e.to("isSticky",t=>t?Pl(this._contentPanelPlaceholder.getBoundingClientRect().width):null),top:e.to("_hasViewportTopOffset",t=>t?Pl(this.viewportTopOffset):null),bottom:e.to("_isStickyToTheLimiter",t=>t?Pl(this.limiterBottomOffset):null),marginLeft:e.to("_marginLeft")}},children:this.content}).render(),this.setTemplate({tag:"div",attributes:{class:["ck","ck-sticky-panel"]},children:[this._contentPanelPlaceholder,this._contentPanel]})}render(){super.render(),this._checkIfShouldBeSticky(),this.listenTo(io.window,"scroll",()=>{this._checkIfShouldBeSticky()}),this.listenTo(this,"change:isActive",()=>{this._checkIfShouldBeSticky()})}_checkIfShouldBeSticky(){const t=this._panelRect=this._contentPanel.getBoundingClientRect();let e;this.limiterElement?(e=this._limiterRect=this.limiterElement.getBoundingClientRect(),this.isSticky=this.isActive&&e.top<this.viewportTopOffset&&this._panelRect.height+this.limiterBottomOffset<e.height):this.isSticky=!1,this.isSticky?(this._isStickyToTheLimiter=e.bottom<t.height+this.limiterBottomOffset+this.viewportTopOffset,this._hasViewportTopOffset=!this._isStickyToTheLimiter&&!!this.viewportTopOffset,this._marginLeft=this._isStickyToTheLimiter?null:Pl(-io.window.scrollX)):(this._isStickyToTheLimiter=!1,this._hasViewportTopOffset=!1,this._marginLeft=null)}}class El{constructor(t){if(Object.assign(this,t),t.actions&&t.keystrokeHandler)for(const e in t.actions){let n=t.actions[e];"string"==typeof n&&(n=[n]);for(const r of n)t.keystrokeHandler.set(r,(t,n)=>{this[e](),n()})}}get first(){return this.focusables.find(Ll)||null}get last(){return this.focusables.filter(Ll).slice(-1)[0]||null}get next(){return this._getFocusableItem(1)}get previous(){return this._getFocusableItem(-1)}get current(){let t=null;return null===this.focusTracker.focusedElement?null:(this.focusables.find((e,n)=>{const r=e.element===this.focusTracker.focusedElement;return r&&(t=n),r}),t)}focusFirst(){this._focus(this.first)}focusLast(){this._focus(this.last)}focusNext(){this._focus(this.next)}focusPrevious(){this._focus(this.previous)}_focus(t){t&&t.focus()}_getFocusableItem(t){const e=this.current,n=this.focusables.length;if(!n)return null;if(null===e)return this[1===t?"first":"last"];let r=(e+n+t)%n;do{const e=this.focusables.get(r);if(Ll(e))return e;r=(r+n+t)%n}while(r!==e);return null}}function Ll(t){return!(!t.focus||"none"==io.window.getComputedStyle(t.element).display)}class Bl extends zl{constructor(t){super(t),this.setTemplate({tag:"span",attributes:{class:["ck","ck-toolbar__separator"]}})}}class Hl extends zl{constructor(t){super(t),this.setTemplate({tag:"span",attributes:{class:["ck","ck-toolbar__line-break"]}})}}class Fl{constructor(t,e){Fl._observerInstance||Fl._createObserver(),this._element=t,this._callback=e,Fl._addElementCallback(t,e),Fl._observerInstance.observe(t)}destroy(){Fl._deleteElementCallback(this._element,this._callback)}static _addElementCallback(t,e){Fl._elementCallbacks||(Fl._elementCallbacks=new Map);let n=Fl._elementCallbacks.get(t);n||(n=new Set,Fl._elementCallbacks.set(t,n)),n.add(e)}static _deleteElementCallback(t,e){const n=Fl._getElementCallbacks(t);n&&(n.delete(e),n.size||(Fl._elementCallbacks.delete(t),Fl._observerInstance.unobserve(t))),Fl._elementCallbacks&&!Fl._elementCallbacks.size&&(Fl._observerInstance=null,Fl._elementCallbacks=null)}static _getElementCallbacks(t){return Fl._elementCallbacks?Fl._elementCallbacks.get(t):null}static _createObserver(){let t;t="function"==typeof io.window.ResizeObserver?io.window.ResizeObserver:Dl,Fl._observerInstance=new t(t=>{for(const e of t){const t=Fl._getElementCallbacks(e.target);if(t)for(const n of t)n(e)}})}}Fl._observerInstance=null,Fl._elementCallbacks=null;class Dl{constructor(t){this._callback=t,this._elements=new Set,this._previousRects=new Map,this._periodicCheckTimeout=null}observe(t){this._elements.add(t),this._checkElementRectsAndExecuteCallback(),1===this._elements.size&&this._startPeriodicCheck()}unobserve(t){this._elements.delete(t),this._previousRects.delete(t),this._elements.size||this._stopPeriodicCheck()}_startPeriodicCheck(){const t=()=>{this._checkElementRectsAndExecuteCallback(),this._periodicCheckTimeout=setTimeout(t,100)};this.listenTo(io.window,"resize",()=>{this._checkElementRectsAndExecuteCallback()}),this._periodicCheckTimeout=setTimeout(t,100)}_stopPeriodicCheck(){clearTimeout(this._periodicCheckTimeout),this.stopListening(),this._previousRects.clear()}_checkElementRectsAndExecuteCallback(){const t=[];for(const e of this._elements)this._hasRectChanged(e)&&t.push({target:e,contentRect:this._previousRects.get(e)});t.length&&this._callback(t)}_hasRectChanged(t){if(!t.ownerDocument.body.contains(t))return!1;const e=new ia(t),n=this._previousRects.get(t),r=!n||!n.isEqual(e);return this._previousRects.set(t,e),r}}On(Dl,po);class Rl extends zl{constructor(t){super(t);const e=this.bindTemplate;this.set("isVisible",!1),this.set("position","se"),this.children=this.createCollection(),this.setTemplate({tag:"div",attributes:{class:["ck","ck-reset","ck-dropdown__panel",e.to("position",t=>"ck-dropdown__panel_"+t),e.if("isVisible","ck-dropdown__panel-visible")]},children:this.children,on:{selectstart:e.to(t=>t.preventDefault())}})}focus(){this.children.length&&this.children.first.focus()}focusLast(){if(this.children.length){const t=this.children.last;"function"==typeof t.focusLast?t.focusLast():t.focus()}}}function Nl({element:t,target:e,positions:n,limiter:r,fitInViewport:i}){F(e)&&(e=e()),F(r)&&(r=r());const o=function(t){return t&&t.parentNode?t.offsetParent===io.document.body?null:t.offsetParent:null}(t),a=new ia(t),s=new ia(e);let c,l;if(r||i){const t=function(t,e){const{elementRect:n,viewportRect:r}=e,i=n.getArea(),o=function(t,{targetRect:e,elementRect:n,limiterRect:r,viewportRect:i}){const o=[],a=n.getArea();for(const s of t){const t=$l(s,e,n);if(!t)continue;const[c,l]=t;let u=0,d=0;if(r)if(i){const t=r.getIntersection(i);t&&(u=t.getIntersectionArea(l))}else u=r.getIntersectionArea(l);i&&(d=i.getIntersectionArea(l));const h={positionName:c,positionRect:l,limiterIntersectArea:u,viewportIntersectArea:d};if(u===a)return[h];o.push(h)}return o}(t,e);if(r){const t=Ul(o.filter(({viewportIntersectArea:t})=>t===i),i);if(t)return t}return Ul(o,i)}(n,{targetRect:s,elementRect:a,limiterRect:r&&new ia(r).getVisible(),viewportRect:i&&new ia(io.window)});[l,c]=t||$l(n[0],s,a)}else[l,c]=$l(n[0],s,a);let u=ql(c);return o&&(u=function({left:t,top:e},n){const r=ql(new ia(n)),i=na(n);return t-=r.left,e-=r.top,t+=n.scrollLeft,e+=n.scrollTop,t-=i.left,e-=i.top,{left:t,top:e}}(u,o)),{left:u.left,top:u.top,name:l}}function $l(t,e,n){const r=t(e,n);if(!r)return null;const{left:i,top:o,name:a}=r;return[a,n.clone().moveTo(i,o)]}function Ul(t,e){let n,r,i=0;for(const{positionName:o,positionRect:a,limiterIntersectArea:s,viewportIntersectArea:c}of t){if(s===e)return[o,a];const t=c**2+s**2;t>i&&(i=t,n=a,r=o)}return n?[r,n]:null}function ql({left:t,top:e}){const{scrollX:n,scrollY:r}=io.window;return{left:t+n,top:e+r}}n(24);class Wl extends zl{constructor(t,e,n){super(t);const r=this.bindTemplate;this.buttonView=e,this.panelView=n,this.set("isOpen",!1),this.set("isEnabled",!0),this.set("class"),this.set("id"),this.set("panelPosition","auto"),this.keystrokes=new Rc,this.setTemplate({tag:"div",attributes:{class:["ck","ck-dropdown",r.to("class"),r.if("isEnabled","ck-disabled",t=>!t)],id:r.to("id"),"aria-describedby":r.to("ariaDescribedById")},children:[e,n]}),e.extendTemplate({attributes:{class:["ck-dropdown__button"]}})}render(){super.render(),this.listenTo(this.buttonView,"open",()=>{this.isOpen=!this.isOpen}),this.panelView.bind("isVisible").to(this,"isOpen"),this.on("change:isOpen",()=>{this.isOpen&&("auto"===this.panelPosition?this.panelView.position=Wl._getOptimalPosition({element:this.panelView.element,target:this.buttonView.element,fitInViewport:!0,positions:this._panelPositions}).name:this.panelView.position=this.panelPosition)}),this.keystrokes.listenTo(this.element);const t=(t,e)=>{this.isOpen&&(this.buttonView.focus(),this.isOpen=!1,e())};this.keystrokes.set("arrowdown",(t,e)=>{this.buttonView.isEnabled&&!this.isOpen&&(this.isOpen=!0,e())}),this.keystrokes.set("arrowright",(t,e)=>{this.isOpen&&e()}),this.keystrokes.set("arrowleft",t),this.keystrokes.set("esc",t)}focus(){this.buttonView.focus()}get _panelPositions(){const{south:t,north:e,southEast:n,southWest:r,northEast:i,northWest:o,southMiddleEast:a,southMiddleWest:s,northMiddleEast:c,northMiddleWest:l}=Wl.defaultPanelPositions;return"rtl"!==this.locale.uiLanguageDirection?[n,r,a,s,t,i,o,c,l,e]:[r,n,s,a,t,o,i,l,c,e]}}Wl.defaultPanelPositions={south:(t,e)=>({top:t.bottom,left:t.left-(e.width-t.width)/2,name:"s"}),southEast:t=>({top:t.bottom,left:t.left,name:"se"}),southWest:(t,e)=>({top:t.bottom,left:t.left-e.width+t.width,name:"sw"}),southMiddleEast:(t,e)=>({top:t.bottom,left:t.left-(e.width-t.width)/4,name:"sme"}),southMiddleWest:(t,e)=>({top:t.bottom,left:t.left-3*(e.width-t.width)/4,name:"smw"}),north:(t,e)=>({top:t.top-e.height,left:t.left-(e.width-t.width)/2,name:"n"}),northEast:(t,e)=>({top:t.top-e.height,left:t.left,name:"ne"}),northWest:(t,e)=>({top:t.top-e.height,left:t.left-e.width+t.width,name:"nw"}),northMiddleEast:(t,e)=>({top:t.top-e.height,left:t.left-(e.width-t.width)/4,name:"nme"}),northMiddleWest:(t,e)=>({top:t.top-e.height,left:t.left-3*(e.width-t.width)/4,name:"nmw"})},Wl._getOptimalPosition=Nl,n(26);class Gl extends zl{constructor(){super();const t=this.bindTemplate;this.set("content",""),this.set("viewBox","0 0 20 20"),this.set("fillColor",""),this.setTemplate({tag:"svg",ns:"http://www.w3.org/2000/svg",attributes:{class:["ck","ck-icon"],viewBox:t.to("viewBox")}})}render(){super.render(),this._updateXMLContent(),this._colorFillPaths(),this.on("change:content",()=>{this._updateXMLContent(),this._colorFillPaths()}),this.on("change:fillColor",()=>{this._colorFillPaths()})}_updateXMLContent(){if(this.content){const t=(new DOMParser).parseFromString(this.content.trim(),"image/svg+xml").querySelector("svg"),e=t.getAttribute("viewBox");for(e&&(this.viewBox=e),this.element.innerHTML="";t.childNodes.length>0;)this.element.appendChild(t.childNodes[0])}}_colorFillPaths(){this.fillColor&&this.element.querySelectorAll(".ck-icon__fill").forEach(t=>{t.style.fill=this.fillColor})}}n(28);class Yl extends zl{constructor(t){super(t),this.set("text",""),this.set("position","s");const e=this.bindTemplate;this.setTemplate({tag:"span",attributes:{class:["ck","ck-tooltip",e.to("position",t=>"ck-tooltip_"+t),e.if("text","ck-hidden",t=>!t.trim())]},children:[{tag:"span",attributes:{class:["ck","ck-tooltip__text"]},children:[{text:e.to("text")}]}]})}}n(30);class Kl extends zl{constructor(t){super(t);const e=this.bindTemplate,n=un();this.set("class"),this.set("labelStyle"),this.set("icon"),this.set("isEnabled",!0),this.set("isOn",!1),this.set("isVisible",!0),this.set("isToggleable",!1),this.set("keystroke"),this.set("label"),this.set("tabindex",-1),this.set("tooltip"),this.set("tooltipPosition","s"),this.set("type","button"),this.set("withText",!1),this.set("withKeystroke",!1),this.children=this.createCollection(),this.tooltipView=this._createTooltipView(),this.labelView=this._createLabelView(n),this.iconView=new Gl,this.iconView.extendTemplate({attributes:{class:"ck-button__icon"}}),this.keystrokeView=this._createKeystrokeView(),this.bind("_tooltipString").to(this,"tooltip",this,"label",this,"keystroke",this._getTooltipString.bind(this)),this.setTemplate({tag:"button",attributes:{class:["ck","ck-button",e.to("class"),e.if("isEnabled","ck-disabled",t=>!t),e.if("isVisible","ck-hidden",t=>!t),e.to("isOn",t=>t?"ck-on":"ck-off"),e.if("withText","ck-button_with-text"),e.if("withKeystroke","ck-button_with-keystroke")],type:e.to("type",t=>t||"button"),tabindex:e.to("tabindex"),"aria-labelledby":"ck-editor__aria-label_"+n,"aria-disabled":e.if("isEnabled",!0,t=>!t),"aria-pressed":e.to("isOn",t=>!!this.isToggleable&&String(t))},children:this.children,on:{mousedown:e.to(t=>{t.preventDefault()}),click:e.to(t=>{this.isEnabled?this.fire("execute"):t.preventDefault()})}})}render(){super.render(),this.icon&&(this.iconView.bind("content").to(this,"icon"),this.children.add(this.iconView)),this.children.add(this.tooltipView),this.children.add(this.labelView),this.withKeystroke&&this.children.add(this.keystrokeView)}focus(){this.element.focus()}_createTooltipView(){const t=new Yl;return t.bind("text").to(this,"_tooltipString"),t.bind("position").to(this,"tooltipPosition"),t}_createLabelView(t){const e=new zl,n=this.bindTemplate;return e.setTemplate({tag:"span",attributes:{class:["ck","ck-button__label"],style:n.to("labelStyle"),id:"ck-editor__aria-label_"+t},children:[{text:this.bindTemplate.to("label")}]}),e}_createKeystrokeView(){const t=new zl;return t.setTemplate({tag:"span",attributes:{class:["ck","ck-button__keystroke"]},children:[{text:this.bindTemplate.to("keystroke",t=>vi(t))}]}),t}_getTooltipString(t,e,n){return t?"string"==typeof t?t:(n&&(n=vi(n)),t instanceof Function?t(e,n):`${e}${n?` (${n})`:""}`):""}}var Ql='<svg viewBox="0 0 10 10" xmlns="http://www.w3.org/2000/svg"><path d="M.941 4.523a.75.75 0 1 1 1.06-1.06l3.006 3.005 3.005-3.005a.75.75 0 1 1 1.06 1.06l-3.549 3.55a.75.75 0 0 1-1.168-.136L.941 4.523z"/></svg>';class Xl extends Kl{constructor(t){super(t),this.arrowView=this._createArrowView(),this.extendTemplate({attributes:{"aria-haspopup":!0}}),this.delegate("execute").to(this,"open")}render(){super.render(),this.children.add(this.arrowView)}_createArrowView(){const t=new Gl;return t.content=Ql,t.extendTemplate({attributes:{class:"ck-dropdown__arrow"}}),t}}n(32);class Jl extends zl{constructor(){super(),this.items=this.createCollection(),this.focusTracker=new Yc,this.keystrokes=new Rc,this._focusCycler=new El({focusables:this.items,focusTracker:this.focusTracker,keystrokeHandler:this.keystrokes,actions:{focusPrevious:"arrowup",focusNext:"arrowdown"}}),this.setTemplate({tag:"ul",attributes:{class:["ck","ck-reset","ck-list"]},children:this.items})}render(){super.render();for(const t of this.items)this.focusTracker.add(t.element);this.items.on("add",(t,e)=>{this.focusTracker.add(e.element)}),this.items.on("remove",(t,e)=>{this.focusTracker.remove(e.element)}),this.keystrokes.listenTo(this.element)}focus(){this._focusCycler.focusFirst()}focusLast(){this._focusCycler.focusLast()}}class Zl extends zl{constructor(t){super(t),this.children=this.createCollection(),this.setTemplate({tag:"li",attributes:{class:["ck","ck-list__item"]},children:this.children})}focus(){this.children.first.focus()}}class tu extends zl{constructor(t){super(t),this.setTemplate({tag:"li",attributes:{class:["ck","ck-list__separator"]}})}}n(34);class eu extends Kl{constructor(t){super(t),this.isToggleable=!0,this.toggleSwitchView=this._createToggleView(),this.extendTemplate({attributes:{class:"ck-switchbutton"}})}render(){super.render(),this.children.add(this.toggleSwitchView)}_createToggleView(){const t=new zl;return t.setTemplate({tag:"span",attributes:{class:["ck","ck-button__toggle"]},children:[{tag:"span",attributes:{class:["ck","ck-button__toggle__inner"]}}]}),t}}function nu({emitter:t,activator:e,callback:n,contextElements:r}){t.listenTo(document,"mousedown",(t,i)=>{if(!e())return;const o="function"==typeof i.composedPath?i.composedPath():[];for(const e of r)if(e.contains(i.target)||o.includes(e))return;n()})}function ru(t,e=Xl){const n=new e(t),r=new Rl(t),i=new Wl(t,n,r);return n.bind("isEnabled").to(i),n instanceof Xl?n.bind("isOn").to(i,"isOpen"):n.arrowView.bind("isOn").to(i,"isOpen"),function(t){(function(t){t.on("render",()=>{nu({emitter:t,activator:()=>t.isOpen,callback:()=>{t.isOpen=!1},contextElements:[t.element]})})})(t),function(t){t.on("execute",e=>{e.source instanceof eu||(t.isOpen=!1)})}(t),function(t){t.keystrokes.set("arrowdown",(e,n)=>{t.isOpen&&(t.panelView.focus(),n())}),t.keystrokes.set("arrowup",(e,n)=>{t.isOpen&&(t.panelView.focusLast(),n())})}(t)}(i),i}function iu(t,e){const n=t.locale,r=t.listView=new Jl(n);r.items.bindTo(e).using(({type:t,model:e})=>{if("separator"===t)return new tu(n);if("button"===t||"switchbutton"===t){const r=new Zl(n);let i;return i="button"===t?new Kl(n):new eu(n),i.bind(...Object.keys(e)).to(e),i.delegate("execute").to(r),r.children.add(i),r}}),t.panelView.children.add(r),r.items.delegate("execute").to(t)}n(36),n(38),n(40);class ou extends zl{constructor(t,e){super(t);const n=this.bindTemplate,r=this.t;this.options=e||{},this.set("ariaLabel",r("Editor toolbar")),this.set("maxWidth","auto"),this.items=this.createCollection(),this.focusTracker=new Yc,this.keystrokes=new Rc,this.set("class"),this.set("isCompact",!1),this.itemsView=new au(t),this.children=this.createCollection(),this.children.add(this.itemsView),this.focusables=this.createCollection(),this._focusCycler=new El({focusables:this.focusables,focusTracker:this.focusTracker,keystrokeHandler:this.keystrokes,actions:{focusPrevious:["arrowleft","arrowup"],focusNext:["arrowright","arrowdown"]}});const i=["ck","ck-toolbar",n.to("class"),n.if("isCompact","ck-toolbar_compact")];var o;this.options.shouldGroupWhenFull&&this.options.isFloating&&i.push("ck-toolbar_floating"),this.setTemplate({tag:"div",attributes:{class:i,role:"toolbar","aria-label":n.to("ariaLabel"),style:{maxWidth:n.to("maxWidth")}},children:this.children,on:{mousedown:(o=this,o.bindTemplate.to(t=>{t.target===o.element&&t.preventDefault()}))}}),this._behavior=this.options.shouldGroupWhenFull?new cu(this):new su(this)}render(){super.render();for(const t of this.items)this.focusTracker.add(t.element);this.items.on("add",(t,e)=>{this.focusTracker.add(e.element)}),this.items.on("remove",(t,e)=>{this.focusTracker.remove(e.element)}),this.keystrokes.listenTo(this.element),this._behavior.render(this)}destroy(){return this._behavior.destroy(),super.destroy()}focus(){this._focusCycler.focusFirst()}focusLast(){this._focusCycler.focusLast()}fillFromConfig(t,e){const n=Qc(t),r=n.items.filter((t,r,i)=>"|"===t||-1===n.removeItems.indexOf(t)&&("-"===t?!this.options.shouldGroupWhenFull||(Object(hn.c)("toolbarview-line-break-ignored-when-grouping-items",i),!1):!!e.has(t)||(Object(hn.c)("toolbarview-item-unavailable",{name:t}),!1))),i=this._cleanSeparators(r).map(t=>"|"===t?new Bl:"-"===t?new Hl:e.create(t));this.items.addMany(i)}_cleanSeparators(t){const e=t=>"-"!==t&&"|"!==t,n=t.length,r=t.findIndex(e),i=n-t.slice().reverse().findIndex(e);return t.slice(r,i).filter((t,n,r)=>!!e(t)||!(n>0&&r[n-1]===t))}}class au extends zl{constructor(t){super(t),this.children=this.createCollection(),this.setTemplate({tag:"div",attributes:{class:["ck","ck-toolbar__items"]},children:this.children})}}class su{constructor(t){const e=t.bindTemplate;t.set("isVertical",!1),t.itemsView.children.bindTo(t.items).using(t=>t),t.focusables.bindTo(t.items).using(t=>t),t.extendTemplate({attributes:{class:[e.if("isVertical","ck-toolbar_vertical")]}})}render(){}destroy(){}}class cu{constructor(t){this.view=t,this.viewChildren=t.children,this.viewFocusables=t.focusables,this.viewItemsView=t.itemsView,this.viewFocusTracker=t.focusTracker,this.viewLocale=t.locale,this.ungroupedItems=t.createCollection(),this.groupedItems=t.createCollection(),this.groupedItemsDropdown=this._createGroupedItemsDropdown(),this.resizeObserver=null,this.cachedPadding=null,this.shouldUpdateGroupingOnNextResize=!1,t.itemsView.children.bindTo(this.ungroupedItems).using(t=>t),this.ungroupedItems.on("add",this._updateFocusCycleableItems.bind(this)),this.ungroupedItems.on("remove",this._updateFocusCycleableItems.bind(this)),t.children.on("add",this._updateFocusCycleableItems.bind(this)),t.children.on("remove",this._updateFocusCycleableItems.bind(this)),t.items.on("change",(t,e)=>{const n=e.index;for(const r of e.removed)n>=this.ungroupedItems.length?this.groupedItems.remove(r):this.ungroupedItems.remove(r);for(let r=n;r<n+e.added.length;r++){const t=e.added[r-n];r>this.ungroupedItems.length?this.groupedItems.add(t,r-this.ungroupedItems.length):this.ungroupedItems.add(t,r)}this._updateGrouping()}),t.extendTemplate({attributes:{class:["ck-toolbar_grouping"]}})}render(t){this.viewElement=t.element,this._enableGroupingOnResize(),this._enableGroupingOnMaxWidthChange(t)}destroy(){this.groupedItemsDropdown.destroy(),this.resizeObserver.destroy()}_updateGrouping(){if(!this.viewElement.ownerDocument.body.contains(this.viewElement))return;if(!this.viewElement.offsetParent)return void(this.shouldUpdateGroupingOnNextResize=!0);const t=this.groupedItems.length;let e;for(;this._areItemsOverflowing;)this._groupLastItem(),e=!0;if(!e&&this.groupedItems.length){for(;this.groupedItems.length&&!this._areItemsOverflowing;)this._ungroupFirstItem();this._areItemsOverflowing&&this._groupLastItem()}this.groupedItems.length!==t&&this.view.fire("groupedItemsUpdate")}get _areItemsOverflowing(){if(!this.ungroupedItems.length)return!1;const t=this.viewElement,e=this.viewLocale.uiLanguageDirection,n=new ia(t.lastChild),r=new ia(t);if(!this.cachedPadding){const n=io.window.getComputedStyle(t),r="ltr"===e?"paddingRight":"paddingLeft";this.cachedPadding=Number.parseInt(n[r])}return"ltr"===e?n.right>r.right-this.cachedPadding:n.left<r.left+this.cachedPadding}_enableGroupingOnResize(){let t;this.resizeObserver=new Fl(this.viewElement,e=>{t&&t===e.contentRect.width&&!this.shouldUpdateGroupingOnNextResize||(this.shouldUpdateGroupingOnNextResize=!1,this._updateGrouping(),t=e.contentRect.width)}),this._updateGrouping()}_enableGroupingOnMaxWidthChange(t){t.on("change:maxWidth",()=>{this._updateGrouping()})}_groupLastItem(){this.groupedItems.length||(this.viewChildren.add(new Bl),this.viewChildren.add(this.groupedItemsDropdown),this.viewFocusTracker.add(this.groupedItemsDropdown.element)),this.groupedItems.add(this.ungroupedItems.remove(this.ungroupedItems.last),0)}_ungroupFirstItem(){this.ungroupedItems.add(this.groupedItems.remove(this.groupedItems.first)),this.groupedItems.length||(this.viewChildren.remove(this.groupedItemsDropdown),this.viewChildren.remove(this.viewChildren.last),this.viewFocusTracker.remove(this.groupedItemsDropdown.element))}_createGroupedItemsDropdown(){const t=this.viewLocale,e=t.t,n=ru(t);return n.class="ck-toolbar__grouped-dropdown",n.panelPosition="ltr"===t.uiLanguageDirection?"sw":"se",function(t,e){const n=t.locale,r=n.t,i=t.toolbarView=new ou(n);i.set("ariaLabel",r("Dropdown toolbar")),t.extendTemplate({attributes:{class:["ck-toolbar-dropdown"]}}),e.map(t=>i.items.add(t)),t.panelView.children.add(i),i.items.delegate("execute").to(t)}(n,[]),n.buttonView.set({label:e("Show more items"),tooltip:!0,tooltipPosition:"rtl"===t.uiLanguageDirection?"se":"sw",icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><circle cx="9.5" cy="4.5" r="1.5"/><circle cx="9.5" cy="10.5" r="1.5"/><circle cx="9.5" cy="16.5" r="1.5"/></svg>'}),n.toolbarView.items.bindTo(this.groupedItems).using(t=>t),n}_updateFocusCycleableItems(){this.viewFocusables.clear(),this.ungroupedItems.map(t=>{this.viewFocusables.add(t)}),this.groupedItems.length&&this.viewFocusables.add(this.groupedItemsDropdown)}}n(42);class lu extends Vl{constructor(t,e,n={}){super(t),this.stickyPanel=new Il(t),this.toolbar=new ou(t,{shouldGroupWhenFull:n.shouldToolbarGroupWhenFull}),this.editable=new xl(t,e)}render(){super.render(),this.stickyPanel.content.add(this.toolbar),this.top.add(this.stickyPanel),this.main.add(this.editable)}}class uu extends $c{constructor(t,e){super(e),nn(t)&&(this.sourceElement=t),this.model.document.createRoot();const n=!this.config.get("toolbar.shouldNotGroupWhenFull"),r=new lu(this.locale,this.editing.view,{shouldToolbarGroupWhenFull:n});this.ui=new rl(this,r),function(t){if(!F(t.updateSourceElement))throw new hn.a("attachtoform-missing-elementapi-interface",t);const e=t.sourceElement;if(e&&"textarea"===e.tagName.toLowerCase()&&e.form){let n;const r=e.form,i=()=>t.updateSourceElement();F(r.submit)&&(n=r.submit,r.submit=()=>{i(),n.apply(r)}),r.addEventListener("submit",i),t.on("destroy",()=>{r.removeEventListener("submit",i),n&&(r.submit=n)})}}(this)}destroy(){return this.sourceElement&&this.updateSourceElement(),this.ui.destroy(),super.destroy()}static create(t,e={}){return new Promise(n=>{const r=new this(t,e);n(r.initPlugins().then(()=>r.ui.init(nn(t)?t:null)).then(()=>{if(!nn(t)&&e.initialData)throw new hn.a("editor-create-initial-data",null);const n=e.initialData||function(t){return nn(t)?(e=t,e instanceof HTMLTextAreaElement?e.value:e.innerHTML):t;var e}(t);return r.data.init(n)}).then(()=>r.fire("ready")).then(()=>r))})}}On(uu,Uc),On(uu,qc);class du{constructor(t){this.editor=t,this.set("isEnabled",!0),this._disableStack=new Set}forceDisabled(t){this._disableStack.add(t),1==this._disableStack.size&&(this.on("set:isEnabled",hu,{priority:"highest"}),this.isEnabled=!1)}clearForceDisabled(t){this._disableStack.delete(t),0==this._disableStack.size&&(this.off("set:isEnabled",hu),this.isEnabled=!0)}destroy(){this.stopListening()}static get isContextPlugin(){return!1}}function hu(t){t.return=!1,t.stop()}On(du,$r);class fu{constructor(t){this.files=function(t){const e=t.files?Array.from(t.files):[],n=t.items?Array.from(t.items):[];return e.length?e:n.filter(t=>"file"===t.kind).map(t=>t.getAsFile())}(t),this._native=t}get types(){return this._native.types}getData(t){return this._native.getData(t)}setData(t,e){this._native.setData(t,e)}}class pu extends Ho{constructor(t){super(t);const e=this.document;function n(t,n){n.preventDefault();const r=n.dropRange?[n.dropRange]:Array.from(e.selection.getRanges()),i=new cn(e,"clipboardInput");e.fire(i,{dataTransfer:n.dataTransfer,targetRanges:r}),i.stop.called&&n.stopPropagation()}this.domEventType=["paste","copy","cut","drop","dragover"],this.listenTo(e,"paste",n,{priority:"low"}),this.listenTo(e,"drop",n,{priority:"low"})}onDomEvent(t){const e={dataTransfer:new fu(t.clipboardData?t.clipboardData:t.dataTransfer)};"drop"==t.type&&(e.dropRange=function(t,e){const n=e.target.ownerDocument,r=e.clientX,i=e.clientY;let o;return n.caretRangeFromPoint&&n.caretRangeFromPoint(r,i)?o=n.caretRangeFromPoint(r,i):e.rangeParent&&(o=n.createRange(),o.setStart(e.rangeParent,e.rangeOffset),o.collapse(!0)),o?t.domConverter.domRangeToView(o):t.document.selection.getFirstRange()}(this.view,t)),this.fire(t.type,t,e)}}class mu extends du{static get pluginName(){return"PastePlainText"}init(){const t=this.editor.editing.view,e=t.document;let n=!1;t.addObserver(pu),this.listenTo(e,"keydown",(t,e)=>{n=e.shiftKey}),this.listenTo(e,"clipboardInput",(t,e)=>{n&&(e.asPlainText=!0)},{priority:"high"})}}const bu=["figcaption","li"];class gu extends du{static get pluginName(){return"Clipboard"}static get requires(){return[mu]}init(){const t=this.editor,e=t.model.document,n=t.editing.view,r=n.document;function i(n,i){const o=i.dataTransfer;i.preventDefault();const a=t.data.toView(t.model.getSelectedContent(e.selection));r.fire("clipboardOutput",{dataTransfer:o,content:a,method:n.name})}n.addObserver(pu),this.listenTo(r,"clipboardInput",e=>{t.isReadOnly&&e.stop()},{priority:"highest"}),this.listenTo(r,"clipboardInput",(t,e)=>{const r=e.dataTransfer;let i="";var o;r.getData("text/html")?i=function(t){return t.replace(/<span(?: class="Apple-converted-space"|)>(\s+)<\/span>/g,(t,e)=>1==e.length?" ":e)}(r.getData("text/html")):r.getData("text/plain")&&(((o=(o=r.getData("text/plain")).replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/\r?\n\r?\n/g,"</p><p>").replace(/\r?\n/g,"<br>").replace(/^\s/,"&nbsp;").replace(/\s$/,"&nbsp;").replace(/\s\s/g," &nbsp;")).includes("</p><p>")||o.includes("<br>"))&&(o=`<p>${o}</p>`),i=o),i=this.editor.data.htmlProcessor.toView(i);const a=new cn(this,"inputTransformation");this.fire(a,{content:i,dataTransfer:r,asPlainText:e.asPlainText}),a.stop.called&&t.stop(),n.scrollToTheSelection()},{priority:"low"}),this.listenTo(this,"inputTransformation",(t,e)=>{if(!e.content.isEmpty){const n=this.editor.data,r=this.editor.model,i=n.toModel(e.content,"$clipboardHolder");if(0==i.childCount)return;r.change(t=>{const n=r.document.selection;if(e.asPlainText||function(t,e){if(t.childCount>1)return!1;const n=t.getChild(0);return!e.isObject(n)&&0==[...n.getAttributeKeys()].length}(i,r.schema)){const e=Array.from(n.getAttributes()).filter(([t])=>r.schema.getAttributeProperties(t).isFormatting);n.isCollapsed||r.deleteContent(n,{doNotAutoparagraph:!0}),e.push(...n.getAttributes());const o=t.createRangeIn(i);for(const n of o.getItems())(n.is("$text")||n.is("$textProxy"))&&t.setAttributes(e,n)}r.insertContent(i)}),t.stop()}},{priority:"low"}),this.listenTo(r,"copy",i,{priority:"low"}),this.listenTo(r,"cut",(e,n)=>{t.isReadOnly?n.preventDefault():i(e,n)},{priority:"low"}),this.listenTo(r,"clipboardOutput",(n,r)=>{r.content.isEmpty||(r.dataTransfer.setData("text/html",this.editor.data.htmlProcessor.toData(r.content)),r.dataTransfer.setData("text/plain",function t(e){let n="";if(e.is("$text")||e.is("$textProxy"))n=e.data;else if(e.is("element","img")&&e.hasAttribute("alt"))n=e.getAttribute("alt");else if(e.is("element","br"))n="\n";else{let r=null;for(const i of e.getChildren()){const e=t(i);r&&(r.is("containerElement")||i.is("containerElement"))&&(bu.includes(r.name)||bu.includes(i.name)?n+="\n":n+="\n\n"),n+=e,r=i}}return n}(r.content))),"cut"==r.method&&t.model.deleteContent(e.selection)},{priority:"low"})}}class vu{constructor(t){this.editor=t,this.set("value",void 0),this.set("isEnabled",!1),this._disableStack=new Set,this.decorate("execute"),this.listenTo(this.editor.model.document,"change",()=>{this.refresh()}),this.on("execute",t=>{this.isEnabled||t.stop()},{priority:"high"}),this.listenTo(t,"change:isReadOnly",(t,e,n)=>{n?this.forceDisabled("readOnlyMode"):this.clearForceDisabled("readOnlyMode")})}refresh(){this.isEnabled=!0}forceDisabled(t){this._disableStack.add(t),1==this._disableStack.size&&(this.on("set:isEnabled",wu,{priority:"highest"}),this.isEnabled=!1)}clearForceDisabled(t){this._disableStack.delete(t),0==this._disableStack.size&&(this.off("set:isEnabled",wu),this.refresh())}execute(){}destroy(){this.stopListening()}}function wu(t){t.return=!1,t.stop()}function*yu(t,e){for(const n of e)n&&t.getAttributeProperties(n[0]).copyOnEnter&&(yield n)}On(vu,$r);class ku extends vu{execute(){const t=this.editor.model,e=t.document;t.change(n=>{!function(t,e,n,r){const i=n.isCollapsed,o=n.getFirstRange(),a=o.start.parent,s=o.end.parent;if(r.isLimit(a)||r.isLimit(s))i||a!=s||t.deleteContent(n);else if(i){const t=yu(e.model.schema,n.getAttributes());_u(e,o.start),e.setSelectionAttribute(t)}else{const r=!(o.start.isAtStart&&o.end.isAtEnd),i=a==s;t.deleteContent(n,{leaveUnmerged:r}),r&&(i?_u(e,n.focus):e.setSelection(s,0))}}(this.editor.model,n,e.selection,t.schema),this.fire("afterExecute",{writer:n})})}}function _u(t,e){t.split(e),t.setSelection(e.parent.nextSibling,0)}class Ou extends go{constructor(t){super(t);const e=this.document;e.on("keydown",(t,n)=>{if(this.isEnabled&&n.keyCode==mi.enter){let r;e.once("enter",t=>r=t,{priority:"highest"}),e.fire("enter",new Bo(e,n.domEvent,{isSoft:n.shiftKey})),r&&r.stop.called&&t.stop()}})}observe(){}}class zu extends du{static get pluginName(){return"Enter"}init(){const t=this.editor,e=t.editing.view,n=e.document;e.addObserver(Ou),t.commands.add("enter",new ku(t)),this.listenTo(n,"enter",(n,r)=>{r.preventDefault(),r.isSoft||(t.execute("enter"),e.scrollToTheSelection())},{priority:"low"})}}class Au extends vu{execute(){const t=this.editor.model,e=t.document;t.change(n=>{!function(t,e,n){const r=n.isCollapsed,i=n.getFirstRange(),o=i.start.parent,a=i.end.parent,s=o==a;if(r){const r=yu(t.schema,n.getAttributes());ju(t,e,i.end),e.removeSelectionAttribute(n.getAttributeKeys()),e.setSelectionAttribute(r)}else{const r=!(i.start.isAtStart&&i.end.isAtEnd);t.deleteContent(n,{leaveUnmerged:r}),s?ju(t,e,n.focus):r&&e.setSelection(a,0)}}(t,n,e.selection),this.fire("afterExecute",{writer:n})})}refresh(){const t=this.editor.model,e=t.document;this.isEnabled=function(t,e){if(e.rangeCount>1)return!1;const n=e.anchor;if(!n||!t.checkChild(n,"softBreak"))return!1;const r=e.getFirstRange(),i=r.start.parent,o=r.end.parent;return!Mu(i,t)&&!Mu(o,t)||i===o}(t.schema,e.selection)}}function ju(t,e,n){const r=e.createElement("softBreak");t.insertContent(r,n),e.setSelection(r,"after")}function Mu(t,e){return!t.is("rootElement")&&(e.isLimit(t)||Mu(t.parent,e))}class Cu extends du{static get pluginName(){return"ShiftEnter"}init(){const t=this.editor,e=t.model.schema,n=t.conversion,r=t.editing.view,i=r.document;e.register("softBreak",{allowWhere:"$text",isInline:!0}),n.for("upcast").elementToElement({model:"softBreak",view:"br"}),n.for("downcast").elementToElement({model:"softBreak",view:(t,{writer:e})=>e.createEmptyElement("br")}),r.addObserver(Ou),t.commands.add("shiftEnter",new Au(t)),this.listenTo(i,"enter",(e,n)=>{n.preventDefault(),n.isSoft&&(t.execute("shiftEnter"),r.scrollToTheSelection())},{priority:"low"})}}class Vu extends vu{execute(){const t=this.editor.model,e=t.document.selection;let n=t.schema.getLimitElement(e);if(e.containsEntireContent(n)||!Su(t.schema,n))do{if(n=n.parent,!n)return}while(!Su(t.schema,n));t.change(t=>{t.setSelection(n,"in")})}}function Su(t,e){return t.isLimit(e)&&(t.checkChild(e,"$text")||t.checkChild(e,"paragraph"))}const xu=gi("Ctrl+A");class Tu extends du{static get pluginName(){return"SelectAllEditing"}init(){const t=this.editor,e=t.editing.view.document;t.commands.add("selectAll",new Vu(t)),this.listenTo(e,"keydown",(e,n)=>{bi(n)===xu&&(t.execute("selectAll"),n.preventDefault())})}}class Pu extends du{static get pluginName(){return"SelectAllUI"}init(){const t=this.editor;t.ui.componentFactory.add("selectAll",e=>{const n=t.commands.get("selectAll"),r=new Kl(e),i=e.t;return r.set({label:i("Select all"),icon:'<svg width="20" height="20" xmlns="http://www.w3.org/2000/svg"><path d="M.75 15.5a.75.75 0 0 1 .75.75V18l.008.09A.5.5 0 0 0 2 18.5h1.75a.75.75 0 1 1 0 1.5H1.5l-.144-.007a1.5 1.5 0 0 1-1.35-1.349L0 18.5v-2.25a.75.75 0 0 1 .75-.75zm18.5 0a.75.75 0 0 1 .75.75v2.25l-.007.144a1.5 1.5 0 0 1-1.349 1.35L18.5 20h-2.25a.75.75 0 1 1 0-1.5H18a.5.5 0 0 0 .492-.41L18.5 18v-1.75a.75.75 0 0 1 .75-.75zm-10.45 3c.11 0 .2.09.2.2v1.1a.2.2 0 0 1-.2.2H7.2a.2.2 0 0 1-.2-.2v-1.1c0-.11.09-.2.2-.2h1.6zm4 0c.11 0 .2.09.2.2v1.1a.2.2 0 0 1-.2.2h-1.6a.2.2 0 0 1-.2-.2v-1.1c0-.11.09-.2.2-.2h1.6zm.45-5.5a.75.75 0 1 1 0 1.5h-8.5a.75.75 0 1 1 0-1.5h8.5zM1.3 11c.11 0 .2.09.2.2v1.6a.2.2 0 0 1-.2.2H.2a.2.2 0 0 1-.2-.2v-1.6c0-.11.09-.2.2-.2h1.1zm18.5 0c.11 0 .2.09.2.2v1.6a.2.2 0 0 1-.2.2h-1.1a.2.2 0 0 1-.2-.2v-1.6c0-.11.09-.2.2-.2h1.1zm-4.55-2a.75.75 0 1 1 0 1.5H4.75a.75.75 0 1 1 0-1.5h10.5zM1.3 7c.11 0 .2.09.2.2v1.6a.2.2 0 0 1-.2.2H.2a.2.2 0 0 1-.2-.2V7.2c0-.11.09-.2.2-.2h1.1zm18.5 0c.11 0 .2.09.2.2v1.6a.2.2 0 0 1-.2.2h-1.1a.2.2 0 0 1-.2-.2V7.2c0-.11.09-.2.2-.2h1.1zm-4.55-2a.75.75 0 1 1 0 1.5h-2.5a.75.75 0 1 1 0-1.5h2.5zm-5 0a.75.75 0 1 1 0 1.5h-5.5a.75.75 0 0 1 0-1.5h5.5zm-6.5-5a.75.75 0 0 1 0 1.5H2a.5.5 0 0 0-.492.41L1.5 2v1.75a.75.75 0 0 1-1.5 0V1.5l.007-.144A1.5 1.5 0 0 1 1.356.006L1.5 0h2.25zM18.5 0l.144.007a1.5 1.5 0 0 1 1.35 1.349L20 1.5v2.25a.75.75 0 1 1-1.5 0V2l-.008-.09A.5.5 0 0 0 18 1.5h-1.75a.75.75 0 1 1 0-1.5h2.25zM8.8 0c.11 0 .2.09.2.2v1.1a.2.2 0 0 1-.2.2H7.2a.2.2 0 0 1-.2-.2V.2c0-.11.09-.2.2-.2h1.6zm4 0c.11 0 .2.09.2.2v1.1a.2.2 0 0 1-.2.2h-1.6a.2.2 0 0 1-.2-.2V.2c0-.11.09-.2.2-.2h1.6z"/></svg>',keystroke:"Ctrl+A",tooltip:!0}),r.bind("isOn","isEnabled").to(n,"value","isEnabled"),this.listenTo(r,"execute",()=>{t.execute("selectAll"),t.editing.view.focus()}),r})}}class Iu extends du{static get requires(){return[Tu,Pu]}static get pluginName(){return"SelectAll"}}class Eu{constructor(t,e=20){this.model=t,this.size=0,this.limit=e,this.isLocked=!1,this._changeCallback=(t,e)=>{"transparent"!=e.type&&e!==this._batch&&this._reset(!0)},this._selectionChangeCallback=()=>{this._reset()},this.model.document.on("change",this._changeCallback),this.model.document.selection.on("change:range",this._selectionChangeCallback),this.model.document.selection.on("change:attribute",this._selectionChangeCallback)}get batch(){return this._batch||(this._batch=this.model.createBatch()),this._batch}input(t){this.size+=t,this.size>=this.limit&&this._reset(!0)}lock(){this.isLocked=!0}unlock(){this.isLocked=!1}destroy(){this.model.document.off("change",this._changeCallback),this.model.document.selection.off("change:range",this._selectionChangeCallback),this.model.document.selection.off("change:attribute",this._selectionChangeCallback)}_reset(t){this.isLocked&&!t||(this._batch=null,this.size=0)}}class Lu extends vu{constructor(t,e){super(t),this._buffer=new Eu(t.model,e),this._batches=new WeakSet}get buffer(){return this._buffer}destroy(){super.destroy(),this._buffer.destroy()}execute(t={}){const e=this.editor.model,n=e.document,r=t.text||"",i=r.length,o=t.range?e.createSelection(t.range):n.selection,a=t.resultRange;e.enqueueChange(this._buffer.batch,t=>{this._buffer.lock(),this._batches.add(this._buffer.batch),e.deleteContent(o),r&&e.insertContent(t.createText(r,n.selection.getAttributes()),o),a?t.setSelection(a):o.is("documentSelection")||t.setSelection(o),this._buffer.unlock(),this._buffer.input(i)})}}const Bu=[bi("arrowUp"),bi("arrowRight"),bi("arrowDown"),bi("arrowLeft"),9,16,17,18,19,20,27,33,34,35,36,45,91,93,144,145,173,174,175,176,177,178,179,255];for(let Rg=112;Rg<=135;Rg++)Bu.push(Rg);function Hu(t){return!!t.ctrlKey||Bu.includes(t.keyCode)}function Fu(t){if(t.newChildren.length-t.oldChildren.length!=1)return;const e=function(t,e){const n=[];let r,i=0;return t.forEach(t=>{"equal"==t?(o(),i++):"insert"==t?(a("insert")?r.values.push(e[i]):(o(),r={type:"insert",index:i,values:[e[i]]}),i++):a("delete")?r.howMany++:(o(),r={type:"delete",index:i,howMany:1})}),o(),n;function o(){r&&(n.push(r),r=null)}function a(t){return r&&r.type==t}}(Qi(t.oldChildren,t.newChildren,Du),t.newChildren);if(e.length>1)return;const n=e[0];return n.values[0]&&n.values[0].is("$text")?n:void 0}function Du(t,e){return t&&t.is("$text")&&e&&e.is("$text")?t.data===e.data:t===e}class Ru{constructor(t){this.editor=t,this.editing=this.editor.editing}handle(t,e){if(function(t){if(0==t.length)return!1;for(const e of t)if("children"===e.type&&!Fu(e))return!0;return!1}(t))this._handleContainerChildrenMutations(t,e);else for(const n of t)this._handleTextMutation(n,e),this._handleTextNodeInsertion(n)}_handleContainerChildrenMutations(t,e){const n=function(t){const e=t.map(t=>t.node).reduce((t,e)=>t.getCommonAncestor(e,{includeSelf:!0}));if(e)return e.getAncestors({includeSelf:!0,parentFirst:!0}).find(t=>t.is("containerElement")||t.is("rootElement"))}(t);if(!n)return;const r=this.editor.editing.view.domConverter.mapViewToDom(n),i=new co(this.editor.editing.view.document),o=this.editor.data.toModel(i.domToView(r)).getChild(0),a=this.editor.editing.mapper.toModelElement(n);if(!a)return;const s=Array.from(o.getChildren()),c=Array.from(a.getChildren()),l=s[s.length-1],u=c[c.length-1],d=l&&l.is("element","softBreak"),h=u&&!u.is("element","softBreak");d&&h&&s.pop();const f=this.editor.model.schema;if(!Nu(s,f)||!Nu(c,f))return;const p=s.map(t=>t.is("$text")?t.data:"@").join("").replace(/\u00A0/g," "),m=c.map(t=>t.is("$text")?t.data:"@").join("").replace(/\u00A0/g," ");if(m===p)return;const b=Qi(m,p),{firstChangeAt:g,insertions:v,deletions:w}=$u(b);let y=null;e&&(y=this.editing.mapper.toModelRange(e.getFirstRange()));const k=p.substr(g,v),_=this.editor.model.createRange(this.editor.model.createPositionAt(a,g),this.editor.model.createPositionAt(a,g+w));this.editor.execute("input",{text:k,range:_,resultRange:y})}_handleTextMutation(t,e){if("text"!=t.type)return;const n=t.newText.replace(/\u00A0/g," "),r=t.oldText.replace(/\u00A0/g," ");if(r===n)return;const i=Qi(r,n),{firstChangeAt:o,insertions:a,deletions:s}=$u(i);let c=null;e&&(c=this.editing.mapper.toModelRange(e.getFirstRange()));const l=this.editing.view.createPositionAt(t.node,o),u=this.editing.mapper.toModelPosition(l),d=this.editor.model.createRange(u,u.getShiftedBy(s)),h=n.substr(o,a);this.editor.execute("input",{text:h,range:d,resultRange:c})}_handleTextNodeInsertion(t){if("children"!=t.type)return;const e=Fu(t),n=this.editing.view.createPositionAt(t.node,e.index),r=this.editing.mapper.toModelPosition(n),i=e.values[0].data;this.editor.execute("input",{text:i.replace(/\u00A0/g," "),range:this.editor.model.createRange(r)})}}function Nu(t,e){return t.every(t=>e.isInline(t))}function $u(t){let e=null,n=null;for(let o=0;o<t.length;o++)"equal"!=t[o]&&(e=null===e?o:e,n=o);let r=0,i=0;for(let o=e;o<=n;o++)"insert"!=t[o]&&r++,"delete"!=t[o]&&i++;return{insertions:i,deletions:r,firstChangeAt:e}}class Uu extends du{static get pluginName(){return"Input"}init(){const t=this.editor,e=new Lu(t,t.config.get("typing.undoStep")||20);t.commands.add("input",e),function(t){let e=null;const n=t.model,r=t.editing.view,i=t.commands.get("input");function o(t){const o=n.document,s=r.document.isComposing,c=e&&e.isEqual(o.selection);e=null,i.isEnabled&&(Hu(t)||o.selection.isCollapsed||s&&229===t.keyCode||!s&&229===t.keyCode&&c||a())}function a(){const t=i.buffer;t.lock();const e=t.batch;i._batches.add(e),n.enqueueChange(e,()=>{n.deleteContent(n.document.selection)}),t.unlock()}hi.isAndroid?r.document.on("beforeinput",(t,e)=>o(e),{priority:"lowest"}):r.document.on("keydown",(t,e)=>o(e),{priority:"lowest"}),r.document.on("compositionstart",(function(){const t=n.document,e=1!==t.selection.rangeCount||t.selection.getFirstRange().isFlat;t.selection.isCollapsed||e||a()}),{priority:"lowest"}),r.document.on("compositionend",()=>{e=n.createSelection(n.document.selection)},{priority:"lowest"})}(t),function(t){t.editing.view.document.on("mutations",(e,n,r)=>{new Ru(t).handle(n,r)})}(t)}isInput(t){return this.editor.commands.get("input")._batches.has(t)}}class qu extends vu{constructor(t,e){super(t),this.direction=e,this._buffer=new Eu(t.model,t.config.get("typing.undoStep"))}get buffer(){return this._buffer}execute(t={}){const e=this.editor.model,n=e.document;e.enqueueChange(this._buffer.batch,r=>{this._buffer.lock();const i=r.createSelection(t.selection||n.selection),o=t.sequence||1,a=i.isCollapsed;if(i.isCollapsed&&e.modifySelection(i,{direction:this.direction,unit:t.unit}),this._shouldEntireContentBeReplacedWithParagraph(o))return void this._replaceEntireContentWithParagraph(r);if(this._shouldReplaceFirstBlockWithParagraph(i,o))return void this.editor.execute("paragraph",{selection:i});if(i.isCollapsed)return;let s=0;i.getFirstRange().getMinimalFlatRanges().forEach(t=>{s+=ni(t.getWalker({singleCharacters:!0,ignoreElementEnd:!0,shallow:!0}))}),e.deleteContent(i,{doNotResetEntireContent:a,direction:this.direction}),this._buffer.input(s),r.setSelection(i),this._buffer.unlock()})}_shouldEntireContentBeReplacedWithParagraph(t){if(t>1)return!1;const e=this.editor.model,n=e.document.selection,r=e.schema.getLimitElement(n);if(!n.isCollapsed||!n.containsEntireContent(r))return!1;if(!e.schema.checkChild(r,"paragraph"))return!1;const i=r.getChild(0);return!i||"paragraph"!==i.name}_replaceEntireContentWithParagraph(t){const e=this.editor.model,n=e.document.selection,r=e.schema.getLimitElement(n),i=t.createElement("paragraph");t.remove(t.createRangeIn(r)),t.insert(i,r),t.setSelection(i,0)}_shouldReplaceFirstBlockWithParagraph(t,e){const n=this.editor.model;if(e>1||"backward"!=this.direction)return!1;if(!t.isCollapsed)return!1;const r=t.getFirstPosition(),i=n.schema.getLimitElement(r),o=i.getChild(0);return r.parent==o&&!!t.containsEntireContent(o)&&!!n.schema.checkChild(i,"paragraph")&&"paragraph"!=o.name}}class Wu extends go{constructor(t){super(t);const e=t.document;let n=0;function r(t,n,r){let i;e.once("delete",t=>i=t,{priority:Number.POSITIVE_INFINITY}),e.fire("delete",new Bo(e,n,r)),i&&i.stop.called&&t.stop()}e.on("keyup",(t,e)=>{e.keyCode!=mi.delete&&e.keyCode!=mi.backspace||(n=0)}),e.on("keydown",(t,e)=>{const i={};if(e.keyCode==mi.delete)i.direction="forward",i.unit="character";else{if(e.keyCode!=mi.backspace)return;i.direction="backward",i.unit="codePoint"}const o=hi.isMac?e.altKey:e.ctrlKey;i.unit=o?"word":i.unit,i.sequence=++n,r(t,e.domEvent,i)}),hi.isAndroid&&e.on("beforeinput",(e,n)=>{if("deleteContentBackward"!=n.domEvent.inputType)return;const i={unit:"codepoint",direction:"backward",sequence:1},o=n.domTarget.ownerDocument.defaultView.getSelection();o.anchorNode==o.focusNode&&o.anchorOffset+1!=o.focusOffset&&(i.selectionToRemove=t.domConverter.domSelectionToView(o)),r(e,n.domEvent,i)})}observe(){}}class Gu extends du{static get pluginName(){return"Delete"}init(){const t=this.editor,e=t.editing.view,n=e.document;if(e.addObserver(Wu),t.commands.add("forwardDelete",new qu(t,"forward")),t.commands.add("delete",new qu(t,"backward")),this.listenTo(n,"delete",(n,r)=>{const i={unit:r.unit,sequence:r.sequence};if(r.selectionToRemove){const e=t.model.createSelection(),n=[];for(const i of r.selectionToRemove.getRanges())n.push(t.editing.mapper.toModelRange(i));e.setTo(n),i.selection=e}t.execute("forward"==r.direction?"forwardDelete":"delete",i),r.preventDefault(),e.scrollToTheSelection()}),hi.isAndroid){let t=null;this.listenTo(n,"delete",(e,n)=>{const r=n.domTarget.ownerDocument.defaultView.getSelection();t={anchorNode:r.anchorNode,anchorOffset:r.anchorOffset,focusNode:r.focusNode,focusOffset:r.focusOffset}},{priority:"lowest"}),this.listenTo(n,"keyup",(e,n)=>{if(t){const e=n.domTarget.ownerDocument.defaultView.getSelection();e.collapse(t.anchorNode,t.anchorOffset),e.extend(t.focusNode,t.focusOffset),t=null}})}}}class Yu extends du{static get requires(){return[Uu,Gu]}static get pluginName(){return"Typing"}}const Ku=new Map;function Qu(t,e,n){let r=Ku.get(t);r||(r=new Map,Ku.set(t,r)),r.set(e,n)}function Xu(t){return[t]}function Ju(t,e,n={}){const r=function(t,e){const n=Ku.get(t);return n&&n.has(e)?n.get(e):Xu}(t.constructor,e.constructor);try{return r(t=t.clone(),e,n)}catch(t){throw t}}function Zu(t,e,n){t=t.slice(),e=e.slice();const r=new td(n.document,n.useRelations,n.forceWeakRemove);r.setOriginalOperations(t),r.setOriginalOperations(e);const i=r.originalOperations;if(0==t.length||0==e.length)return{operationsA:t,operationsB:e,originalOperations:i};const o=new WeakMap;for(const c of t)o.set(c,0);const a={nextBaseVersionA:t[t.length-1].baseVersion+1,nextBaseVersionB:e[e.length-1].baseVersion+1,originalOperationsACount:t.length,originalOperationsBCount:e.length};let s=0;for(;s<t.length;){const n=t[s],i=o.get(n);if(i==e.length){s++;continue}const a=e[i],c=Ju(n,a,r.getContext(n,a,!0)),l=Ju(a,n,r.getContext(a,n,!1));r.updateRelation(n,a),r.setOriginalOperations(c,n),r.setOriginalOperations(l,a);for(const t of c)o.set(t,i+l.length);t.splice(s,1,...c),e.splice(i,1,...l)}if(n.padWithNoOps){const n=t.length-a.originalOperationsACount,r=e.length-a.originalOperationsBCount;nd(t,r-n),nd(e,n-r)}return ed(t,a.nextBaseVersionB),ed(e,a.nextBaseVersionA),{operationsA:t,operationsB:e,originalOperations:i}}class td{constructor(t,e,n=!1){this.originalOperations=new Map,this._history=t.history,this._useRelations=e,this._forceWeakRemove=!!n,this._relations=new Map}setOriginalOperations(t,e=null){const n=e?this.originalOperations.get(e):null;for(const r of t)this.originalOperations.set(r,n||r)}updateRelation(t,e){switch(t.constructor){case Qs:switch(e.constructor){case ec:t.targetPosition.isEqual(e.sourcePosition)||e.movedRange.containsPosition(t.targetPosition)?this._setRelation(t,e,"insertAtSource"):t.targetPosition.isEqual(e.deletionPosition)?this._setRelation(t,e,"insertBetween"):t.targetPosition.isAfter(e.sourcePosition)&&this._setRelation(t,e,"moveTargetAfter");break;case Qs:t.targetPosition.isEqual(e.sourcePosition)||t.targetPosition.isBefore(e.sourcePosition)?this._setRelation(t,e,"insertBefore"):this._setRelation(t,e,"insertAfter")}break;case nc:switch(e.constructor){case ec:t.splitPosition.isBefore(e.sourcePosition)&&this._setRelation(t,e,"splitBefore");break;case Qs:(t.splitPosition.isEqual(e.sourcePosition)||t.splitPosition.isBefore(e.sourcePosition))&&this._setRelation(t,e,"splitBefore")}break;case ec:switch(e.constructor){case ec:t.targetPosition.isEqual(e.sourcePosition)||this._setRelation(t,e,"mergeTargetNotMoved"),t.sourcePosition.isEqual(e.targetPosition)&&this._setRelation(t,e,"mergeSourceNotMoved"),t.sourcePosition.isEqual(e.sourcePosition)&&this._setRelation(t,e,"mergeSameElement");break;case nc:t.sourcePosition.isEqual(e.splitPosition)&&this._setRelation(t,e,"splitAtSource")}break;case Js:{const n=t.newRange;if(!n)return;switch(e.constructor){case Qs:{const r=Va._createFromPositionAndShift(e.sourcePosition,e.howMany),i=r.containsPosition(n.start)||r.start.isEqual(n.start),o=r.containsPosition(n.end)||r.end.isEqual(n.end);!i&&!o||r.containsRange(n)||this._setRelation(t,e,{side:i?"left":"right",path:i?n.start.path.slice():n.end.path.slice()});break}case ec:{const r=n.start.isEqual(e.targetPosition),i=n.start.isEqual(e.deletionPosition),o=n.end.isEqual(e.deletionPosition),a=n.end.isEqual(e.sourcePosition);(r||i||o||a)&&this._setRelation(t,e,{wasInLeftElement:r,wasStartBeforeMergedElement:i,wasEndBeforeMergedElement:o,wasInRightElement:a});break}}break}}}getContext(t,e,n){return{aIsStrong:n,aWasUndone:this._wasUndone(t),bWasUndone:this._wasUndone(e),abRelation:this._useRelations?this._getRelation(t,e):null,baRelation:this._useRelations?this._getRelation(e,t):null,forceWeakRemove:this._forceWeakRemove}}_wasUndone(t){const e=this.originalOperations.get(t);return e.wasUndone||this._history.isUndoneOperation(e)}_getRelation(t,e){const n=this.originalOperations.get(e),r=this._history.getUndoneOperation(n);if(!r)return null;const i=this.originalOperations.get(t),o=this._relations.get(i);return o&&o.get(r)||null}_setRelation(t,e,n){const r=this.originalOperations.get(t),i=this.originalOperations.get(e);let o=this._relations.get(r);o||(o=new Map,this._relations.set(r,o)),o.set(i,n)}}function ed(t,e){for(const n of t)n.baseVersion=e++}function nd(t,e){for(let n=0;n<e;n++)t.push(new kc(0))}function rd(t,e,n){const r=t.nodes.getNode(0).getAttribute(e);if(r==n)return null;const i=new Va(t.position,t.position.getShiftedBy(t.howMany));return new Ys(i,e,r,n,0)}function id(t,e){return null===t.targetPosition._getTransformedByDeletion(e.sourcePosition,e.howMany)}function od(t,e){const n=[];for(let r=0;r<t.length;r++){const i=t[r],o=new Qs(i.start,i.end.offset-i.start.offset,e,0);n.push(o);for(let e=r+1;e<t.length;e++)t[e]=t[e]._getTransformedByMove(o.sourcePosition,o.targetPosition,o.howMany)[0];e=e._getTransformedByMove(o.sourcePosition,o.targetPosition,o.howMany)}return n}Qu(Ys,Ys,(t,e,n)=>{if(t.key===e.key&&t.range.start.hasSameParentAs(e.range.start)){const r=t.range.getDifference(e.range).map(e=>new Ys(e,t.key,t.oldValue,t.newValue,0)),i=t.range.getIntersection(e.range);return i&&n.aIsStrong&&r.push(new Ys(i,e.key,e.newValue,t.newValue,0)),0==r.length?[new kc(0)]:r}return[t]}),Qu(Ys,Xs,(t,e)=>{if(t.range.start.hasSameParentAs(e.position)&&t.range.containsPosition(e.position)){const n=t.range._getTransformedByInsertion(e.position,e.howMany,!e.shouldReceiveAttributes).map(e=>new Ys(e,t.key,t.oldValue,t.newValue,t.baseVersion));if(e.shouldReceiveAttributes){const r=rd(e,t.key,t.oldValue);r&&n.unshift(r)}return n}return t.range=t.range._getTransformedByInsertion(e.position,e.howMany,!1)[0],[t]}),Qu(Ys,ec,(t,e)=>{const n=[];t.range.start.hasSameParentAs(e.deletionPosition)&&(t.range.containsPosition(e.deletionPosition)||t.range.start.isEqual(e.deletionPosition))&&n.push(Va._createFromPositionAndShift(e.graveyardPosition,1));const r=t.range._getTransformedByMergeOperation(e);return r.isCollapsed||n.push(r),n.map(e=>new Ys(e,t.key,t.oldValue,t.newValue,t.baseVersion))}),Qu(Ys,Qs,(t,e)=>function(t,e){const n=Va._createFromPositionAndShift(e.sourcePosition,e.howMany);let r=null,i=[];n.containsRange(t,!0)?r=t:t.start.hasSameParentAs(n.start)?(i=t.getDifference(n),r=t.getIntersection(n)):i=[t];const o=[];for(let a of i){a=a._getTransformedByDeletion(e.sourcePosition,e.howMany);const t=e.getMovedRangeStart(),n=a.start.hasSameParentAs(t);a=a._getTransformedByInsertion(t,e.howMany,n),o.push(...a)}return r&&o.push(r._getTransformedByMove(e.sourcePosition,e.targetPosition,e.howMany,!1)[0]),o}(t.range,e).map(e=>new Ys(e,t.key,t.oldValue,t.newValue,t.baseVersion))),Qu(Ys,nc,(t,e)=>{if(t.range.end.isEqual(e.insertionPosition))return e.graveyardPosition||t.range.end.offset++,[t];if(t.range.start.hasSameParentAs(e.splitPosition)&&t.range.containsPosition(e.splitPosition)){const n=t.clone();return n.range=new Va(e.moveTargetPosition.clone(),t.range.end._getCombined(e.splitPosition,e.moveTargetPosition)),t.range.end=e.splitPosition.clone(),t.range.end.stickiness="toPrevious",[t,n]}return t.range=t.range._getTransformedBySplitOperation(e),[t]}),Qu(Xs,Ys,(t,e)=>{const n=[t];if(t.shouldReceiveAttributes&&t.position.hasSameParentAs(e.range.start)&&e.range.containsPosition(t.position)){const r=rd(t,e.key,e.newValue);r&&n.push(r)}return n}),Qu(Xs,Xs,(t,e,n)=>(t.position.isEqual(e.position)&&n.aIsStrong||(t.position=t.position._getTransformedByInsertOperation(e)),[t])),Qu(Xs,Qs,(t,e)=>(t.position=t.position._getTransformedByMoveOperation(e),[t])),Qu(Xs,nc,(t,e)=>(t.position=t.position._getTransformedBySplitOperation(e),[t])),Qu(Xs,ec,(t,e)=>(t.position=t.position._getTransformedByMergeOperation(e),[t])),Qu(Js,Xs,(t,e)=>(t.oldRange&&(t.oldRange=t.oldRange._getTransformedByInsertOperation(e)[0]),t.newRange&&(t.newRange=t.newRange._getTransformedByInsertOperation(e)[0]),[t])),Qu(Js,Js,(t,e,n)=>{if(t.name==e.name){if(!n.aIsStrong)return[new kc(0)];t.oldRange=e.newRange?e.newRange.clone():null}return[t]}),Qu(Js,ec,(t,e)=>(t.oldRange&&(t.oldRange=t.oldRange._getTransformedByMergeOperation(e)),t.newRange&&(t.newRange=t.newRange._getTransformedByMergeOperation(e)),[t])),Qu(Js,Qs,(t,e,n)=>{if(t.oldRange&&(t.oldRange=Va._createFromRanges(t.oldRange._getTransformedByMoveOperation(e))),t.newRange){if(n.abRelation){const r=Va._createFromRanges(t.newRange._getTransformedByMoveOperation(e));if("left"==n.abRelation.side&&e.targetPosition.isEqual(t.newRange.start))return t.newRange.start.path=n.abRelation.path,t.newRange.end=r.end,[t];if("right"==n.abRelation.side&&e.targetPosition.isEqual(t.newRange.end))return t.newRange.start=r.start,t.newRange.end.path=n.abRelation.path,[t]}t.newRange=Va._createFromRanges(t.newRange._getTransformedByMoveOperation(e))}return[t]}),Qu(Js,nc,(t,e,n)=>{if(t.oldRange&&(t.oldRange=t.oldRange._getTransformedBySplitOperation(e)),t.newRange){if(n.abRelation){const r=t.newRange._getTransformedBySplitOperation(e);return t.newRange.start.isEqual(e.splitPosition)&&n.abRelation.wasStartBeforeMergedElement?t.newRange.start=Aa._createAt(e.insertionPosition):t.newRange.start.isEqual(e.splitPosition)&&!n.abRelation.wasInLeftElement&&(t.newRange.start=Aa._createAt(e.moveTargetPosition)),t.newRange.end.isEqual(e.splitPosition)&&n.abRelation.wasInRightElement?t.newRange.end=Aa._createAt(e.moveTargetPosition):t.newRange.end.isEqual(e.splitPosition)&&n.abRelation.wasEndBeforeMergedElement?t.newRange.end=Aa._createAt(e.insertionPosition):t.newRange.end=r.end,[t]}t.newRange=t.newRange._getTransformedBySplitOperation(e)}return[t]}),Qu(ec,Xs,(t,e)=>(t.sourcePosition.hasSameParentAs(e.position)&&(t.howMany+=e.howMany),t.sourcePosition=t.sourcePosition._getTransformedByInsertOperation(e),t.targetPosition=t.targetPosition._getTransformedByInsertOperation(e),[t])),Qu(ec,ec,(t,e,n)=>{if(t.sourcePosition.isEqual(e.sourcePosition)&&t.targetPosition.isEqual(e.targetPosition)){if(n.bWasUndone){const n=e.graveyardPosition.path.slice();return n.push(0),t.sourcePosition=new Aa(e.graveyardPosition.root,n),t.howMany=0,[t]}return[new kc(0)]}if(t.sourcePosition.isEqual(e.sourcePosition)&&!t.targetPosition.isEqual(e.targetPosition)&&!n.bWasUndone&&"splitAtSource"!=n.abRelation){const r="$graveyard"==t.targetPosition.root.rootName,i="$graveyard"==e.targetPosition.root.rootName,o=r&&!i;if(i&&!r||!o&&n.aIsStrong){const n=e.targetPosition._getTransformedByMergeOperation(e),r=t.targetPosition._getTransformedByMergeOperation(e);return[new Qs(n,t.howMany,r,0)]}return[new kc(0)]}return t.sourcePosition.hasSameParentAs(e.targetPosition)&&(t.howMany+=e.howMany),t.sourcePosition=t.sourcePosition._getTransformedByMergeOperation(e),t.targetPosition=t.targetPosition._getTransformedByMergeOperation(e),t.graveyardPosition.isEqual(e.graveyardPosition)&&n.aIsStrong||(t.graveyardPosition=t.graveyardPosition._getTransformedByMergeOperation(e)),[t]}),Qu(ec,Qs,(t,e,n)=>{const r=Va._createFromPositionAndShift(e.sourcePosition,e.howMany);return"remove"==e.type&&!n.bWasUndone&&!n.forceWeakRemove&&t.deletionPosition.hasSameParentAs(e.sourcePosition)&&r.containsPosition(t.sourcePosition)?[new kc(0)]:(t.sourcePosition.hasSameParentAs(e.targetPosition)&&(t.howMany+=e.howMany),t.sourcePosition.hasSameParentAs(e.sourcePosition)&&(t.howMany-=e.howMany),t.sourcePosition=t.sourcePosition._getTransformedByMoveOperation(e),t.targetPosition=t.targetPosition._getTransformedByMoveOperation(e),t.graveyardPosition.isEqual(e.targetPosition)||(t.graveyardPosition=t.graveyardPosition._getTransformedByMoveOperation(e)),[t])}),Qu(ec,nc,(t,e,n)=>{if(e.graveyardPosition&&(t.graveyardPosition=t.graveyardPosition._getTransformedByDeletion(e.graveyardPosition,1),t.deletionPosition.isEqual(e.graveyardPosition)&&(t.howMany=e.howMany)),t.targetPosition.isEqual(e.splitPosition)){const r=0!=e.howMany,i=e.graveyardPosition&&t.deletionPosition.isEqual(e.graveyardPosition);if(r||i||"mergeTargetNotMoved"==n.abRelation)return t.sourcePosition=t.sourcePosition._getTransformedBySplitOperation(e),[t]}if(t.sourcePosition.isEqual(e.splitPosition)){if("mergeSourceNotMoved"==n.abRelation)return t.howMany=0,t.targetPosition=t.targetPosition._getTransformedBySplitOperation(e),[t];if("mergeSameElement"==n.abRelation||t.sourcePosition.offset>0)return t.sourcePosition=e.moveTargetPosition.clone(),t.targetPosition=t.targetPosition._getTransformedBySplitOperation(e),[t]}return t.sourcePosition.hasSameParentAs(e.splitPosition)&&(t.howMany=e.splitPosition.offset),t.sourcePosition=t.sourcePosition._getTransformedBySplitOperation(e),t.targetPosition=t.targetPosition._getTransformedBySplitOperation(e),[t]}),Qu(Qs,Xs,(t,e)=>{const n=Va._createFromPositionAndShift(t.sourcePosition,t.howMany)._getTransformedByInsertOperation(e,!1)[0];return t.sourcePosition=n.start,t.howMany=n.end.offset-n.start.offset,t.targetPosition.isEqual(e.position)||(t.targetPosition=t.targetPosition._getTransformedByInsertOperation(e)),[t]}),Qu(Qs,Qs,(t,e,n)=>{const r=Va._createFromPositionAndShift(t.sourcePosition,t.howMany),i=Va._createFromPositionAndShift(e.sourcePosition,e.howMany);let o,a=n.aIsStrong,s=!n.aIsStrong;if("insertBefore"==n.abRelation||"insertAfter"==n.baRelation?s=!0:"insertAfter"!=n.abRelation&&"insertBefore"!=n.baRelation||(s=!1),o=t.targetPosition.isEqual(e.targetPosition)&&s?t.targetPosition._getTransformedByDeletion(e.sourcePosition,e.howMany):t.targetPosition._getTransformedByMove(e.sourcePosition,e.targetPosition,e.howMany),id(t,e)&&id(e,t))return[e.getReversed()];if(r.containsPosition(e.targetPosition)&&r.containsRange(i,!0))return r.start=r.start._getTransformedByMove(e.sourcePosition,e.targetPosition,e.howMany),r.end=r.end._getTransformedByMove(e.sourcePosition,e.targetPosition,e.howMany),od([r],o);if(i.containsPosition(t.targetPosition)&&i.containsRange(r,!0))return r.start=r.start._getCombined(e.sourcePosition,e.getMovedRangeStart()),r.end=r.end._getCombined(e.sourcePosition,e.getMovedRangeStart()),od([r],o);const c=Tn(t.sourcePosition.getParentPath(),e.sourcePosition.getParentPath());if("prefix"==c||"extension"==c)return r.start=r.start._getTransformedByMove(e.sourcePosition,e.targetPosition,e.howMany),r.end=r.end._getTransformedByMove(e.sourcePosition,e.targetPosition,e.howMany),od([r],o);"remove"!=t.type||"remove"==e.type||n.aWasUndone||n.forceWeakRemove?"remove"==t.type||"remove"!=e.type||n.bWasUndone||n.forceWeakRemove||(a=!1):a=!0;const l=[],u=r.getDifference(i);for(const h of u){h.start=h.start._getTransformedByDeletion(e.sourcePosition,e.howMany),h.end=h.end._getTransformedByDeletion(e.sourcePosition,e.howMany);const t="same"==Tn(h.start.getParentPath(),e.getMovedRangeStart().getParentPath()),n=h._getTransformedByInsertion(e.getMovedRangeStart(),e.howMany,t);l.push(...n)}const d=r.getIntersection(i);return null!==d&&a&&(d.start=d.start._getCombined(e.sourcePosition,e.getMovedRangeStart()),d.end=d.end._getCombined(e.sourcePosition,e.getMovedRangeStart()),0===l.length?l.push(d):1==l.length?i.start.isBefore(r.start)||i.start.isEqual(r.start)?l.unshift(d):l.push(d):l.splice(1,0,d)),0===l.length?[new kc(t.baseVersion)]:od(l,o)}),Qu(Qs,nc,(t,e,n)=>{let r=t.targetPosition.clone();t.targetPosition.isEqual(e.insertionPosition)&&e.graveyardPosition&&"moveTargetAfter"!=n.abRelation||(r=t.targetPosition._getTransformedBySplitOperation(e));const i=Va._createFromPositionAndShift(t.sourcePosition,t.howMany);if(i.end.isEqual(e.insertionPosition))return e.graveyardPosition||t.howMany++,t.targetPosition=r,[t];if(i.start.hasSameParentAs(e.splitPosition)&&i.containsPosition(e.splitPosition)){let t=new Va(e.splitPosition,i.end);return t=t._getTransformedBySplitOperation(e),od([new Va(i.start,e.splitPosition),t],r)}t.targetPosition.isEqual(e.splitPosition)&&"insertAtSource"==n.abRelation&&(r=e.moveTargetPosition),t.targetPosition.isEqual(e.insertionPosition)&&"insertBetween"==n.abRelation&&(r=t.targetPosition);const o=[i._getTransformedBySplitOperation(e)];if(e.graveyardPosition){const r=i.start.isEqual(e.graveyardPosition)||i.containsPosition(e.graveyardPosition);t.howMany>1&&r&&!n.aWasUndone&&o.push(Va._createFromPositionAndShift(e.insertionPosition,1))}return od(o,r)}),Qu(Qs,ec,(t,e,n)=>{const r=Va._createFromPositionAndShift(t.sourcePosition,t.howMany);if(e.deletionPosition.hasSameParentAs(t.sourcePosition)&&r.containsPosition(e.sourcePosition))if("remove"!=t.type||n.forceWeakRemove){if(1==t.howMany)return n.bWasUndone?(t.sourcePosition=e.graveyardPosition.clone(),t.targetPosition=t.targetPosition._getTransformedByMergeOperation(e),[t]):[new kc(0)]}else if(!n.aWasUndone){const n=[];let r=e.graveyardPosition.clone(),i=e.targetPosition._getTransformedByMergeOperation(e);t.howMany>1&&(n.push(new Qs(t.sourcePosition,t.howMany-1,t.targetPosition,0)),r=r._getTransformedByMove(t.sourcePosition,t.targetPosition,t.howMany-1),i=i._getTransformedByMove(t.sourcePosition,t.targetPosition,t.howMany-1));const o=e.deletionPosition._getCombined(t.sourcePosition,t.targetPosition),a=new Qs(r,1,o,0),s=a.getMovedRangeStart().path.slice();s.push(0);const c=new Aa(a.targetPosition.root,s);i=i._getTransformedByMove(r,o,1);const l=new Qs(i,e.howMany,c,0);return n.push(a),n.push(l),n}const i=Va._createFromPositionAndShift(t.sourcePosition,t.howMany)._getTransformedByMergeOperation(e);return t.sourcePosition=i.start,t.howMany=i.end.offset-i.start.offset,t.targetPosition=t.targetPosition._getTransformedByMergeOperation(e),[t]}),Qu(Zs,Xs,(t,e)=>(t.position=t.position._getTransformedByInsertOperation(e),[t])),Qu(Zs,ec,(t,e)=>t.position.isEqual(e.deletionPosition)?(t.position=e.graveyardPosition.clone(),t.position.stickiness="toNext",[t]):(t.position=t.position._getTransformedByMergeOperation(e),[t])),Qu(Zs,Qs,(t,e)=>(t.position=t.position._getTransformedByMoveOperation(e),[t])),Qu(Zs,Zs,(t,e,n)=>{if(t.position.isEqual(e.position)){if(!n.aIsStrong)return[new kc(0)];t.oldName=e.newName}return[t]}),Qu(Zs,nc,(t,e)=>{if("same"==Tn(t.position.path,e.splitPosition.getParentPath())&&!e.graveyardPosition){const e=new Zs(t.position.getShiftedBy(1),t.oldName,t.newName,0);return[t,e]}return t.position=t.position._getTransformedBySplitOperation(e),[t]}),Qu(tc,tc,(t,e,n)=>{if(t.root===e.root&&t.key===e.key){if(!n.aIsStrong||t.newValue===e.newValue)return[new kc(0)];t.oldValue=e.newValue}return[t]}),Qu(nc,Xs,(t,e)=>(t.splitPosition.hasSameParentAs(e.position)&&t.splitPosition.offset<e.position.offset&&(t.howMany+=e.howMany),t.splitPosition=t.splitPosition._getTransformedByInsertOperation(e),t.insertionPosition=nc.getInsertionPosition(t.splitPosition),[t])),Qu(nc,ec,(t,e,n)=>{if(!t.graveyardPosition&&!n.bWasUndone&&t.splitPosition.hasSameParentAs(e.sourcePosition)){const n=e.graveyardPosition.path.slice();n.push(0);const r=new Aa(e.graveyardPosition.root,n),i=nc.getInsertionPosition(new Aa(e.graveyardPosition.root,n)),o=new nc(r,0,null,0);return o.insertionPosition=i,t.splitPosition=t.splitPosition._getTransformedByMergeOperation(e),t.insertionPosition=nc.getInsertionPosition(t.splitPosition),t.graveyardPosition=o.insertionPosition.clone(),t.graveyardPosition.stickiness="toNext",[o,t]}return t.splitPosition.hasSameParentAs(e.deletionPosition)&&!t.splitPosition.isAfter(e.deletionPosition)&&t.howMany--,t.splitPosition.hasSameParentAs(e.targetPosition)&&(t.howMany+=e.howMany),t.splitPosition=t.splitPosition._getTransformedByMergeOperation(e),t.insertionPosition=nc.getInsertionPosition(t.splitPosition),t.graveyardPosition&&(t.graveyardPosition=t.graveyardPosition._getTransformedByMergeOperation(e)),[t]}),Qu(nc,Qs,(t,e,n)=>{const r=Va._createFromPositionAndShift(e.sourcePosition,e.howMany);if(t.graveyardPosition){const i=r.start.isEqual(t.graveyardPosition)||r.containsPosition(t.graveyardPosition);if(!n.bWasUndone&&i){const n=t.splitPosition._getTransformedByMoveOperation(e),r=t.graveyardPosition._getTransformedByMoveOperation(e),i=r.path.slice();i.push(0);const o=new Aa(r.root,i);return[new Qs(n,t.howMany,o,0)]}t.graveyardPosition=t.graveyardPosition._getTransformedByMoveOperation(e)}if(t.splitPosition.hasSameParentAs(e.sourcePosition)&&r.containsPosition(t.splitPosition)){const n=e.howMany-(t.splitPosition.offset-e.sourcePosition.offset);return t.howMany-=n,t.splitPosition.hasSameParentAs(e.targetPosition)&&t.splitPosition.offset<e.targetPosition.offset&&(t.howMany+=e.howMany),t.splitPosition=e.sourcePosition.clone(),t.insertionPosition=nc.getInsertionPosition(t.splitPosition),[t]}return!t.splitPosition.isEqual(e.targetPosition)||"insertAtSource"!=n.baRelation&&"splitBefore"!=n.abRelation?(e.sourcePosition.isEqual(e.targetPosition)||(t.splitPosition.hasSameParentAs(e.sourcePosition)&&t.splitPosition.offset<=e.sourcePosition.offset&&(t.howMany-=e.howMany),t.splitPosition.hasSameParentAs(e.targetPosition)&&t.splitPosition.offset<e.targetPosition.offset&&(t.howMany+=e.howMany)),t.splitPosition.stickiness="toNone",t.splitPosition=t.splitPosition._getTransformedByMoveOperation(e),t.splitPosition.stickiness="toNext",t.graveyardPosition?t.insertionPosition=t.insertionPosition._getTransformedByMoveOperation(e):t.insertionPosition=nc.getInsertionPosition(t.splitPosition),[t]):(t.howMany+=e.howMany,t.splitPosition=t.splitPosition._getTransformedByDeletion(e.sourcePosition,e.howMany),t.insertionPosition=nc.getInsertionPosition(t.splitPosition),[t])}),Qu(nc,nc,(t,e,n)=>{if(t.splitPosition.isEqual(e.splitPosition)){if(!t.graveyardPosition&&!e.graveyardPosition)return[new kc(0)];if(t.graveyardPosition&&e.graveyardPosition&&t.graveyardPosition.isEqual(e.graveyardPosition))return[new kc(0)];if("splitBefore"==n.abRelation)return t.howMany=0,t.graveyardPosition=t.graveyardPosition._getTransformedBySplitOperation(e),[t]}if(t.graveyardPosition&&e.graveyardPosition&&t.graveyardPosition.isEqual(e.graveyardPosition)){const r="$graveyard"==t.splitPosition.root.rootName,i="$graveyard"==e.splitPosition.root.rootName,o=r&&!i;if(i&&!r||!o&&n.aIsStrong){const n=[];return e.howMany&&n.push(new Qs(e.moveTargetPosition,e.howMany,e.splitPosition,0)),t.howMany&&n.push(new Qs(t.splitPosition,t.howMany,t.moveTargetPosition,0)),n}return[new kc(0)]}if(t.graveyardPosition&&(t.graveyardPosition=t.graveyardPosition._getTransformedBySplitOperation(e)),t.splitPosition.isEqual(e.insertionPosition)&&"splitBefore"==n.abRelation)return t.howMany++,[t];if(e.splitPosition.isEqual(t.insertionPosition)&&"splitBefore"==n.baRelation){const n=e.insertionPosition.path.slice();n.push(0);const r=new Aa(e.insertionPosition.root,n);return[t,new Qs(t.insertionPosition,1,r,0)]}return t.splitPosition.hasSameParentAs(e.splitPosition)&&t.splitPosition.offset<e.splitPosition.offset&&(t.howMany-=e.howMany),t.splitPosition=t.splitPosition._getTransformedBySplitOperation(e),t.insertionPosition=nc.getInsertionPosition(t.splitPosition),[t]});class ad extends vu{constructor(t){super(t),this._stack=[],this._createdBatches=new WeakSet,this.refresh(),this.listenTo(t.data,"set",()=>this.clearStack())}refresh(){this.isEnabled=this._stack.length>0}addBatch(t){const e=this.editor.model.document.selection,n={ranges:e.hasOwnRange?Array.from(e.getRanges()):[],isBackward:e.isBackward};this._stack.push({batch:t,selection:n}),this.refresh()}clearStack(){this._stack=[],this.refresh()}_restoreSelection(t,e,n){const r=this.editor.model,i=r.document,o=[],a=t.map(t=>t.getTransformedByOperations(n)),s=a.flat();for(const c of a){const t=c.filter(t=>t.root!=i.graveyard).filter(t=>!cd(t,s));t.length&&(sd(t),o.push(t[0]))}o.length&&r.change(t=>{t.setSelection(o,{backward:e})})}_undo(t,e){const n=this.editor.model,r=n.document;this._createdBatches.add(e);const i=t.operations.slice().filter(t=>t.isDocumentOperation);i.reverse();for(const o of i){const t=o.baseVersion+1,i=Array.from(r.history.getOperations(t)),a=Zu([o.getReversed()],i,{useRelations:!0,document:this.editor.model.document,padWithNoOps:!1,forceWeakRemove:!0}).operationsA;for(const s of a)e.addOperation(s),n.applyOperation(s),r.history.setOperationAsUndone(o,s)}}}function sd(t){t.sort((t,e)=>t.start.isBefore(e.start)?-1:1);for(let e=1;e<t.length;e++){const n=t[e-1].getJoined(t[e],!0);n&&(e--,t.splice(e,2,n))}}function cd(t,e){return e.some(e=>e!==t&&e.containsRange(t,!0))}class ld extends ad{execute(t=null){const e=t?this._stack.findIndex(e=>e.batch==t):this._stack.length-1,n=this._stack.splice(e,1)[0],r=this.editor.model.createBatch("transparent");this.editor.model.enqueueChange(r,()=>{this._undo(n.batch,r);const t=this.editor.model.document.history.getOperations(n.batch.baseVersion);this._restoreSelection(n.selection.ranges,n.selection.isBackward,t),this.fire("revert",n.batch,r)}),this.refresh()}}class ud extends ad{execute(){const t=this._stack.pop(),e=this.editor.model.createBatch("transparent");this.editor.model.enqueueChange(e,()=>{const n=t.batch.operations[t.batch.operations.length-1].baseVersion+1,r=this.editor.model.document.history.getOperations(n);this._restoreSelection(t.selection.ranges,t.selection.isBackward,r),this._undo(t.batch,e)}),this.refresh()}}class dd extends du{static get pluginName(){return"UndoEditing"}constructor(t){super(t),this._batchRegistry=new WeakSet}init(){const t=this.editor;this._undoCommand=new ld(t),this._redoCommand=new ud(t),t.commands.add("undo",this._undoCommand),t.commands.add("redo",this._redoCommand),this.listenTo(t.model,"applyOperation",(t,e)=>{const n=e[0];if(!n.isDocumentOperation)return;const r=n.batch,i=this._redoCommand._createdBatches.has(r),o=this._undoCommand._createdBatches.has(r);this._batchRegistry.has(r)||"transparent"==r.type&&!i&&!o||(i?this._undoCommand.addBatch(r):o||(this._undoCommand.addBatch(r),this._redoCommand.clearStack()),this._batchRegistry.add(r))},{priority:"highest"}),this.listenTo(this._undoCommand,"revert",(t,e,n)=>{this._redoCommand.addBatch(n)}),t.keystrokes.set("CTRL+Z","undo"),t.keystrokes.set("CTRL+Y","redo"),t.keystrokes.set("CTRL+SHIFT+Z","redo")}}var hd='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M5.042 9.367l2.189 1.837a.75.75 0 0 1-.965 1.149l-3.788-3.18a.747.747 0 0 1-.21-.284.75.75 0 0 1 .17-.945L6.23 4.762a.75.75 0 1 1 .964 1.15L4.863 7.866h8.917A.75.75 0 0 1 14 7.9a4 4 0 1 1-1.477 7.718l.344-1.489a2.5 2.5 0 1 0 1.094-4.73l.008-.032H5.042z"/></svg>',fd='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M14.958 9.367l-2.189 1.837a.75.75 0 0 0 .965 1.149l3.788-3.18a.747.747 0 0 0 .21-.284.75.75 0 0 0-.17-.945L13.77 4.762a.75.75 0 1 0-.964 1.15l2.331 1.955H6.22A.75.75 0 0 0 6 7.9a4 4 0 1 0 1.477 7.718l-.344-1.489A2.5 2.5 0 1 1 6.039 9.4l-.008-.032h8.927z"/></svg>';class pd extends du{init(){const t=this.editor,e=t.locale,n=t.t,r="ltr"==e.uiLanguageDirection?hd:fd,i="ltr"==e.uiLanguageDirection?fd:hd;this._addButton("undo",n("Undo"),"CTRL+Z",r),this._addButton("redo",n("Redo"),"CTRL+Y",i)}_addButton(t,e,n,r){const i=this.editor;i.ui.componentFactory.add(t,o=>{const a=i.commands.get(t),s=new Kl(o);return s.set({label:e,icon:r,keystroke:n,tooltip:!0}),s.bind("isEnabled").to(a,"isEnabled"),this.listenTo(s,"execute",()=>{i.execute(t),i.editing.view.focus()}),s})}}class md extends du{static get requires(){return[dd,pd]}static get pluginName(){return"Undo"}}class bd{constructor(t){this.context=t}destroy(){this.stopListening()}static get isContextPlugin(){return!0}}On(bd,$r);class gd extends bd{static get pluginName(){return"PendingActions"}init(){this.set("hasAny",!1),this._actions=new zn({idProperty:"_id"}),this._actions.delegate("add","remove").to(this)}add(t){if("string"!=typeof t)throw new hn.a("pendingactions-add-invalid-message",this);const e=Object.create($r);return e.set("message",t),this._actions.add(e),this.hasAny=!0,e}remove(t){this._actions.remove(t),this.hasAny=!!this._actions.length}get first(){return this._actions.get(0)}[Symbol.iterator](){return this._actions[Symbol.iterator]()}}class vd{constructor(){const t=new window.FileReader;this._reader=t,this._data=void 0,this.set("loaded",0),t.onprogress=t=>{this.loaded=t.loaded}}get error(){return this._reader.error}get data(){return this._data}read(t){const e=this._reader;return this.total=t.size,new Promise((n,r)=>{e.onload=()=>{const t=e.result;this._data=t,n(t)},e.onerror=()=>{r("error")},e.onabort=()=>{r("aborted")},this._reader.readAsDataURL(t)})}abort(){this._reader.abort()}}On(vd,$r);class wd extends du{static get pluginName(){return"FileRepository"}static get requires(){return[gd]}init(){this.loaders=new zn,this.loaders.on("add",()=>this._updatePendingAction()),this.loaders.on("remove",()=>this._updatePendingAction()),this._loadersMap=new Map,this._pendingAction=null,this.set("uploaded",0),this.set("uploadTotal",null),this.bind("uploadedPercent").to(this,"uploaded",this,"uploadTotal",(t,e)=>e?t/e*100:0)}getLoader(t){return this._loadersMap.get(t)||null}createLoader(t){if(!this.createUploadAdapter)return Object(hn.c)("filerepository-no-upload-adapter"),null;const e=new yd(Promise.resolve(t),this.createUploadAdapter);return this.loaders.add(e),this._loadersMap.set(t,e),t instanceof Promise&&e.file.then(t=>{this._loadersMap.set(t,e)}).catch(()=>{}),e.on("change:uploaded",()=>{let t=0;for(const e of this.loaders)t+=e.uploaded;this.uploaded=t}),e.on("change:uploadTotal",()=>{let t=0;for(const e of this.loaders)e.uploadTotal&&(t+=e.uploadTotal);this.uploadTotal=t}),e}destroyLoader(t){const e=t instanceof yd?t:this.getLoader(t);e._destroy(),this.loaders.remove(e),this._loadersMap.forEach((t,n)=>{t===e&&this._loadersMap.delete(n)})}_updatePendingAction(){const t=this.editor.plugins.get(gd);if(this.loaders.length){if(!this._pendingAction){const e=this.editor.t,n=t=>`${e("Upload in progress")} ${parseInt(t)}%.`;this._pendingAction=t.add(n(this.uploadedPercent)),this._pendingAction.bind("message").to(this,"uploadedPercent",n)}}else t.remove(this._pendingAction),this._pendingAction=null}}On(wd,$r);class yd{constructor(t,e){this.id=un(),this._filePromiseWrapper=this._createFilePromiseWrapper(t),this._adapter=e(this),this._reader=new vd,this.set("status","idle"),this.set("uploaded",0),this.set("uploadTotal",null),this.bind("uploadedPercent").to(this,"uploaded",this,"uploadTotal",(t,e)=>e?t/e*100:0),this.set("uploadResponse",null)}get file(){return this._filePromiseWrapper?this._filePromiseWrapper.promise.then(t=>this._filePromiseWrapper?t:null):Promise.resolve(null)}get data(){return this._reader.data}read(){if("idle"!=this.status)throw new hn.a("filerepository-read-wrong-status",this);return this.status="reading",this.file.then(t=>this._reader.read(t)).then(t=>{if("reading"!==this.status)throw this.status;return this.status="idle",t}).catch(t=>{if("aborted"===t)throw this.status="aborted","aborted";throw this.status="error",this._reader.error?this._reader.error:t})}upload(){if("idle"!=this.status)throw new hn.a("filerepository-upload-wrong-status",this);return this.status="uploading",this.file.then(()=>this._adapter.upload()).then(t=>(this.uploadResponse=t,this.status="idle",t)).catch(t=>{if("aborted"===this.status)throw"aborted";throw this.status="error",t})}abort(){const t=this.status;this.status="aborted",this._filePromiseWrapper.isFulfilled?"reading"==t?this._reader.abort():"uploading"==t&&this._adapter.abort&&this._adapter.abort():(this._filePromiseWrapper.promise.catch(()=>{}),this._filePromiseWrapper.rejecter("aborted")),this._destroy()}_destroy(){this._filePromiseWrapper=void 0,this._reader=void 0,this._adapter=void 0,this.uploadResponse=void 0}_createFilePromiseWrapper(t){const e={};return e.promise=new Promise((n,r)=>{e.rejecter=r,e.isFulfilled=!1,t.then(t=>{e.isFulfilled=!0,n(t)}).catch(t=>{e.isFulfilled=!0,r(t)})}),e}}function kd(){let t=function(t){t=t.toLowerCase();const e=document.cookie.split(";");for(const n of e){const e=n.split("=");if(decodeURIComponent(e[0].trim().toLowerCase())===t)return decodeURIComponent(e[1])}return null}("ckCsrfToken");var e,n;return t&&40==t.length||(t=function(t){let e="";const n=new Uint8Array(t);window.crypto.getRandomValues(n);for(let r=0;r<n.length;r++){const t="abcdefghijklmnopqrstuvwxyz0123456789".charAt(n[r]%"abcdefghijklmnopqrstuvwxyz0123456789".length);e+=Math.random()>.5?t.toUpperCase():t}return e}(40),e="ckCsrfToken",n=t,document.cookie=encodeURIComponent(e)+"="+encodeURIComponent(n)+";path=/"),t}On(yd,$r);class _d extends du{static get requires(){return[wd]}static get pluginName(){return"CKFinderUploadAdapter"}init(){const t=this.editor.config.get("ckfinder.uploadUrl");t&&(this.editor.plugins.get(wd).createUploadAdapter=e=>new Od(e,t,this.editor.t))}}class Od{constructor(t,e,n){this.loader=t,this.url=e,this.t=n}upload(){return this.loader.file.then(t=>new Promise((e,n)=>{this._initRequest(),this._initListeners(e,n,t),this._sendRequest(t)}))}abort(){this.xhr&&this.xhr.abort()}_initRequest(){const t=this.xhr=new XMLHttpRequest;t.open("POST",this.url,!0),t.responseType="json"}_initListeners(t,e,n){const r=this.xhr,i=this.loader,o=(0,this.t)("Cannot upload file:")+` ${n.name}.`;r.addEventListener("error",()=>e(o)),r.addEventListener("abort",()=>e()),r.addEventListener("load",()=>{const n=r.response;if(!n||!n.uploaded)return e(n&&n.error&&n.error.message?n.error.message:o);t({default:n.url})}),r.upload&&r.upload.addEventListener("progress",t=>{t.lengthComputable&&(i.uploadTotal=t.total,i.uploaded=t.loaded)})}_sendRequest(t){const e=new FormData;e.append("upload",t),e.append("ckCsrfToken",kd()),this.xhr.send(e)}}function zd(t){const e=t.next();return e.done?null:e.value}function Ad(t,e,n,r){let i,o=null;"function"==typeof r?i=r:(o=t.commands.get(r),i=()=>{t.execute(r)}),t.model.document.on("change:data",(a,s)=>{if(o&&!o.isEnabled||!e.isEnabled)return;const c=zd(t.model.document.selection.getRanges());if(!c.isCollapsed)return;if("transparent"==s.type)return;const l=Array.from(t.model.document.differ.getChanges()),u=l[0];if(1!=l.length||"insert"!==u.type||"$text"!=u.name||1!=u.length)return;const d=u.position.parent;if(d.is("element","codeBlock"))return;if(d.is("element","listItem")&&!["numberedList","bulletedList","todoList"].includes(r))return;if(o&&!0===o.value)return;const h=d.getChild(0),f=t.model.createRangeOn(h);if(!f.containsRange(c)&&!c.end.isEqual(f.end))return;const p=n.exec(h.data.substr(0,c.end.offset));p&&t.model.enqueueChange(e=>{const n=e.createPositionAt(d,0),r=e.createPositionAt(d,p[0].length),o=new Na(n,r);if(!1!==i({match:p})){e.remove(o);const n=t.model.document.selection.getFirstRange(),r=e.createRangeIn(d);!d.isEmpty||r.isEqual(n)||r.containsRange(n,!0)||e.remove(d)}o.detach()})})}function jd(t,e,n,r){let i,o;n instanceof RegExp?i=n:o=n,o=o||(t=>{let e;const n=[],r=[];for(;null!==(e=i.exec(t))&&!(e&&e.length<4);){let{index:t,1:i,2:o,3:a}=e;const s=i+o+a;t+=e[0].length-s.length;const c=[t,t+i.length],l=[t+i.length+o.length,t+i.length+o.length+a.length];n.push(c),n.push(l),r.push([t+i.length,t+i.length+o.length])}return{remove:n,format:r}}),t.model.document.on("change:data",(n,i)=>{if("transparent"==i.type||!e.isEnabled)return;const a=t.model,s=a.document.selection;if(!s.isCollapsed)return;const c=Array.from(a.document.differ.getChanges()),l=c[0];if(1!=c.length||"insert"!==l.type||"$text"!=l.name||1!=l.length)return;const u=s.focus,d=u.parent,{text:h,range:f}=function(t,e){let n=t.start;return{text:Array.from(t.getItems()).reduce((t,r)=>!r.is("$text")&&!r.is("$textProxy")||r.getAttribute("code")?(n=e.createPositionAfter(r),""):t+r.data,""),range:e.createRange(n,t.end)}}(a.createRange(a.createPositionAt(d,0),u),a),p=o(h),m=Md(f.start,p.format,a),b=Md(f.start,p.remove,a);m.length&&b.length&&a.enqueueChange(t=>{if(!1!==r(t,m))for(const e of b.reverse())t.remove(e)})})}function Md(t,e,n){return e.filter(t=>void 0!==t[0]&&void 0!==t[1]).map(e=>n.createRange(t.getShiftedBy(e[0]),t.getShiftedBy(e[1])))}function Cd(t,e){return(n,r)=>{if(!t.commands.get(e).isEnabled)return!1;const i=t.model.schema.getValidRanges(r,e);for(const t of i)n.setAttribute(e,!0,t);n.removeSelectionAttribute(e)}}class Vd extends vu{constructor(t,e){super(t),this.attributeKey=e}refresh(){const t=this.editor.model,e=t.document;this.value=this._getValueFromFirstAllowedNode(),this.isEnabled=t.schema.checkAttributeInSelection(e.selection,this.attributeKey)}execute(t={}){const e=this.editor.model,n=e.document.selection,r=void 0===t.forceValue?!this.value:t.forceValue;e.change(t=>{if(n.isCollapsed)r?t.setSelectionAttribute(this.attributeKey,!0):t.removeSelectionAttribute(this.attributeKey);else{const i=e.schema.getValidRanges(n.getRanges(),this.attributeKey);for(const e of i)r?t.setAttribute(this.attributeKey,r,e):t.removeAttribute(this.attributeKey,e)}})}_getValueFromFirstAllowedNode(){const t=this.editor.model,e=t.schema,n=t.document.selection;if(n.isCollapsed)return n.hasAttribute(this.attributeKey);for(const r of n.getRanges())for(const t of r.getItems())if(e.checkAttribute(t,this.attributeKey))return t.hasAttribute(this.attributeKey);return!1}}class Sd extends du{static get pluginName(){return"BoldEditing"}init(){const t=this.editor;t.model.schema.extend("$text",{allowAttributes:"bold"}),t.model.schema.setAttributeProperties("bold",{isFormatting:!0,copyOnEnter:!0}),t.conversion.attributeToElement({model:"bold",view:"strong",upcastAlso:["b",t=>{const e=t.getStyle("font-weight");return e?"bold"==e||Number(e)>=600?{name:!0,styles:["font-weight"]}:void 0:null}]}),t.commands.add("bold",new Vd(t,"bold")),t.keystrokes.set("CTRL+B","bold")}}class xd extends du{init(){const t=this.editor,e=t.t;t.ui.componentFactory.add("bold",n=>{const r=t.commands.get("bold"),i=new Kl(n);return i.set({label:e("Bold"),icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M10.187 17H5.773c-.637 0-1.092-.138-1.364-.415-.273-.277-.409-.718-.409-1.323V4.738c0-.617.14-1.062.419-1.332.279-.27.73-.406 1.354-.406h4.68c.69 0 1.288.041 1.793.124.506.083.96.242 1.36.478.341.197.644.447.906.75a3.262 3.262 0 0 1 .808 2.162c0 1.401-.722 2.426-2.167 3.075C15.05 10.175 16 11.315 16 13.01a3.756 3.756 0 0 1-2.296 3.504 6.1 6.1 0 0 1-1.517.377c-.571.073-1.238.11-2 .11zm-.217-6.217H7v4.087h3.069c1.977 0 2.965-.69 2.965-2.072 0-.707-.256-1.22-.768-1.537-.512-.319-1.277-.478-2.296-.478zM7 5.13v3.619h2.606c.729 0 1.292-.067 1.69-.2a1.6 1.6 0 0 0 .91-.765c.165-.267.247-.566.247-.897 0-.707-.26-1.176-.778-1.409-.519-.232-1.31-.348-2.375-.348H7z"/></svg>',keystroke:"CTRL+B",tooltip:!0,isToggleable:!0}),i.bind("isOn","isEnabled").to(r,"value","isEnabled"),this.listenTo(i,"execute",()=>{t.execute("bold"),t.editing.view.focus()}),i})}}class Td extends du{static get pluginName(){return"ItalicEditing"}init(){const t=this.editor;t.model.schema.extend("$text",{allowAttributes:"italic"}),t.model.schema.setAttributeProperties("italic",{isFormatting:!0,copyOnEnter:!0}),t.conversion.attributeToElement({model:"italic",view:"i",upcastAlso:["em",{styles:{"font-style":"italic"}}]}),t.commands.add("italic",new Vd(t,"italic")),t.keystrokes.set("CTRL+I","italic")}}class Pd extends du{init(){const t=this.editor,e=t.t;t.ui.componentFactory.add("italic",n=>{const r=t.commands.get("italic"),i=new Kl(n);return i.set({label:e("Italic"),icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M9.586 14.633l.021.004c-.036.335.095.655.393.962.082.083.173.15.274.201h1.474a.6.6 0 1 1 0 1.2H5.304a.6.6 0 0 1 0-1.2h1.15c.474-.07.809-.182 1.005-.334.157-.122.291-.32.404-.597l2.416-9.55a1.053 1.053 0 0 0-.281-.823 1.12 1.12 0 0 0-.442-.296H8.15a.6.6 0 0 1 0-1.2h6.443a.6.6 0 1 1 0 1.2h-1.195c-.376.056-.65.155-.823.296-.215.175-.423.439-.623.79l-2.366 9.347z"/></svg>',keystroke:"CTRL+I",tooltip:!0,isToggleable:!0}),i.bind("isOn","isEnabled").to(r,"value","isEnabled"),this.listenTo(i,"execute",()=>{t.execute("italic"),t.editing.view.focus()}),i})}}class Id extends vu{refresh(){this.value=this._getValue(),this.isEnabled=this._checkEnabled()}execute(t={}){const e=this.editor.model,n=e.schema,r=e.document.selection,i=Array.from(r.getSelectedBlocks()),o=void 0===t.forceValue?!this.value:t.forceValue;e.change(t=>{if(o){const e=i.filter(t=>Ed(t)||Bd(n,t));this._applyQuote(t,e)}else this._removeQuote(t,i.filter(Ed))})}_getValue(){const t=zd(this.editor.model.document.selection.getSelectedBlocks());return!(!t||!Ed(t))}_checkEnabled(){if(this.value)return!0;const t=this.editor.model.document.selection,e=this.editor.model.schema,n=zd(t.getSelectedBlocks());return!!n&&Bd(e,n)}_removeQuote(t,e){Ld(t,e).reverse().forEach(e=>{if(e.start.isAtStart&&e.end.isAtEnd)return void t.unwrap(e.start.parent);if(e.start.isAtStart){const n=t.createPositionBefore(e.start.parent);return void t.move(e,n)}e.end.isAtEnd||t.split(e.end);const n=t.createPositionAfter(e.end.parent);t.move(e,n)})}_applyQuote(t,e){const n=[];Ld(t,e).reverse().forEach(e=>{let r=Ed(e.start);r||(r=t.createElement("blockQuote"),t.wrap(e,r)),n.push(r)}),n.reverse().reduce((e,n)=>e.nextSibling==n?(t.merge(t.createPositionAfter(e)),e):n)}}function Ed(t){return"blockQuote"==t.parent.name?t.parent:null}function Ld(t,e){let n,r=0;const i=[];for(;r<e.length;){const o=e[r],a=e[r+1];n||(n=t.createPositionBefore(o)),a&&o.nextSibling==a||(i.push(t.createRange(n,t.createPositionAfter(o))),n=null),r++}return i}function Bd(t,e){const n=t.checkChild(e.parent,"blockQuote"),r=t.checkChild(["$root","blockQuote"],e);return n&&r}class Hd extends du{static get pluginName(){return"BlockQuoteEditing"}init(){const t=this.editor,e=t.model.schema;t.commands.add("blockQuote",new Id(t)),e.register("blockQuote",{allowWhere:"$block",allowContentOf:"$root"}),e.addChildCheck((t,e)=>{if(t.endsWith("blockQuote")&&"blockQuote"==e.name)return!1}),t.conversion.elementToElement({model:"blockQuote",view:"blockquote"}),t.model.document.registerPostFixer(n=>{const r=t.model.document.differ.getChanges();for(const t of r)if("insert"==t.type){const r=t.position.nodeAfter;if(!r)continue;if(r.is("element","blockQuote")&&r.isEmpty)return n.remove(r),!0;if(r.is("element","blockQuote")&&!e.checkChild(t.position,r))return n.unwrap(r),!0;if(r.is("element")){const t=n.createRangeIn(r);for(const r of t.getItems())if(r.is("element","blockQuote")&&!e.checkChild(n.createPositionBefore(r),r))return n.unwrap(r),!0}}else if("remove"==t.type){const e=t.position.parent;if(e.is("element","blockQuote")&&e.isEmpty)return n.remove(e),!0}return!1});const n=this.editor.editing.view.document,r=t.model.document.selection,i=t.commands.get("blockQuote");this.listenTo(n,"enter",(e,n)=>{r.isCollapsed&&i.value&&r.getLastPosition().parent.isEmpty&&(t.execute("blockQuote"),t.editing.view.scrollToTheSelection(),n.preventDefault(),e.stop())},{priority:dn.normal-10}),this.listenTo(n,"delete",(e,n)=>{if("backward"!=n.direction||!r.isCollapsed||!i.value)return;const o=r.getLastPosition().parent;o.isEmpty&&!o.previousSibling&&(t.execute("blockQuote"),t.editing.view.scrollToTheSelection(),n.preventDefault(),e.stop())},{priority:dn.high+5})}}n(44);class Fd extends du{init(){const t=this.editor,e=t.t;t.ui.componentFactory.add("blockQuote",n=>{const r=t.commands.get("blockQuote"),i=new Kl(n);return i.set({label:e("Block quote"),icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M3 10.423a6.5 6.5 0 0 1 6.056-6.408l.038.67C6.448 5.423 5.354 7.663 5.22 10H9c.552 0 .5.432.5.986v4.511c0 .554-.448.503-1 .503h-5c-.552 0-.5-.449-.5-1.003v-4.574zm8 0a6.5 6.5 0 0 1 6.056-6.408l.038.67c-2.646.739-3.74 2.979-3.873 5.315H17c.552 0 .5.432.5.986v4.511c0 .554-.448.503-1 .503h-5c-.552 0-.5-.449-.5-1.003v-4.574z"/></svg>',tooltip:!0,isToggleable:!0}),i.bind("isOn","isEnabled").to(r,"value","isEnabled"),this.listenTo(i,"execute",()=>{t.execute("blockQuote"),t.editing.view.focus()}),i})}}class Dd extends du{static get pluginName(){return"CKFinderUI"}init(){const t=this.editor,e=t.ui.componentFactory,n=t.t;e.add("ckfinder",e=>{const r=t.commands.get("ckfinder"),i=new Kl(e);return i.set({label:n("Insert image or file"),icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M11.627 16.5zm5.873-.196zm0-7.001V8h-13v8.5h4.341c.191.54.457 1.044.785 1.5H2a1.5 1.5 0 0 1-1.5-1.5v-13A1.5 1.5 0 0 1 2 2h4.5a1.5 1.5 0 0 1 1.06.44L9.122 4H16a1.5 1.5 0 0 1 1.5 1.5v1A1.5 1.5 0 0 1 19 8v2.531a6.027 6.027 0 0 0-1.5-1.228zM16 6.5v-1H8.5l-2-2H2v13h1V8a1.5 1.5 0 0 1 1.5-1.5H16z"/><path d="M14.5 19.5a5 5 0 1 1 0-10 5 5 0 0 1 0 10zM15 14v-2h-1v2h-2v1h2v2h1v-2h2v-1h-2z"/></svg>',tooltip:!0}),i.bind("isEnabled").to(r),i.on("execute",()=>{t.execute("ckfinder"),t.editing.view.focus()}),i})}}class Rd extends go{observe(t){this.listenTo(t,"load",(t,e)=>{const n=e.target;this.checkShouldIgnoreEventFromTarget(n)||"IMG"==n.tagName&&this._fireEvents(e)},{useCapture:!0})}_fireEvents(t){this.isEnabled&&(this.document.fire("layoutChanged"),this.document.fire("imageLoaded",t))}}class Nd{constructor(){this._stack=[]}add(t,e){const n=this._stack,r=n[0];this._insertDescriptor(t);const i=n[0];r===i||$d(r,i)||this.fire("change:top",{oldDescriptor:r,newDescriptor:i,writer:e})}remove(t,e){const n=this._stack,r=n[0];this._removeDescriptor(t);const i=n[0];r===i||$d(r,i)||this.fire("change:top",{oldDescriptor:r,newDescriptor:i,writer:e})}_insertDescriptor(t){const e=this._stack,n=e.findIndex(e=>e.id===t.id);if($d(t,e[n]))return;n>-1&&e.splice(n,1);let r=0;for(;e[r]&&Ud(e[r],t);)r++;e.splice(r,0,t)}_removeDescriptor(t){const e=this._stack,n=e.findIndex(e=>e.id===t);n>-1&&e.splice(n,1)}}function $d(t,e){return t&&e&&t.priority==e.priority&&qd(t.classes)==qd(e.classes)}function Ud(t,e){return t.priority>e.priority||!(t.priority<e.priority)&&qd(t.classes)>qd(e.classes)}function qd(t){return Array.isArray(t)?t.sort().join(","):t}On(Nd,mn),n(46);const Wd=Tl("px"),Gd=io.document.body;class Yd extends zl{constructor(t){super(t);const e=this.bindTemplate;this.set("top",0),this.set("left",0),this.set("position","arrow_nw"),this.set("isVisible",!1),this.set("withArrow",!0),this.set("class"),this.content=this.createCollection(),this.setTemplate({tag:"div",attributes:{class:["ck","ck-balloon-panel",e.to("position",t=>"ck-balloon-panel_"+t),e.if("isVisible","ck-balloon-panel_visible"),e.if("withArrow","ck-balloon-panel_with-arrow"),e.to("class")],style:{top:e.to("top",Wd),left:e.to("left",Wd)}},children:this.content})}show(){this.isVisible=!0}hide(){this.isVisible=!1}attachTo(t){this.show();const e=Yd.defaultPositions,n=Object.assign({},{element:this.element,positions:[e.southArrowNorth,e.southArrowNorthMiddleWest,e.southArrowNorthMiddleEast,e.southArrowNorthWest,e.southArrowNorthEast,e.northArrowSouth,e.northArrowSouthMiddleWest,e.northArrowSouthMiddleEast,e.northArrowSouthWest,e.northArrowSouthEast],limiter:Gd,fitInViewport:!0},t),r=Yd._getOptimalPosition(n),i=parseInt(r.left),o=parseInt(r.top),a=r.name;Object.assign(this,{top:o,left:i,position:a})}pin(t){this.unpin(),this._pinWhenIsVisibleCallback=()=>{this.isVisible?this._startPinning(t):this._stopPinning()},this._startPinning(t),this.listenTo(this,"change:isVisible",this._pinWhenIsVisibleCallback)}unpin(){this._pinWhenIsVisibleCallback&&(this._stopPinning(),this.stopListening(this,"change:isVisible",this._pinWhenIsVisibleCallback),this._pinWhenIsVisibleCallback=null,this.hide())}_startPinning(t){this.attachTo(t);const e=Kd(t.target),n=t.limiter?Kd(t.limiter):Gd;this.listenTo(io.document,"scroll",(r,i)=>{const o=i.target,a=e&&o.contains(e),s=n&&o.contains(n);!a&&!s&&e&&n||this.attachTo(t)},{useCapture:!0}),this.listenTo(io.window,"resize",()=>{this.attachTo(t)})}_stopPinning(){this.stopListening(io.document,"scroll"),this.stopListening(io.window,"resize")}}function Kd(t){return nn(t)?t:ea(t)?t.commonAncestorContainer:"function"==typeof t?Kd(t()):null}function Qd(t,e){return t.top-e.height-Yd.arrowVerticalOffset}function Xd(t){return t.bottom+Yd.arrowVerticalOffset}function Jd(t,e,n){return t&&th(t)&&!n.isInline(e)}function Zd(t){return t.getAttribute("widget-type-around")}function th(t){return!!t.is("element")&&!!t.getCustomProperty("widget")}function eh(t,e,n={}){if(!t.is("containerElement"))throw new hn.a("widget-to-widget-wrong-element-type",null,{element:t});return e.setAttribute("contenteditable","false",t),e.addClass("ck-widget",t),e.setCustomProperty("widget",!0,t),t.getFillerOffset=sh,n.label&&function(t,e,n){n.setCustomProperty("widgetLabel",e,t)}(t,n.label,e),n.hasSelectionHandle&&function(t,e){const n=e.createUIElement("div",{class:"ck ck-widget__selection-handle"},(function(t){const e=this.toDomElement(t),n=new Gl;return n.set("content",'<svg viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg"><path d="M4 0v1H1v3H0V.5A.5.5 0 0 1 .5 0H4zm8 0h3.5a.5.5 0 0 1 .5.5V4h-1V1h-3V0zM4 16H.5a.5.5 0 0 1-.5-.5V12h1v3h3v1zm8 0v-1h3v-3h1v3.5a.5.5 0 0 1-.5.5H12z"/><path fill-opacity=".256" d="M1 1h14v14H1z"/><g class="ck-icon__selected-indicator"><path d="M7 0h2v1H7V0zM0 7h1v2H0V7zm15 0h1v2h-1V7zm-8 8h2v1H7v-1z"/><path fill-opacity=".254" d="M1 1h14v14H1z"/></g></svg>'),n.render(),e.appendChild(n.element),e}));e.insert(e.createPositionAt(t,0),n),e.addClass(["ck-widget_with-selection-handle"],t)}(t,e),nh(t,e,(t,e,n)=>n.addClass(jn(e.classes),t),(t,e,n)=>n.removeClass(jn(e.classes),t)),t}function nh(t,e,n,r){const i=new Nd;i.on("change:top",(e,i)=>{i.oldDescriptor&&r(t,i.oldDescriptor,i.writer),i.newDescriptor&&n(t,i.newDescriptor,i.writer)}),e.setCustomProperty("addHighlight",(t,e,n)=>i.add(e,n),t),e.setCustomProperty("removeHighlight",(t,e,n)=>i.remove(e,n),t)}function rh(t){const e=t.getCustomProperty("widgetLabel");return e?"function"==typeof e?e():e:""}function ih(t,e){return e.addClass(["ck-editor__editable","ck-editor__nested-editable"],t),e.setAttribute("contenteditable",t.isReadOnly?"false":"true",t),t.on("change:isReadOnly",(n,r,i)=>{e.setAttribute("contenteditable",i?"false":"true",t)}),t.on("change:isFocused",(n,r,i)=>{i?e.addClass("ck-editor__nested-editable_focused",t):e.removeClass("ck-editor__nested-editable_focused",t)}),t}function oh(t,e){const n=t.getSelectedElement();if(n){const r=Zd(t);if(r)return e.createPositionAt(n,r);if(e.schema.isBlock(n))return e.createPositionAfter(n)}const r=t.getSelectedBlocks().next().value;if(r){if(r.isEmpty)return e.createPositionAt(r,0);const n=e.createPositionAfter(r);return t.focus.isTouching(n)?n:e.createPositionBefore(r)}return t.focus}function ah(t,e){const n=new ia(io.window),r=n.getIntersection(t),i=e.height+Yd.arrowVerticalOffset;if(t.top-i>n.top||t.bottom+i<n.bottom)return null;const o=r||t,a=o.left+o.width/2-e.width/2;return{top:Math.max(t.top,0)+Yd.arrowVerticalOffset,left:a,name:"arrow_n"}}function sh(){return null}function ch(t){const e=t.getSelectedElement();return e&&function(t){return!!t.getCustomProperty("image")&&th(t)}(e)?e:null}function lh(t){return!!t&&t.is("element","image")}function uh(t,e={},n=null){t.change(r=>{const i=r.createElement("image",e),o=n||oh(t.document.selection,t);t.insertContent(i,o),i.parent&&r.setSelection(i,"on")})}function dh(t){const e=t.schema,n=t.document.selection;return function(t,e,n){const r=function(t,e){const n=oh(t,e).parent;return n.isEmpty&&!n.is("element","$root")?n.parent:n}(t,n);return e.checkChild(r,"image")}(n,e,t)&&!function(t,e){const n=t.getSelectedElement();return n&&e.isObject(n)}(n,e)&&function(t){return[...t.focus.getAncestors()].every(t=>!t.is("element","image"))}(n)}function hh(t){const e=[];for(const n of t.getChildren())e.push(n),n.is("element")&&e.push(...n.getChildren());return e.find(t=>t.is("element","img"))}function fh(t){return n=>{n.on(`attribute:${t}:image`,e)};function e(t,e,n){if(!n.consumable.consume(e.item,t.name))return;const r=n.writer,i=hh(n.mapper.toViewElement(e.item));r.setAttribute(e.attributeKey,e.attributeNewValue||"",i)}}Yd.arrowHorizontalOffset=25,Yd.arrowVerticalOffset=10,Yd._getOptimalPosition=Nl,Yd.defaultPositions={northWestArrowSouthWest:(t,e)=>({top:Qd(t,e),left:t.left-Yd.arrowHorizontalOffset,name:"arrow_sw"}),northWestArrowSouthMiddleWest:(t,e)=>({top:Qd(t,e),left:t.left-.25*e.width-Yd.arrowHorizontalOffset,name:"arrow_smw"}),northWestArrowSouth:(t,e)=>({top:Qd(t,e),left:t.left-e.width/2,name:"arrow_s"}),northWestArrowSouthMiddleEast:(t,e)=>({top:Qd(t,e),left:t.left-.75*e.width+Yd.arrowHorizontalOffset,name:"arrow_sme"}),northWestArrowSouthEast:(t,e)=>({top:Qd(t,e),left:t.left-e.width+Yd.arrowHorizontalOffset,name:"arrow_se"}),northArrowSouthWest:(t,e)=>({top:Qd(t,e),left:t.left+t.width/2-Yd.arrowHorizontalOffset,name:"arrow_sw"}),northArrowSouthMiddleWest:(t,e)=>({top:Qd(t,e),left:t.left+t.width/2-.25*e.width-Yd.arrowHorizontalOffset,name:"arrow_smw"}),northArrowSouth:(t,e)=>({top:Qd(t,e),left:t.left+t.width/2-e.width/2,name:"arrow_s"}),northArrowSouthMiddleEast:(t,e)=>({top:Qd(t,e),left:t.left+t.width/2-.75*e.width+Yd.arrowHorizontalOffset,name:"arrow_sme"}),northArrowSouthEast:(t,e)=>({top:Qd(t,e),left:t.left+t.width/2-e.width+Yd.arrowHorizontalOffset,name:"arrow_se"}),northEastArrowSouthWest:(t,e)=>({top:Qd(t,e),left:t.right-Yd.arrowHorizontalOffset,name:"arrow_sw"}),northEastArrowSouthMiddleWest:(t,e)=>({top:Qd(t,e),left:t.right-.25*e.width-Yd.arrowHorizontalOffset,name:"arrow_smw"}),northEastArrowSouth:(t,e)=>({top:Qd(t,e),left:t.right-e.width/2,name:"arrow_s"}),northEastArrowSouthMiddleEast:(t,e)=>({top:Qd(t,e),left:t.right-.75*e.width+Yd.arrowHorizontalOffset,name:"arrow_sme"}),northEastArrowSouthEast:(t,e)=>({top:Qd(t,e),left:t.right-e.width+Yd.arrowHorizontalOffset,name:"arrow_se"}),southWestArrowNorthWest:(t,e)=>({top:Xd(t),left:t.left-Yd.arrowHorizontalOffset,name:"arrow_nw"}),southWestArrowNorthMiddleWest:(t,e)=>({top:Xd(t),left:t.left-.25*e.width-Yd.arrowHorizontalOffset,name:"arrow_nmw"}),southWestArrowNorth:(t,e)=>({top:Xd(t),left:t.left-e.width/2,name:"arrow_n"}),southWestArrowNorthMiddleEast:(t,e)=>({top:Xd(t),left:t.left-.75*e.width+Yd.arrowHorizontalOffset,name:"arrow_nme"}),southWestArrowNorthEast:(t,e)=>({top:Xd(t),left:t.left-e.width+Yd.arrowHorizontalOffset,name:"arrow_ne"}),southArrowNorthWest:(t,e)=>({top:Xd(t),left:t.left+t.width/2-Yd.arrowHorizontalOffset,name:"arrow_nw"}),southArrowNorthMiddleWest:(t,e)=>({top:Xd(t),left:t.left+t.width/2-.25*e.width-Yd.arrowHorizontalOffset,name:"arrow_nmw"}),southArrowNorth:(t,e)=>({top:Xd(t),left:t.left+t.width/2-e.width/2,name:"arrow_n"}),southArrowNorthMiddleEast:(t,e)=>({top:Xd(t),left:t.left+t.width/2-.75*e.width+Yd.arrowHorizontalOffset,name:"arrow_nme"}),southArrowNorthEast:(t,e)=>({top:Xd(t),left:t.left+t.width/2-e.width+Yd.arrowHorizontalOffset,name:"arrow_ne"}),southEastArrowNorthWest:(t,e)=>({top:Xd(t),left:t.right-Yd.arrowHorizontalOffset,name:"arrow_nw"}),southEastArrowNorthMiddleWest:(t,e)=>({top:Xd(t),left:t.right-.25*e.width-Yd.arrowHorizontalOffset,name:"arrow_nmw"}),southEastArrowNorth:(t,e)=>({top:Xd(t),left:t.right-e.width/2,name:"arrow_n"}),southEastArrowNorthMiddleEast:(t,e)=>({top:Xd(t),left:t.right-.75*e.width+Yd.arrowHorizontalOffset,name:"arrow_nme"}),southEastArrowNorthEast:(t,e)=>({top:Xd(t),left:t.right-e.width+Yd.arrowHorizontalOffset,name:"arrow_ne"})};class ph extends vu{refresh(){this.isEnabled=dh(this.editor.model)}execute(t){const e=this.editor.model;for(const n of jn(t.source))uh(e,{src:n})}}class mh extends du{static get pluginName(){return"ImageEditing"}init(){const t=this.editor,e=t.model.schema,n=t.t,r=t.conversion;t.editing.view.addObserver(Rd),e.register("image",{isObject:!0,isBlock:!0,allowWhere:"$block",allowAttributes:["alt","src","srcset"]}),r.for("dataDowncast").elementToElement({model:"image",view:(t,{writer:e})=>bh(e)}),r.for("editingDowncast").elementToElement({model:"image",view:(t,{writer:e})=>function(t,e,n){return e.setCustomProperty("image",!0,t),eh(t,e,{label:function(){const e=hh(t).getAttribute("alt");return e?`${e} ${n}`:n}})}(bh(e),e,n("image widget"))}),r.for("downcast").add(fh("src")).add(fh("alt")).add(function(){return e=>{e.on("attribute:srcset:image",t)};function t(t,e,n){if(!n.consumable.consume(e.item,t.name))return;const r=n.writer,i=hh(n.mapper.toViewElement(e.item));if(null===e.attributeNewValue){const t=e.attributeOldValue;t.data&&(r.removeAttribute("srcset",i),r.removeAttribute("sizes",i),t.width&&r.removeAttribute("width",i))}else{const t=e.attributeNewValue;t.data&&(r.setAttribute("srcset",t.data,i),r.setAttribute("sizes","100vw",i),t.width&&r.setAttribute("width",t.width,i))}}}()),r.for("upcast").elementToElement({view:{name:"img",attributes:{src:!0}},model:(t,{writer:e})=>e.createElement("image",{src:t.getAttribute("src")})}).attributeToAttribute({view:{name:"img",key:"alt"},model:"alt"}).attributeToAttribute({view:{name:"img",key:"srcset"},model:{key:"srcset",value:t=>{const e={data:t.getAttribute("srcset")};return t.hasAttribute("width")&&(e.width=t.getAttribute("width")),e}}}).add(function(){return e=>{e.on("element:figure",t)};function t(t,e,n){if(!n.consumable.test(e.viewItem,{name:!0,classes:"image"}))return;const r=hh(e.viewItem);if(!r||!r.hasAttribute("src")||!n.consumable.test(r,{name:!0}))return;const i=zd(n.convertItem(r,e.modelCursor).modelRange.getItems());i&&(n.convertChildren(e.viewItem,i),n.updateConversionResult(i,e))}}()),t.commands.add("imageInsert",new ph(t))}}function bh(t){const e=t.createEmptyElement("img"),n=t.createContainerElement("figure",{class:"image"});return t.insert(t.createPositionAt(n,0),e),n}class gh extends Ho{constructor(t){super(t),this.domEventType="mousedown"}onDomEvent(t){this.fire(t.type,t)}}class vh extends du{static get pluginName(){return"TwoStepCaretMovement"}constructor(t){super(t),this.attributes=new Set,this._overrideUid=null}init(){const t=this.editor,e=t.model,n=t.editing.view,r=t.locale,i=e.document.selection;this.listenTo(n.document,"keydown",(t,e)=>{if(!i.isCollapsed)return;if(e.shiftKey||e.altKey||e.ctrlKey)return;const n=e.keyCode==mi.arrowright,o=e.keyCode==mi.arrowleft;if(!n&&!o)return;const a=r.contentLanguageDirection;let s=!1;s="ltr"===a&&n||"rtl"===a&&o?this._handleForwardMovement(e):this._handleBackwardMovement(e),!0===s&&t.stop()},{priority:dn.get("high")+1}),this._isNextGravityRestorationSkipped=!1,this.listenTo(i,"change:range",(t,e)=>{this._isNextGravityRestorationSkipped?this._isNextGravityRestorationSkipped=!1:this._isGravityOverridden&&(!e.directChange&&_h(i.getFirstPosition(),this.attributes)||this._restoreGravity())})}registerAttribute(t){this.attributes.add(t)}_handleForwardMovement(t){const e=this.attributes,n=this.editor.model.document.selection,r=n.getFirstPosition();return!this._isGravityOverridden&&(!r.isAtStart||!wh(n,e))&&(_h(r,e)?(kh(t),this._overrideGravity(),!0):void 0)}_handleBackwardMovement(t){const e=this.attributes,n=this.editor.model,r=n.document.selection,i=r.getFirstPosition();return this._isGravityOverridden?(kh(t),this._restoreGravity(),yh(n,e,i),!0):i.isAtStart?!!wh(r,e)&&(kh(t),yh(n,e,i),!0):function(t,e){return _h(t.getShiftedBy(-1),e)}(i,e)?i.isAtEnd&&!wh(r,e)&&_h(i,e)?(kh(t),yh(n,e,i),!0):(this._isNextGravityRestorationSkipped=!0,this._overrideGravity(),!1):void 0}get _isGravityOverridden(){return!!this._overrideUid}_overrideGravity(){this._overrideUid=this.editor.model.change(t=>t.overrideSelectionGravity())}_restoreGravity(){this.editor.model.change(t=>{t.restoreSelectionGravity(this._overrideUid),this._overrideUid=null})}}function wh(t,e){for(const n of e)if(t.hasAttribute(n))return!0;return!1}function yh(t,e,n){const r=n.nodeBefore;t.change(t=>{r?t.setSelectionAttribute(r.getAttributes()):t.removeSelectionAttribute(e)})}function kh(t){t.preventDefault()}function _h(t,e){const{nodeBefore:n,nodeAfter:r}=t;for(const i of e){const t=n?n.getAttribute(i):void 0;if((r?r.getAttribute(i):void 0)!==t)return!0}return!1}function Oh(t,e,n,r){return r.createRange(zh(t,e,n,!0,r),zh(t,e,n,!1,r))}function zh(t,e,n,r,i){let o=t.textNode||(r?t.nodeBefore:t.nodeAfter),a=null;for(;o&&o.getAttribute(e)==n;)a=o,o=r?o.previousSibling:o.nextSibling;return a?i.createPositionAt(a,r?"before":"after"):t}class Ah{constructor(){this._definitions=new Set}get length(){return this._definitions.size}add(t){Array.isArray(t)?t.forEach(t=>this._definitions.add(t)):this._definitions.add(t)}getDispatcher(){return t=>{t.on("attribute:linkHref",(t,e,n)=>{if(!n.consumable.test(e.item,"attribute:linkHref"))return;const r=n.writer,i=r.document.selection;for(const o of this._definitions){const t=r.createAttributeElement("a",o.attributes,{priority:5});r.setCustomProperty("link",!0,t),o.callback(e.attributeNewValue)?e.item.is("selection")?r.wrap(i.getFirstRange(),t):r.wrap(n.mapper.toViewRange(e.range),t):r.unwrap(n.mapper.toViewRange(e.range),t)}},{priority:"high"})}}getDispatcherForLinkedImage(){return t=>{t.on("attribute:linkHref:image",(t,e,n)=>{const r=n.mapper.toViewElement(e.item),i=Array.from(r.getChildren()).find(t=>"a"===t.name);for(const o of this._definitions){const t=Bn(o.attributes);if(o.callback(e.attributeNewValue))for(const[e,r]of t)"class"===e?n.writer.addClass(r,i):n.writer.setAttribute(e,r,i);else for(const[e,r]of t)"class"===e?n.writer.removeClass(r,i):n.writer.removeAttribute(e,i)}})}}}var jh=function(t,e,n){var r=t.length;return n=void 0===n?r:n,!e&&n>=r?t:ir(t,e,n)},Mh=RegExp("[\\u200d\\ud800-\\udfff\\u0300-\\u036f\\ufe20-\\ufe2f\\u20d0-\\u20ff\\ufe0e\\ufe0f]"),Ch=function(t){return Mh.test(t)},Vh=function(t){return t.split("")},Sh="[\\ud800-\\udfff]",xh="[\\u0300-\\u036f\\ufe20-\\ufe2f\\u20d0-\\u20ff]",Th="\\ud83c[\\udffb-\\udfff]",Ph="[^\\ud800-\\udfff]",Ih="(?:\\ud83c[\\udde6-\\uddff]){2}",Eh="[\\ud800-\\udbff][\\udc00-\\udfff]",Lh="(?:"+xh+"|"+Th+")?",Bh="[\\ufe0e\\ufe0f]?"+Lh+"(?:\\u200d(?:"+[Ph,Ih,Eh].join("|")+")[\\ufe0e\\ufe0f]?"+Lh+")*",Hh="(?:"+[Ph+xh+"?",xh,Ih,Eh,Sh].join("|")+")",Fh=RegExp(Th+"(?="+Th+")|"+Hh+Bh,"g"),Dh=function(t){return t.match(Fh)||[]},Rh=function(t){return Ch(t)?Dh(t):Vh(t)},Nh=function(t){return function(e){e=Zn(e);var n=Ch(e)?Rh(e):void 0,r=n?n[0]:e.charAt(0),i=n?jh(n,1).join(""):e.slice(1);return r[t]()+i}}("toUpperCase");const $h=/[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205f\u3000]/g,Uh=/^(?:(?:https?|ftps?|mailto):|[^a-z]|[a-z+.-]+(?:[^a-z+.:-]|$))/i,qh=/^[\S]+@((?![-_])(?:[-\w\u00a1-\uffff]{0,63}[^-_]\.))+(?:[a-z\u00a1-\uffff]{2,})$/i,Wh=/^((\w+:(\/{2,})?)|(\W))/i;function Gh(t,{writer:e}){const n=e.createAttributeElement("a",{href:t},{priority:5});return e.setCustomProperty("link",!0,n),n}function Yh(t){return function(t){return t.replace($h,"").match(Uh)}(t=String(t))?t:"#"}function Kh(t,e){return!!t&&t.is("element","image")&&e.checkAttribute("image","linkHref")}function Qh(t,e){const n=(r=t,qh.test(r)?"mailto:":e);var r;const i=!!n&&!Wh.test(t);return t&&i?n+t:t}class Xh extends vu{constructor(t){super(t),this.manualDecorators=new zn,this.automaticDecorators=new Ah}restoreManualDecoratorStates(){for(const t of this.manualDecorators)t.value=this._getDecoratorStateFromModel(t.id)}refresh(){const t=this.editor.model,e=t.document,n=zd(e.selection.getSelectedBlocks());Kh(n,t.schema)?(this.value=n.getAttribute("linkHref"),this.isEnabled=t.schema.checkAttribute(n,"linkHref")):(this.value=e.selection.getAttribute("linkHref"),this.isEnabled=t.schema.checkAttributeInSelection(e.selection,"linkHref"));for(const r of this.manualDecorators)r.value=this._getDecoratorStateFromModel(r.id)}execute(t,e={}){const n=this.editor.model,r=n.document.selection,i=[],o=[];for(const a in e)e[a]?i.push(a):o.push(a);n.change(e=>{if(r.isCollapsed){const a=r.getFirstPosition();if(r.hasAttribute("linkHref")){const s=Oh(a,"linkHref",r.getAttribute("linkHref"),n);e.setAttribute("linkHref",t,s),i.forEach(t=>{e.setAttribute(t,!0,s)}),o.forEach(t=>{e.removeAttribute(t,s)}),e.setSelection(e.createPositionAfter(s.end.nodeBefore))}else if(""!==t){const o=Bn(r.getAttributes());o.set("linkHref",t),i.forEach(t=>{o.set(t,!0)});const{end:s}=n.insertContent(e.createText(t,o),a);e.setSelection(s)}["linkHref",...i,...o].forEach(t=>{e.removeSelectionAttribute(t)})}else{const a=n.schema.getValidRanges(r.getRanges(),"linkHref"),s=[];for(const t of r.getSelectedBlocks())n.schema.checkAttribute(t,"linkHref")&&s.push(e.createRangeOn(t));const c=s.slice();for(const t of a)this._isRangeToUpdate(t,s)&&c.push(t);for(const n of c)e.setAttribute("linkHref",t,n),i.forEach(t=>{e.setAttribute(t,!0,n)}),o.forEach(t=>{e.removeAttribute(t,n)})}})}_getDecoratorStateFromModel(t){const e=this.editor.model,n=e.document,r=zd(n.selection.getSelectedBlocks());return Kh(r,e.schema)?r.getAttribute(t):n.selection.getAttribute(t)}_isRangeToUpdate(t,e){for(const n of e)if(n.containsRange(t))return!1;return!0}}class Jh extends vu{refresh(){const t=this.editor.model,e=t.document,n=zd(e.selection.getSelectedBlocks());Kh(n,t.schema)?this.isEnabled=t.schema.checkAttribute(n,"linkHref"):this.isEnabled=t.schema.checkAttributeInSelection(e.selection,"linkHref")}execute(){const t=this.editor,e=this.editor.model,n=e.document.selection,r=t.commands.get("link");e.change(t=>{const i=n.isCollapsed?[Oh(n.getFirstPosition(),"linkHref",n.getAttribute("linkHref"),e)]:e.schema.getValidRanges(n.getRanges(),"linkHref");for(const e of i)if(t.removeAttribute("linkHref",e),r)for(const n of r.manualDecorators)t.removeAttribute(n.id,e)})}}class Zh{constructor({id:t,label:e,attributes:n,defaultValue:r}){this.id=t,this.set("value"),this.defaultValue=r,this.label=e,this.attributes=n}}On(Zh,$r),n(48);const tf=/^(https?:)?\/\//;class ef extends du{static get pluginName(){return"LinkEditing"}static get requires(){return[vh,Uu,gu]}constructor(t){super(t),t.config.define("link",{addTargetToExternalLinks:!1})}init(){const t=this.editor;t.model.schema.extend("$text",{allowAttributes:"linkHref"}),t.conversion.for("dataDowncast").attributeToElement({model:"linkHref",view:Gh}),t.conversion.for("editingDowncast").attributeToElement({model:"linkHref",view:(t,e)=>Gh(Yh(t),e)}),t.conversion.for("upcast").elementToAttribute({view:{name:"a",attributes:{href:!0}},model:{key:"linkHref",value:t=>t.getAttribute("href")}}),t.commands.add("link",new Xh(t)),t.commands.add("unlink",new Jh(t));const e=function(t,e){const n={"Open in a new tab":t("Open in a new tab"),Downloadable:t("Downloadable")};return e.forEach(t=>(t.label&&n[t.label]&&(t.label=n[t.label]),t)),e}(t.t,function(t){const e=[];if(t)for(const[n,r]of Object.entries(t)){const t=Object.assign({},r,{id:"link"+Nh(n)});e.push(t)}return e}(t.config.get("link.decorators")));this._enableAutomaticDecorators(e.filter(t=>"automatic"===t.mode)),this._enableManualDecorators(e.filter(t=>"manual"===t.mode)),t.plugins.get(vh).registerAttribute("linkHref"),function(t,e,n,r){const i=t.editing.view,o=new Set;i.document.registerPostFixer(i=>{const a=t.model.document.selection;let s=!1;if(a.hasAttribute(e)){const c=Oh(a.getFirstPosition(),e,a.getAttribute(e),t.model),l=t.editing.mapper.toViewRange(c);for(const t of l.getItems())t.is("element",n)&&!t.hasClass(r)&&(i.addClass(r,t),o.add(t),s=!0)}return s}),t.conversion.for("editingDowncast").add(t=>{function e(){i.change(t=>{for(const e of o.values())t.removeClass(r,e),o.delete(e)})}t.on("insert",e,{priority:"highest"}),t.on("remove",e,{priority:"highest"}),t.on("attribute",e,{priority:"highest"}),t.on("selection",e,{priority:"highest"})})}(t,"linkHref","a","ck-link_selected"),this._enableInsertContentSelectionAttributesFixer(),this._enableClickingAfterLink(),this._enableTypingOverLink(),this._handleDeleteContentAfterLink()}_enableAutomaticDecorators(t){const e=this.editor,n=e.commands.get("link").automaticDecorators;e.config.get("link.addTargetToExternalLinks")&&n.add({id:"linkIsExternal",mode:"automatic",callback:t=>tf.test(t),attributes:{target:"_blank",rel:"noopener noreferrer"}}),n.add(t),n.length&&e.conversion.for("downcast").add(n.getDispatcher())}_enableManualDecorators(t){if(!t.length)return;const e=this.editor,n=e.commands.get("link").manualDecorators;t.forEach(t=>{e.model.schema.extend("$text",{allowAttributes:t.id}),n.add(new Zh(t)),e.conversion.for("downcast").attributeToElement({model:t.id,view:(e,{writer:r})=>{if(e){const e=n.get(t.id).attributes,i=r.createAttributeElement("a",e,{priority:5});return r.setCustomProperty("link",!0,i),i}}}),e.conversion.for("upcast").elementToAttribute({view:{name:"a",attributes:n.get(t.id).attributes},model:{key:t.id}})})}_enableInsertContentSelectionAttributesFixer(){const t=this.editor,e=t.model,n=e.document.selection,r=t.commands.get("link");this.listenTo(e,"insertContent",()=>{const t=n.anchor.nodeBefore,i=n.anchor.nodeAfter;n.hasAttribute("linkHref")&&t&&t.hasAttribute("linkHref")&&(i&&i.hasAttribute("linkHref")||e.change(t=>{nf(t,r.manualDecorators)}))},{priority:"low"})}_enableClickingAfterLink(){const t=this.editor,e=t.commands.get("link");t.editing.view.addObserver(gh);let n=!1;this.listenTo(t.editing.view.document,"mousedown",()=>{n=!0}),this.listenTo(t.editing.view.document,"selectionChange",()=>{if(!n)return;n=!1;const r=t.model.document.selection;if(!r.isCollapsed)return;if(!r.hasAttribute("linkHref"))return;const i=r.getFirstPosition(),o=Oh(i,"linkHref",r.getAttribute("linkHref"),t.model);(i.isTouching(o.start)||i.isTouching(o.end))&&t.model.change(t=>{nf(t,e.manualDecorators)})})}_enableTypingOverLink(){const t=this.editor,e=t.editing.view;let n,r;this.listenTo(e.document,"delete",()=>{r=!0},{priority:"high"}),this.listenTo(t.model,"deleteContent",()=>{const e=t.model.document.selection;e.isCollapsed||(r?r=!1:rf(t)&&function(t){const e=t.document.selection,n=e.getFirstPosition(),r=e.getLastPosition(),i=n.nodeAfter;if(!i)return!1;if(!i.is("$text"))return!1;if(!i.hasAttribute("linkHref"))return!1;const o=r.textNode||r.nodeBefore;return i===o||Oh(n,"linkHref",i.getAttribute("linkHref"),t).containsRange(t.createRange(n,r),!0)}(t.model)&&(n=e.getAttributes()))},{priority:"high"}),this.listenTo(t.model,"insertContent",(e,[i])=>{r=!1,rf(t)&&n&&(t.model.change(t=>{for(const[e,r]of n)t.setAttribute(e,r,i)}),n=null)},{priority:"high"})}_handleDeleteContentAfterLink(){const t=this.editor,e=t.model,n=e.document.selection,r=t.editing.view,i=t.commands.get("link");let o=!1,a=!1;this.listenTo(r.document,"delete",(t,e)=>{a=e.domEvent.keyCode===mi.backspace},{priority:"high"}),this.listenTo(e,"deleteContent",()=>{o=!1;const t=n.getFirstPosition(),r=n.getAttribute("linkHref");if(!r)return;const i=Oh(t,"linkHref",r,e);o=i.containsPosition(t)||i.end.isEqual(t)},{priority:"high"}),this.listenTo(e,"deleteContent",()=>{a&&(a=!1,o||t.model.enqueueChange(t=>{nf(t,i.manualDecorators)}))},{priority:"low"})}}function nf(t,e){t.removeSelectionAttribute("linkHref");for(const n of e)t.removeSelectionAttribute(n.id)}function rf(t){return t.plugins.get("Input").isInput(t.model.change(t=>t.batch))}class of extends bd{static get pluginName(){return"Notification"}init(){this.on("show:warning",(t,e)=>{window.alert(e.message)},{priority:"lowest"})}showSuccess(t,e={}){this._showNotification({message:t,type:"success",namespace:e.namespace,title:e.title})}showInfo(t,e={}){this._showNotification({message:t,type:"info",namespace:e.namespace,title:e.title})}showWarning(t,e={}){this._showNotification({message:t,type:"warning",namespace:e.namespace,title:e.title})}_showNotification(t){const e="show:"+t.type+(t.namespace?":"+t.namespace:"");this.fire(e,{message:t.message,type:t.type,title:t.title||""})}}class af extends vu{constructor(t){super(t),this.stopListening(this.editor.model.document,"change"),this.listenTo(this.editor.model.document,"change",()=>this.refresh(),{priority:"low"})}refresh(){const t=this.editor.commands.get("imageInsert"),e=this.editor.commands.get("link");this.isEnabled=t.isEnabled||e.isEnabled}execute(){const t=this.editor,e=this.editor.config.get("ckfinder.openerMethod")||"modal";if("popup"!=e&&"modal"!=e)throw new hn.a("ckfinder-unknown-openermethod",t);const n=this.editor.config.get("ckfinder.options")||{};n.chooseFiles=!0;const r=n.onInit;n.language||(n.language=t.locale.uiLanguage),n.onInit=e=>{r&&r(e),e.on("files:choose",n=>{const r=n.data.files.toArray(),i=r.filter(t=>!t.isImage()),o=r.filter(t=>t.isImage());for(const e of i)t.execute("link",e.getUrl());const a=[];for(const t of o){const n=t.getUrl();a.push(n||e.request("file:getProxyUrl",{file:t}))}a.length&&sf(t,a)}),e.on("file:choose:resizedImage",e=>{const n=e.data.resizedUrl;if(n)sf(t,[n]);else{const e=t.plugins.get("Notification"),n=t.locale.t;e.showWarning(n("Could not obtain resized image URL."),{title:n("Selecting resized image failed"),namespace:"ckfinder"})}})},window.CKFinder[e](n)}}function sf(t,e){if(t.commands.get("imageInsert").isEnabled)t.execute("imageInsert",{source:e});else{const e=t.plugins.get("Notification"),n=t.locale.t;e.showWarning(n("Could not insert image at the current position."),{title:n("Inserting image failed"),namespace:"ckfinder"})}}class cf extends du{static get pluginName(){return"CKFinderEditing"}static get requires(){return[of,mh,ef]}init(){const t=this.editor;t.commands.add("ckfinder",new af(t))}}const lf=/^data:(\S*?);base64,/;class uf{constructor(t,e,n){if(!t)throw new hn.a("fileuploader-missing-file",null);if(!e)throw new hn.a("fileuploader-missing-token",null);if(!n)throw new hn.a("fileuploader-missing-api-address",null);this.file=function(t){if("string"!=typeof t)return!1;const e=t.match(lf);return!(!e||!e.length)}(t)?function(t,e=512){try{const n=t.match(lf)[1],r=atob(t.replace(lf,"")),i=[];for(let t=0;t<r.length;t+=e){const n=r.slice(t,t+e),o=new Array(n.length);for(let t=0;t<n.length;t++)o[t]=n.charCodeAt(t);i.push(new Uint8Array(o))}return new Blob(i,{type:n})}catch(t){throw new hn.a("fileuploader-decoding-image-data-error",null)}}(t):t,this._token=e,this._apiAddress=n}onProgress(t){return this.on("progress",(e,n)=>t(n)),this}onError(t){return this.once("error",(e,n)=>t(n)),this}abort(){this.xhr.abort()}send(){return this._prepareRequest(),this._attachXHRListeners(),this._sendRequest()}_prepareRequest(){const t=new XMLHttpRequest;t.open("POST",this._apiAddress),t.setRequestHeader("Authorization",this._token.value),t.responseType="json",this.xhr=t}_attachXHRListeners(){const t=this,e=this.xhr;function n(e){return()=>t.fire("error",e)}e.addEventListener("error",n("Network Error")),e.addEventListener("abort",n("Abort")),e.upload&&e.upload.addEventListener("progress",t=>{t.lengthComputable&&this.fire("progress",{total:t.total,uploaded:t.loaded})}),e.addEventListener("load",()=>{const t=e.status,n=e.response;if(t<200||t>299)return this.fire("error",n.message||n.error)})}_sendRequest(){const t=new FormData,e=this.xhr;return t.append("file",this.file),new Promise((n,r)=>{e.addEventListener("load",()=>{const t=e.status,i=e.response;return t<200||t>299?i.message?r(new hn.a("fileuploader-uploading-data-failed",this,{message:i.message})):r(i.error):n(i)}),e.addEventListener("error",()=>r(new Error("Network Error"))),e.addEventListener("abort",()=>r(new Error("Abort"))),e.send(t)})}}On(uf,mn);const df={autoRefresh:!0};class hf{constructor(t,e=df){if(!t)throw new hn.a("token-missing-token-url",this);e.initValue&&this._validateTokenValue(e.initValue),this.set("value",e.initValue),this._refresh="function"==typeof t?t:()=>{return e=t,new Promise((t,n)=>{const r=new XMLHttpRequest;r.open("GET",e),r.addEventListener("load",()=>{const e=r.status,i=r.response;return e<200||e>299?n(new hn.a("token-cannot-download-new-token",null)):t(i)}),r.addEventListener("error",()=>n(new Error("Network Error"))),r.addEventListener("abort",()=>n(new Error("Abort"))),r.send()});var e},this._options=Object.assign({},df,e)}init(){return new Promise((t,e)=>{this.value?(this._options.autoRefresh&&this._registerRefreshTokenTimeout(),t(this)):this.refreshToken().then(t).catch(e)})}refreshToken(){return this._refresh().then(t=>{this._validateTokenValue(t),this.set("value",t),this._options.autoRefresh&&this._registerRefreshTokenTimeout()}).then(()=>this)}destroy(){clearTimeout(this._tokenRefreshTimeout)}_validateTokenValue(t){const e="string"==typeof t,n=!/^".*"$/.test(t),r=e&&3===t.split(".").length;if(!n||!r)throw new hn.a("token-not-in-jwt-format",this)}_registerRefreshTokenTimeout(){const t=this._getTokenRefreshTimeoutTime();clearTimeout(this._tokenRefreshTimeout),this._tokenRefreshTimeout=setTimeout(()=>{this.refreshToken()},t)}_getTokenRefreshTimeoutTime(){try{const[,t]=this.value.split("."),{exp:e}=JSON.parse(atob(t));return e?Math.floor((1e3*e-Date.now())/2):36e5}catch(t){return 36e5}}static create(t,e=df){return new hf(t,e).init()}}On(hf,$r);var ff=hf;class pf extends bd{static get pluginName(){return"CloudServices"}init(){const t=this.context.config.get("cloudServices")||{};for(const e in t)this[e]=t[e];if(this._tokens=new Map,this.tokenUrl)return this.token=new pf.Token(this.tokenUrl),this._tokens.set(this.tokenUrl,this.token),this.token.init();this.token=null}registerTokenUrl(t){if(this._tokens.has(t))return Promise.resolve(this.getTokenFor(t));const e=new pf.Token(t);return this._tokens.set(t,e),e.init()}getTokenFor(t){const e=this._tokens.get(t);if(!e)throw new hn.a("cloudservices-token-not-registered",this);return e}destroy(){super.destroy();for(const t of this._tokens.values())t.destroy()}}pf.Token=ff;class mf extends du{static get requires(){return[wd,pf]}init(){const t=this.editor,e=t.plugins.get(pf),n=e.token,r=e.uploadUrl;n&&(this._uploadGateway=new mf._UploadGateway(n,r),t.plugins.get(wd).createUploadAdapter=t=>new bf(this._uploadGateway,t))}}class bf{constructor(t,e){this.uploadGateway=t,this.loader=e}upload(){return this.loader.file.then(t=>(this.fileUploader=this.uploadGateway.upload(t),this.fileUploader.on("progress",(t,e)=>{this.loader.uploadTotal=e.total,this.loader.uploaded=e.uploaded}),this.fileUploader.send()))}abort(){this.fileUploader.abort()}}mf._UploadGateway=class{constructor(t,e){if(!t)throw new hn.a("uploadgateway-missing-token",null);if(!e)throw new hn.a("uploadgateway-missing-api-address",null);this._token=t,this._apiAddress=e}upload(t){return new uf(t,this._token,this._apiAddress)}},n(50);const gf=["before","after"],vf=(new DOMParser).parseFromString('<svg viewBox="0 0 10 8" xmlns="http://www.w3.org/2000/svg"><path d="M9.055.263v3.972h-6.77M1 4.216l2-2.038m-2 2l2 2.038"/></svg>',"image/svg+xml").firstChild;class wf extends du{static get pluginName(){return"WidgetTypeAround"}constructor(t){super(t),this._currentFakeCaretModelElement=null}init(){const t=this.editor,e=t.editing.view;this.on("change:isEnabled",(n,r,i)=>{e.change(t=>{for(const n of e.document.roots)i?t.removeClass("ck-widget__type-around_disabled",n):t.addClass("ck-widget__type-around_disabled",n)}),i||t.model.change(t=>{t.removeSelectionAttribute("widget-type-around")})}),this._enableTypeAroundUIInjection(),this._enableInsertingParagraphsOnButtonClick(),this._enableInsertingParagraphsOnEnterKeypress(),this._enableInsertingParagraphsOnTypingKeystroke(),this._enableTypeAroundFakeCaretActivationUsingKeyboardArrows(),this._enableDeleteIntegration(),this._enableInsertContentIntegration()}destroy(){this._currentFakeCaretModelElement=null}_insertParagraph(t,e){const n=this.editor,r=n.editing.view;n.execute("insertParagraph",{position:n.model.createPositionAt(t,e)}),r.focus(),r.scrollToTheSelection()}_listenToIfEnabled(t,e,n,r){this.listenTo(t,e,(...t)=>{this.isEnabled&&n(...t)},r)}_insertParagraphAccordingToFakeCaretPosition(){const t=this.editor.model.document.selection,e=Zd(t);if(!e)return!1;const n=t.getSelectedElement();return this._insertParagraph(n,e),!0}_enableTypeAroundUIInjection(){const t=this.editor,e=t.model.schema,n=t.locale.t,r={before:n("Insert paragraph before block"),after:n("Insert paragraph after block")};t.editing.downcastDispatcher.on("insert",(t,n,i)=>{const o=i.mapper.toViewElement(n.item);Jd(o,n.item,e)&&function(t,e,n){const r=t.createUIElement("div",{class:"ck ck-reset_all ck-widget__type-around"},(function(t){const n=this.toDomElement(t);return function(t,e){for(const n of gf){const r=new ol({tag:"div",attributes:{class:["ck","ck-widget__type-around__button","ck-widget__type-around__button_"+n],title:e[n]},children:[t.ownerDocument.importNode(vf,!0)]});t.appendChild(r.render())}}(n,e),function(t){const e=new ol({tag:"div",attributes:{class:["ck","ck-widget__type-around__fake-caret"]}});t.appendChild(e.render())}(n),n}));t.insert(t.createPositionAt(n,"end"),r)}(i.writer,r,o)},{priority:"low"})}_enableTypeAroundFakeCaretActivationUsingKeyboardArrows(){const t=this.editor,e=t.model,n=e.document.selection,r=e.schema,i=t.editing.view;function o(t){return"ck-widget_type-around_show-fake-caret_"+t}this._listenToIfEnabled(i.document,"keydown",(t,e)=>{wi(e.keyCode)&&this._handleArrowKeyPress(t,e)},{priority:dn.get("high")+10}),this._listenToIfEnabled(n,"change:range",(e,n)=>{n.directChange&&t.model.change(t=>{t.removeSelectionAttribute("widget-type-around")})}),this._listenToIfEnabled(e.document,"change:data",()=>{const e=n.getSelectedElement();e&&Jd(t.editing.mapper.toViewElement(e),e,r)||t.model.change(t=>{t.removeSelectionAttribute("widget-type-around")})}),this._listenToIfEnabled(t.editing.downcastDispatcher,"selection",(t,e,n)=>{const i=n.writer;if(this._currentFakeCaretModelElement){const t=n.mapper.toViewElement(this._currentFakeCaretModelElement);t&&(i.removeClass(gf.map(o),t),this._currentFakeCaretModelElement=null)}const a=e.selection.getSelectedElement();if(!a)return;const s=n.mapper.toViewElement(a);if(!Jd(s,a,r))return;const c=Zd(e.selection);c&&(i.addClass(o(c),s),this._currentFakeCaretModelElement=a)}),this._listenToIfEnabled(t.ui.focusTracker,"change:isFocused",(e,n,r)=>{r||t.model.change(t=>{t.removeSelectionAttribute("widget-type-around")})})}_handleArrowKeyPress(t,e){const n=this.editor,r=n.model,i=r.document.selection,o=r.schema,a=n.editing.view,s=ki(e.keyCode,n.locale.contentLanguageDirection),c=a.document.selection.getSelectedElement();let l;Jd(c,n.editing.mapper.toModelElement(c),o)?l=this._handleArrowKeyPressOnSelectedWidget(s):i.isCollapsed&&(l=this._handleArrowKeyPressWhenSelectionNextToAWidget(s)),l&&(e.preventDefault(),t.stop())}_handleArrowKeyPressOnSelectedWidget(t){const e=this.editor.model,n=Zd(e.document.selection);return e.change(e=>n?n!==(t?"after":"before")&&(e.removeSelectionAttribute("widget-type-around"),!0):(e.setSelectionAttribute("widget-type-around",t?"after":"before"),!0))}_handleArrowKeyPressWhenSelectionNextToAWidget(t){const e=this.editor,n=e.model,r=n.schema,i=e.plugins.get("Widget"),o=i._getObjectElementNextToSelection(t);return!!Jd(e.editing.mapper.toViewElement(o),o,r)&&(n.change(e=>{i._setSelectionOverElement(o),e.setSelectionAttribute("widget-type-around",t?"before":"after")}),!0)}_enableInsertingParagraphsOnButtonClick(){const t=this.editor,e=t.editing.view;this._listenToIfEnabled(e.document,"mousedown",(n,r)=>{const i=r.domTarget.closest(".ck-widget__type-around__button");if(!i)return;const o=function(t){return t.classList.contains("ck-widget__type-around__button_before")?"before":"after"}(i),a=function(t,e){const n=t.closest(".ck-widget");return e.mapDomToView(n)}(i,e.domConverter),s=t.editing.mapper.toModelElement(a);this._insertParagraph(s,o),r.preventDefault(),n.stop()})}_enableInsertingParagraphsOnEnterKeypress(){const t=this.editor,e=t.editing.view;this._listenToIfEnabled(e.document,"enter",(n,r)=>{const i=e.document.selection.getSelectedElement(),o=t.editing.mapper.toModelElement(i),a=t.model.schema;let s;this._insertParagraphAccordingToFakeCaretPosition()?s=!0:Jd(i,o,a)&&(this._insertParagraph(o,r.isSoft?"before":"after"),s=!0),s&&(r.preventDefault(),n.stop())})}_enableInsertingParagraphsOnTypingKeystroke(){const t=this.editor.editing.view,e=[mi.enter,mi.delete,mi.backspace];this._listenToIfEnabled(t.document,"keydown",(t,n)=>{e.includes(n.keyCode)||Hu(n)||this._insertParagraphAccordingToFakeCaretPosition()},{priority:dn.get("high")+1})}_enableDeleteIntegration(){const t=this.editor,e=t.editing.view,n=t.model,r=n.schema;this._listenToIfEnabled(e.document,"delete",(e,i)=>{const o=Zd(n.document.selection);if(!o)return;const a=i.direction,s=n.document.selection.getSelectedElement(),c="forward"==a;if("before"===o===c)t.execute("delete",{selection:n.createSelection(s,"on")});else{const e=r.getNearestSelectionRange(n.createPositionAt(s,o),a);if(e)if(e.isCollapsed){const i=n.createSelection(e.start);if(n.modifySelection(i,{direction:a}),i.focus.isEqual(e.start)){const t=function(t,e){let n=e;for(const r of e.getAncestors({parentFirst:!0})){if(r.childCount>1||t.isLimit(r))break;n=r}return n}(r,e.start.parent);n.deleteContent(n.createSelection(t,"on"),{doNotAutoparagraph:!0})}else n.change(n=>{n.setSelection(e),t.execute(c?"forwardDelete":"delete")})}else n.change(n=>{n.setSelection(e),t.execute(c?"forwardDelete":"delete")})}i.preventDefault(),e.stop()},{priority:dn.get("high")+1})}_enableInsertContentIntegration(){const t=this.editor,e=this.editor.model,n=e.document.selection;this._listenToIfEnabled(t.model,"insertContent",(t,[r,i])=>{if(i&&!i.is("documentSelection"))return;const o=Zd(n);return o?(t.stop(),e.change(t=>{const i=n.getSelectedElement(),a=e.createPositionAt(i,o),s=t.createSelection(a),c=e.insertContent(r,s);return t.setSelection(s),c})):void 0},{priority:"high"})}}function yf(t){const e=t.model;return(n,r)=>{const i=r.keyCode==mi.arrowup,o=r.keyCode==mi.arrowdown,a=r.shiftKey,s=e.document.selection;if(!i&&!o)return;const c=o;if(a&&function(t,e){return!t.isCollapsed&&t.isBackward==e}(s,c))return;const l=function(t,e,n){const r=t.model;if(n){const t=e.isCollapsed?e.focus:e.getLastPosition(),n=kf(r,t,"forward");if(!n)return null;const i=r.createRange(t,n),o=_f(r.schema,i,"backward");return o&&t.isBefore(o)?r.createRange(t,o):null}{const t=e.isCollapsed?e.focus:e.getFirstPosition(),n=kf(r,t,"backward");if(!n)return null;const i=r.createRange(n,t),o=_f(r.schema,i,"forward");return o&&t.isAfter(o)?r.createRange(o,t):null}}(t,s,c);l&&!l.isCollapsed&&function(t,e,n){const r=t.model,i=t.view.domConverter;if(n){const t=r.createSelection(e.start);r.modifySelection(t),t.focus.isAtEnd||e.start.isEqual(t.focus)||(e=r.createRange(t.focus,e.end))}const o=t.mapper.toViewRange(e),a=i.viewRangeToDom(o),s=ia.getDomRangeRects(a);let c;for(const l of s)if(void 0!==c){if(Math.round(l.top)>=c)return!1;c=Math.max(c,Math.round(l.bottom))}else c=Math.round(l.bottom);return!0}(t,l,c)&&(e.change(t=>{const n=c?l.end:l.start;if(a){const r=e.createSelection(s.anchor);r.setFocus(n),t.setSelection(r)}else t.setSelection(n)}),n.stop(),r.preventDefault(),r.stopPropagation())}}function kf(t,e,n){const r=t.schema,i=t.createRangeIn(e.root),o="forward"==n?"elementStart":"elementEnd";for(const{previousPosition:a,item:s,type:c}of i.getWalker({startPosition:e,direction:n})){if(r.isLimit(s)&&!r.isInline(s))return a;if(c==o&&r.isBlock(s))return null}return null}function _f(t,e,n){const r="backward"==n?e.end:e.start;if(t.checkChild(r,"$text"))return r;for(const{nextPosition:i}of e.getWalker({direction:n}))if(t.checkChild(i,"$text"))return i}n(52);class Of extends du{static get pluginName(){return"Widget"}static get requires(){return[wf]}init(){const t=this.editor.editing.view,e=t.document;this._previouslySelected=new Set,this.editor.editing.downcastDispatcher.on("selection",(t,e,n)=>{this._clearPreviouslySelectedWidgets(n.writer);const r=n.writer,i=r.document.selection,o=i.getSelectedElement();let a=null;for(const s of i.getRanges())for(const t of s){const e=t.item;th(e)&&!zf(e,a)&&(r.addClass("ck-widget_selected",e),this._previouslySelected.add(e),a=e,e==o&&r.setSelection(i.getRanges(),{fake:!0,label:rh(o)}))}},{priority:"low"}),t.addObserver(gh),this.listenTo(e,"mousedown",(...t)=>this._onMousedown(...t)),this.listenTo(e,"keydown",(...t)=>{this._handleSelectionChangeOnArrowKeyPress(...t)},{priority:"high"}),this.listenTo(e,"keydown",(...t)=>{this._preventDefaultOnArrowKeyPress(...t)},{priority:dn.get("high")-20}),this.listenTo(e,"keydown",yf(this.editor.editing)),this.listenTo(e,"delete",(t,e)=>{this._handleDelete("forward"==e.direction)&&(e.preventDefault(),t.stop())},{priority:"high"})}_onMousedown(t,e){const n=this.editor,r=n.editing.view,i=r.document;let o=e.target;if(function(t){for(;t;){if(t.is("editableElement")&&!t.is("rootElement"))return!0;if(th(t))return!1;t=t.parent}return!1}(o)){if((hi.isSafari||hi.isGecko)&&e.domEvent.detail>=3){const t=n.editing.mapper,r=o.is("attributeElement")?o.findAncestor(t=>!t.is("attributeElement")):o,i=t.toModelElement(r);e.preventDefault(),this.editor.model.change(t=>{t.setSelection(i,"in")})}return}if(!th(o)&&(o=o.findAncestor(th),!o))return;e.preventDefault(),i.isFocused||r.focus();const a=n.editing.mapper.toModelElement(o);this._setSelectionOverElement(a)}_handleSelectionChangeOnArrowKeyPress(t,e){const n=e.keyCode;if(!wi(n))return;const r=this.editor.model,i=r.schema,o=r.document.selection,a=o.getSelectedElement(),s=ki(n,this.editor.locale.contentLanguageDirection);if(a&&i.isObject(a)){const n=s?o.getLastPosition():o.getFirstPosition(),a=i.getNearestSelectionRange(n,s?"forward":"backward");return void(a&&(r.change(t=>{t.setSelection(a)}),e.preventDefault(),t.stop()))}if(!o.isCollapsed)return;const c=this._getObjectElementNextToSelection(s);c&&i.isObject(c)&&(this._setSelectionOverElement(c),e.preventDefault(),t.stop())}_preventDefaultOnArrowKeyPress(t,e){if(!wi(e.keyCode))return;const n=this.editor.model,r=n.schema,i=n.document.selection.getSelectedElement();i&&r.isObject(i)&&(e.preventDefault(),t.stop())}_handleDelete(t){if(this.editor.isReadOnly)return;const e=this.editor.model.document.selection;if(!e.isCollapsed)return;const n=this._getObjectElementNextToSelection(t);return n?(this.editor.model.change(t=>{let r=e.anchor.parent;for(;r.isEmpty;){const e=r;r=e.parent,t.remove(e)}this._setSelectionOverElement(n)}),!0):void 0}_setSelectionOverElement(t){this.editor.model.change(e=>{e.setSelection(e.createRangeOn(t))})}_getObjectElementNextToSelection(t){const e=this.editor.model,n=e.schema,r=e.document.selection,i=e.createSelection(r);e.modifySelection(i,{direction:t?"forward":"backward"});const o=t?i.focus.nodeBefore:i.focus.nodeAfter;return o&&n.isObject(o)?o:null}_clearPreviouslySelectedWidgets(t){for(const e of this._previouslySelected)t.removeClass("ck-widget_selected",e);this._previouslySelected.clear()}}function zf(t,e){return!!e&&Array.from(t.getAncestors()).includes(e)}class Af extends vu{refresh(){const t=this.editor.model.document.selection.getSelectedElement();this.isEnabled=lh(t),lh(t)&&t.hasAttribute("alt")?this.value=t.getAttribute("alt"):this.value=!1}execute(t){const e=this.editor.model,n=e.document.selection.getSelectedElement();e.change(e=>{e.setAttribute("alt",t.newValue,n)})}}class jf extends du{static get pluginName(){return"ImageTextAlternativeEditing"}init(){this.editor.commands.add("imageTextAlternative",new Af(this.editor))}}n(54);class Mf extends zl{constructor(t,e){super(t);const n="ck-labeled-field-view-"+un(),r="ck-labeled-field-view-status-"+un();this.fieldView=e(this,n,r),this.set("label"),this.set("isEnabled",!0),this.set("isEmpty",!0),this.set("isFocused",!1),this.set("errorText",null),this.set("infoText",null),this.set("class"),this.set("placeholder"),this.labelView=this._createLabelView(n),this.statusView=this._createStatusView(r),this.bind("_statusText").to(this,"errorText",this,"infoText",(t,e)=>t||e);const i=this.bindTemplate;this.setTemplate({tag:"div",attributes:{class:["ck","ck-labeled-field-view",i.to("class"),i.if("isEnabled","ck-disabled",t=>!t),i.if("isEmpty","ck-labeled-field-view_empty"),i.if("isFocused","ck-labeled-field-view_focused"),i.if("placeholder","ck-labeled-field-view_placeholder"),i.if("errorText","ck-error")]},children:[{tag:"div",attributes:{class:["ck","ck-labeled-field-view__input-wrapper"]},children:[this.fieldView,this.labelView]},this.statusView]})}_createLabelView(t){const e=new Cl(this.locale);return e.for=t,e.bind("text").to(this,"label"),e}_createStatusView(t){const e=new zl(this.locale),n=this.bindTemplate;return e.setTemplate({tag:"div",attributes:{class:["ck","ck-labeled-field-view__status",n.if("errorText","ck-labeled-field-view__status_error"),n.if("_statusText","ck-hidden",t=>!t)],id:t,role:n.if("errorText","alert")},children:[{text:n.to("_statusText")}]}),e}focus(){this.fieldView.focus()}}n(56);class Cf extends zl{constructor(t){super(t),this.set("value"),this.set("id"),this.set("placeholder"),this.set("isReadOnly",!1),this.set("hasError",!1),this.set("ariaDescribedById"),this.focusTracker=new Yc,this.bind("isFocused").to(this.focusTracker),this.set("isEmpty",!0);const e=this.bindTemplate;this.setTemplate({tag:"input",attributes:{type:"text",class:["ck","ck-input","ck-input-text",e.if("isFocused","ck-input_focused"),e.if("isEmpty","ck-input-text_empty"),e.if("hasError","ck-error")],id:e.to("id"),placeholder:e.to("placeholder"),readonly:e.to("isReadOnly"),"aria-invalid":e.if("hasError",!0),"aria-describedby":e.to("ariaDescribedById")},on:{input:e.to("input"),change:e.to(this._updateIsEmpty.bind(this))}})}render(){super.render(),this.focusTracker.add(this.element),this._setDomElementValue(this.value),this._updateIsEmpty(),this.on("change:value",(t,e,n)=>{this._setDomElementValue(n),this._updateIsEmpty()})}select(){this.element.select()}focus(){this.element.focus()}_updateIsEmpty(){this.isEmpty=!this.element.value}_setDomElementValue(t){this.element.value=t||0===t?t:""}}function Vf(t,e,n){const r=new Cf(t.locale);return r.set({id:e,ariaDescribedById:n}),r.bind("isReadOnly").to(t,"isEnabled",t=>!t),r.bind("hasError").to(t,"errorText",t=>!!t),r.on("input",()=>{t.errorText=null}),t.bind("isEmpty","isFocused","placeholder").to(r),r}function Sf(t){t.set("_isCssTransitionsDisabled",!1),t.disableCssTransitions=()=>{t._isCssTransitionsDisabled=!0},t.enableCssTransitions=()=>{t._isCssTransitionsDisabled=!1},t.extendTemplate({attributes:{class:[t.bindTemplate.if("_isCssTransitionsDisabled","ck-transitions-disabled")]}})}function xf({view:t}){t.listenTo(t.element,"submit",(e,n)=>{n.preventDefault(),t.fire("submit")},{useCapture:!0})}var Tf='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M6.972 16.615a.997.997 0 0 1-.744-.292l-4.596-4.596a1 1 0 1 1 1.414-1.414l3.926 3.926 9.937-9.937a1 1 0 0 1 1.414 1.415L7.717 16.323a.997.997 0 0 1-.745.292z"/></svg>',Pf='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M11.591 10.177l4.243 4.242a1 1 0 0 1-1.415 1.415l-4.242-4.243-4.243 4.243a1 1 0 0 1-1.414-1.415l4.243-4.242L4.52 5.934A1 1 0 0 1 5.934 4.52l4.243 4.243 4.242-4.243a1 1 0 1 1 1.415 1.414l-4.243 4.243z"/></svg>';n(58),n(7);class If extends zl{constructor(t){super(t);const e=this.locale.t;this.focusTracker=new Yc,this.keystrokes=new Rc,this.labeledInput=this._createLabeledInputView(),this.saveButtonView=this._createButton(e("Save"),Tf,"ck-button-save"),this.saveButtonView.type="submit",this.cancelButtonView=this._createButton(e("Cancel"),Pf,"ck-button-cancel","cancel"),this._focusables=new il,this._focusCycler=new El({focusables:this._focusables,focusTracker:this.focusTracker,keystrokeHandler:this.keystrokes,actions:{focusPrevious:"shift + tab",focusNext:"tab"}}),this.setTemplate({tag:"form",attributes:{class:["ck","ck-text-alternative-form","ck-responsive-form"],tabindex:"-1"},children:[this.labeledInput,this.saveButtonView,this.cancelButtonView]}),Sf(this)}render(){super.render(),this.keystrokes.listenTo(this.element),xf({view:this}),[this.labeledInput,this.saveButtonView,this.cancelButtonView].forEach(t=>{this._focusables.add(t),this.focusTracker.add(t.element)})}_createButton(t,e,n,r){const i=new Kl(this.locale);return i.set({label:t,icon:e,tooltip:!0}),i.extendTemplate({attributes:{class:n}}),r&&i.delegate("execute").to(this,r),i}_createLabeledInputView(){const t=this.locale.t,e=new Mf(this.locale,Vf);return e.label=t("Text alternative"),e}}n(61),n(63);const Ef=Tl("px");class Lf extends du{static get pluginName(){return"ContextualBalloon"}constructor(t){super(t),this.positionLimiter=()=>{const t=this.editor.editing.view,e=t.document.selection.editableElement;return e?t.domConverter.mapViewToDom(e.root):null},this.set("visibleView",null),this.view=new Yd(t.locale),t.ui.view.body.add(this.view),t.ui.focusTracker.add(this.view.element),this._viewToStack=new Map,this._idToStack=new Map,this.set("_numberOfStacks",0),this.set("_singleViewMode",!1),this._rotatorView=this._createRotatorView(),this._fakePanelsView=this._createFakePanelsView()}hasView(t){return Array.from(this._viewToStack.keys()).includes(t)}add(t){if(this.hasView(t.view))throw new hn.a("contextualballoon-add-view-exist",[this,t]);const e=t.stackId||"main";if(!this._idToStack.has(e))return this._idToStack.set(e,new Map([[t.view,t]])),this._viewToStack.set(t.view,this._idToStack.get(e)),this._numberOfStacks=this._idToStack.size,void(this._visibleStack&&!t.singleViewMode||this.showStack(e));const n=this._idToStack.get(e);t.singleViewMode&&this.showStack(e),n.set(t.view,t),this._viewToStack.set(t.view,n),n===this._visibleStack&&this._showView(t)}remove(t){if(!this.hasView(t))throw new hn.a("contextualballoon-remove-view-not-exist",[this,t]);const e=this._viewToStack.get(t);this._singleViewMode&&this.visibleView===t&&(this._singleViewMode=!1),this.visibleView===t&&(1===e.size?this._idToStack.size>1?this._showNextStack():(this.view.hide(),this.visibleView=null,this._rotatorView.hideView()):this._showView(Array.from(e.values())[e.size-2])),1===e.size?(this._idToStack.delete(this._getStackId(e)),this._numberOfStacks=this._idToStack.size):e.delete(t),this._viewToStack.delete(t)}updatePosition(t){t&&(this._visibleStack.get(this.visibleView).position=t),this.view.pin(this._getBalloonPosition()),this._fakePanelsView.updatePosition()}showStack(t){this.visibleStack=t;const e=this._idToStack.get(t);if(!e)throw new hn.a("contextualballoon-showstack-stack-not-exist",this);this._visibleStack!==e&&this._showView(Array.from(e.values()).pop())}get _visibleStack(){return this._viewToStack.get(this.visibleView)}_getStackId(t){return Array.from(this._idToStack.entries()).find(e=>e[1]===t)[0]}_showNextStack(){const t=Array.from(this._idToStack.values());let e=t.indexOf(this._visibleStack)+1;t[e]||(e=0),this.showStack(this._getStackId(t[e]))}_showPrevStack(){const t=Array.from(this._idToStack.values());let e=t.indexOf(this._visibleStack)-1;t[e]||(e=t.length-1),this.showStack(this._getStackId(t[e]))}_createRotatorView(){const t=new Bf(this.editor.locale),e=this.editor.locale.t;return this.view.content.add(t),t.bind("isNavigationVisible").to(this,"_numberOfStacks",this,"_singleViewMode",(t,e)=>!e&&t>1),t.on("change:isNavigationVisible",()=>this.updatePosition(),{priority:"low"}),t.bind("counter").to(this,"visibleView",this,"_numberOfStacks",(t,n)=>{if(n<2)return"";const r=Array.from(this._idToStack.values()).indexOf(this._visibleStack)+1;return e("%0 of %1",[r,n])}),t.buttonNextView.on("execute",()=>{t.focusTracker.isFocused&&this.editor.editing.view.focus(),this._showNextStack()}),t.buttonPrevView.on("execute",()=>{t.focusTracker.isFocused&&this.editor.editing.view.focus(),this._showPrevStack()}),t}_createFakePanelsView(){const t=new Hf(this.editor.locale,this.view);return t.bind("numberOfPanels").to(this,"_numberOfStacks",this,"_singleViewMode",(t,e)=>!e&&t>=2?Math.min(t-1,2):0),t.listenTo(this.view,"change:top",()=>t.updatePosition()),t.listenTo(this.view,"change:left",()=>t.updatePosition()),this.editor.ui.view.body.add(t),t}_showView({view:t,balloonClassName:e="",withArrow:n=!0,singleViewMode:r=!1}){this.view.class=e,this.view.withArrow=n,this._rotatorView.showView(t),this.visibleView=t,this.view.pin(this._getBalloonPosition()),this._fakePanelsView.updatePosition(),r&&(this._singleViewMode=!0)}_getBalloonPosition(){let t=Array.from(this._visibleStack.values()).pop().position;return t&&!t.limiter&&(t=Object.assign({},t,{limiter:this.positionLimiter})),t}}class Bf extends zl{constructor(t){super(t);const e=t.t,n=this.bindTemplate;this.set("isNavigationVisible",!0),this.focusTracker=new Yc,this.buttonPrevView=this._createButtonView(e("Previous"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M11.463 5.187a.888.888 0 1 1 1.254 1.255L9.16 10l3.557 3.557a.888.888 0 1 1-1.254 1.255L7.26 10.61a.888.888 0 0 1 .16-1.382l4.043-4.042z"/></svg>'),this.buttonNextView=this._createButtonView(e("Next"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M8.537 14.813a.888.888 0 1 1-1.254-1.255L10.84 10 7.283 6.442a.888.888 0 1 1 1.254-1.255L12.74 9.39a.888.888 0 0 1-.16 1.382l-4.043 4.042z"/></svg>'),this.content=this.createCollection(),this.setTemplate({tag:"div",attributes:{class:["ck","ck-balloon-rotator"],"z-index":"-1"},children:[{tag:"div",attributes:{class:["ck-balloon-rotator__navigation",n.to("isNavigationVisible",t=>t?"":"ck-hidden")]},children:[this.buttonPrevView,{tag:"span",attributes:{class:["ck-balloon-rotator__counter"]},children:[{text:n.to("counter")}]},this.buttonNextView]},{tag:"div",attributes:{class:"ck-balloon-rotator__content"},children:this.content}]})}render(){super.render(),this.focusTracker.add(this.element)}showView(t){this.hideView(),this.content.add(t)}hideView(){this.content.clear()}_createButtonView(t,e){const n=new Kl(this.locale);return n.set({label:t,icon:e,tooltip:!0}),n}}class Hf extends zl{constructor(t,e){super(t);const n=this.bindTemplate;this.set("top",0),this.set("left",0),this.set("height",0),this.set("width",0),this.set("numberOfPanels",0),this.content=this.createCollection(),this._balloonPanelView=e,this.setTemplate({tag:"div",attributes:{class:["ck-fake-panel",n.to("numberOfPanels",t=>t?"":"ck-hidden")],style:{top:n.to("top",Ef),left:n.to("left",Ef),width:n.to("width",Ef),height:n.to("height",Ef)}},children:this.content}),this.on("change:numberOfPanels",(t,e,n,r)=>{n>r?this._addPanels(n-r):this._removePanels(r-n),this.updatePosition()})}_addPanels(t){for(;t--;){const t=new zl;t.setTemplate({tag:"div"}),this.content.add(t),this.registerChild(t)}}_removePanels(t){for(;t--;){const t=this.content.last;this.content.remove(t),this.deregisterChild(t),t.destroy()}}updatePosition(){if(this.numberOfPanels){const{top:t,left:e}=this._balloonPanelView,{width:n,height:r}=new ia(this._balloonPanelView.element);Object.assign(this,{top:t,left:e,width:n,height:r})}}}function Ff(t){const e=t.editing.view,n=Yd.defaultPositions;return{target:e.domConverter.viewToDom(e.document.selection.getSelectedElement()),positions:[n.northArrowSouth,n.northArrowSouthWest,n.northArrowSouthEast,n.southArrowNorth,n.southArrowNorthWest,n.southArrowNorthEast]}}class Df extends du{static get requires(){return[Lf]}static get pluginName(){return"ImageTextAlternativeUI"}init(){this._createButton(),this._createForm()}destroy(){super.destroy(),this._form.destroy()}_createButton(){const t=this.editor,e=t.t;t.ui.componentFactory.add("imageTextAlternative",n=>{const r=t.commands.get("imageTextAlternative"),i=new Kl(n);return i.set({label:e("Change image text alternative"),icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M5.085 6.22L2.943 4.078a.75.75 0 1 1 1.06-1.06l2.592 2.59A11.094 11.094 0 0 1 10 5.068c4.738 0 8.578 3.101 8.578 5.083 0 1.197-1.401 2.803-3.555 3.887l1.714 1.713a.75.75 0 0 1-.09 1.138.488.488 0 0 1-.15.084.75.75 0 0 1-.821-.16L6.17 7.304c-.258.11-.51.233-.757.365l6.239 6.24-.006.005.78.78c-.388.094-.78.166-1.174.215l-1.11-1.11h.011L4.55 8.197a7.2 7.2 0 0 0-.665.514l-.112.098 4.897 4.897-.005.006 1.276 1.276a10.164 10.164 0 0 1-1.477-.117l-.479-.479-.009.009-4.863-4.863-.022.031a2.563 2.563 0 0 0-.124.2c-.043.077-.08.158-.108.241a.534.534 0 0 0-.028.133.29.29 0 0 0 .008.072.927.927 0 0 0 .082.226c.067.133.145.26.234.379l3.242 3.365.025.01.59.623c-3.265-.918-5.59-3.155-5.59-4.668 0-1.194 1.448-2.838 3.663-3.93zm7.07.531a4.632 4.632 0 0 1 1.108 5.992l.345.344.046-.018a9.313 9.313 0 0 0 2-1.112c.256-.187.5-.392.727-.613.137-.134.27-.277.392-.431.072-.091.141-.185.203-.286.057-.093.107-.19.148-.292a.72.72 0 0 0 .036-.12.29.29 0 0 0 .008-.072.492.492 0 0 0-.028-.133.999.999 0 0 0-.036-.096 2.165 2.165 0 0 0-.071-.145 2.917 2.917 0 0 0-.125-.2 3.592 3.592 0 0 0-.263-.335 5.444 5.444 0 0 0-.53-.523 7.955 7.955 0 0 0-1.054-.768 9.766 9.766 0 0 0-1.879-.891c-.337-.118-.68-.219-1.027-.301zm-2.85.21l-.069.002a.508.508 0 0 0-.254.097.496.496 0 0 0-.104.679.498.498 0 0 0 .326.199l.045.005c.091.003.181.003.272.012a2.45 2.45 0 0 1 2.017 1.513c.024.061.043.125.069.185a.494.494 0 0 0 .45.287h.008a.496.496 0 0 0 .35-.158.482.482 0 0 0 .13-.335.638.638 0 0 0-.048-.219 3.379 3.379 0 0 0-.36-.723 3.438 3.438 0 0 0-2.791-1.543l-.028-.001h-.013z"/></svg>',tooltip:!0}),i.bind("isEnabled").to(r,"isEnabled"),this.listenTo(i,"execute",()=>{this._showForm()}),i})}_createForm(){const t=this.editor,e=t.editing.view.document;this._balloon=this.editor.plugins.get("ContextualBalloon"),this._form=new If(t.locale),this._form.render(),this.listenTo(this._form,"submit",()=>{t.execute("imageTextAlternative",{newValue:this._form.labeledInput.fieldView.element.value}),this._hideForm(!0)}),this.listenTo(this._form,"cancel",()=>{this._hideForm(!0)}),this._form.keystrokes.set("Esc",(t,e)=>{this._hideForm(!0),e()}),this.listenTo(t.ui,"update",()=>{ch(e.selection)?this._isVisible&&function(t){const e=t.plugins.get("ContextualBalloon");if(ch(t.editing.view.document.selection)){const n=Ff(t);e.updatePosition(n)}}(t):this._hideForm(!0)}),nu({emitter:this._form,activator:()=>this._isVisible,contextElements:[this._balloon.view.element],callback:()=>this._hideForm()})}_showForm(){if(this._isVisible)return;const t=this.editor,e=t.commands.get("imageTextAlternative"),n=this._form.labeledInput;this._form.disableCssTransitions(),this._isInBalloon||this._balloon.add({view:this._form,position:Ff(t)}),n.fieldView.value=n.fieldView.element.value=e.value||"",this._form.labeledInput.fieldView.select(),this._form.enableCssTransitions()}_hideForm(t){this._isInBalloon&&(this._form.focusTracker.isFocused&&this._form.saveButtonView.focus(),this._balloon.remove(this._form),t&&this.editor.editing.view.focus())}get _isVisible(){return this._balloon.visibleView===this._form}get _isInBalloon(){return this._balloon.hasView(this._form)}}class Rf extends du{static get requires(){return[jf,Df]}static get pluginName(){return"ImageTextAlternative"}}n(65);class Nf extends du{static get requires(){return[mh,Of,Rf]}static get pluginName(){return"Image"}}class $f extends zl{constructor(t){super(t),this.buttonView=new Kl(t),this._fileInputView=new Uf(t),this._fileInputView.bind("acceptedType").to(this),this._fileInputView.bind("allowMultipleFiles").to(this),this._fileInputView.delegate("done").to(this),this.setTemplate({tag:"span",attributes:{class:"ck-file-dialog-button"},children:[this.buttonView,this._fileInputView]}),this.buttonView.on("execute",()=>{this._fileInputView.open()})}focus(){this.buttonView.focus()}}class Uf extends zl{constructor(t){super(t),this.set("acceptedType"),this.set("allowMultipleFiles",!1);const e=this.bindTemplate;this.setTemplate({tag:"input",attributes:{class:["ck-hidden"],type:"file",tabindex:"-1",accept:e.to("acceptedType"),multiple:e.to("allowMultipleFiles")},on:{change:e.to(()=>{this.element&&this.element.files&&this.element.files.length&&this.fire("done",this.element.files),this.element.value=""})}})}open(){this.element.click()}}function qf(t){const e=t.map(t=>t.replace("+","\\+"));return new RegExp(`^image\\/(${e.join("|")})$`)}function Wf(t){return new Promise((e,n)=>{const r=t.getAttribute("src");fetch(r).then(t=>t.blob()).then(t=>{const n=Gf(t,r),i=n.replace("image/",""),o=new File([t],"image."+i,{type:n});e(o)}).catch(t=>t&&"TypeError"===t.name?function(t){return function(t){return new Promise((e,n)=>{const r=io.document.createElement("img");r.addEventListener("load",()=>{const t=io.document.createElement("canvas");t.width=r.width,t.height=r.height,t.getContext("2d").drawImage(r,0,0),t.toBlob(t=>t?e(t):n())}),r.addEventListener("error",()=>n()),r.src=t})}(t).then(e=>{const n=Gf(e,t),r=n.replace("image/","");return new File([e],"image."+r,{type:n})})}(r).then(e).catch(n):n(t))})}function Gf(t,e){return t.type?t.type:e.match(/data:(image\/\w+);base64/)?e.match(/data:(image\/\w+);base64/)[1].toLowerCase():"image/jpeg"}class Yf extends du{static get pluginName(){return"ImageUploadUI"}init(){const t=this.editor,e=t.t;t.ui.componentFactory.add("imageUpload",n=>{const r=new $f(n),i=t.commands.get("imageUpload"),o=t.config.get("image.upload.types"),a=qf(o);return r.set({acceptedType:o.map(t=>"image/"+t).join(","),allowMultipleFiles:!0}),r.buttonView.set({label:e("Insert image"),icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M6.91 10.54c.26-.23.64-.21.88.03l3.36 3.14 2.23-2.06a.64.64 0 0 1 .87 0l2.52 2.97V4.5H3.2v10.12l3.71-4.08zm10.27-7.51c.6 0 1.09.47 1.09 1.05v11.84c0 .59-.49 1.06-1.09 1.06H2.79c-.6 0-1.09-.47-1.09-1.06V4.08c0-.58.49-1.05 1.1-1.05h14.38zm-5.22 5.56a1.96 1.96 0 1 1 3.4-1.96 1.96 1.96 0 0 1-3.4 1.96z"/></svg>',tooltip:!0}),r.buttonView.bind("isEnabled").to(i),r.on("done",(e,n)=>{const r=Array.from(n).filter(t=>a.test(t.type));r.length&&t.execute("imageUpload",{file:r})}),r})}}n(67),n(69),n(71);class Kf extends du{constructor(t){super(t),this.placeholder="data:image/svg+xml;utf8,"+encodeURIComponent('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 700 250"><rect rx="4"/></svg>')}init(){this.editor.editing.downcastDispatcher.on("attribute:uploadStatus:image",(...t)=>this.uploadStatusChange(...t))}uploadStatusChange(t,e,n){const r=this.editor,i=e.item,o=i.getAttribute("uploadId");if(!n.consumable.consume(e.item,t.name))return;const a=r.plugins.get(wd),s=o?e.attributeNewValue:null,c=this.placeholder,l=r.editing.mapper.toViewElement(i),u=n.writer;if("reading"==s)return Qf(l,u),void Xf(c,l,u);if("uploading"==s){const t=a.loaders.get(o);return Qf(l,u),void(t?(Jf(l,u),function(t,e,n,r){const i=function(t){const e=t.createUIElement("div",{class:"ck-progress-bar"});return t.setCustomProperty("progressBar",!0,e),e}(e);e.insert(e.createPositionAt(t,"end"),i),n.on("change:uploadedPercent",(t,e,n)=>{r.change(t=>{t.setStyle("width",n+"%",i)})})}(l,u,t,r.editing.view),function(t,e,n){if(n.data){const r=hh(t);e.setAttribute("src",n.data,r)}}(l,u,t)):Xf(c,l,u))}"complete"==s&&a.loaders.get(o)&&function(t,e,n){const r=e.createUIElement("div",{class:"ck-image-upload-complete-icon"});e.insert(e.createPositionAt(t,"end"),r),setTimeout(()=>{n.change(t=>t.remove(t.createRangeOn(r)))},3e3)}(l,u,r.editing.view),function(t,e){tp(t,e,"progressBar")}(l,u),Jf(l,u),function(t,e){e.removeClass("ck-appear",t)}(l,u)}}function Qf(t,e){t.hasClass("ck-appear")||e.addClass("ck-appear",t)}function Xf(t,e,n){e.hasClass("ck-image-upload-placeholder")||n.addClass("ck-image-upload-placeholder",e);const r=hh(e);r.getAttribute("src")!==t&&n.setAttribute("src",t,r),Zf(e,"placeholder")||n.insert(n.createPositionAfter(r),function(t){const e=t.createUIElement("div",{class:"ck-upload-placeholder-loader"});return t.setCustomProperty("placeholder",!0,e),e}(n))}function Jf(t,e){t.hasClass("ck-image-upload-placeholder")&&e.removeClass("ck-image-upload-placeholder",t),tp(t,e,"placeholder")}function Zf(t,e){for(const n of t.getChildren())if(n.getCustomProperty(e))return n}function tp(t,e,n){const r=Zf(t,n);r&&e.remove(e.createRangeOn(r))}class ep{constructor(t){this.document=t}createDocumentFragment(t){return new Ci(this.document,t)}createElement(t,e,n){return new Ir(this.document,t,e,n)}createText(t){return new En(this.document,t)}clone(t,e=!1){return t._clone(e)}appendChild(t,e){return e._appendChild(t)}insertChild(t,e,n){return n._insertChild(t,e)}removeChildren(t,e,n){return n._removeChildren(t,e)}remove(t){const e=t.parent;return e?this.removeChildren(e.getChildIndex(t),1,e):[]}replace(t,e){const n=t.parent;if(n){const r=n.getChildIndex(t);return this.removeChildren(r,1,n),this.insertChild(r,e,n),!0}return!1}unwrapElement(t){const e=t.parent;if(e){const n=e.getChildIndex(t);this.remove(t),this.insertChild(n,t.getChildren(),e)}}rename(t,e){const n=new Ir(this.document,t,e.getAttributes(),e.getChildren());return this.replace(e,n)?n:null}setAttribute(t,e,n){n._setAttribute(t,e)}removeAttribute(t,e){e._removeAttribute(t)}addClass(t,e){e._addClass(t)}removeClass(t,e){e._removeClass(t)}setStyle(t,e,n){_(t)&&void 0===n&&(n=e),n._setStyle(t,e)}removeStyle(t,e){e._removeStyle(t)}setCustomProperty(t,e,n){n._setCustomProperty(t,e)}removeCustomProperty(t,e){return e._removeCustomProperty(t)}createPositionAt(t,e){return Zr._createAt(t,e)}createPositionAfter(t){return Zr._createAfter(t)}createPositionBefore(t){return Zr._createBefore(t)}createRange(t,e){return new ti(t,e)}createRangeOn(t){return ti._createOn(t)}createRangeIn(t){return ti._createIn(t)}createSelection(t,e,n){return new ri(t,e,n)}}class np extends vu{refresh(){const t=this.editor.model.document.selection.getSelectedElement(),e=t&&"image"===t.name||!1;this.isEnabled=dh(this.editor.model)||e}execute(t){const e=this.editor,n=e.model,r=e.plugins.get(wd);for(const i of jn(t.file))rp(n,r,i)}}function rp(t,e,n){const r=e.createLoader(n);r&&uh(t,{uploadId:r.id})}class ip extends du{static get requires(){return[wd,of,gu]}static get pluginName(){return"ImageUploadEditing"}constructor(t){super(t),t.config.define("image",{upload:{types:["jpeg","png","gif","bmp","webp","tiff"]}})}init(){const t=this.editor,e=t.model.document,n=t.model.schema,r=t.conversion,i=t.plugins.get(wd),o=qf(t.config.get("image.upload.types"));n.extend("image",{allowAttributes:["uploadId","uploadStatus"]}),t.commands.add("imageUpload",new np(t)),r.for("upcast").attributeToAttribute({view:{name:"img",key:"uploadId"},model:"uploadId"}),this.listenTo(t.editing.view.document,"clipboardInput",(e,n)=>{if(r=n.dataTransfer,Array.from(r.types).includes("text/html")&&""!==r.getData("text/html"))return;var r;const i=Array.from(n.dataTransfer.files).filter(t=>!!t&&o.test(t.type)),a=n.targetRanges.map(e=>t.editing.mapper.toModelRange(e));t.model.change(n=>{n.setSelection(a),i.length&&(e.stop(),t.model.enqueueChange("default",()=>{t.execute("imageUpload",{file:i})}))})}),this.listenTo(t.plugins.get(gu),"inputTransformation",(e,n)=>{const r=Array.from(t.editing.view.createRangeIn(n.content)).filter(t=>{return!(!(e=t.item).is("element","img")||!e.getAttribute("src"))&&(e.getAttribute("src").match(/^data:image\/\w+;base64,/g)||e.getAttribute("src").match(/^blob:/g))&&!t.item.getAttribute("uploadProcessed");var e}).map(t=>({promise:Wf(t.item),imageElement:t.item}));if(!r.length)return;const o=new ep(t.editing.view.document);for(const t of r){o.setAttribute("uploadProcessed",!0,t.imageElement);const e=i.createLoader(t.promise);e&&(o.setAttribute("src","",t.imageElement),o.setAttribute("uploadId",e.id,t.imageElement))}}),t.editing.view.document.on("dragover",(t,e)=>{e.preventDefault()}),e.on("change",()=>{const n=e.differ.getChanges({includeChangesInGraveyard:!0});for(const e of n)if("insert"==e.type&&"$text"!=e.name){const n=e.position.nodeAfter,r="$graveyard"==e.position.root.rootName;for(const e of op(t,n)){const t=e.getAttribute("uploadId");if(!t)continue;const n=i.loaders.get(t);n&&(r?n.abort():"idle"==n.status&&this._readAndUpload(n,e))}}})}_readAndUpload(t,e){const n=this.editor,r=n.model,i=n.locale.t,o=n.plugins.get(wd),a=n.plugins.get(of);return r.enqueueChange("transparent",t=>{t.setAttribute("uploadStatus","reading",e)}),t.read().then(()=>{const i=t.upload();if(hi.isSafari){const t=hh(n.editing.mapper.toViewElement(e));n.editing.view.once("render",()=>{if(!t.parent)return;const e=n.editing.view.domConverter.mapViewToDom(t.parent);if(!e)return;const r=e.style.display;e.style.display="none",e._ckHack=e.offsetHeight,e.style.display=r})}return r.enqueueChange("transparent",t=>{t.setAttribute("uploadStatus","uploading",e)}),i}).then(t=>{r.enqueueChange("transparent",n=>{n.setAttributes({uploadStatus:"complete",src:t.default},e),this._parseAndSetSrcsetAttributeOnImage(t,e,n)}),s()}).catch(n=>{if("error"!==t.status&&"aborted"!==t.status)throw n;"error"==t.status&&n&&a.showWarning(n,{title:i("Upload failed"),namespace:"upload"}),s(),r.enqueueChange("transparent",t=>{t.remove(e)})});function s(){r.enqueueChange("transparent",t=>{t.removeAttribute("uploadId",e),t.removeAttribute("uploadStatus",e)}),o.destroyLoader(t)}}_parseAndSetSrcsetAttributeOnImage(t,e,n){let r=0;const i=Object.keys(t).filter(t=>{const e=parseInt(t,10);if(!isNaN(e))return r=Math.max(r,e),!0}).map(e=>`${t[e]} ${e}w`).join(", ");""!=i&&n.setAttribute("srcset",{data:i,width:r},e)}}function op(t,e){return Array.from(t.model.createRangeOn(e)).filter(t=>t.item.is("element","image")).map(t=>t.item)}class ap extends du{static get pluginName(){return"ImageUpload"}static get requires(){return[ip,Yf,Kf]}}class sp extends vu{refresh(){const t=this.editor.model,e=zd(t.document.selection.getSelectedBlocks());this.value=!!e&&e.is("element","paragraph"),this.isEnabled=!!e&&cp(e,t.schema)}execute(t={}){const e=this.editor.model,n=e.document;e.change(r=>{const i=(t.selection||n.selection).getSelectedBlocks();for(const t of i)!t.is("element","paragraph")&&cp(t,e.schema)&&r.rename(t,"paragraph")})}}function cp(t,e){return e.checkChild(t.parent,"paragraph")&&!e.isObject(t)}class lp extends vu{execute(t){const e=this.editor.model;let n=t.position;e.change(t=>{const r=t.createElement("paragraph");if(!e.schema.checkChild(n.parent,r)){const i=e.schema.findAllowedParent(n,r);if(!i)return;n=t.split(n,i).position}e.insertContent(r,n),t.setSelection(r,"in")})}}class up extends du{static get pluginName(){return"Paragraph"}init(){const t=this.editor,e=t.model;t.commands.add("paragraph",new sp(t)),t.commands.add("insertParagraph",new lp(t)),e.schema.register("paragraph",{inheritAllFrom:"$block"}),t.conversion.elementToElement({model:"paragraph",view:"p"}),t.conversion.for("upcast").elementToElement({model:(t,{writer:e})=>up.paragraphLikeElements.has(t.name)?t.isEmpty?null:e.createElement("paragraph"):null,view:/.+/,converterPriority:"low"})}}up.paragraphLikeElements=new Set(["blockquote","dd","div","dt","h1","h2","h3","h4","h5","h6","li","p","td","th"]);class dp extends vu{constructor(t,e){super(t),this.modelElements=e}refresh(){const t=zd(this.editor.model.document.selection.getSelectedBlocks());this.value=!!t&&this.modelElements.includes(t.name)&&t.name,this.isEnabled=!!t&&this.modelElements.some(e=>hp(t,e,this.editor.model.schema))}execute(t){const e=this.editor.model,n=e.document,r=t.value;e.change(t=>{const i=Array.from(n.selection.getSelectedBlocks()).filter(t=>hp(t,r,e.schema));for(const e of i)e.is("element",r)||t.rename(e,r)})}}function hp(t,e,n){return n.checkChild(t.parent,e)&&!n.isObject(t)}class fp extends du{static get pluginName(){return"HeadingEditing"}constructor(t){super(t),t.config.define("heading",{options:[{model:"paragraph",title:"Paragraph",class:"ck-heading_paragraph"},{model:"heading1",view:"h2",title:"Heading 1",class:"ck-heading_heading1"},{model:"heading2",view:"h3",title:"Heading 2",class:"ck-heading_heading2"},{model:"heading3",view:"h4",title:"Heading 3",class:"ck-heading_heading3"}]})}static get requires(){return[up]}init(){const t=this.editor,e=t.config.get("heading.options"),n=[];for(const r of e)"paragraph"!==r.model&&(t.model.schema.register(r.model,{inheritAllFrom:"$block"}),t.conversion.elementToElement(r),n.push(r.model));this._addDefaultH1Conversion(t),t.commands.add("heading",new dp(t,n))}afterInit(){const t=this.editor,e=t.commands.get("enter"),n=t.config.get("heading.options");e&&this.listenTo(e,"afterExecute",(e,r)=>{const i=t.model.document.selection.getFirstPosition().parent;n.some(t=>i.is("element",t.model))&&!i.is("element","paragraph")&&0===i.childCount&&r.writer.rename(i,"paragraph")})}_addDefaultH1Conversion(t){t.conversion.for("upcast").elementToElement({model:"heading1",view:"h1",converterPriority:dn.get("low")+1})}}class pp{constructor(t,e){e&&Hr(this,e),t&&this.set(t)}}On(pp,$r),n(12);class mp extends du{init(){const t=this.editor,e=t.t,n=function(t){const e=t.t,n={Paragraph:e("Paragraph"),"Heading 1":e("Heading 1"),"Heading 2":e("Heading 2"),"Heading 3":e("Heading 3"),"Heading 4":e("Heading 4"),"Heading 5":e("Heading 5"),"Heading 6":e("Heading 6")};return t.config.get("heading.options").map(t=>{const e=n[t.title];return e&&e!=t.title&&(t.title=e),t})}(t),r=e("Choose heading"),i=e("Heading");t.ui.componentFactory.add("heading",e=>{const o={},a=new zn,s=t.commands.get("heading"),c=t.commands.get("paragraph"),l=[s];for(const t of n){const e={type:"button",model:new pp({label:t.title,class:t.class,withText:!0})};"paragraph"===t.model?(e.model.bind("isOn").to(c,"value"),e.model.set("commandName","paragraph"),l.push(c)):(e.model.bind("isOn").to(s,"value",e=>e===t.model),e.model.set({commandName:"heading",commandValue:t.model})),a.add(e),o[t.model]=t.title}const u=ru(e);return iu(u,a),u.buttonView.set({isOn:!1,withText:!0,tooltip:i}),u.extendTemplate({attributes:{class:["ck-heading-dropdown"]}}),u.bind("isEnabled").toMany(l,"isEnabled",(...t)=>t.some(t=>t)),u.buttonView.bind("label").to(s,"value",c,"value",(t,e)=>{const n=t||e&&"paragraph";return o[n]?o[n]:r}),this.listenTo(u,"execute",e=>{t.execute(e.source.commandName,e.source.commandValue?{value:e.source.commandValue}:void 0),t.editing.view.focus()}),u})}}function bp(t){for(const e of t.getChildren())if(e&&e.is("element","caption"))return e;return null}function gp(t){const e=t.parent;return"figcaption"==t.name&&e&&"figure"==e.name&&e.hasClass("image")?{name:!0}:null}class vp extends du{static get pluginName(){return"ImageCaptionEditing"}init(){const t=this.editor,e=t.editing.view,n=t.model.schema,r=t.data,i=t.editing,o=t.t;n.register("caption",{allowIn:"image",allowContentOf:"$block",isLimit:!0}),t.model.document.registerPostFixer(t=>this._insertMissingModelCaptionElement(t)),t.conversion.for("upcast").elementToElement({view:gp,model:"caption"}),r.downcastDispatcher.on("insert:caption",wp(t=>t.createContainerElement("figcaption"),!1));const a=function(t,e){return n=>{const r=n.createEditableElement("figcaption");return n.setCustomProperty("imageCaption",!0,r),Jc({view:t,element:r,text:e}),ih(r,n)}}(e,o("Enter image caption"));i.downcastDispatcher.on("insert:caption",wp(a)),i.downcastDispatcher.on("insert",this._fixCaptionVisibility(t=>t.item),{priority:"high"}),i.downcastDispatcher.on("remove",this._fixCaptionVisibility(t=>t.position.parent),{priority:"high"}),e.document.registerPostFixer(t=>this._updateCaptionVisibility(t))}_updateCaptionVisibility(t){const e=this.editor.editing.mapper,n=this._lastSelectedCaption;let r;const i=this.editor.model.document.selection,o=i.getSelectedElement();if(o&&o.is("element","image")){const t=bp(o);r=e.toViewElement(t)}const a=yp(i.getFirstPosition().parent);if(a&&(r=e.toViewElement(a)),r&&!this.editor.isReadOnly)return n?(n===r||(kp(n,t),this._lastSelectedCaption=r),_p(r,t)):(this._lastSelectedCaption=r,_p(r,t));if(n){const e=kp(n,t);return this._lastSelectedCaption=null,e}return!1}_fixCaptionVisibility(t){return(e,n,r)=>{const i=yp(t(n)),o=this.editor.editing.mapper,a=r.writer;if(i){const t=o.toViewElement(i);t&&(i.childCount?a.removeClass("ck-hidden",t):a.addClass("ck-hidden",t))}}}_insertMissingModelCaptionElement(t){const e=this.editor.model,n=e.document.differ.getChanges(),r=[];for(const i of n)if("insert"==i.type&&"$text"!=i.name){const t=i.position.nodeAfter;if(t.is("element","image")&&!bp(t)&&r.push(t),!t.is("element","image")&&t.childCount)for(const n of e.createRangeIn(t).getItems())n.is("element","image")&&!bp(n)&&r.push(n)}for(const i of r)t.appendElement("caption",i);return!!r.length}}function wp(t,e=!0){return(n,r,i)=>{const o=r.item;if((o.childCount||e)&&lh(o.parent)){if(!i.consumable.consume(r.item,"insert"))return;const e=i.mapper.toViewElement(r.range.start.parent),n=t(i.writer),a=i.writer;o.childCount||a.addClass("ck-hidden",n),function(t,e,n,r){const i=r.writer.createPositionAt(n,"end");r.writer.insert(i,t),r.mapper.bindElements(e,t)}(n,r.item,e,i)}}}function yp(t){const e=t.getAncestors({includeSelf:!0}).find(t=>"caption"==t.name);return e&&e.parent&&"image"==e.parent.name?e:null}function kp(t,e){return!t.childCount&&!t.hasClass("ck-hidden")&&(e.addClass("ck-hidden",t),!0)}function _p(t,e){return!!t.hasClass("ck-hidden")&&(e.removeClass("ck-hidden",t),!0)}n(74);class Op extends vu{constructor(t,e){super(t),this.defaultStyle=!1,this.styles=e.reduce((t,e)=>(t[e.name]=e,e.isDefault&&(this.defaultStyle=e.name),t),{})}refresh(){const t=this.editor.model.document.selection.getSelectedElement();if(this.isEnabled=lh(t),t)if(t.hasAttribute("imageStyle")){const e=t.getAttribute("imageStyle");this.value=!!this.styles[e]&&e}else this.value=this.defaultStyle;else this.value=!1}execute(t){const e=t.value,n=this.editor.model,r=n.document.selection.getSelectedElement();n.change(t=>{this.styles[e].isDefault?t.removeAttribute("imageStyle",r):t.setAttribute("imageStyle",e,r)})}}function zp(t,e){for(const n of e)if(n.name===t)return n}var Ap='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2 4.5V3h16v1.5zm2.5 3V12h11V7.5h-11zM4.061 6H15.94c.586 0 1.061.407 1.061.91v5.68c0 .503-.475.91-1.061.91H4.06c-.585 0-1.06-.407-1.06-.91V6.91C3 6.406 3.475 6 4.061 6zM2 16.5V15h16v1.5z"/></svg>',jp='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg" clip-rule="evenodd" stroke-linejoin="round" stroke-miterlimit="1.414"><path d="M18 4.5V3H2v1.5h16zm0 3V6h-5.674v1.5H18zm0 3V9h-5.674v1.5H18zm0 3V12h-5.674v1.5H18zm-8.5-6V12h-6V7.5h6zm.818-1.5H2.682C2.305 6 2 6.407 2 6.91v5.68c0 .503.305.91.682.91h7.636c.377 0 .682-.407.682-.91V6.91c0-.503-.305-.91-.682-.91zM18 16.5V15H2v1.5h16z"/></svg>',Mp='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2 4.5V3h16v1.5zm4.5 3V12h7V7.5h-7zM5.758 6h8.484c.419 0 .758.407.758.91v5.681c0 .502-.34.909-.758.909H5.758c-.419 0-.758-.407-.758-.91V6.91c0-.503.34-.91.758-.91zM2 16.5V15h16v1.5z"/></svg>',Cp='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2 4.5V3h16v1.5zm0 3V6h5.674v1.5zm0 3V9h5.674v1.5zm0 3V12h5.674v1.5zm8.5-6V12h6V7.5h-6zM9.682 6h7.636c.377 0 .682.407.682.91v5.68c0 .503-.305.91-.682.91H9.682c-.377 0-.682-.407-.682-.91V6.91c0-.503.305-.91.682-.91zM2 16.5V15h16v1.5z"/></svg>';const Vp={full:{name:"full",title:"Full size image",icon:Ap,isDefault:!0},side:{name:"side",title:"Side image",icon:Cp,className:"image-style-side"},alignLeft:{name:"alignLeft",title:"Left aligned image",icon:jp,className:"image-style-align-left"},alignCenter:{name:"alignCenter",title:"Centered image",icon:Mp,className:"image-style-align-center"},alignRight:{name:"alignRight",title:"Right aligned image",icon:Cp,className:"image-style-align-right"}},Sp={full:Ap,left:jp,right:Cp,center:Mp};function xp(t=[]){return t.map(Tp)}function Tp(t){if("string"==typeof t){const e=t;Vp[e]?t=Object.assign({},Vp[e]):(Object(hn.c)("image-style-not-found",{name:e}),t={name:e})}else if(Vp[t.name]){const e=Vp[t.name],n=Object.assign({},t);for(const r in e)Object.prototype.hasOwnProperty.call(t,r)||(n[r]=e[r]);t=n}return"string"==typeof t.icon&&Sp[t.icon]&&(t.icon=Sp[t.icon]),t}class Pp extends du{static get pluginName(){return"ImageStyleEditing"}init(){const t=this.editor,e=t.model.schema,n=t.data,r=t.editing;t.config.define("image.styles",["full","side"]);const i=xp(t.config.get("image.styles"));e.extend("image",{allowAttributes:"imageStyle"});const o=function(t){return(e,n,r)=>{if(!r.consumable.consume(n.item,e.name))return;const i=zp(n.attributeNewValue,t),o=zp(n.attributeOldValue,t),a=r.mapper.toViewElement(n.item),s=r.writer;o&&s.removeClass(o.className,a),i&&s.addClass(i.className,a)}}(i);r.downcastDispatcher.on("attribute:imageStyle:image",o),n.downcastDispatcher.on("attribute:imageStyle:image",o),n.upcastDispatcher.on("element:figure",function(t){const e=t.filter(t=>!t.isDefault);return(t,n,r)=>{if(!n.modelRange)return;const i=n.viewItem,o=zd(n.modelRange.getItems());if(!o||r.schema.checkAttribute(o,"imageStyle"))for(const a of e)r.consumable.consume(i,{classes:a.className})&&r.writer.setAttribute("imageStyle",a.name,o)}}(i),{priority:"low"}),t.commands.add("imageStyle",new Op(t,i))}}n(76);class Ip extends du{static get pluginName(){return"ImageStyleUI"}get localizedDefaultStylesTitles(){const t=this.editor.t;return{"Full size image":t("Full size image"),"Side image":t("Side image"),"Left aligned image":t("Left aligned image"),"Centered image":t("Centered image"),"Right aligned image":t("Right aligned image")}}init(){const t=function(t,e){for(const n of t)e[n.title]&&(n.title=e[n.title]);return t}(xp(this.editor.config.get("image.styles")),this.localizedDefaultStylesTitles);for(const e of t)this._createButton(e)}_createButton(t){const e=this.editor,n="imageStyle:"+t.name;e.ui.componentFactory.add(n,n=>{const r=e.commands.get("imageStyle"),i=new Kl(n);return i.set({label:t.title,icon:t.icon,tooltip:!0,isToggleable:!0}),i.bind("isEnabled").to(r,"isEnabled"),i.bind("isOn").to(r,"value",e=>e===t.name),this.listenTo(i,"execute",()=>{e.execute("imageStyle",{value:t.name}),e.editing.view.focus()}),i})}}class Ep extends du{static get requires(){return[Lf]}static get pluginName(){return"WidgetToolbarRepository"}init(){const t=this.editor;if(t.plugins.has("BalloonToolbar")){const e=t.plugins.get("BalloonToolbar");this.listenTo(e,"show",e=>{(function(t){const e=t.getSelectedElement();return!(!e||!th(e))})(t.editing.view.document.selection)&&e.stop()},{priority:"high"})}this._toolbarDefinitions=new Map,this._balloon=this.editor.plugins.get("ContextualBalloon"),this.on("change:isEnabled",()=>{this._updateToolbarsVisibility()}),this.listenTo(t.ui,"update",()=>{this._updateToolbarsVisibility()}),this.listenTo(t.ui.focusTracker,"change:isFocused",()=>{this._updateToolbarsVisibility()},{priority:"low"})}destroy(){super.destroy();for(const t of this._toolbarDefinitions.values())t.view.destroy()}register(t,{ariaLabel:e,items:n,getRelatedElement:r,balloonClassName:i="ck-toolbar-container"}){if(!n.length)return void Object(hn.c)("widget-toolbar-no-items",{toolbarId:t});const o=this.editor,a=o.t,s=new ou(o.locale);if(s.ariaLabel=e||a("Widget toolbar"),this._toolbarDefinitions.has(t))throw new hn.a("widget-toolbar-duplicated",this,{toolbarId:t});s.fillFromConfig(n,o.ui.componentFactory),this._toolbarDefinitions.set(t,{view:s,getRelatedElement:r,balloonClassName:i})}_updateToolbarsVisibility(){let t=0,e=null,n=null;for(const r of this._toolbarDefinitions.values()){const i=r.getRelatedElement(this.editor.editing.view.document.selection);if(this.isEnabled&&i)if(this.editor.ui.focusTracker.isFocused){const o=i.getAncestors().length;o>t&&(t=o,e=i,n=r)}else this._isToolbarVisible(r)&&this._hideToolbar(r);else this._isToolbarInBalloon(r)&&this._hideToolbar(r)}n&&this._showToolbar(n,e)}_hideToolbar(t){this._balloon.remove(t.view),this.stopListening(this._balloon,"change:visibleView")}_showToolbar(t,e){this._isToolbarVisible(t)?Lp(this.editor,e):this._isToolbarInBalloon(t)||(this._balloon.add({view:t.view,position:Bp(this.editor,e),balloonClassName:t.balloonClassName}),this.listenTo(this._balloon,"change:visibleView",()=>{for(const t of this._toolbarDefinitions.values())if(this._isToolbarVisible(t)){const e=t.getRelatedElement(this.editor.editing.view.document.selection);Lp(this.editor,e)}}))}_isToolbarVisible(t){return this._balloon.visibleView===t.view}_isToolbarInBalloon(t){return this._balloon.hasView(t.view)}}function Lp(t,e){const n=t.plugins.get("ContextualBalloon"),r=Bp(t,e);n.updatePosition(r)}function Bp(t,e){const n=t.editing.view,r=Yd.defaultPositions;return{target:n.domConverter.mapViewToDom(e),positions:[r.northArrowSouth,r.northArrowSouthWest,r.northArrowSouthEast,r.southArrowNorth,r.southArrowNorthWest,r.southArrowNorthEast,ah]}}class Hp extends vu{constructor(t){super(t),this._childCommands=[]}refresh(){}execute(...t){return this._getFirstEnabledCommand().execute(t)}registerChildCommand(t){this._childCommands.push(t),t.on("change:isEnabled",()=>this._checkEnabled()),this._checkEnabled()}_checkEnabled(){this.isEnabled=!!this._getFirstEnabledCommand()}_getFirstEnabledCommand(){return this._childCommands.find(t=>t.isEnabled)}}class Fp extends du{static get pluginName(){return"IndentEditing"}init(){const t=this.editor;t.commands.add("indent",new Hp(t)),t.commands.add("outdent",new Hp(t))}}var Dp='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2 3.75c0 .414.336.75.75.75h14.5a.75.75 0 1 0 0-1.5H2.75a.75.75 0 0 0-.75.75zm5 6c0 .414.336.75.75.75h9.5a.75.75 0 1 0 0-1.5h-9.5a.75.75 0 0 0-.75.75zM2.75 16.5h14.5a.75.75 0 1 0 0-1.5H2.75a.75.75 0 1 0 0 1.5zM1.632 6.95L5.02 9.358a.4.4 0 0 1-.013.661l-3.39 2.207A.4.4 0 0 1 1 11.892V7.275a.4.4 0 0 1 .632-.326z"/></svg>',Rp='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2 3.75c0 .414.336.75.75.75h14.5a.75.75 0 1 0 0-1.5H2.75a.75.75 0 0 0-.75.75zm5 6c0 .414.336.75.75.75h9.5a.75.75 0 1 0 0-1.5h-9.5a.75.75 0 0 0-.75.75zM2.75 16.5h14.5a.75.75 0 1 0 0-1.5H2.75a.75.75 0 1 0 0 1.5zm1.618-9.55L.98 9.358a.4.4 0 0 0 .013.661l3.39 2.207A.4.4 0 0 0 5 11.892V7.275a.4.4 0 0 0-.632-.326z"/></svg>';class Np extends du{static get pluginName(){return"IndentUI"}init(){const t=this.editor,e=t.locale,n=t.t,r="ltr"==e.uiLanguageDirection?Dp:Rp,i="ltr"==e.uiLanguageDirection?Rp:Dp;this._defineButton("indent",n("Increase indent"),r),this._defineButton("outdent",n("Decrease indent"),i)}_defineButton(t,e,n){const r=this.editor;r.ui.componentFactory.add(t,i=>{const o=r.commands.get(t),a=new Kl(i);return a.set({label:e,icon:n,tooltip:!0}),a.bind("isOn","isEnabled").to(o,"value","isEnabled"),this.listenTo(a,"execute",()=>{r.execute(t),r.editing.view.focus()}),a})}}class $p extends Ho{constructor(t){super(t),this.domEventType="click"}onDomEvent(t){this.fire(t.type,t)}}n(78);class Up extends zl{constructor(t,e){super(t);const n=t.t;this.focusTracker=new Yc,this.keystrokes=new Rc,this.urlInputView=this._createUrlInput(),this.saveButtonView=this._createButton(n("Save"),Tf,"ck-button-save"),this.saveButtonView.type="submit",this.cancelButtonView=this._createButton(n("Cancel"),Pf,"ck-button-cancel","cancel"),this._manualDecoratorSwitches=this._createManualDecoratorSwitches(e),this.children=this._createFormChildren(e.manualDecorators),this._focusables=new il,this._focusCycler=new El({focusables:this._focusables,focusTracker:this.focusTracker,keystrokeHandler:this.keystrokes,actions:{focusPrevious:"shift + tab",focusNext:"tab"}});const r=["ck","ck-link-form","ck-responsive-form"];e.manualDecorators.length&&r.push("ck-link-form_layout-vertical","ck-vertical-form"),this.setTemplate({tag:"form",attributes:{class:r,tabindex:"-1"},children:this.children}),Sf(this)}getDecoratorSwitchesState(){return Array.from(this._manualDecoratorSwitches).reduce((t,e)=>(t[e.name]=e.isOn,t),{})}render(){super.render(),xf({view:this}),[this.urlInputView,...this._manualDecoratorSwitches,this.saveButtonView,this.cancelButtonView].forEach(t=>{this._focusables.add(t),this.focusTracker.add(t.element)}),this.keystrokes.listenTo(this.element)}focus(){this._focusCycler.focusFirst()}_createUrlInput(){const t=this.locale.t,e=new Mf(this.locale,Vf);return e.label=t("Link URL"),e}_createButton(t,e,n,r){const i=new Kl(this.locale);return i.set({label:t,icon:e,tooltip:!0}),i.extendTemplate({attributes:{class:n}}),r&&i.delegate("execute").to(this,r),i}_createManualDecoratorSwitches(t){const e=this.createCollection();for(const n of t.manualDecorators){const r=new eu(this.locale);r.set({name:n.id,label:n.label,withText:!0}),r.bind("isOn").toMany([n,t],"value",(t,e)=>void 0===e&&void 0===t?n.defaultValue:t),r.on("execute",()=>{n.set("value",!r.isOn)}),e.add(r)}return e}_createFormChildren(t){const e=this.createCollection();if(e.add(this.urlInputView),t.length){const t=new zl;t.setTemplate({tag:"ul",children:this._manualDecoratorSwitches.map(t=>({tag:"li",children:[t],attributes:{class:["ck","ck-list__item"]}})),attributes:{class:["ck","ck-reset","ck-list"]}}),e.add(t)}return e.add(this.saveButtonView),e.add(this.cancelButtonView),e}}n(80);class qp extends zl{constructor(t){super(t);const e=t.t;this.focusTracker=new Yc,this.keystrokes=new Rc,this.previewButtonView=this._createPreviewButton(),this.unlinkButtonView=this._createButton(e("Unlink"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M11.077 15l.991-1.416a.75.75 0 1 1 1.229.86l-1.148 1.64a.748.748 0 0 1-.217.206 5.251 5.251 0 0 1-8.503-5.955.741.741 0 0 1 .12-.274l1.147-1.639a.75.75 0 1 1 1.228.86L4.933 10.7l.006.003a3.75 3.75 0 0 0 6.132 4.294l.006.004zm5.494-5.335a.748.748 0 0 1-.12.274l-1.147 1.639a.75.75 0 1 1-1.228-.86l.86-1.23a3.75 3.75 0 0 0-6.144-4.301l-.86 1.229a.75.75 0 0 1-1.229-.86l1.148-1.64a.748.748 0 0 1 .217-.206 5.251 5.251 0 0 1 8.503 5.955zm-4.563-2.532a.75.75 0 0 1 .184 1.045l-3.155 4.505a.75.75 0 1 1-1.229-.86l3.155-4.506a.75.75 0 0 1 1.045-.184zm4.919 10.562l-1.414 1.414a.75.75 0 1 1-1.06-1.06l1.414-1.415-1.415-1.414a.75.75 0 0 1 1.061-1.06l1.414 1.414 1.414-1.415a.75.75 0 0 1 1.061 1.061l-1.414 1.414 1.414 1.415a.75.75 0 0 1-1.06 1.06l-1.415-1.414z"/></svg>',"unlink"),this.editButtonView=this._createButton(e("Edit link"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M7.3 17.37l-.061.088a1.518 1.518 0 0 1-.934.535l-4.178.663-.806-4.153a1.495 1.495 0 0 1 .187-1.058l.056-.086L8.77 2.639c.958-1.351 2.803-1.076 4.296-.03 1.497 1.047 2.387 2.693 1.433 4.055L7.3 17.37zM9.14 4.728l-5.545 8.346 3.277 2.294 5.544-8.346L9.14 4.728zM6.07 16.512l-3.276-2.295.53 2.73 2.746-.435zM9.994 3.506L13.271 5.8c.316-.452-.16-1.333-1.065-1.966-.905-.634-1.895-.78-2.212-.328zM8 18.5L9.375 17H19v1.5H8z"/></svg>',"edit"),this.set("href"),this._focusables=new il,this._focusCycler=new El({focusables:this._focusables,focusTracker:this.focusTracker,keystrokeHandler:this.keystrokes,actions:{focusPrevious:"shift + tab",focusNext:"tab"}}),this.setTemplate({tag:"div",attributes:{class:["ck","ck-link-actions","ck-responsive-form"],tabindex:"-1"},children:[this.previewButtonView,this.editButtonView,this.unlinkButtonView]})}render(){super.render(),[this.previewButtonView,this.editButtonView,this.unlinkButtonView].forEach(t=>{this._focusables.add(t),this.focusTracker.add(t.element)}),this.keystrokes.listenTo(this.element)}focus(){this._focusCycler.focusFirst()}_createButton(t,e,n){const r=new Kl(this.locale);return r.set({label:t,icon:e,tooltip:!0}),r.delegate("execute").to(this,n),r}_createPreviewButton(){const t=new Kl(this.locale),e=this.bindTemplate,n=this.t;return t.set({withText:!0,tooltip:n("Open link in new tab")}),t.extendTemplate({attributes:{class:["ck","ck-link-actions__preview"],href:e.to("href",t=>t&&Yh(t)),target:"_blank",rel:"noopener noreferrer"}}),t.bind("label").to(this,"href",t=>t||n("This link has no URL")),t.bind("isEnabled").to(this,"href",t=>!!t),t.template.tag="a",t.template.eventListeners={},t}}class Wp extends du{static get requires(){return[Lf]}static get pluginName(){return"LinkUI"}init(){const t=this.editor;t.editing.view.addObserver($p),this.actionsView=this._createActionsView(),this.formView=this._createFormView(),this._balloon=t.plugins.get(Lf),this._createToolbarLinkButton(),this._enableUserBalloonInteractions(),t.conversion.for("editingDowncast").markerToHighlight({model:"link-ui",view:{classes:["ck-fake-link-selection"]}}),t.conversion.for("editingDowncast").markerToElement({model:"link-ui",view:{name:"span",classes:["ck-fake-link-selection","ck-fake-link-selection_collapsed"]}})}destroy(){super.destroy(),this.formView.destroy()}_createActionsView(){const t=this.editor,e=new qp(t.locale),n=t.commands.get("link"),r=t.commands.get("unlink");return e.bind("href").to(n,"value"),e.editButtonView.bind("isEnabled").to(n),e.unlinkButtonView.bind("isEnabled").to(r),this.listenTo(e,"edit",()=>{this._addFormView()}),this.listenTo(e,"unlink",()=>{t.execute("unlink"),this._hideUI()}),e.keystrokes.set("Esc",(t,e)=>{this._hideUI(),e()}),e.keystrokes.set("Ctrl+K",(t,e)=>{this._addFormView(),e()}),e}_createFormView(){const t=this.editor,e=t.commands.get("link"),n=t.config.get("link.defaultProtocol"),r=new Up(t.locale,e);return r.urlInputView.fieldView.bind("value").to(e,"value"),r.urlInputView.bind("isReadOnly").to(e,"isEnabled",t=>!t),r.saveButtonView.bind("isEnabled").to(e),this.listenTo(r,"submit",()=>{const{value:e}=r.urlInputView.fieldView.element,i=Qh(e,n);t.execute("link",i,r.getDecoratorSwitchesState()),this._closeFormView()}),this.listenTo(r,"cancel",()=>{this._closeFormView()}),r.keystrokes.set("Esc",(t,e)=>{this._closeFormView(),e()}),r}_createToolbarLinkButton(){const t=this.editor,e=t.commands.get("link"),n=t.t;t.keystrokes.set("Ctrl+K",(t,n)=>{n(),e.isEnabled&&this._showUI(!0)}),t.ui.componentFactory.add("link",t=>{const r=new Kl(t);return r.isEnabled=!0,r.label=n("Link"),r.icon='<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M11.077 15l.991-1.416a.75.75 0 1 1 1.229.86l-1.148 1.64a.748.748 0 0 1-.217.206 5.251 5.251 0 0 1-8.503-5.955.741.741 0 0 1 .12-.274l1.147-1.639a.75.75 0 1 1 1.228.86L4.933 10.7l.006.003a3.75 3.75 0 0 0 6.132 4.294l.006.004zm5.494-5.335a.748.748 0 0 1-.12.274l-1.147 1.639a.75.75 0 1 1-1.228-.86l.86-1.23a3.75 3.75 0 0 0-6.144-4.301l-.86 1.229a.75.75 0 0 1-1.229-.86l1.148-1.64a.748.748 0 0 1 .217-.206 5.251 5.251 0 0 1 8.503 5.955zm-4.563-2.532a.75.75 0 0 1 .184 1.045l-3.155 4.505a.75.75 0 1 1-1.229-.86l3.155-4.506a.75.75 0 0 1 1.045-.184z"/></svg>',r.keystroke="Ctrl+K",r.tooltip=!0,r.isToggleable=!0,r.bind("isEnabled").to(e,"isEnabled"),r.bind("isOn").to(e,"value",t=>!!t),this.listenTo(r,"execute",()=>this._showUI(!0)),r})}_enableUserBalloonInteractions(){const t=this.editor.editing.view.document;this.listenTo(t,"click",()=>{this._getSelectedLinkElement()&&this._showUI()}),this.editor.keystrokes.set("Tab",(t,e)=>{this._areActionsVisible&&!this.actionsView.focusTracker.isFocused&&(this.actionsView.focus(),e())},{priority:"high"}),this.editor.keystrokes.set("Esc",(t,e)=>{this._isUIVisible&&(this._hideUI(),e())}),nu({emitter:this.formView,activator:()=>this._isUIInPanel,contextElements:[this._balloon.view.element],callback:()=>this._hideUI()})}_addActionsView(){this._areActionsInPanel||this._balloon.add({view:this.actionsView,position:this._getBalloonPositionData()})}_addFormView(){if(this._isFormInPanel)return;const t=this.editor.commands.get("link");this.formView.disableCssTransitions(),this._balloon.add({view:this.formView,position:this._getBalloonPositionData()}),this._balloon.visibleView===this.formView&&this.formView.urlInputView.fieldView.select(),this.formView.enableCssTransitions(),this.formView.urlInputView.fieldView.element.value=t.value||""}_closeFormView(){const t=this.editor.commands.get("link");t.restoreManualDecoratorStates(),void 0!==t.value?this._removeFormView():this._hideUI()}_removeFormView(){this._isFormInPanel&&(this.formView.saveButtonView.focus(),this._balloon.remove(this.formView),this.editor.editing.view.focus(),this._hideFakeVisualSelection())}_showUI(t=!1){this._getSelectedLinkElement()?(this._areActionsVisible?this._addFormView():this._addActionsView(),t&&this._balloon.showStack("main")):(this._showFakeVisualSelection(),this._addActionsView(),t&&this._balloon.showStack("main"),this._addFormView()),this._startUpdatingUI()}_hideUI(){if(!this._isUIInPanel)return;const t=this.editor;this.stopListening(t.ui,"update"),this.stopListening(this._balloon,"change:visibleView"),t.editing.view.focus(),this._removeFormView(),this._balloon.remove(this.actionsView),this._hideFakeVisualSelection()}_startUpdatingUI(){const t=this.editor,e=t.editing.view.document;let n=this._getSelectedLinkElement(),r=o();const i=()=>{const t=this._getSelectedLinkElement(),e=o();n&&!t||!n&&e!==r?this._hideUI():this._isUIVisible&&this._balloon.updatePosition(this._getBalloonPositionData()),n=t,r=e};function o(){return e.selection.focus.getAncestors().reverse().find(t=>t.is("element"))}this.listenTo(t.ui,"update",i),this.listenTo(this._balloon,"change:visibleView",i)}get _isFormInPanel(){return this._balloon.hasView(this.formView)}get _areActionsInPanel(){return this._balloon.hasView(this.actionsView)}get _areActionsVisible(){return this._balloon.visibleView===this.actionsView}get _isUIInPanel(){return this._isFormInPanel||this._areActionsInPanel}get _isUIVisible(){return this._balloon.visibleView==this.formView||this._areActionsVisible}_getBalloonPositionData(){const t=this.editor.editing.view,e=this.editor.model,n=t.document;let r=null;if(e.markers.has("link-ui")){const e=Array.from(this.editor.editing.mapper.markerNameToElements("link-ui")),n=t.createRange(t.createPositionBefore(e[0]),t.createPositionAfter(e[e.length-1]));r=t.domConverter.viewRangeToDom(n)}else{const e=this._getSelectedLinkElement(),i=n.selection.getFirstRange();r=e?t.domConverter.mapViewToDom(e):t.domConverter.viewRangeToDom(i)}return{target:r}}_getSelectedLinkElement(){const t=this.editor.editing.view,e=t.document.selection;if(e.isCollapsed)return Gp(e.getFirstPosition());{const n=e.getFirstRange().getTrimmed(),r=Gp(n.start),i=Gp(n.end);return r&&r==i&&t.createRangeIn(r).getTrimmed().isEqual(n)?r:null}}_showFakeVisualSelection(){const t=this.editor.model;t.change(e=>{const n=t.document.selection.getFirstRange();if(t.markers.has("link-ui"))e.updateMarker("link-ui",{range:n});else if(n.start.isAtEnd){const r=n.start.getLastMatchingPosition(({item:e})=>!t.schema.isContent(e),{boundaries:n});e.addMarker("link-ui",{usingOperation:!1,affectsData:!1,range:e.createRange(r,n.end)})}else e.addMarker("link-ui",{usingOperation:!1,affectsData:!1,range:n})})}_hideFakeVisualSelection(){const t=this.editor.model;t.markers.has("link-ui")&&t.change(t=>{t.removeMarker("link-ui")})}}function Gp(t){return t.getAncestors().find(t=>{return(e=t).is("attributeElement")&&!!e.getCustomProperty("link");var e})}function Yp(t,e){let n=t.start;return{text:Array.from(t.getItems()).reduce((t,r)=>r.is("$text")||r.is("$textProxy")?t+r.data:(n=e.createPositionAfter(r),""),""),range:e.createRange(n,t.end)}}class Kp{constructor(t,e){this.model=t,this.testCallback=e,this.hasMatch=!1,this.set("isEnabled",!0),this.on("change:isEnabled",()=>{this.isEnabled?this._startListening():(this.stopListening(t.document.selection),this.stopListening(t.document))}),this._startListening()}_startListening(){const t=this.model.document;this.listenTo(t.selection,"change:range",(e,{directChange:n})=>{n&&(t.selection.isCollapsed?this._evaluateTextBeforeSelection("selection"):this.hasMatch&&(this.fire("unmatched"),this.hasMatch=!1))}),this.listenTo(t,"change:data",(t,e)=>{"transparent"!=e.type&&this._evaluateTextBeforeSelection("data",{batch:e})})}_evaluateTextBeforeSelection(t,e={}){const n=this.model,r=n.document.selection,i=n.createRange(n.createPositionAt(r.focus.parent,0),r.focus),{text:o,range:a}=Yp(i,n),s=this.testCallback(o);if(!s&&this.hasMatch&&this.fire("unmatched"),this.hasMatch=!!s,s){const n=Object.assign(e,{text:o,range:a});"object"==typeof s&&Object.assign(n,s),this.fire("matched:"+t,n)}}}On(Kp,$r);const Qp=new RegExp("(^|\\s)(((?:(?:(?:https?|ftp):)?\\/\\/)(?:\\S+(?::\\S*)?@)?(?:(?![-_])(?:[-\\w\\u00a1-\\uffff]{0,63}[^-_]\\.)+(?:[a-z\\u00a1-\\uffff]{2,}))(?::\\d{2,5})?(?:[/?#]\\S*)?)|((www.|(\\S+@))((?![-_])(?:[-\\w\\u00a1-\\uffff]{0,63}[^-_]\\.))+(?:[a-z\\u00a1-\\uffff]{2,})))$","i");class Xp extends du{static get pluginName(){return"AutoLink"}init(){const t=this.editor.model.document.selection;t.on("change:range",()=>{this.isEnabled=!t.anchor.parent.is("element","codeBlock")}),this._enableTypingHandling()}afterInit(){this._enableEnterHandling(),this._enableShiftEnterHandling()}_enableTypingHandling(){const t=this.editor,e=new Kp(t.model,t=>{if(!function(t){return t.length>4&&" "===t[t.length-1]&&" "!==t[t.length-2]}(t))return;const e=Jp(t.substr(0,t.length-1));return e?{url:e}:void 0}),n=t.plugins.get("Input");e.on("matched:data",(e,r)=>{const{batch:i,range:o,url:a}=r;if(!n.isInput(i))return;const s=o.end.getShiftedBy(-1),c=s.getShiftedBy(-a.length),l=t.model.createRange(c,s);this._applyAutoLink(a,l)}),e.bind("isEnabled").to(this)}_enableEnterHandling(){const t=this.editor,e=t.model,n=t.commands.get("enter");n&&n.on("execute",()=>{const t=e.document.selection.getFirstPosition();if(!t.parent.previousSibling)return;const n=e.createRangeIn(t.parent.previousSibling);this._checkAndApplyAutoLinkOnRange(n)})}_enableShiftEnterHandling(){const t=this.editor,e=t.model,n=t.commands.get("shiftEnter");n&&n.on("execute",()=>{const t=e.document.selection.getFirstPosition(),n=e.createRange(e.createPositionAt(t.parent,0),t.getShiftedBy(-1));this._checkAndApplyAutoLinkOnRange(n)})}_checkAndApplyAutoLinkOnRange(t){const e=this.editor.model,{text:n,range:r}=Yp(t,e),i=Jp(n);if(i){const t=e.createRange(r.end.getShiftedBy(-i.length),r.end);this._applyAutoLink(i,t)}}_applyAutoLink(t,e){const n=this.editor.model;this.isEnabled&&function(t,e){return e.schema.checkAttributeInSelection(e.createSelection(t),"linkHref")}(e,n)&&n.enqueueChange(n=>{const r=this.editor.config.get("link.defaultProtocol"),i=Qh(t,r);n.setAttribute("linkHref",i,e)})}}function Jp(t){const e=Qp.exec(t);return e?e[2]:null}class Zp extends vu{constructor(t,e){super(t),this.type=e}refresh(){this.value=this._getValue(),this.isEnabled=this._checkEnabled()}execute(){const t=this.editor.model,e=t.document,n=Array.from(e.selection.getSelectedBlocks()).filter(e=>em(e,t.schema)),r=!0===this.value;t.change(t=>{if(r){let e=n[n.length-1].nextSibling,r=Number.POSITIVE_INFINITY,i=[];for(;e&&"listItem"==e.name&&0!==e.getAttribute("listIndent");){const t=e.getAttribute("listIndent");t<r&&(r=t);const n=t-r;i.push({element:e,listIndent:n}),e=e.nextSibling}i=i.reverse();for(const n of i)t.setAttribute("listIndent",n.listIndent,n.element)}if(!r){let t=Number.POSITIVE_INFINITY;for(const e of n)e.is("element","listItem")&&e.getAttribute("listIndent")<t&&(t=e.getAttribute("listIndent"));t=0===t?1:t,tm(n,!0,t),tm(n,!1,t)}for(const e of n.reverse())r&&"listItem"==e.name?t.rename(e,"paragraph"):r||"listItem"==e.name?r||"listItem"!=e.name||e.getAttribute("listType")==this.type||t.setAttribute("listType",this.type,e):(t.setAttributes({listType:this.type,listIndent:0},e),t.rename(e,"listItem"));this.fire("_executeCleanup",n)})}_getValue(){const t=zd(this.editor.model.document.selection.getSelectedBlocks());return!!t&&t.is("element","listItem")&&t.getAttribute("listType")==this.type}_checkEnabled(){if(this.value)return!0;const t=this.editor.model.document.selection,e=this.editor.model.schema,n=zd(t.getSelectedBlocks());return!!n&&em(n,e)}}function tm(t,e,n){const r=e?t[0]:t[t.length-1];if(r.is("element","listItem")){let i=r[e?"previousSibling":"nextSibling"],o=r.getAttribute("listIndent");for(;i&&i.is("element","listItem")&&i.getAttribute("listIndent")>=n;)o>i.getAttribute("listIndent")&&(o=i.getAttribute("listIndent")),i.getAttribute("listIndent")==o&&t[e?"unshift":"push"](i),i=i[e?"previousSibling":"nextSibling"]}}function em(t,e){return e.checkChild(t.parent,"listItem")&&!e.isObject(t)}class nm extends vu{constructor(t,e){super(t),this._indentBy="forward"==e?1:-1}refresh(){this.isEnabled=this._checkEnabled()}execute(){const t=this.editor.model,e=t.document;let n=Array.from(e.selection.getSelectedBlocks());t.change(t=>{const e=n[n.length-1];let r=e.nextSibling;for(;r&&"listItem"==r.name&&r.getAttribute("listIndent")>e.getAttribute("listIndent");)n.push(r),r=r.nextSibling;this._indentBy<0&&(n=n.reverse());for(const i of n){const e=i.getAttribute("listIndent")+this._indentBy;e<0?t.rename(i,"paragraph"):t.setAttribute("listIndent",e,i)}this.fire("_executeCleanup",n)})}_checkEnabled(){const t=zd(this.editor.model.document.selection.getSelectedBlocks());if(!t||!t.is("element","listItem"))return!1;if(this._indentBy>0){const e=t.getAttribute("listIndent"),n=t.getAttribute("listType");let r=t.previousSibling;for(;r&&r.is("element","listItem")&&r.getAttribute("listIndent")>=e;){if(r.getAttribute("listIndent")==e)return r.getAttribute("listType")==n;r=r.previousSibling}return!1}return!0}}function rm(t,e){const n=e.mapper,r=e.writer,i="numbered"==t.getAttribute("listType")?"ol":"ul",o=function(t){const e=t.createContainerElement("li");return e.getFillerOffset=lm,e}(r),a=r.createContainerElement(i,null);return r.insert(r.createPositionAt(a,0),o),n.bindElements(t,o),o}function im(t,e,n,r){const i=e.parent,o=n.mapper,a=n.writer;let s=o.toViewPosition(r.createPositionBefore(t));const c=sm(t.previousSibling,{sameIndent:!0,smallerIndent:!0,listIndent:t.getAttribute("listIndent")}),l=t.previousSibling;if(c&&c.getAttribute("listIndent")==t.getAttribute("listIndent")){const t=o.toViewElement(c);s=a.breakContainer(a.createPositionAfter(t))}else if(l&&"listItem"==l.name){s=o.toViewPosition(r.createPositionAt(l,"end"));const t=o.findMappedViewAncestor(s),e=function(t){for(const e of t.getChildren())if("ul"==e.name||"ol"==e.name)return e;return null}(t);s=e?a.createPositionBefore(e):a.createPositionAt(t,"end")}else s=o.toViewPosition(r.createPositionBefore(t));if(s=am(s),a.insert(s,i),l&&"listItem"==l.name){const t=o.toViewElement(l),n=a.createRange(a.createPositionAt(t,0),s).getWalker({ignoreElementEnd:!0});for(const r of n)if(r.item.is("element","li")){const t=a.breakContainer(a.createPositionBefore(r.item)),i=r.item.parent,o=a.createPositionAt(e,"end");om(a,o.nodeBefore,o.nodeAfter),a.move(a.createRangeOn(i),o),n.position=t}}else{const n=i.nextSibling;if(n&&(n.is("element","ul")||n.is("element","ol"))){let r=null;for(const e of n.getChildren()){const n=o.toModelElement(e);if(!(n&&n.getAttribute("listIndent")>t.getAttribute("listIndent")))break;r=e}r&&(a.breakContainer(a.createPositionAfter(r)),a.move(a.createRangeOn(r.parent),a.createPositionAt(e,"end")))}}om(a,i,i.nextSibling),om(a,i.previousSibling,i)}function om(t,e,n){return!e||!n||"ul"!=e.name&&"ol"!=e.name||e.name!=n.name||e.getAttribute("class")!==n.getAttribute("class")?null:t.mergeContainers(t.createPositionAfter(e))}function am(t){return t.getLastMatchingPosition(t=>t.item.is("uiElement"))}function sm(t,e){const n=!!e.sameIndent,r=!!e.smallerIndent,i=e.listIndent;let o=t;for(;o&&"listItem"==o.name;){const t=o.getAttribute("listIndent");if(n&&i==t||r&&i>t)return o;o="forward"===e.direction?o.nextSibling:o.previousSibling}return null}function cm(t,e,n,r){t.ui.componentFactory.add(e,i=>{const o=t.commands.get(e),a=new Kl(i);return a.set({label:n,icon:r,tooltip:!0,isToggleable:!0}),a.bind("isOn","isEnabled").to(o,"value","isEnabled"),a.on("execute",()=>{t.execute(e),t.editing.view.focus()}),a})}function lm(){const t=!this.isEmpty&&("ul"==this.getChild(0).name||"ol"==this.getChild(0).name);return this.isEmpty||t?0:Br.call(this)}function um(t){return(e,n,r)=>{const i=r.consumable;if(!i.test(n.item,"insert")||!i.test(n.item,"attribute:listType")||!i.test(n.item,"attribute:listIndent"))return;i.consume(n.item,"insert"),i.consume(n.item,"attribute:listType"),i.consume(n.item,"attribute:listIndent");const o=n.item;im(o,rm(o,r),r,t)}}function dm(t,e,n){if(!n.consumable.consume(e.item,"attribute:listType"))return;const r=n.mapper.toViewElement(e.item),i=n.writer;i.breakContainer(i.createPositionBefore(r)),i.breakContainer(i.createPositionAfter(r));const o=r.parent,a="numbered"==e.attributeNewValue?"ol":"ul";i.rename(a,o)}function hm(t,e,n){const r=n.mapper.toViewElement(e.item).parent,i=n.writer;om(i,r,r.nextSibling),om(i,r.previousSibling,r);for(const o of e.item.getChildren())n.consumable.consume(o,"insert")}function fm(t,e,n){if("listItem"!=e.item.name){let t=n.mapper.toViewPosition(e.range.start);const r=n.writer,i=[];for(;("ul"==t.parent.name||"ol"==t.parent.name)&&(t=r.breakContainer(t),"li"==t.parent.name);){const e=t,n=r.createPositionAt(t.parent,"end");if(!e.isEqual(n)){const t=r.remove(r.createRange(e,n));i.push(t)}t=r.createPositionAfter(t.parent)}if(i.length>0){for(let e=0;e<i.length;e++){const n=t.nodeBefore;if(t=r.insert(t,i[e]).end,e>0){const e=om(r,n,n.nextSibling);e&&e.parent==n&&t.offset--}}om(r,t.nodeBefore,t.nodeAfter)}}}function pm(t,e,n){const r=n.mapper.toViewPosition(e.position),i=r.nodeBefore,o=r.nodeAfter;om(n.writer,i,o)}function mm(t,e,n){if(n.consumable.consume(e.viewItem,{name:!0})){const t=n.writer,r=t.createElement("listItem"),i=function(t){let e=0,n=t.parent;for(;n;){if(n.is("element","li"))e++;else{const t=n.previousSibling;t&&t.is("element","li")&&e++}n=n.parent}return e}(e.viewItem);t.setAttribute("listIndent",i,r);const o=e.viewItem.parent&&"ol"==e.viewItem.parent.name?"numbered":"bulleted";if(t.setAttribute("listType",o,r),!n.safeInsert(r,e.modelCursor))return;const a=function(t,e,n){const{writer:r,schema:i}=n;let o=r.createPositionAfter(t);for(const a of e)if("ul"==a.name||"ol"==a.name)o=n.convertItem(a,o).modelCursor;else{const e=n.convertItem(a,r.createPositionAt(t,"end")),s=e.modelRange.start.nodeAfter;s&&s.is("element")&&!i.checkChild(t,s.name)&&(t=e.modelCursor.parent.is("element","listItem")?e.modelCursor.parent:ym(e.modelCursor),o=r.createPositionAfter(t))}return o}(r,e.viewItem.getChildren(),n);e.modelRange=t.createRange(e.modelCursor,a),n.updateConversionResult(r,e)}}function bm(t,e,n){if(n.consumable.test(e.viewItem,{name:!0})){const t=Array.from(e.viewItem.getChildren());for(const e of t)!e.is("element","li")&&!_m(e)&&e._remove()}}function gm(t,e,n){if(n.consumable.test(e.viewItem,{name:!0})){if(0===e.viewItem.childCount)return;const t=[...e.viewItem.getChildren()];let n=!1,r=!0;for(const e of t)n&&!_m(e)&&e._remove(),e.is("$text")?(r&&(e._data=e.data.replace(/^\s+/,"")),e.nextSibling&&!_m(e.nextSibling)||(e._data=e.data.replace(/\s+$/,""))):_m(e)&&(n=!0),r=!1}}function vm(t){return(e,n)=>{if(n.isPhantom)return;const r=n.modelPosition.nodeBefore;if(r&&r.is("element","listItem")){const e=n.mapper.toViewElement(r),i=e.getAncestors().find(_m),o=t.createPositionAt(e,0).getWalker();for(const t of o){if("elementStart"==t.type&&t.item.is("element","li")){n.viewPosition=t.previousPosition;break}if("elementEnd"==t.type&&t.item==i){n.viewPosition=t.nextPosition;break}}}}}function wm(t,[e,n]){let r,i=e.is("documentFragment")?e.getChild(0):e;if(r=n?this.createSelection(n):this.document.selection,i&&i.is("element","listItem")){const t=r.getFirstPosition();let e=null;if(t.parent.is("element","listItem")?e=t.parent:t.nodeBefore&&t.nodeBefore.is("element","listItem")&&(e=t.nodeBefore),e){const t=e.getAttribute("listIndent");if(t>0)for(;i&&i.is("element","listItem");)i._setAttribute("listIndent",i.getAttribute("listIndent")+t),i=i.nextSibling}}}function ym(t){const e=new Oa({startPosition:t});let n;do{n=e.next()}while(!n.value.item.is("element","listItem"));return n.value.item}function km(t,e,n,r,i,o){const a=sm(e.nodeBefore,{sameIndent:!0,smallerIndent:!0,listIndent:t,foo:"b"}),s=i.mapper,c=i.writer,l=a?a.getAttribute("listIndent"):null;let u;if(a)if(l==t){const t=s.toViewElement(a).parent;u=c.createPositionAfter(t)}else{const t=o.createPositionAt(a,"end");u=s.toViewPosition(t)}else u=n;u=am(u);for(const d of[...r.getChildren()])_m(d)&&(u=c.move(c.createRangeOn(d),u).end,om(c,d,d.nextSibling),om(c,d.previousSibling,d))}function _m(t){return t.is("element","ol")||t.is("element","ul")}class Om extends du{static get pluginName(){return"ListEditing"}static get requires(){return[up]}init(){const t=this.editor;t.model.schema.register("listItem",{inheritAllFrom:"$block",allowAttributes:["listType","listIndent"]});const e=t.data,n=t.editing;var r;t.model.document.registerPostFixer(e=>function(t,e){const n=t.document.differ.getChanges(),r=new Map;let i=!1;for(const c of n)if("insert"==c.type&&"listItem"==c.name)o(c.position);else if("insert"==c.type&&"listItem"!=c.name){if("$text"!=c.name){const n=c.position.nodeAfter;n.hasAttribute("listIndent")&&(e.removeAttribute("listIndent",n),i=!0),n.hasAttribute("listType")&&(e.removeAttribute("listType",n),i=!0),n.hasAttribute("listStyle")&&(e.removeAttribute("listStyle",n),i=!0);for(const e of Array.from(t.createRangeIn(n)).filter(t=>t.item.is("element","listItem")))o(e.previousPosition)}o(c.position.getShiftedBy(c.length))}else"remove"==c.type&&"listItem"==c.name?o(c.position):("attribute"==c.type&&"listIndent"==c.attributeKey||"attribute"==c.type&&"listType"==c.attributeKey)&&o(c.range.start);for(const c of r.values())a(c),s(c);return i;function o(t){const e=t.nodeBefore;if(e&&e.is("element","listItem")){let t=e;if(r.has(t))return;for(let e=t.previousSibling;e&&e.is("element","listItem");e=t.previousSibling)if(t=e,r.has(t))return;r.set(e,t)}else{const e=t.nodeAfter;e&&e.is("element","listItem")&&r.set(e,e)}}function a(t){let n=0,r=null;for(;t&&t.is("element","listItem");){const o=t.getAttribute("listIndent");if(o>n){let a;null===r?(r=o-n,a=n):(r>o&&(r=o),a=o-r),e.setAttribute("listIndent",a,t),i=!0}else r=null,n=t.getAttribute("listIndent")+1;t=t.nextSibling}}function s(t){let n=[],r=null;for(;t&&t.is("element","listItem");){const o=t.getAttribute("listIndent");if(r&&r.getAttribute("listIndent")>o&&(n=n.slice(0,o+1)),0!=o)if(n[o]){const r=n[o];t.getAttribute("listType")!=r&&(e.setAttribute("listType",r,t),i=!0)}else n[o]=t.getAttribute("listType");r=t,t=t.nextSibling}}}(t.model,e)),n.mapper.registerViewToModelLength("li",zm),e.mapper.registerViewToModelLength("li",zm),n.mapper.on("modelToViewPosition",vm(n.view)),n.mapper.on("viewToModelPosition",(r=t.model,(t,e)=>{const n=e.viewPosition,i=n.parent,o=e.mapper;if("ul"==i.name||"ol"==i.name){if(n.isAtEnd){const t=o.toModelElement(n.nodeBefore),i=o.getModelLength(n.nodeBefore);e.modelPosition=r.createPositionBefore(t).getShiftedBy(i)}else{const t=o.toModelElement(n.nodeAfter);e.modelPosition=r.createPositionBefore(t)}t.stop()}else if("li"==i.name&&n.nodeBefore&&("ul"==n.nodeBefore.name||"ol"==n.nodeBefore.name)){const a=o.toModelElement(i);let s=1,c=n.nodeBefore;for(;c&&_m(c);)s+=o.getModelLength(c),c=c.previousSibling;e.modelPosition=r.createPositionBefore(a).getShiftedBy(s),t.stop()}})),e.mapper.on("modelToViewPosition",vm(n.view)),t.conversion.for("editingDowncast").add(e=>{e.on("insert",fm,{priority:"high"}),e.on("insert:listItem",um(t.model)),e.on("attribute:listType:listItem",dm,{priority:"high"}),e.on("attribute:listType:listItem",hm,{priority:"low"}),e.on("attribute:listIndent:listItem",function(t){return(e,n,r)=>{if(!r.consumable.consume(n.item,"attribute:listIndent"))return;const i=r.mapper.toViewElement(n.item),o=r.writer;o.breakContainer(o.createPositionBefore(i)),o.breakContainer(o.createPositionAfter(i));const a=i.parent,s=a.previousSibling,c=o.createRangeOn(a);o.remove(c),s&&s.nextSibling&&om(o,s,s.nextSibling),km(n.attributeOldValue+1,n.range.start,c.start,i,r,t),im(n.item,i,r,t);for(const t of n.item.getChildren())r.consumable.consume(t,"insert")}}(t.model)),e.on("remove:listItem",function(t){return(e,n,r)=>{const i=r.mapper.toViewPosition(n.position).getLastMatchingPosition(t=>!t.item.is("element","li")).nodeAfter,o=r.writer;o.breakContainer(o.createPositionBefore(i)),o.breakContainer(o.createPositionAfter(i));const a=i.parent,s=a.previousSibling,c=o.createRangeOn(a),l=o.remove(c);s&&s.nextSibling&&om(o,s,s.nextSibling),km(r.mapper.toModelElement(i).getAttribute("listIndent")+1,n.position,c.start,i,r,t);for(const t of o.createRangeIn(l).getItems())r.mapper.unbindViewElement(t);e.stop()}}(t.model)),e.on("remove",pm,{priority:"low"})}),t.conversion.for("dataDowncast").add(e=>{e.on("insert",fm,{priority:"high"}),e.on("insert:listItem",um(t.model))}),t.conversion.for("upcast").add(t=>{t.on("element:ul",bm,{priority:"high"}),t.on("element:ol",bm,{priority:"high"}),t.on("element:li",gm,{priority:"high"}),t.on("element:li",mm)}),t.model.on("insertContent",wm,{priority:"high"}),t.commands.add("numberedList",new Zp(t,"numbered")),t.commands.add("bulletedList",new Zp(t,"bulleted")),t.commands.add("indentList",new nm(t,"forward")),t.commands.add("outdentList",new nm(t,"backward"));const i=n.view.document;this.listenTo(i,"enter",(t,e)=>{const n=this.editor.model.document,r=n.selection.getLastPosition().parent;n.selection.isCollapsed&&"listItem"==r.name&&r.isEmpty&&(this.editor.execute("outdentList"),e.preventDefault(),t.stop())}),this.listenTo(i,"delete",(t,e)=>{if("backward"!==e.direction)return;const n=this.editor.model.document.selection;if(!n.isCollapsed)return;const r=n.getFirstPosition();if(!r.isAtStart)return;const i=r.parent;"listItem"===i.name&&(i.previousSibling&&"listItem"===i.previousSibling.name||(this.editor.execute("outdentList"),e.preventDefault(),t.stop()))},{priority:dn.high+10});const o=t=>(e,n)=>{this.editor.commands.get(t).isEnabled&&(this.editor.execute(t),n())};t.keystrokes.set("Tab",o("indentList")),t.keystrokes.set("Shift+Tab",o("outdentList"))}afterInit(){const t=this.editor.commands,e=t.get("indent"),n=t.get("outdent");e&&e.registerChildCommand(t.get("indentList")),n&&n.registerChildCommand(t.get("outdentList"))}}function zm(t){let e=1;for(const n of t.getChildren())if("ul"==n.name||"ol"==n.name)for(const t of n.getChildren())e+=zm(t);return e}class Am extends du{init(){const t=this.editor.t;cm(this.editor,"numberedList",t("Numbered List"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M7 5.75c0 .414.336.75.75.75h9.5a.75.75 0 1 0 0-1.5h-9.5a.75.75 0 0 0-.75.75zM3.5 3v5H2V3.7H1v-1h2.5V3zM.343 17.857l2.59-3.257H2.92a.6.6 0 1 0-1.04 0H.302a2 2 0 1 1 3.995 0h-.001c-.048.405-.16.734-.333.988-.175.254-.59.692-1.244 1.312H4.3v1h-4l.043-.043zM7 14.75a.75.75 0 0 1 .75-.75h9.5a.75.75 0 1 1 0 1.5h-9.5a.75.75 0 0 1-.75-.75z"/></svg>'),cm(this.editor,"bulletedList",t("Bulleted List"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M7 5.75c0 .414.336.75.75.75h9.5a.75.75 0 1 0 0-1.5h-9.5a.75.75 0 0 0-.75.75zm-6 0C1 4.784 1.777 4 2.75 4c.966 0 1.75.777 1.75 1.75 0 .966-.777 1.75-1.75 1.75C1.784 7.5 1 6.723 1 5.75zm6 9c0 .414.336.75.75.75h9.5a.75.75 0 1 0 0-1.5h-9.5a.75.75 0 0 0-.75.75zm-6 0c0-.966.777-1.75 1.75-1.75.966 0 1.75.777 1.75 1.75 0 .966-.777 1.75-1.75 1.75-.966 0-1.75-.777-1.75-1.75z"/></svg>')}}function jm(t,e){return t=>{t.on("attribute:url:media",n)};function n(n,r,i){if(!i.consumable.consume(r.item,n.name))return;const o=r.attributeNewValue,a=i.writer,s=i.mapper.toViewElement(r.item),c=[...s.getChildren()].find(t=>t.getCustomProperty("media-content"));a.remove(c);const l=t.getMediaViewElement(a,o,e);a.insert(a.createPositionAt(s,0),l)}}function Mm(t,e,n,r){const i=t.createContainerElement("figure",{class:"media"});return t.insert(t.createPositionAt(i,0),e.getMediaViewElement(t,n,r)),i}function Cm(t){const e=t.getSelectedElement();return e&&e.is("element","media")?e:null}function Vm(t,e,n){t.change(r=>{const i=r.createElement("media",{url:e});t.insertContent(i,n),r.setSelection(i,"on")})}class Sm extends vu{refresh(){const t=this.editor.model,e=t.document.selection,n=t.schema,r=oh(e,t),i=Cm(e);let o=r.parent;o.isEmpty&&!t.schema.isLimit(o)&&(o=o.parent),this.value=i?i.getAttribute("url"):null,this.isEnabled=n.checkChild(o,"media")}execute(t){const e=this.editor.model,n=e.document.selection,r=Cm(n);if(r)e.change(e=>{e.setAttribute("url",t,r)});else{const r=oh(n,e);Vm(e,t,r)}}}class xm{constructor(t,e){const n=e.providers,r=e.extraProviders||[],i=new Set(e.removeProviders),o=n.concat(r).filter(t=>{const e=t.name;return e?!i.has(e):(Object(hn.c)("media-embed-no-provider-name",{provider:t}),!1)});this.locale=t,this.providerDefinitions=o}hasMedia(t){return!!this._getMedia(t)}getMediaViewElement(t,e,n){return this._getMedia(e).getViewElement(t,n)}_getMedia(t){if(!t)return new Tm(this.locale);t=t.trim();for(const e of this.providerDefinitions){const n=e.html,r=jn(e.url);for(const e of r){const r=this._getUrlMatches(t,e);if(r)return new Tm(this.locale,t,r,n)}}return null}_getUrlMatches(t,e){let n=t.match(e);if(n)return n;let r=t.replace(/^https?:\/\//,"");return n=r.match(e),n||(r=r.replace(/^www\./,""),n=r.match(e),n||null)}}class Tm{constructor(t,e,n,r){this.url=this._getValidUrl(e),this._t=t.t,this._match=n,this._previewRenderer=r}getViewElement(t,e){const n={};let r;if(e.renderForEditingView||e.renderMediaPreview&&this.url&&this._previewRenderer){this.url&&(n["data-oembed-url"]=this.url),e.renderForEditingView&&(n.class="ck-media__wrapper");const i=this._getPreviewHtml(e);r=t.createRawElement("div",n,(function(t){t.innerHTML=i}))}else this.url&&(n.url=this.url),r=t.createEmptyElement("oembed",n);return t.setCustomProperty("media-content",!0,r),r}_getPreviewHtml(t){return this._previewRenderer?this._previewRenderer(this._match):this.url&&t.renderForEditingView?this._getPlaceholderHtml():""}_getPlaceholderHtml(){const t=new Yl,e=new Gl;return t.text=this._t("Open media in new tab"),e.content='<svg viewBox="0 0 64 42" xmlns="http://www.w3.org/2000/svg"><path d="M47.426 17V3.713L63.102 0v19.389h-.001l.001.272c0 1.595-2.032 3.43-4.538 4.098-2.506.668-4.538-.083-4.538-1.678 0-1.594 2.032-3.43 4.538-4.098.914-.244 2.032-.565 2.888-.603V4.516L49.076 7.447v9.556A1.014 1.014 0 0 0 49 17h-1.574zM29.5 17h-8.343a7.073 7.073 0 1 0-4.657 4.06v3.781H3.3a2.803 2.803 0 0 1-2.8-2.804V8.63a2.803 2.803 0 0 1 2.8-2.805h4.082L8.58 2.768A1.994 1.994 0 0 1 10.435 1.5h8.985c.773 0 1.477.448 1.805 1.149l1.488 3.177H26.7c1.546 0 2.8 1.256 2.8 2.805V17zm-11.637 0H17.5a1 1 0 0 0-1 1v.05A4.244 4.244 0 1 1 17.863 17zm29.684 2c.97 0 .953-.048.953.889v20.743c0 .953.016.905-.953.905H19.453c-.97 0-.953.048-.953-.905V19.89c0-.937-.016-.889.97-.889h28.077zm-4.701 19.338V22.183H24.154v16.155h18.692zM20.6 21.375v1.616h1.616v-1.616H20.6zm0 3.231v1.616h1.616v-1.616H20.6zm0 3.231v1.616h1.616v-1.616H20.6zm0 3.231v1.616h1.616v-1.616H20.6zm0 3.231v1.616h1.616v-1.616H20.6zm0 3.231v1.616h1.616V37.53H20.6zm24.233-16.155v1.616h1.615v-1.616h-1.615zm0 3.231v1.616h1.615v-1.616h-1.615zm0 3.231v1.616h1.615v-1.616h-1.615zm0 3.231v1.616h1.615v-1.616h-1.615zm0 3.231v1.616h1.615v-1.616h-1.615zm0 3.231v1.616h1.615V37.53h-1.615zM29.485 25.283a.4.4 0 0 1 .593-.35l9.05 4.977a.4.4 0 0 1 0 .701l-9.05 4.978a.4.4 0 0 1-.593-.35v-9.956z"/></svg>',e.viewBox="0 0 64 42",new ol({tag:"div",attributes:{class:"ck ck-reset_all ck-media__placeholder"},children:[{tag:"div",attributes:{class:"ck-media__placeholder__icon"},children:[e]},{tag:"a",attributes:{class:"ck-media__placeholder__url",target:"_blank",rel:"noopener noreferrer",href:this.url},children:[{tag:"span",attributes:{class:"ck-media__placeholder__url__text"},children:[this.url]},t]}]}).render().outerHTML}_getValidUrl(t){return t?t.match(/^https?/)?t:"https://"+t:null}}n(82);class Pm extends du{static get pluginName(){return"MediaEmbedEditing"}constructor(t){super(t),t.config.define("mediaEmbed",{providers:[{name:"dailymotion",url:/^dailymotion\.com\/video\/(\w+)/,html:t=>`<div style="position: relative; padding-bottom: 100%; height: 0; "><iframe src="https://www.dailymotion.com/embed/video/${t[1]}" style="position: absolute; width: 100%; height: 100%; top: 0; left: 0;" frameborder="0" width="480" height="270" allowfullscreen allow="autoplay"></iframe></div>`},{name:"spotify",url:[/^open\.spotify\.com\/(artist\/\w+)/,/^open\.spotify\.com\/(album\/\w+)/,/^open\.spotify\.com\/(track\/\w+)/],html:t=>`<div style="position: relative; padding-bottom: 100%; height: 0; padding-bottom: 126%;"><iframe src="https://open.spotify.com/embed/${t[1]}" style="position: absolute; width: 100%; height: 100%; top: 0; left: 0;" frameborder="0" allowtransparency="true" allow="encrypted-media"></iframe></div>`},{name:"youtube",url:[/^(?:m\.)?youtube\.com\/watch\?v=([\w-]+)/,/^(?:m\.)?youtube\.com\/v\/([\w-]+)/,/^youtube\.com\/embed\/([\w-]+)/,/^youtu\.be\/([\w-]+)/],html:t=>`<div style="position: relative; padding-bottom: 100%; height: 0; padding-bottom: 56.2493%;"><iframe src="https://www.youtube.com/embed/${t[1]}" style="position: absolute; width: 100%; height: 100%; top: 0; left: 0;" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe></div>`},{name:"vimeo",url:[/^vimeo\.com\/(\d+)/,/^vimeo\.com\/[^/]+\/[^/]+\/video\/(\d+)/,/^vimeo\.com\/album\/[^/]+\/video\/(\d+)/,/^vimeo\.com\/channels\/[^/]+\/(\d+)/,/^vimeo\.com\/groups\/[^/]+\/videos\/(\d+)/,/^vimeo\.com\/ondemand\/[^/]+\/(\d+)/,/^player\.vimeo\.com\/video\/(\d+)/],html:t=>`<div style="position: relative; padding-bottom: 100%; height: 0; padding-bottom: 56.2493%;"><iframe src="https://player.vimeo.com/video/${t[1]}" style="position: absolute; width: 100%; height: 100%; top: 0; left: 0;" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe></div>`},{name:"instagram",url:/^instagram\.com\/p\/(\w+)/},{name:"twitter",url:/^twitter\.com/},{name:"googleMaps",url:/^google\.com\/maps/},{name:"flickr",url:/^flickr\.com/},{name:"facebook",url:/^facebook\.com/}]}),this.registry=new xm(t.locale,t.config.get("mediaEmbed"))}init(){const t=this.editor,e=t.model.schema,n=t.t,r=t.conversion,i=t.config.get("mediaEmbed.previewsInData"),o=this.registry;t.commands.add("mediaEmbed",new Sm(t)),e.register("media",{isObject:!0,isBlock:!0,allowWhere:"$block",allowAttributes:["url"]}),r.for("dataDowncast").elementToElement({model:"media",view:(t,{writer:e})=>{const n=t.getAttribute("url");return Mm(e,o,n,{renderMediaPreview:n&&i})}}),r.for("dataDowncast").add(jm(o,{renderMediaPreview:i})),r.for("editingDowncast").elementToElement({model:"media",view:(t,{writer:e})=>{const r=t.getAttribute("url");return function(t,e,n){return e.setCustomProperty("media",!0,t),eh(t,e,{label:n})}(Mm(e,o,r,{renderForEditingView:!0}),e,n("media widget"))}}),r.for("editingDowncast").add(jm(o,{renderForEditingView:!0})),r.for("upcast").elementToElement({view:{name:"oembed",attributes:{url:!0}},model:(t,{writer:e})=>{const n=t.getAttribute("url");if(o.hasMedia(n))return e.createElement("media",{url:n})}}).elementToElement({view:{name:"div",attributes:{"data-oembed-url":!0}},model:(t,{writer:e})=>{const n=t.getAttribute("data-oembed-url");if(o.hasMedia(n))return e.createElement("media",{url:n})}})}}const Im=/^(?:http(s)?:\/\/)?[\w.-]+(?:\.[\w.-]+)+[\w\-._~:/?#[\]@!$&'()*+,;=%]+$/;class Em extends du{static get requires(){return[gu,md]}static get pluginName(){return"AutoMediaEmbed"}constructor(t){super(t),this._timeoutId=null,this._positionToInsert=null}init(){const t=this.editor,e=t.model.document;this.listenTo(t.plugins.get(gu),"inputTransformation",()=>{const t=e.selection.getFirstRange(),n=Oc.fromPosition(t.start);n.stickiness="toPrevious";const r=Oc.fromPosition(t.end);r.stickiness="toNext",e.once("change:data",()=>{this._embedMediaBetweenPositions(n,r),n.detach(),r.detach()},{priority:"high"})}),t.commands.get("undo").on("execute",()=>{this._timeoutId&&(io.window.clearTimeout(this._timeoutId),this._positionToInsert.detach(),this._timeoutId=null,this._positionToInsert=null)},{priority:"high"})}_embedMediaBetweenPositions(t,e){const n=this.editor,r=n.plugins.get(Pm).registry,i=new Na(t,e),o=i.getWalker({ignoreElementEnd:!0});let a="";for(const s of o)s.item.is("$textProxy")&&(a+=s.item.data);a=a.trim(),a.match(Im)&&r.hasMedia(a)&&n.commands.get("mediaEmbed").isEnabled?(this._positionToInsert=Oc.fromPosition(t),this._timeoutId=io.window.setTimeout(()=>{n.model.change(t=>{let e;this._timeoutId=null,t.remove(i),i.detach(),"$graveyard"!==this._positionToInsert.root.rootName&&(e=this._positionToInsert),Vm(n.model,a,e),this._positionToInsert.detach(),this._positionToInsert=null})},100)):i.detach()}}n(84);class Lm extends zl{constructor(t,e){super(e);const n=e.t;this.focusTracker=new Yc,this.keystrokes=new Rc,this.set("mediaURLInputValue",""),this.urlInputView=this._createUrlInput(),this.saveButtonView=this._createButton(n("Save"),Tf,"ck-button-save"),this.saveButtonView.type="submit",this.saveButtonView.bind("isEnabled").to(this,"mediaURLInputValue",t=>!!t),this.cancelButtonView=this._createButton(n("Cancel"),Pf,"ck-button-cancel","cancel"),this._focusables=new il,this._focusCycler=new El({focusables:this._focusables,focusTracker:this.focusTracker,keystrokeHandler:this.keystrokes,actions:{focusPrevious:"shift + tab",focusNext:"tab"}}),this._validators=t,this.setTemplate({tag:"form",attributes:{class:["ck","ck-media-form","ck-responsive-form"],tabindex:"-1"},children:[this.urlInputView,this.saveButtonView,this.cancelButtonView]}),Sf(this)}render(){super.render(),xf({view:this}),[this.urlInputView,this.saveButtonView,this.cancelButtonView].forEach(t=>{this._focusables.add(t),this.focusTracker.add(t.element)}),this.keystrokes.listenTo(this.element);const t=t=>t.stopPropagation();this.keystrokes.set("arrowright",t),this.keystrokes.set("arrowleft",t),this.keystrokes.set("arrowup",t),this.keystrokes.set("arrowdown",t),this.listenTo(this.urlInputView.element,"selectstart",(t,e)=>{e.stopPropagation()},{priority:"high"})}focus(){this._focusCycler.focusFirst()}get url(){return this.urlInputView.fieldView.element.value.trim()}set url(t){this.urlInputView.fieldView.element.value=t.trim()}isValid(){this.resetFormStatus();for(const t of this._validators){const e=t(this);if(e)return this.urlInputView.errorText=e,!1}return!0}resetFormStatus(){this.urlInputView.errorText=null,this.urlInputView.infoText=this._urlInputViewInfoDefault}_createUrlInput(){const t=this.locale.t,e=new Mf(this.locale,Vf),n=e.fieldView;return this._urlInputViewInfoDefault=t("Paste the media URL in the input."),this._urlInputViewInfoTip=t("Tip: Paste the URL into the content to embed faster."),e.label=t("Media URL"),e.infoText=this._urlInputViewInfoDefault,n.on("input",()=>{e.infoText=n.element.value?this._urlInputViewInfoTip:this._urlInputViewInfoDefault,this.mediaURLInputValue=n.element.value.trim()}),e}_createButton(t,e,n,r){const i=new Kl(this.locale);return i.set({label:t,icon:e,tooltip:!0}),i.extendTemplate({attributes:{class:n}}),r&&i.delegate("execute").to(this,r),i}}class Bm extends du{static get requires(){return[Pm]}static get pluginName(){return"MediaEmbedUI"}init(){const t=this.editor,e=t.commands.get("mediaEmbed"),n=t.plugins.get(Pm).registry;t.ui.componentFactory.add("mediaEmbed",r=>{const i=ru(r),o=new Lm(function(t,e){return[e=>{if(!e.url.length)return t("The URL must not be empty.")},n=>{if(!e.hasMedia(n.url))return t("This media URL is not supported.")}]}(t.t,n),t.locale);return this._setUpDropdown(i,o,e,t),this._setUpForm(i,o,e),i})}_setUpDropdown(t,e,n){const r=this.editor,i=r.t,o=t.buttonView;function a(){r.editing.view.focus(),t.isOpen=!1}t.bind("isEnabled").to(n),t.panelView.children.add(e),o.set({label:i("Insert media"),icon:'<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M18.68 3.03c.6 0 .59-.03.59.55v12.84c0 .59.01.56-.59.56H1.29c-.6 0-.59.03-.59-.56V3.58c0-.58-.01-.55.6-.55h17.38zM15.77 15V5H4.2v10h11.57zM2 4v1h1V4H2zm0 2v1h1V6H2zm0 2v1h1V8H2zm0 2v1h1v-1H2zm0 2v1h1v-1H2zm0 2v1h1v-1H2zM17 4v1h1V4h-1zm0 2v1h1V6h-1zm0 2v1h1V8h-1zm0 2v1h1v-1h-1zm0 2v1h1v-1h-1zm0 2v1h1v-1h-1zM7.5 7.177a.4.4 0 0 1 .593-.351l5.133 2.824a.4.4 0 0 1 0 .7l-5.133 2.824a.4.4 0 0 1-.593-.35V7.176v.001z"/></svg>',tooltip:!0}),o.on("open",()=>{e.disableCssTransitions(),e.url=n.value||"",e.urlInputView.fieldView.select(),e.focus(),e.enableCssTransitions()},{priority:"low"}),t.on("submit",()=>{e.isValid()&&(r.execute("mediaEmbed",e.url),a())}),t.on("change:isOpen",()=>e.resetFormStatus()),t.on("cancel",()=>a())}_setUpForm(t,e,n){e.delegate("submit","cancel").to(t),e.urlInputView.bind("value").to(n,"value"),e.urlInputView.bind("isReadOnly").to(n,"isEnabled",t=>!t)}}function Hm(t,e){if(!t.childCount)return;const n=new ep(t.document),r=function(t,e){const n=e.createRangeIn(t),r=new Hn({name:/^p|h\d+$/,styles:{"mso-list":/.*/}}),i=[];for(const o of n)if("elementStart"===o.type&&r.match(o.item)){const t=Rm(o.item);i.push({element:o.item,id:t.id,order:t.order,indent:t.indent})}return i}(t,n);if(!r.length)return;let i=null,o=1;r.forEach((t,a)=>{const s=function(t,e){if(!t)return!0;if(t.id!==e.id)return e.indent-t.indent!=1;const n=e.element.previousSibling;return!n||(r=n,!(r.is("element","ol")||r.is("element","ul")));var r}(r[a-1],t),c=s?null:r[a-1],l=(d=t,(u=c)?d.indent-u.indent:d.indent-1);var u,d;if(s&&(i=null,o=1),!i||0!==l){const r=function(t,e){const n=new RegExp(`@list l${t.id}:level${t.indent}\\s*({[^}]*)`,"gi"),r=/mso-level-number-format:([^;]*);/gi,i=n.exec(e);let o="decimal",a="ol";if(i&&i[1]){const e=r.exec(i[1]);if(e&&e[1]&&(o=e[1].trim(),a="bullet"!==o&&"image"!==o?"ol":"ul"),"bullet"===o){const e=function(t){const e=function(t){if(t.getChild(0).is("$text"))return null;const e=t.getChild(0).getChild(0);return e.is("$text")?e:e.getChild(0)}(t);if(!e)return null;const n=e._data;return"o"===n?"circle":"·"===n?"disc":"§"===n?"square":null}(t.element);e&&(o=e)}}return{type:a,style:Fm(o)}}(t,e);if(i){if(t.indent>o){const t=i.getChild(i.childCount-1),e=t.getChild(t.childCount-1);i=Dm(r,e,n),o+=1}else if(t.indent<o){const e=o-t.indent;i=function(t,e){const n=t.getAncestors({parentFirst:!0});let r=null,i=0;for(const o of n)if("ul"!==o.name&&"ol"!==o.name||i++,i===e){r=o;break}return r}(i,e),o=parseInt(t.indent)}}else i=Dm(r,t.element,n);t.indent<=o&&(i.is("element",r.type)||(i=n.rename(r.type,i)))}const h=function(t,e){return function(t,e){const n=new Hn({name:"span",styles:{"mso-list":"Ignore"}}),r=e.createRangeIn(t);for(const i of r)"elementStart"===i.type&&n.match(i.item)&&e.remove(i.item)}(t,e),e.rename("li",t)}(t.element,n);n.appendChild(h,i)})}function Fm(t){switch(t){case"arabic-leading-zero":return"decimal-leading-zero";case"alpha-upper":return"upper-alpha";case"alpha-lower":return"lower-alpha";case"roman-upper":return"upper-roman";case"roman-lower":return"lower-roman";case"circle":case"disc":case"square":return t;default:return null}}function Dm(t,e,n){const r=e.parent,i=n.createElement(t.type),o=r.getChildIndex(e)+1;return n.insertChild(o,i,r),t.style&&n.setStyle("list-style-type",t.style,i),i}function Rm(t){const e={},n=t.getStyle("mso-list");if(n){const t=n.match(/(^|\s+)l(\d+)/i),r=n.match(/\s*lfo(\d+)/i),i=n.match(/\s*level(\d+)/i);t&&r&&i&&(e.id=t[2],e.order=r[1],e.indent=i[1])}return e}n(86);const Nm=/id=("|')docs-internal-guid-[-0-9a-f]+("|')/i;class $m{constructor(t){this.document=t}isActive(t){return Nm.test(t)}execute(t){const e=new ep(this.document);!function(t,e){for(const n of t.getChildren())if(n.is("element","b")&&"normal"===n.getStyle("font-weight")){const r=t.getChildIndex(n);e.remove(n),e.insertChild(r,n.getChildren(),t)}}(t.content,e),function(t,e){for(const n of e.createRangeIn(t)){const t=n.item;if(t.is("element","li")){const n=t.getChild(0);n&&n.is("element","p")&&e.unwrapElement(n)}}}(t.content,e)}}function Um(t){return t.replace(/<span(?: class="Apple-converted-space"|)>(\s+)<\/span>/g,(t,e)=>1===e.length?" ":Array(e.length+1).join("  ").substr(0,e.length))}function qm(t,e){const n=new DOMParser,r=function(t){return Um(Um(t)).replace(/(<span\s+style=['"]mso-spacerun:yes['"]>[\s]*?)[\r\n]+(\s*<\/span>)/g,"$1$2").replace(/<span\s+style=['"]mso-spacerun:yes['"]><\/span>/g,"").replace(/ <\//g," </").replace(/ <o:p><\/o:p>/g," <o:p></o:p>").replace(/<o:p>(&nbsp;|\u00A0)<\/o:p>/g,"").replace(/>(\s*[\r\n]\s*)</g,"><")}(function(t){const e=t.match(/<\/body>(.*?)(<\/html>|$)/);return e&&e[1]&&(t=t.slice(0,e.index)+t.slice(e.index).replace(e[1],"")),t}(t=t.replace(/<!--\[if gte vml 1]>/g,""))),i=n.parseFromString(r,"text/html");!function(t){t.querySelectorAll("span[style*=spacerun]").forEach(t=>{const e=t.innerText.length||0;t.innerHTML=Array(e+1).join("  ").substr(0,e)})}(i);const o=i.body.innerHTML,a=function(t,e){const n=new oi(e),r=new co(n,{blockFillerMode:"nbsp"}),i=t.createDocumentFragment(),o=t.body.childNodes;for(;o.length>0;)i.appendChild(o[0]);return r.domToView(i)}(i,e),s=function(t){const e=[],n=[],r=Array.from(t.getElementsByTagName("style"));for(const i of r)i.sheet&&i.sheet.cssRules&&i.sheet.cssRules.length&&(e.push(i.sheet),n.push(i.innerHTML));return{styles:e,stylesString:n.join(" ")}}(i);return{body:a,bodyString:o,styles:s.styles,stylesString:s.stylesString}}function Wm(t,e){if(!t.childCount)return;const n=new ep;!function(t,e,n){const r=n.createRangeIn(e),i=new Hn({name:"img"}),o=[];for(const a of r)if(i.match(a.item)){const e=a.item,n=e.getAttribute("v:shapes")?e.getAttribute("v:shapes").split(" "):[];n.length&&n.every(e=>t.indexOf(e)>-1)?o.push(e):e.getAttribute("src")||o.push(e)}for(const a of o)n.remove(a)}(function(t,e){const n=e.createRangeIn(t),r=new Hn({name:/v:(.+)/}),i=[];for(const o of n){const t=o.item,e=t.previousSibling&&t.previousSibling.name||null;r.match(t)&&t.getAttribute("o:gfxdata")&&"v:shapetype"!==e&&i.push(o.item.getAttribute("id"))}return i}(t,n),t,n),function(t,e){const n=e.createRangeIn(t),r=new Hn({name:/v:(.+)/}),i=[];for(const o of n)r.match(o.item)&&i.push(o.item);for(const o of i)e.remove(o)}(t,n);const r=function(t,e){const n=e.createRangeIn(t),r=new Hn({name:"img"}),i=[];for(const o of n)r.match(o.item)&&o.item.getAttribute("src").startsWith("file://")&&i.push(o.item);return i}(t,n);r.length&&function(t,e,n){if(t.length===e.length)for(let i=0;i<t.length;i++){const o=`data:${e[i].type};base64,${r=e[i].hex,btoa(r.match(/\w{2}/g).map(t=>String.fromCharCode(parseInt(t,16))).join(""))}`;n.setAttribute("src",o,t[i])}var r}(r,function(t){if(!t)return[];const e=/{\\pict[\s\S]+?\\bliptag-?\d+(\\blipupi-?\d+)?({\\\*\\blipuid\s?[\da-fA-F]+)?[\s}]*?/,n=new RegExp("(?:("+e.source+"))([\\da-fA-F\\s]+)\\}","g"),r=t.match(n),i=[];if(r)for(const o of r){let t=!1;o.includes("\\pngblip")?t="image/png":o.includes("\\jpegblip")&&(t="image/jpeg"),t&&i.push({hex:o.replace(e,"").replace(/[^\da-fA-F]/g,""),type:t})}return i}(e),n)}const Gm=/<meta\s*name="?generator"?\s*content="?microsoft\s*word\s*\d+"?\/?>/i,Ym=/xmlns:o="urn:schemas-microsoft-com/i;class Km{constructor(t){this.document=t}isActive(t){return Gm.test(t)||Ym.test(t)}execute(t){const{body:e,stylesString:n}=qm(t.dataTransfer.getData("text/html"),this.document.stylesProcessor);Hm(e,n),Wm(e,t.dataTransfer.getData("text/rtf")),t.content=e}}function Qm(t,e,n,r,i=1){e>i?r.setAttribute(t,e,n):r.removeAttribute(t,n)}function Xm(t,e,n={}){const r=t.createElement("tableCell",n);return t.insertElement("paragraph",r),t.insert(r,e),r}function Jm(t,e){const n=e.parent.parent,r=parseInt(n.getAttribute("headingColumns")||0),{column:i}=t.getCellLocation(e);return!!r&&i<r}function Zm(){return t=>{t.on("element:table",(t,e,n)=>{const r=e.viewItem;if(!n.consumable.test(r,{name:!0}))return;const{rows:i,headingRows:o,headingColumns:a}=function(t){const e={headingRows:0,headingColumns:0},n=[],r=[];let i;for(const o of Array.from(t.getChildren()))if("tbody"===o.name||"thead"===o.name||"tfoot"===o.name){"thead"!==o.name||i||(i=o);const t=Array.from(o.getChildren()).filter(t=>t.is("element","tr"));for(const o of t)if("thead"===o.parent.name&&o.parent===i)e.headingRows++,n.push(o);else{r.push(o);const t=tb(o);t>e.headingColumns&&(e.headingColumns=t)}}return e.rows=[...n,...r],e}(r),s={};a&&(s.headingColumns=a),o&&(s.headingRows=o);const c=n.writer.createElement("table",s);if(n.safeInsert(c,e.modelCursor)){if(n.consumable.consume(r,{name:!0}),i.forEach(t=>n.convertItem(t,n.writer.createPositionAt(c,"end"))),c.isEmpty){const t=n.writer.createElement("tableRow");n.writer.insert(t,n.writer.createPositionAt(c,"end")),Xm(n.writer,n.writer.createPositionAt(t,"end"))}n.updateConversionResult(c,e)}})}}function tb(t){let e=0,n=0;const r=Array.from(t.getChildren()).filter(t=>"th"===t.name||"td"===t.name);for(;n<r.length&&"th"===r[n].name;){const t=r[n];e+=parseInt(t.getAttribute("colspan")||1),n++}return e}class eb{constructor(t,e={}){this._table=t,this._startRow=void 0!==e.row?e.row:e.startRow||0,this._endRow=void 0!==e.row?e.row:e.endRow,this._startColumn=void 0!==e.column?e.column:e.startColumn||0,this._endColumn=void 0!==e.column?e.column:e.endColumn,this._includeAllSlots=!!e.includeAllSlots,this._skipRows=new Set,this._row=0,this._column=0,this._cellIndex=0,this._spannedCells=new Map,this._nextCellAtColumn=-1}[Symbol.iterator](){return this}next(){const t=this._table.getChild(this._row);if(!t||this._isOverEndRow())return{done:!0};if(this._isOverEndColumn())return this._advanceToNextRow();let e=null;const n=this._getSpanned();if(n)this._includeAllSlots&&!this._shouldSkipSlot()&&(e=this._formatOutValue(n.cell,n.row,n.column));else{const n=t.getChild(this._cellIndex);if(!n)return this._advanceToNextRow();const r=parseInt(n.getAttribute("colspan")||1),i=parseInt(n.getAttribute("rowspan")||1);(r>1||i>1)&&this._recordSpans(n,i,r),this._shouldSkipSlot()||(e=this._formatOutValue(n)),this._nextCellAtColumn=this._column+r}return this._column++,this._column==this._nextCellAtColumn&&this._cellIndex++,e||this.next()}skipRow(t){this._skipRows.add(t)}_advanceToNextRow(){return this._row++,this._column=0,this._cellIndex=0,this._nextCellAtColumn=-1,this.next()}_isOverEndRow(){return void 0!==this._endRow&&this._row>this._endRow}_isOverEndColumn(){return void 0!==this._endColumn&&this._column>this._endColumn}_formatOutValue(t,e=this._row,n=this._column){return{done:!1,value:new nb(this,t,e,n)}}_shouldSkipSlot(){const t=this._skipRows.has(this._row),e=this._row<this._startRow,n=this._column<this._startColumn,r=void 0!==this._endColumn&&this._column>this._endColumn;return t||e||n||r}_getSpanned(){const t=this._spannedCells.get(this._row);return t&&t.get(this._column)||null}_recordSpans(t,e,n){const r={cell:t,row:this._row,column:this._column};for(let i=this._row;i<this._row+e;i++)for(let t=this._column;t<this._column+n;t++)i==this._row&&t==this._column||this._markSpannedCell(i,t,r)}_markSpannedCell(t,e,n){this._spannedCells.has(t)||this._spannedCells.set(t,new Map),this._spannedCells.get(t).set(e,n)}}class nb{constructor(t,e,n,r){this.cell=e,this.row=t._row,this.column=t._column,this.cellAnchorRow=n,this.cellAnchorColumn=r,this._cellIndex=t._cellIndex,this._table=t._table}get isAnchor(){return this.row===this.cellAnchorRow&&this.column===this.cellAnchorColumn}get cellWidth(){return parseInt(this.cell.getAttribute("colspan")||1)}get cellHeight(){return parseInt(this.cell.getAttribute("rowspan")||1)}getPositionBefore(){return this._table.root.document.model.createPositionAt(this._table.getChild(this.row),this._cellIndex)}}function rb(t={}){return e=>e.on("insert:table",(e,n,r)=>{const i=n.item;if(!r.consumable.consume(i,"insert"))return;r.consumable.consume(i,"attribute:headingRows:table"),r.consumable.consume(i,"attribute:headingColumns:table");const o=t&&t.asWidget,a=r.writer.createContainerElement("figure",{class:"table"}),s=r.writer.createContainerElement("table");let c;var l,u;r.writer.insert(r.writer.createPositionAt(a,0),s),o&&(l=a,(u=r.writer).setCustomProperty("table",!0,l),c=eh(l,u,{hasSelectionHandle:!0}));const d=new eb(i),h={headingRows:i.getAttribute("headingRows")||0,headingColumns:i.getAttribute("headingColumns")||0},f=new Map;for(const m of d){const{row:e,cell:n}=m,o=i.getChild(e),a=f.get(e)||cb(s,o,e,h,r);f.set(e,a),r.consumable.consume(n,"insert"),sb(m,h,r.writer.createPositionAt(a,"end"),r,t)}for(const t of i.getChildren()){const e=t.index;f.has(e)||f.set(e,cb(s,t,e,h,r))}const p=r.mapper.toViewPosition(n.range.start);r.mapper.bindElements(i,o?c:a),r.writer.insert(p,o?c:a)})}function ib(t,e){const{writer:n}=e;if(t.parent.is("element","tableCell"))return ob(t)?n.createContainerElement("span",{style:"display:inline-block"}):n.createContainerElement("p")}function ob(t){return 1===t.parent.childCount&&!hb(t)}function ab(t,e,n){const{cell:r}=t,i=lb(t,e),o=n.mapper.toViewElement(r);o&&o.name!==i&&function(t,e,n){const r=n.writer,i=n.mapper.toViewElement(t),o=ih(r.createEditableElement(e,i.getAttributes()),r);nh(o,r,(t,e,n)=>n.addClass(jn(e.classes),t),(t,e,n)=>n.removeClass(jn(e.classes),t)),r.insert(r.createPositionAfter(i),o),r.move(r.createRangeIn(i),r.createPositionAt(o,0)),r.remove(r.createRangeOn(i)),n.mapper.unbindViewElement(i),n.mapper.bindElements(t,o)}(r,i,n)}function sb(t,e,n,r,i){const o=i&&i.asWidget,a=lb(t,e),s=o?ih(r.writer.createEditableElement(a),r.writer):r.writer.createContainerElement(a);o&&nh(s,r.writer,(t,e,n)=>n.addClass(jn(e.classes),t),(t,e,n)=>n.removeClass(jn(e.classes),t));const c=t.cell,l=c.getChild(0),u=1===c.childCount&&"paragraph"===l.name;if(r.writer.insert(n,s),r.mapper.bindElements(c,s),!o&&!hb(l)&&u){const t=c.getChild(0);r.consumable.consume(t,"insert"),r.mapper.bindElements(t,s)}}function cb(t,e,n,r,i){i.consumable.consume(e,"insert");const o=e.isEmpty?i.writer.createEmptyElement("tr"):i.writer.createContainerElement("tr");i.mapper.bindElements(e,o);const a=r.headingRows,s=function(t,e,n){const r=ub(t,e);return r||function(t,e,n){const r=n.writer.createContainerElement(t),i=n.writer.createPositionAt(e,"tbody"==t?"end":0);return n.writer.insert(i,r),r}(t,e,n)}(function(t,e){return t<e.headingRows?"thead":"tbody"}(n,r),t,i),c=a>0&&n>=a?n-a:n,l=i.writer.createPositionAt(s,c);return i.writer.insert(l,o),o}function lb(t,e){const{row:n,column:r}=t,{headingColumns:i,headingRows:o}=e;return o&&o>n||i&&i>r?"th":"td"}function ub(t,e){for(const n of e.getChildren())if(n.name==t)return n}function db(t,e,n){const r=ub(t,e);r&&0===r.childCount&&n.writer.remove(n.writer.createRangeOn(r))}function hb(t){return!![...t.getAttributeKeys()].length}class fb extends vu{refresh(){const t=this.editor.model,e=t.document.selection,n=t.schema,r=function(t){const e=t.parent;return e===e.root?e:e.parent}(e.getFirstPosition());this.isEnabled=n.checkChild(r,"table")}execute(t={}){const e=this.editor.model,n=e.document.selection,r=this.editor.plugins.get("TableUtils"),i=oh(n,e);e.change(n=>{const o=r.createTable(n,t);e.insertContent(o,i),n.setSelection(n.createPositionAt(o.getNodeByPath([0,0,0]),0))})}}function pb(t){const e=[];for(const n of yb(t.getRanges())){const t=n.getContainedElement();t&&t.is("element","tableCell")&&e.push(t)}return e}function mb(t){const e=[];for(const n of t.getRanges()){const t=n.start.findAncestor("tableCell");t&&e.push(t)}return e}function bb(t){const e=pb(t);return e.length?e:mb(t)}function gb(t){return kb(t.map(t=>t.parent.index))}function vb(t){const e=t[0].findAncestor("table");return kb([...new eb(e)].filter(e=>t.includes(e.cell)).map(t=>t.column))}function wb(t,e){if(t.length<2||!function(t){const e=t[0].findAncestor("table"),n=gb(t),r=parseInt(e.getAttribute("headingRows")||0);if(!Ob(n,r))return!1;const i=parseInt(e.getAttribute("headingColumns")||0);return Ob(vb(t),i)}(t))return!1;const n=new Set,r=new Set;let i=0;for(const o of t){const{row:t,column:a}=e.getCellLocation(o),s=parseInt(o.getAttribute("rowspan")||1),c=parseInt(o.getAttribute("colspan")||1);n.add(t),r.add(a),s>1&&n.add(t+s-1),c>1&&r.add(a+c-1),i+=s*c}return function(t,e){const n=Array.from(t.values()),r=Array.from(e.values()),i=Math.max(...n),o=Math.min(...n),a=Math.max(...r),s=Math.min(...r);return(i-o+1)*(a-s+1)}(n,r)==i}function yb(t){return Array.from(t).sort(_b)}function kb(t){const e=t.sort((t,e)=>t-e);return{first:e[0],last:e[e.length-1]}}function _b(t,e){const n=t.start,r=e.start;return n.isBefore(r)?-1:1}function Ob({first:t,last:e},n){return t<n===e<n}class zb extends vu{constructor(t,e={}){super(t),this.order=e.order||"below"}refresh(){const t=this.editor.model.document.selection.getFirstPosition().findAncestor("table");this.isEnabled=!!t}execute(){const t=this.editor,e=t.model.document.selection,n=t.plugins.get("TableUtils"),r="above"===this.order,i=bb(e),o=gb(i),a=r?o.first:o.last,s=i[0].findAncestor("table");n.insertRows(s,{at:r?a:a+1,copyStructureFromAbove:!r})}}class Ab extends vu{constructor(t,e={}){super(t),this.order=e.order||"right"}refresh(){const t=this.editor.model.document.selection.getFirstPosition().findAncestor("table");this.isEnabled=!!t}execute(){const t=this.editor,e=t.model.document.selection,n=t.plugins.get("TableUtils"),r="left"===this.order,i=bb(e),o=vb(i),a=r?o.first:o.last,s=i[0].findAncestor("table");n.insertColumns(s,{columns:1,at:r?a:a+1})}}class jb extends vu{constructor(t,e={}){super(t),this.direction=e.direction||"horizontally"}refresh(){const t=bb(this.editor.model.document.selection);this.isEnabled=1===t.length}execute(){const t=bb(this.editor.model.document.selection)[0],e="horizontally"===this.direction,n=this.editor.plugins.get("TableUtils");e?n.splitCellHorizontally(t,2):n.splitCellVertically(t,2)}}function Mb(t,e,n){const{startRow:r,startColumn:i,endRow:o,endColumn:a}=e,s=n.createElement("table"),c=o-r+1;for(let u=0;u<c;u++)n.insertElement("tableRow",s,"end");const l=[...new eb(t,{startRow:r,endRow:o,startColumn:i,endColumn:a,includeAllSlots:!0})];for(const{row:u,column:d,cell:h,isAnchor:f,cellAnchorRow:p,cellAnchorColumn:m}of l){const t=u-r,e=s.getChild(t);if(f){const t=n.cloneElement(h);n.append(t,e),Tb(t,u,d,o,a,n)}else(p<r||m<i)&&Xm(n,n.createPositionAt(e,"end"))}return function(t,e,n,r,i){const o=parseInt(e.getAttribute("headingRows")||0);o>0&&Qm("headingRows",o-n,t,i,0);const a=parseInt(e.getAttribute("headingColumns")||0);a>0&&Qm("headingColumns",a-r,t,i,0)}(s,t,r,i,n),s}function Cb(t,e,n=0){const r=[],i=new eb(t,{startRow:n,endRow:e-1});for(const o of i){const{row:t,cellHeight:n}=o,i=t+n-1;t<e&&e<=i&&r.push(o)}return r}function Vb(t,e,n){const r=t.parent,i=r.parent,o=r.index,a=e-o,s={},c=parseInt(t.getAttribute("rowspan"))-a;c>1&&(s.rowspan=c);const l=parseInt(t.getAttribute("colspan")||1);l>1&&(s.colspan=l);const u=o+a,d=[...new eb(i,{startRow:o,endRow:u,includeAllSlots:!0})];let h,f=null;for(const p of d){const{row:e,column:r,cell:i}=p;i===t&&void 0===h&&(h=r),void 0!==h&&h===r&&e===u&&(f=Xm(n,p.getPositionBefore(),s))}return Qm("rowspan",a,t,n),f}function Sb(t,e){const n=[],r=new eb(t);for(const i of r){const{column:t,cellWidth:r}=i,o=t+r-1;t<e&&e<=o&&n.push(i)}return n}function xb(t,e,n,r){const i=n-e,o={},a=parseInt(t.getAttribute("colspan"))-i;a>1&&(o.colspan=a);const s=parseInt(t.getAttribute("rowspan")||1);s>1&&(o.rowspan=s);const c=Xm(r,r.createPositionAfter(t),o);return Qm("colspan",i,t,r),c}function Tb(t,e,n,r,i,o){const a=parseInt(t.getAttribute("colspan")||1),s=parseInt(t.getAttribute("rowspan")||1);n+a-1>i&&Qm("colspan",i-n+1,t,o,1),e+s-1>r&&Qm("rowspan",r-e+1,t,o,1)}function Pb(t,e){const n=e.getColumns(t),r=new Array(n).fill(0);for(const{column:o}of new eb(t))r[o]++;const i=r.reduce((t,e,n)=>e?t:[...t,n],[]);if(i.length>0){const n=i[i.length-1];return e.removeColumns(t,{at:n}),!0}return!1}function Ib(t,e){const n=[];for(let r=0;r<t.childCount;r++)t.getChild(r).isEmpty&&n.push(r);if(n.length>0){const r=n[n.length-1];return e.removeRows(t,{at:r}),!0}return!1}function Eb(t,e){Pb(t,e)||Ib(t,e)}function Lb(t,e){const n=Array.from(new eb(t,{startColumn:e.firstColumn,endColumn:e.lastColumn,row:e.lastRow}));if(n.every(({cellHeight:t})=>1===t))return e.lastRow;const r=n[0].cellHeight-1;return e.lastRow+r}function Bb(t,e){const n=Array.from(new eb(t,{startRow:e.firstRow,endRow:e.lastRow,column:e.lastColumn}));if(n.every(({cellWidth:t})=>1===t))return e.lastColumn;const r=n[0].cellWidth-1;return e.lastColumn+r}class Hb extends vu{constructor(t,e){super(t),this.direction=e.direction,this.isHorizontal="right"==this.direction||"left"==this.direction}refresh(){const t=this._getMergeableCell();this.value=t,this.isEnabled=!!t}execute(){const t=this.editor.model,e=mb(t.document.selection)[0],n=this.value,r=this.direction;t.change(t=>{const i="right"==r||"down"==r,o=i?e:n,a=i?n:e,s=a.parent;!function(t,e,n){Fb(t)||(Fb(e)&&n.remove(n.createRangeIn(e)),n.move(n.createRangeIn(t),n.createPositionAt(e,"end"))),n.remove(t)}(a,o,t);const c=this.isHorizontal?"colspan":"rowspan",l=parseInt(e.getAttribute(c)||1),u=parseInt(n.getAttribute(c)||1);t.setAttribute(c,l+u,o),t.setSelection(t.createRangeIn(o));const d=this.editor.plugins.get("TableUtils");Eb(s.findAncestor("table"),d)})}_getMergeableCell(){const t=mb(this.editor.model.document.selection)[0];if(!t)return;const e=this.editor.plugins.get("TableUtils"),n=this.isHorizontal?function(t,e,n){const r=t.parent.parent,i="right"==e?t.nextSibling:t.previousSibling,o=(r.getAttribute("headingColumns")||0)>0;if(!i)return;const a="right"==e?t:i,s="right"==e?i:t,{column:c}=n.getCellLocation(a),{column:l}=n.getCellLocation(s),u=parseInt(a.getAttribute("colspan")||1),d=Jm(n,a),h=Jm(n,s);return o&&d!=h?void 0:c+u===l?i:void 0}(t,this.direction,e):function(t,e){const n=t.parent,r=n.parent,i=r.getChildIndex(n);if("down"==e&&i===r.childCount-1||"up"==e&&0===i)return;const o=parseInt(t.getAttribute("rowspan")||1),a=r.getAttribute("headingRows")||0,s="down"==e&&i+o===a,c="up"==e&&i===a;if(a&&(s||c))return;const l=parseInt(t.getAttribute("rowspan")||1),u="down"==e?i+l:i,d=[...new eb(r,{endRow:u})],h=d.find(e=>e.cell===t).column,f=d.find(({row:t,cellHeight:n,column:r})=>r===h&&("down"==e?t===u:u===t+n));return f&&f.cell}(t,this.direction);if(!n)return;const r=this.isHorizontal?"rowspan":"colspan",i=parseInt(t.getAttribute(r)||1);return parseInt(n.getAttribute(r)||1)===i?n:void 0}}function Fb(t){return 1==t.childCount&&t.getChild(0).is("element","paragraph")&&t.getChild(0).isEmpty}class Db extends vu{refresh(){const t=bb(this.editor.model.document.selection),e=t[0];if(e){const n=e.findAncestor("table"),r=this.editor.plugins.get("TableUtils").getRows(n)-1,i=gb(t),o=0===i.first&&i.last===r;this.isEnabled=!o}else this.isEnabled=!1}execute(){const t=this.editor.model,e=bb(t.document.selection),n=gb(e),r=e[0],i=r.findAncestor("table"),o=this.editor.plugins.get("TableUtils").getCellLocation(r).column;t.change(t=>{const e=n.last-n.first+1;this.editor.plugins.get("TableUtils").removeRows(i,{at:n.first,rows:e});const r=function(t,e,n){const r=t.getChild(e)||t.getChild(t.childCount-1);let i=r.getChild(0),o=0;for(const a of r.getChildren()){if(o>n)return i;i=a,o+=parseInt(a.getAttribute("colspan")||1)}return i}(i,n.first,o);t.setSelection(t.createPositionAt(r,0))})}}class Rb extends vu{refresh(){const t=bb(this.editor.model.document.selection),e=t[0];if(e){const n=e.findAncestor("table"),r=this.editor.plugins.get("TableUtils").getColumns(n),{first:i,last:o}=vb(t);this.isEnabled=o-i<r-1}else this.isEnabled=!1}execute(){const[t,e]=function(t){const e=bb(t),n=e[0],r=e.pop(),i=[n,r];return n.isBefore(r)?i:i.reverse()}(this.editor.model.document.selection),n=t.parent.parent,r=[...new eb(n)],i={first:r.find(e=>e.cell===t).column,last:r.find(t=>t.cell===e).column},o=function(t,e,n,r){return parseInt(n.getAttribute("colspan")||1)>1?n:e.previousSibling||n.nextSibling?n.nextSibling||e.previousSibling:r.first?t.reverse().find(({column:t})=>t<r.first).cell:t.reverse().find(({column:t})=>t>r.last).cell}(r,t,e,i);this.editor.model.change(t=>{const e=i.last-i.first+1;this.editor.plugins.get("TableUtils").removeColumns(n,{at:i.first,columns:e}),t.setSelection(t.createPositionAt(o,0))})}}class Nb extends vu{refresh(){const t=bb(this.editor.model.document.selection),e=t.length>0;this.isEnabled=e,this.value=e&&t.every(t=>this._isInHeading(t,t.parent.parent))}execute(t={}){if(t.forceValue===this.value)return;const e=this.editor.model,n=bb(e.document.selection),r=n[0].findAncestor("table"),{first:i,last:o}=gb(n),a=this.value?i:o+1,s=r.getAttribute("headingRows")||0;e.change(t=>{if(a){const e=Cb(r,a,a>s?s:0);for(const{cell:n}of e)Vb(n,a,t)}Qm("headingRows",a,r,t,0)})}_isInHeading(t,e){const n=parseInt(e.getAttribute("headingRows")||0);return!!n&&t.parent.index<n}}class $b extends vu{refresh(){const t=bb(this.editor.model.document.selection),e=this.editor.plugins.get("TableUtils"),n=t.length>0;this.isEnabled=n,this.value=n&&t.every(t=>Jm(e,t))}execute(t={}){if(t.forceValue===this.value)return;const e=this.editor.model,n=bb(e.document.selection),r=n[0].findAncestor("table"),{first:i,last:o}=vb(n),a=this.value?i:o+1;e.change(t=>{if(a){const e=Sb(r,a);for(const{cell:n,column:r}of e)xb(n,r,a,t)}Qm("headingColumns",a,r,t,0)})}}class Ub extends du{static get pluginName(){return"TableUtils"}init(){this.decorate("insertColumns"),this.decorate("insertRows")}getCellLocation(t){const e=t.parent,n=e.parent,r=n.getChildIndex(e),i=new eb(n,{row:r});for(const{cell:o,row:a,column:s}of i)if(o===t)return{row:a,column:s}}createTable(t,e){const n=t.createElement("table");return qb(t,n,0,parseInt(e.rows)||2,parseInt(e.columns)||2),e.headingRows&&Qm("headingRows",e.headingRows,n,t,0),e.headingColumns&&Qm("headingColumns",e.headingColumns,n,t,0),n}insertRows(t,e={}){const n=this.editor.model,r=e.at||0,i=e.rows||1,o=void 0!==e.copyStructureFromAbove,a=e.copyStructureFromAbove?r-1:r,s=this.getRows(t),c=this.getColumns(t);n.change(e=>{const n=t.getAttribute("headingRows")||0;if(n>r&&Qm("headingRows",n+i,t,e,0),!o&&(0===r||r===s))return void qb(e,t,r,i,c);const l=o?Math.max(r,a):r,u=new eb(t,{endRow:l}),d=new Array(c).fill(1);for(const{row:t,column:s,cellHeight:c,cellWidth:h,cell:f}of u){const n=t+c-1,l=t<=a&&a<=n;t<r&&r<=n?(e.setAttribute("rowspan",c+i,f),d[s]=-h):o&&l&&(d[s]=h)}for(let o=0;o<i;o++){const n=e.createElement("tableRow");e.insert(n,t,r);for(let t=0;t<d.length;t++){const r=d[t],i=e.createPositionAt(n,"end");r>0&&Xm(e,i,r>1?{colspan:r}:null),t+=Math.abs(r)-1}}})}insertColumns(t,e={}){const n=this.editor.model,r=e.at||0,i=e.columns||1;n.change(e=>{const n=t.getAttribute("headingColumns");r<n&&e.setAttribute("headingColumns",n+i,t);const o=this.getColumns(t);if(0===r||o===r){for(const n of t.getChildren())Wb(i,e,e.createPositionAt(n,r?"end":0));return}const a=new eb(t,{column:r,includeAllSlots:!0});for(const t of a){const{row:n,cell:o,cellAnchorColumn:s,cellAnchorRow:c,cellWidth:l,cellHeight:u}=t;if(s<r){e.setAttribute("colspan",l+i,o);const t=c+u-1;for(let e=n;e<=t;e++)a.skipRow(e)}else Wb(i,e,t.getPositionBefore())}})}removeRows(t,e){const n=this.editor.model,r=e.rows||1,i=e.at,o=i+r-1;n.change(e=>{const{cellsToMove:n,cellsToTrim:r}=function(t,e,n){const r=new Map,i=[];for(const{row:o,column:a,cellHeight:s,cell:c}of new eb(t,{endRow:n})){const t=o+s-1;if(o>=e&&o<=n&&t>n){const t=s-(n-o+1);r.set(a,{cell:c,rowspan:t})}if(o<e&&t>=e){let r;r=t>=n?n-e+1:t-e+1,i.push({cell:c,rowspan:s-r})}}return{cellsToMove:r,cellsToTrim:i}}(t,i,o);n.size&&function(t,e,n,r){const i=[...new eb(t,{includeAllSlots:!0,row:e})],o=t.getChild(e);let a;for(const{column:s,cell:c,isAnchor:l}of i)if(n.has(s)){const{cell:t,rowspan:e}=n.get(s),i=a?r.createPositionAfter(a):r.createPositionAt(o,0);r.move(r.createRangeOn(t),i),Qm("rowspan",e,t,r),a=t}else l&&(a=c)}(t,o+1,n,e);for(let a=o;a>=i;a--)e.remove(t.getChild(a));for(const{rowspan:t,cell:i}of r)Qm("rowspan",t,i,e);!function(t,e,n,r){const i=t.getAttribute("headingRows")||0;e<i&&Qm("headingRows",n<i?i-(n-e+1):e,t,r,0)}(t,i,o,e),Pb(t,this)||Ib(t,this)})}removeColumns(t,e){const n=this.editor.model,r=e.at,i=e.columns||1,o=e.at+i-1;n.change(e=>{!function(t,e,n){const r=t.getAttribute("headingColumns")||0;if(r&&e.first<r){const i=Math.min(r-1,e.last)-e.first+1;n.setAttribute("headingColumns",r-i,t)}}(t,{first:r,last:o},e);for(let n=o;n>=r;n--)for(const{cell:r,column:i,cellWidth:o}of[...new eb(t)])i<=n&&o>1&&i+o>n?Qm("colspan",o-1,r,e):i===n&&e.remove(r);Ib(t,this)||Pb(t,this)})}splitCellVertically(t,e=2){const n=this.editor.model,r=t.parent.parent,i=parseInt(t.getAttribute("rowspan")||1),o=parseInt(t.getAttribute("colspan")||1);n.change(n=>{if(o>1){const{newCellsSpan:r,updatedSpan:a}=Gb(o,e);Qm("colspan",a,t,n);const s={};r>1&&(s.colspan=r),i>1&&(s.rowspan=i),Wb(o>e?e-1:o-1,n,n.createPositionAfter(t),s)}if(o<e){const a=e-o,s=[...new eb(r)],{column:c}=s.find(({cell:e})=>e===t),l=s.filter(({cell:e,cellWidth:n,column:r})=>e!==t&&r===c||r<c&&r+n>c);for(const{cell:t,cellWidth:e}of l)n.setAttribute("colspan",e+a,t);const u={};i>1&&(u.rowspan=i),Wb(a,n,n.createPositionAfter(t),u);const d=r.getAttribute("headingColumns")||0;d>c&&Qm("headingColumns",d+a,r,n)}})}splitCellHorizontally(t,e=2){const n=this.editor.model,r=t.parent,i=r.parent,o=i.getChildIndex(r),a=parseInt(t.getAttribute("rowspan")||1),s=parseInt(t.getAttribute("colspan")||1);n.change(n=>{if(a>1){const r=[...new eb(i,{startRow:o,endRow:o+a-1,includeAllSlots:!0})],{newCellsSpan:c,updatedSpan:l}=Gb(a,e);Qm("rowspan",l,t,n);const{column:u}=r.find(({cell:e})=>e===t),d={};c>1&&(d.rowspan=c),s>1&&(d.colspan=s);for(const t of r){const{column:e,row:r}=t,i=e===u,a=(r+o+l)%c==0;r>=o+l&&i&&a&&Wb(1,n,t.getPositionBefore(),d)}}if(a<e){const r=e-a,c=[...new eb(i,{startRow:0,endRow:o})];for(const{cell:e,cellHeight:i,row:a}of c)if(e!==t&&a+i>o){const t=i+r;n.setAttribute("rowspan",t,e)}const l={};s>1&&(l.colspan=s),qb(n,i,o+1,r,1,l);const u=i.getAttribute("headingRows")||0;u>o&&Qm("headingRows",u+r,i,n)}})}getColumns(t){return[...t.getChild(0).getChildren()].reduce((t,e)=>t+parseInt(e.getAttribute("colspan")||1),0)}getRows(t){return t.childCount}}function qb(t,e,n,r,i,o={}){for(let a=0;a<r;a++){const r=t.createElement("tableRow");t.insert(r,e,n),Wb(i,t,t.createPositionAt(r,"end"),o)}}function Wb(t,e,n,r={}){for(let i=0;i<t;i++)Xm(e,n,r)}function Gb(t,e){if(t<e)return{newCellsSpan:1,updatedSpan:1};const n=Math.floor(t/e);return{newCellsSpan:n,updatedSpan:t-n*e+n}}class Yb extends vu{refresh(){const t=pb(this.editor.model.document.selection);this.isEnabled=wb(t,this.editor.plugins.get(Ub))}execute(){const t=this.editor.model,e=this.editor.plugins.get(Ub);t.change(n=>{const r=pb(t.document.selection),i=r.shift(),{mergeWidth:o,mergeHeight:a}=function(t,e,n){let r=0,i=0;for(const s of e){const{row:t,column:e}=n.getCellLocation(s);r=Xb(s,e,r,"colspan"),i=Xb(s,t,i,"rowspan")}const{row:o,column:a}=n.getCellLocation(t);return{mergeWidth:r-a,mergeHeight:i-o}}(i,r,e);Qm("colspan",o,i,n),Qm("rowspan",a,i,n);for(const t of r)Kb(t,i,n);Eb(i.findAncestor("table"),e),n.setSelection(i,"in")})}}function Kb(t,e,n){Qb(t)||(Qb(e)&&n.remove(n.createRangeIn(e)),n.move(n.createRangeIn(t),n.createPositionAt(e,"end"))),n.remove(t)}function Qb(t){return 1==t.childCount&&t.getChild(0).is("element","paragraph")&&t.getChild(0).isEmpty}function Xb(t,e,n,r){const i=parseInt(t.getAttribute(r)||1);return Math.max(n,e+i)}class Jb extends vu{refresh(){const t=bb(this.editor.model.document.selection);this.isEnabled=t.length>0}execute(){const t=this.editor.model,e=bb(t.document.selection),n=gb(e),r=e[0].findAncestor("table"),i=[];for(let o=n.first;o<=n.last;o++)for(const e of r.getChild(o).getChildren())i.push(t.createRangeOn(e));t.change(t=>{t.setSelection(i)})}}class Zb extends vu{refresh(){const t=bb(this.editor.model.document.selection);this.isEnabled=t.length>0}execute(){const t=this.editor.model,e=bb(t.document.selection),n=e[0],r=e.pop(),i=n.findAncestor("table"),o=this.editor.plugins.get("TableUtils"),a=o.getCellLocation(n),s=o.getCellLocation(r),c=Math.min(a.column,s.column),l=Math.max(a.column,s.column),u=[];for(const d of new eb(i,{startColumn:c,endColumn:l}))u.push(t.createRangeOn(d.cell));t.change(t=>{t.setSelection(u)})}}function tg(t){t.document.registerPostFixer(e=>function(t,e){const n=e.document.differ.getChanges();let r=!1;const i=new Set;for(const o of n){let e;"table"==o.name&&"insert"==o.type&&(e=o.position.nodeAfter),"tableRow"!=o.name&&"tableCell"!=o.name||(e=o.position.findAncestor("table")),rg(o)&&(e=o.range.start.findAncestor("table")),e&&!i.has(e)&&(r=eg(e,t)||r,r=ng(e,t)||r,i.add(e))}return r}(e,t))}function eg(t,e){let n=!1;const r=function(t){const e=parseInt(t.getAttribute("headingRows")||0),n=t.childCount,r=[];for(const{row:i,cell:o,cellHeight:a}of new eb(t)){if(a<2)continue;const t=i<e?e:n;if(i+a>t){const e=t-i;r.push({cell:o,rowspan:e})}}return r}(t);if(r.length){n=!0;for(const t of r)Qm("rowspan",t.rowspan,t.cell,e,1)}return n}function ng(t,e){let n=!1;const r=function(t){const e=new Array(t.childCount).fill(0);for(const{row:n}of new eb(t,{includeAllSlots:!0}))e[n]++;return e}(t),i=[];for(const[a,s]of r.entries())s||i.push(a);if(i.length){n=!0;for(const n of i.reverse())e.remove(t.getChild(n)),r.splice(n,1)}const o=r[0];if(!r.every(t=>t===o)){const i=r.reduce((t,e)=>e>t?e:t,0);for(const[o,a]of r.entries()){const r=i-a;if(r){for(let n=0;n<r;n++)Xm(e,e.createPositionAt(t.getChild(o),"end"));n=!0}}}return n}function rg(t){const e="attribute"===t.type,n=t.attributeKey;return e&&("headingRows"===n||"colspan"===n||"rowspan"===n)}function ig(t){t.document.registerPostFixer(e=>function(t,e){const n=e.document.differ.getChanges();let r=!1;for(const i of n)"insert"==i.type&&"table"==i.name&&(r=og(i.position.nodeAfter,t)||r),"insert"==i.type&&"tableRow"==i.name&&(r=ag(i.position.nodeAfter,t)||r),"insert"==i.type&&"tableCell"==i.name&&(r=sg(i.position.nodeAfter,t)||r),cg(i)&&(r=sg(i.position.parent,t)||r);return r}(e,t))}function og(t,e){let n=!1;for(const r of t.getChildren())n=ag(r,e)||n;return n}function ag(t,e){let n=!1;for(const r of t.getChildren())n=sg(r,e)||n;return n}function sg(t,e){if(0==t.childCount)return e.insertElement("paragraph",t),!0;const n=Array.from(t.getChildren()).filter(t=>t.is("$text"));for(const r of n)e.wrap(e.createRangeOn(r),"paragraph");return!!n.length}function cg(t){return!(!t.position||!t.position.parent.is("element","tableCell"))&&("insert"==t.type&&"$text"==t.name||"remove"==t.type)}function lg(t,e){t.document.registerPostFixer(()=>function(t,e){const n=new Set;for(const r of t.getChanges()){const t="attribute"==r.type?r.range.start.parent:r.position.parent;t.is("element","tableCell")&&n.add(t)}for(const r of n.values())for(const n of[...r.getChildren()].filter(t=>ug(t,e)))t.refreshItem(n);return!1}(t.document.differ,e))}function ug(t,e){if(!t.is("element","paragraph"))return!1;const n=e.toViewElement(t);return!!n&&ob(t)!==n.is("element","span")}function dg(t){t.document.registerPostFixer(()=>function(t){const e=t.document.differ,n=new Set;for(const r of e.getChanges()){if("attribute"!=r.type)continue;const t=r.range.start.nodeAfter;t&&t.is("element","table")&&"headingRows"==r.attributeKey&&n.add(t)}if(n.size){for(const t of n.values())e.refreshItem(t);return!0}return!1}(t))}n(88);class hg extends du{static get pluginName(){return"TableEditing"}init(){const t=this.editor,e=t.model,n=e.schema,r=t.conversion;n.register("table",{allowWhere:"$block",allowAttributes:["headingRows","headingColumns"],isObject:!0,isBlock:!0}),n.register("tableRow",{allowIn:"table",isLimit:!0}),n.register("tableCell",{allowIn:"tableRow",allowAttributes:["colspan","rowspan"],isLimit:!0,isSelectable:!0}),n.extend("$block",{allowIn:"tableCell"}),n.addChildCheck((t,e)=>{if("table"==e.name&&Array.from(t.getNames()).includes("table"))return!1}),r.for("upcast").add(Zm()),r.for("editingDowncast").add(rb({asWidget:!0})),r.for("dataDowncast").add(rb()),r.for("upcast").elementToElement({model:"tableRow",view:"tr"}),r.for("upcast").add(t=>{t.on("element:tr",(t,e)=>{e.viewItem.isEmpty&&0==e.modelCursor.index&&t.stop()},{priority:"high"})}),r.for("editingDowncast").add(t=>t.on("insert:tableRow",(t,e,n)=>{const r=e.item;if(!n.consumable.consume(r,"insert"))return;const i=r.parent,o=function(t){for(const e of t.getChildren())if("table"===e.name)return e}(n.mapper.toViewElement(i)),a=i.getChildIndex(r),s=new eb(i,{row:a}),c={headingRows:i.getAttribute("headingRows")||0,headingColumns:i.getAttribute("headingColumns")||0},l=new Map;for(const u of s){const t=l.get(a)||cb(o,r,a,c,n);l.set(a,t),n.consumable.consume(u.cell,"insert"),sb(u,c,n.writer.createPositionAt(t,"end"),n,{asWidget:!0})}})),r.for("editingDowncast").add(t=>t.on("remove:tableRow",(t,e,n)=>{t.stop();const r=n.writer,i=n.mapper,o=i.toViewPosition(e.position).getLastMatchingPosition(t=>!t.item.is("element","tr")).nodeAfter,a=o.parent.parent,s=r.createRangeOn(o),c=r.remove(s);for(const l of r.createRangeIn(c).getItems())i.unbindViewElement(l);db("thead",a,n),db("tbody",a,n)},{priority:"higher"})),r.for("upcast").elementToElement({model:"tableCell",view:"td"}),r.for("upcast").elementToElement({model:"tableCell",view:"th"}),r.for("editingDowncast").add(t=>t.on("insert:tableCell",(t,e,n)=>{const r=e.item;if(!n.consumable.consume(r,"insert"))return;const i=r.parent,o=i.parent,a=o.getChildIndex(i),s=new eb(o,{row:a}),c={headingRows:o.getAttribute("headingRows")||0,headingColumns:o.getAttribute("headingColumns")||0};for(const l of s)if(l.cell===r){const t=n.mapper.toViewElement(i);return void sb(l,c,n.writer.createPositionAt(t,i.getChildIndex(r)),n,{asWidget:!0})}})),t.conversion.for("editingDowncast").elementToElement({model:"paragraph",view:ib,converterPriority:"high"}),r.attributeToAttribute({model:"colspan",view:"colspan"}),r.attributeToAttribute({model:"rowspan",view:"rowspan"}),r.for("editingDowncast").add(t=>t.on("attribute:headingColumns:table",(t,e,n)=>{const r=e.item;if(!n.consumable.consume(e.item,t.name))return;const i={headingRows:r.getAttribute("headingRows")||0,headingColumns:r.getAttribute("headingColumns")||0},o=e.attributeOldValue,a=e.attributeNewValue,s=(o>a?o:a)-1;for(const c of new eb(r,{endColumn:s}))ab(c,i,n)})),t.commands.add("insertTable",new fb(t)),t.commands.add("insertTableRowAbove",new zb(t,{order:"above"})),t.commands.add("insertTableRowBelow",new zb(t,{order:"below"})),t.commands.add("insertTableColumnLeft",new Ab(t,{order:"left"})),t.commands.add("insertTableColumnRight",new Ab(t,{order:"right"})),t.commands.add("removeTableRow",new Db(t)),t.commands.add("removeTableColumn",new Rb(t)),t.commands.add("splitTableCellVertically",new jb(t,{direction:"vertically"})),t.commands.add("splitTableCellHorizontally",new jb(t,{direction:"horizontally"})),t.commands.add("mergeTableCells",new Yb(t)),t.commands.add("mergeTableCellRight",new Hb(t,{direction:"right"})),t.commands.add("mergeTableCellLeft",new Hb(t,{direction:"left"})),t.commands.add("mergeTableCellDown",new Hb(t,{direction:"down"})),t.commands.add("mergeTableCellUp",new Hb(t,{direction:"up"})),t.commands.add("setTableColumnHeader",new $b(t)),t.commands.add("setTableRowHeader",new Nb(t)),t.commands.add("selectTableRow",new Jb(t)),t.commands.add("selectTableColumn",new Zb(t)),dg(e),tg(e),lg(e,t.editing.mapper),ig(e)}static get requires(){return[Ub]}}n(90);class fg extends zl{constructor(t){super(t);const e=this.bindTemplate;this.set("icon"),this.set("isEnabled",!0),this.set("isOn",!1),this.set("isToggleable",!1),this.set("isVisible",!0),this.set("keystroke"),this.set("label"),this.set("tabindex",-1),this.set("tooltip"),this.set("tooltipPosition","s"),this.set("type","button"),this.set("withText",!1),this.children=this.createCollection(),this.actionView=this._createActionView(),this.arrowView=this._createArrowView(),this.keystrokes=new Rc,this.focusTracker=new Yc,this.setTemplate({tag:"div",attributes:{class:["ck","ck-splitbutton",e.if("isVisible","ck-hidden",t=>!t),this.arrowView.bindTemplate.if("isOn","ck-splitbutton_open")]},children:this.children})}render(){super.render(),this.children.add(this.actionView),this.children.add(this.arrowView),this.focusTracker.add(this.actionView.element),this.focusTracker.add(this.arrowView.element),this.keystrokes.listenTo(this.element),this.keystrokes.set("arrowright",(t,e)=>{this.focusTracker.focusedElement===this.actionView.element&&(this.arrowView.focus(),e())}),this.keystrokes.set("arrowleft",(t,e)=>{this.focusTracker.focusedElement===this.arrowView.element&&(this.actionView.focus(),e())})}focus(){this.actionView.focus()}_createActionView(){const t=new Kl;return t.bind("icon","isEnabled","isOn","isToggleable","keystroke","label","tabindex","tooltip","tooltipPosition","type","withText").to(this),t.extendTemplate({attributes:{class:"ck-splitbutton__action"}}),t.delegate("execute").to(this),t}_createArrowView(){const t=new Kl,e=t.bindTemplate;return t.icon=Ql,t.extendTemplate({attributes:{class:"ck-splitbutton__arrow","aria-haspopup":!0,"aria-expanded":e.to("isOn",t=>String(t))}}),t.bind("isEnabled").to(this),t.delegate("execute").to(this,"open"),t}}n(92);class pg extends zl{constructor(t){super(t);const e=this.bindTemplate;this.items=this._createGridCollection(),this.set("rows",0),this.set("columns",0),this.bind("label").to(this,"columns",this,"rows",(t,e)=>`${e} × ${t}`),this.setTemplate({tag:"div",attributes:{class:["ck"]},children:[{tag:"div",attributes:{class:["ck-insert-table-dropdown__grid"]},on:{"mouseover@.ck-insert-table-dropdown-grid-box":e.to("boxover")},children:this.items},{tag:"div",attributes:{class:["ck-insert-table-dropdown__label"]},children:[{text:e.to("label")}]}],on:{mousedown:e.to(t=>{t.preventDefault()}),click:e.to(()=>{this.fire("execute")})}}),this.on("boxover",(t,e)=>{const{row:n,column:r}=e.target.dataset;this.set({rows:parseInt(n),columns:parseInt(r)})}),this.on("change:columns",()=>{this._highlightGridBoxes()}),this.on("change:rows",()=>{this._highlightGridBoxes()})}focus(){}focusLast(){}_highlightGridBoxes(){const t=this.rows,e=this.columns;this.items.map((n,r)=>{const i=Math.floor(r/10)<t&&r%10<e;n.set("isOn",i)})}_createGridCollection(){const t=[];for(let e=0;e<100;e++){const n=Math.floor(e/10),r=e%10;t.push(new mg(this.locale,n+1,r+1))}return this.createCollection(t)}}class mg extends zl{constructor(t,e,n){super(t);const r=this.bindTemplate;this.set("isOn",!1),this.setTemplate({tag:"div",attributes:{class:["ck-insert-table-dropdown-grid-box",r.if("isOn","ck-on")],"data-row":e,"data-column":n}})}}class bg extends du{init(){const t=this.editor,e=this.editor.t,n="ltr"===t.locale.contentLanguageDirection;t.ui.componentFactory.add("insertTable",n=>{const r=t.commands.get("insertTable"),i=ru(n);let o;return i.bind("isEnabled").to(r),i.buttonView.set({icon:'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M3 6v3h4V6H3zm0 4v3h4v-3H3zm0 4v3h4v-3H3zm5 3h4v-3H8v3zm5 0h4v-3h-4v3zm4-4v-3h-4v3h4zm0-4V6h-4v3h4zm1.5 8a1.5 1.5 0 0 1-1.5 1.5H3A1.5 1.5 0 0 1 1.5 17V4c.222-.863 1.068-1.5 2-1.5h13c.932 0 1.778.637 2 1.5v13zM12 13v-3H8v3h4zm0-4V6H8v3h4z"/></svg>',label:e("Insert table"),tooltip:!0}),i.on("change:isOpen",()=>{o||(o=new pg(n),i.panelView.children.add(o),o.delegate("execute").to(i),i.buttonView.on("open",()=>{o.rows=0,o.columns=0}),i.on("execute",()=>{t.execute("insertTable",{rows:o.rows,columns:o.columns}),t.editing.view.focus()}))}),i}),t.ui.componentFactory.add("tableColumn",t=>{const r=[{type:"switchbutton",model:{commandName:"setTableColumnHeader",label:e("Header column"),bindIsOn:!0}},{type:"separator"},{type:"button",model:{commandName:n?"insertTableColumnLeft":"insertTableColumnRight",label:e("Insert column left")}},{type:"button",model:{commandName:n?"insertTableColumnRight":"insertTableColumnLeft",label:e("Insert column right")}},{type:"button",model:{commandName:"removeTableColumn",label:e("Delete column")}},{type:"button",model:{commandName:"selectTableColumn",label:e("Select column")}}];return this._prepareDropdown(e("Column"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2.5 1h15A1.5 1.5 0 0 1 19 2.5v15a1.5 1.5 0 0 1-1.5 1.5h-15A1.5 1.5 0 0 1 1 17.5v-15A1.5 1.5 0 0 1 2.5 1zM2 2v16h16V2H2z" opacity=".6"/><path d="M18 7v1H2V7h16zm0 5v1H2v-1h16z" opacity=".6"/><path d="M14 1v18a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V1a1 1 0 0 1 1-1h6a1 1 0 0 1 1 1zm-2 1H8v4h4V2zm0 6H8v4h4V8zm0 6H8v4h4v-4z"/></svg>',r,t)}),t.ui.componentFactory.add("tableRow",t=>{const n=[{type:"switchbutton",model:{commandName:"setTableRowHeader",label:e("Header row"),bindIsOn:!0}},{type:"separator"},{type:"button",model:{commandName:"insertTableRowAbove",label:e("Insert row above")}},{type:"button",model:{commandName:"insertTableRowBelow",label:e("Insert row below")}},{type:"button",model:{commandName:"removeTableRow",label:e("Delete row")}},{type:"button",model:{commandName:"selectTableRow",label:e("Select row")}}];return this._prepareDropdown(e("Row"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2.5 1h15A1.5 1.5 0 0 1 19 2.5v15a1.5 1.5 0 0 1-1.5 1.5h-15A1.5 1.5 0 0 1 1 17.5v-15A1.5 1.5 0 0 1 2.5 1zM2 2v16h16V2H2z" opacity=".6"/><path d="M7 2h1v16H7V2zm5 0h1v16h-1V2z" opacity=".6"/><path d="M1 6h18a1 1 0 0 1 1 1v6a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V7a1 1 0 0 1 1-1zm1 2v4h4V8H2zm6 0v4h4V8H8zm6 0v4h4V8h-4z"/></svg>',n,t)}),t.ui.componentFactory.add("mergeTableCells",t=>{const r=[{type:"button",model:{commandName:"mergeTableCellUp",label:e("Merge cell up")}},{type:"button",model:{commandName:n?"mergeTableCellRight":"mergeTableCellLeft",label:e("Merge cell right")}},{type:"button",model:{commandName:"mergeTableCellDown",label:e("Merge cell down")}},{type:"button",model:{commandName:n?"mergeTableCellLeft":"mergeTableCellRight",label:e("Merge cell left")}},{type:"separator"},{type:"button",model:{commandName:"splitTableCellVertically",label:e("Split cell vertically")}},{type:"button",model:{commandName:"splitTableCellHorizontally",label:e("Split cell horizontally")}}];return this._prepareMergeSplitButtonDropdown(e("Merge cells"),'<svg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"><path d="M2.5 1h15A1.5 1.5 0 0 1 19 2.5v15a1.5 1.5 0 0 1-1.5 1.5h-15A1.5 1.5 0 0 1 1 17.5v-15A1.5 1.5 0 0 1 2.5 1zM2 2v16h16V2H2z" opacity=".6"/><path d="M7 2h1v16H7V2zm5 0h1v7h-1V2zm6 5v1H2V7h16zM8 12v1H2v-1h6z" opacity=".6"/><path d="M7 7h12a1 1 0 0 1 1 1v11a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V8a1 1 0 0 1 1-1zm1 2v9h10V9H8z"/></svg>',r,t)})}_prepareDropdown(t,e,n,r){const i=this.editor,o=ru(r),a=this._fillDropdownWithListOptions(o,n);return o.buttonView.set({label:t,icon:e,tooltip:!0}),o.bind("isEnabled").toMany(a,"isEnabled",(...t)=>t.some(t=>t)),this.listenTo(o,"execute",t=>{i.execute(t.source.commandName),i.editing.view.focus()}),o}_prepareMergeSplitButtonDropdown(t,e,n,r){const i=this.editor,o=ru(r,fg);return this._fillDropdownWithListOptions(o,n),o.buttonView.set({label:t,icon:e,tooltip:!0,isEnabled:!0}),this.listenTo(o.buttonView,"execute",()=>{i.execute("mergeTableCells"),i.editing.view.focus()}),this.listenTo(o,"execute",t=>{i.execute(t.source.commandName),i.editing.view.focus()}),o}_fillDropdownWithListOptions(t,e){const n=this.editor,r=[],i=new zn;for(const o of e)gg(o,n,r,i);return iu(t,i,n.ui.componentFactory),r}}function gg(t,e,n,r){const i=t.model=new pp(t.model),{commandName:o,bindIsOn:a}=t.model;if("button"===t.type||"switchbutton"===t.type){const t=e.commands.get(o);n.push(t),i.set({commandName:o}),i.bind("isEnabled").to(t),a&&i.bind("isOn").to(t,"value")}i.set({withText:!0}),r.add(t)}n(94);class vg extends du{static get pluginName(){return"TableSelection"}static get requires(){return[Ub]}init(){const t=this.editor.model;this.listenTo(t,"deleteContent",(t,e)=>this._handleDeleteContent(t,e),{priority:"high"}),this._defineSelectionConverter(),this._enablePluginDisabling()}getSelectedTableCells(){const t=pb(this.editor.model.document.selection);return 0==t.length?null:t}getSelectionAsFragment(){const t=this.getSelectedTableCells();return t?this.editor.model.change(e=>{const n=e.createDocumentFragment(),r=this.editor.plugins.get("TableUtils"),{first:i,last:o}=vb(t),{first:a,last:s}=gb(t),c=t[0].findAncestor("table");let l=s,u=o;if(wb(t,r)){const t={firstColumn:i,lastColumn:o,firstRow:a,lastRow:s};l=Lb(c,t),u=Bb(c,t)}const d=Mb(c,{startRow:a,startColumn:i,endRow:l,endColumn:u},e);return e.insert(d,n,0),n}):null}setCellSelection(t,e){const n=this._getCellsToSelect(t,e);this.editor.model.change(t=>{t.setSelection(n.cells.map(e=>t.createRangeOn(e)),{backward:n.backward})})}getFocusCell(){const t=[...this.editor.model.document.selection.getRanges()].pop().getContainedElement();return t&&t.is("element","tableCell")?t:null}getAnchorCell(){const t=zd(this.editor.model.document.selection.getRanges()).getContainedElement();return t&&t.is("element","tableCell")?t:null}_defineSelectionConverter(){const t=this.editor,e=new Set;t.conversion.for("editingDowncast").add(t=>t.on("selection",(t,n,r)=>{const i=r.writer;!function(t){for(const n of e)t.removeClass("ck-editor__editable_selected",n);e.clear()}(i);const o=this.getSelectedTableCells();if(!o)return;for(const s of o){const t=r.mapper.toViewElement(s);i.addClass("ck-editor__editable_selected",t),e.add(t)}const a=r.mapper.toViewElement(o[o.length-1]);i.setSelection(a,0)},{priority:"lowest"}))}_enablePluginDisabling(){const t=this.editor;this.on("change:isEnabled",()=>{if(!this.isEnabled){const e=this.getSelectedTableCells();if(!e)return;t.model.change(n=>{const r=n.createPositionAt(e[0],0),i=t.model.schema.getNearestSelectionRange(r);n.setSelection(i)})}})}_handleDeleteContent(t,e){const[n,r]=e,i=this.editor.model,o=!r||"backward"==r.direction,a=pb(n);a.length&&(t.stop(),i.change(t=>{const e=a[o?a.length-1:0];i.change(t=>{for(const e of a)i.deleteContent(t.createSelection(e,"in"))});const r=i.schema.getNearestSelectionRange(t.createPositionAt(e,0));n.is("documentSelection")?t.setSelection(r):n.setTo(r)}))}_getCellsToSelect(t,e){const n=this.editor.plugins.get("TableUtils"),r=n.getCellLocation(t),i=n.getCellLocation(e),o=Math.min(r.row,i.row),a=Math.max(r.row,i.row),s=Math.min(r.column,i.column),c=Math.max(r.column,i.column),l=new Array(a-o+1).fill(null).map(()=>[]),u={startRow:o,endRow:a,startColumn:s,endColumn:c};for(const{row:f,cell:p}of new eb(t.findAncestor("table"),u))l[f-o].push(p);const d=i.row<r.row,h=i.column<r.column;return d&&l.reverse(),h&&l.forEach(t=>t.reverse()),{cells:l.flat(),backward:d||h}}}class wg extends du{static get pluginName(){return"TableClipboard"}static get requires(){return[vg,Ub]}init(){const t=this.editor,e=t.editing.view.document;this.listenTo(e,"copy",(t,e)=>this._onCopyCut(t,e)),this.listenTo(e,"cut",(t,e)=>this._onCopyCut(t,e)),this.listenTo(t.model,"insertContent",(t,e)=>this._onInsertContent(t,...e),{priority:"high"}),this.decorate("_replaceTableSlotCell")}_onCopyCut(t,e){const n=this.editor.plugins.get(vg);if(!n.getSelectedTableCells())return;if("cut"==t.name&&this.editor.isReadOnly)return;e.preventDefault(),t.stop();const r=this.editor.data,i=this.editor.editing.view.document,o=r.toView(n.getSelectionAsFragment());i.fire("clipboardOutput",{dataTransfer:e.dataTransfer,content:o,method:t.name})}_onInsertContent(t,e,n){if(n&&!n.is("documentSelection"))return;const r=this.editor.model,i=this.editor.plugins.get(Ub);let o=function(t,e){if(!t.is("documentFragment")&&!t.is("element"))return null;if(t.is("element","table"))return t;if(1==t.childCount&&t.getChild(0).is("element","table"))return t.getChild(0);const n=e.createRangeIn(t);for(const r of n.getItems())if(r.is("element","table")){const t=e.createRange(n.start,e.createPositionBefore(r));if(e.hasContent(t,{ignoreWhitespaces:!0}))return null;const i=e.createRange(e.createPositionAfter(r),n.end);return e.hasContent(i,{ignoreWhitespaces:!0})?null:r}return null}(e,r);if(!o)return;const a=bb(r.document.selection);a.length?(t.stop(),r.change(t=>{const e={width:i.getColumns(o),height:i.getRows(o)},n=function(t,e,n,r){const i=t[0].findAncestor("table"),o=vb(t),a=gb(t),s={firstColumn:o.first,lastColumn:o.last,firstRow:a.first,lastRow:a.last},c=1===t.length;return c&&(s.lastRow+=e.height-1,s.lastColumn+=e.width-1,function(t,e,n,r){const i=r.getColumns(t),o=r.getRows(t);n>i&&r.insertColumns(t,{at:i,columns:n-i}),e>o&&r.insertRows(t,{at:o,rows:e-o})}(i,s.lastRow+1,s.lastColumn+1,r)),c||!wb(t,r)?function(t,e,n){const{firstRow:r,lastRow:i,firstColumn:o,lastColumn:a}=e,s={first:r,last:i},c={first:o,last:a};kg(t,o,s,n),kg(t,a+1,s,n),yg(t,r,c,n),yg(t,i+1,c,n,r)}(i,s,n):(s.lastRow=Lb(i,s),s.lastColumn=Bb(i,s)),s}(a,e,t,i),r=n.lastRow-n.firstRow+1,s=n.lastColumn-n.firstColumn+1,c={startRow:0,startColumn:0,endRow:Math.min(r,e.height)-1,endColumn:Math.min(s,e.width)-1};o=Mb(o,c,t);const l=a[0].findAncestor("table"),u=this._replaceSelectedCellsWithPasted(o,e,l,n,t);if(this.editor.plugins.get("TableSelection").isEnabled){const e=yb(u.map(e=>t.createRangeOn(e)));t.setSelection(e)}else t.setSelection(u[0],0)})):Eb(o,i)}_replaceSelectedCellsWithPasted(t,e,n,r,i){const{width:o,height:a}=e,s=function(t,e,n){const r=new Array(n).fill(null).map(()=>new Array(e).fill(null));for(const{column:i,row:o,cell:a}of new eb(t))r[o][i]=a;return r}(t,o,a),c=[...new eb(n,{startRow:r.firstRow,endRow:r.lastRow,startColumn:r.firstColumn,endColumn:r.lastColumn,includeAllSlots:!0})],l=[];let u;for(const m of c){const{row:t,column:e}=m;e===r.firstColumn&&(u=m.getPositionBefore());const n=t-r.firstRow,c=e-r.firstColumn,d=s[n%a][c%o],h=d?i.cloneElement(d):null,f=this._replaceTableSlotCell(m,h,u,i);f&&(Tb(f,t,e,r.lastRow,r.lastColumn,i),l.push(f),u=i.createPositionAfter(f))}const d=parseInt(n.getAttribute("headingRows")||0),h=parseInt(n.getAttribute("headingColumns")||0),f=r.firstRow<d&&d<=r.lastRow,p=r.firstColumn<h&&h<=r.lastColumn;if(f){const t=yg(n,d,{first:r.firstColumn,last:r.lastColumn},i,r.firstRow);l.push(...t)}if(p){const t=kg(n,h,{first:r.firstRow,last:r.lastRow},i);l.push(...t)}return l}_replaceTableSlotCell(t,e,n,r){const{cell:i,isAnchor:o}=t;return o&&r.remove(i),e?(r.insert(e,n),e):null}}function yg(t,e,n,r,i=0){if(!(e<1))return Cb(t,e,i).filter(({column:t,cellWidth:e})=>_g(t,e,n)).map(({cell:t})=>Vb(t,e,r))}function kg(t,e,n,r){if(!(e<1))return Sb(t,e).filter(({row:t,cellHeight:e})=>_g(t,e,n)).map(({cell:t,column:n})=>xb(t,n,e,r))}function _g(t,e,n){const r=t+e-1,{first:i,last:o}=n;return t>=i&&t<=o||t<i&&r>=i}class Og extends du{static get pluginName(){return"TableKeyboard"}static get requires(){return[vg]}init(){const t=this.editor.editing.view.document;this.editor.keystrokes.set("Tab",(...t)=>this._handleTabOnSelectedTable(...t),{priority:"low"}),this.editor.keystrokes.set("Tab",this._getTabHandler(!0),{priority:"low"}),this.editor.keystrokes.set("Shift+Tab",this._getTabHandler(!1),{priority:"low"}),this.listenTo(t,"keydown",(...t)=>this._onKeydown(...t),{priority:dn.get("high")-10})}_handleTabOnSelectedTable(t,e){const n=this.editor,r=n.model.document.selection.getSelectedElement();r&&r.is("element","table")&&(e(),n.model.change(t=>{t.setSelection(t.createRangeIn(r.getChild(0).getChild(0)))}))}_getTabHandler(t){const e=this.editor;return(n,r)=>{let i=mb(e.model.document.selection)[0];if(i||(i=this.editor.plugins.get("TableSelection").getFocusCell()),!i)return;r();const o=i.parent,a=o.parent,s=a.getChildIndex(o),c=o.getChildIndex(i),l=0===c;if(!t&&l&&0===s)return void e.model.change(t=>{t.setSelection(t.createRangeOn(a))});const u=c===o.childCount-1,d=s===a.childCount-1;if(t&&d&&u&&(e.execute("insertTableRowBelow"),s===a.childCount-1))return void e.model.change(t=>{t.setSelection(t.createRangeOn(a))});let h;if(t&&u){const t=a.getChild(s+1);h=t.getChild(0)}else if(!t&&l){const t=a.getChild(s-1);h=t.getChild(t.childCount-1)}else h=o.getChild(c+(t?1:-1));e.model.change(t=>{t.setSelection(t.createRangeIn(h))})}}_onKeydown(t,e){const n=this.editor,r=e.keyCode;if(!wi(r))return;const i=yi(r,n.locale.contentLanguageDirection);this._handleArrowKeys(i,e.shiftKey)&&(e.preventDefault(),e.stopPropagation(),t.stop())}_handleArrowKeys(t,e){const n=this.editor.model.document.selection,r=["right","down"].includes(t),i=pb(n);if(i.length){let n;return n=e?this.editor.plugins.get("TableSelection").getFocusCell():r?i[i.length-1]:i[0],this._navigateFromCellInDirection(n,t,e),!0}const o=n.focus.findAncestor("tableCell");return!!o&&!(e&&!n.isCollapsed&&n.isBackward==r)&&!!this._isSelectionAtCellEdge(n,o,r)&&(this._navigateFromCellInDirection(o,t,e),!0)}_isSelectionAtCellEdge(t,e,n){const r=this.editor.model,i=this.editor.model.schema,o=n?t.getLastPosition():t.getFirstPosition();if(!i.getLimitElement(o).is("element","tableCell"))return r.createPositionAt(e,n?"end":0).isTouching(o);const a=r.createSelection(o);return r.modifySelection(a,{direction:n?"forward":"backward"}),o.isEqual(a.focus)}_navigateFromCellInDirection(t,e,n=!1){const r=this.editor.model,i=t.findAncestor("table"),o=[...new eb(i,{includeAllSlots:!0})],{row:a,column:s}=o[o.length-1],c=o.find(({cell:e})=>e==t);let{row:l,column:u}=c;switch(e){case"left":u--;break;case"up":l--;break;case"right":u+=c.cellWidth;break;case"down":l+=c.cellHeight}if(l<0||l>a||u<0&&l<=0||u>s&&l>=a)return void r.change(t=>{t.setSelection(t.createRangeOn(i))});u<0?(u=n?0:s,l--):u>s&&(u=n?s:0,l++);const d=o.find(t=>t.row==l&&t.column==u).cell,h=["right","down"].includes(e),f=this.editor.plugins.get("TableSelection");if(n&&f.isEnabled){const e=f.getAnchorCell()||t;f.setCellSelection(e,d)}else{const t=r.createPositionAt(d,h?0:"end");r.change(e=>{e.setSelection(t)})}}}class zg extends Ho{constructor(t){super(t),this.domEventType=["mousemove","mouseup","mouseleave"]}onDomEvent(t){this.fire(t.type,t)}}class Ag extends du{static get pluginName(){return"TableMouse"}static get requires(){return[vg]}init(){this.editor.editing.view.addObserver(zg),this._enableShiftClickSelection(),this._enableMouseDragSelection()}_enableShiftClickSelection(){const t=this.editor;let e=!1;const n=t.plugins.get(vg);this.listenTo(t.editing.view.document,"mousedown",(r,i)=>{if(!this.isEnabled||!n.isEnabled)return;if(!i.domEvent.shiftKey)return;const o=n.getAnchorCell()||mb(t.model.document.selection)[0];if(!o)return;const a=this._getModelTableCellFromDomEvent(i);a&&jg(o,a)&&(e=!0,n.setCellSelection(o,a),i.preventDefault())}),this.listenTo(t.editing.view.document,"mouseup",()=>{e=!1}),this.listenTo(t.editing.view.document,"selectionChange",t=>{e&&t.stop()},{priority:"highest"})}_enableMouseDragSelection(){const t=this.editor;let e,n,r=!1,i=!1;const o=t.plugins.get(vg);this.listenTo(t.editing.view.document,"mousedown",(t,n)=>{this.isEnabled&&o.isEnabled&&(n.domEvent.shiftKey||n.domEvent.ctrlKey||n.domEvent.altKey||(e=this._getModelTableCellFromDomEvent(n)))}),this.listenTo(t.editing.view.document,"mousemove",(t,a)=>{if(!a.domEvent.buttons)return;if(!e)return;const s=this._getModelTableCellFromDomEvent(a);s&&jg(e,s)&&(n=s,r||n==e||(r=!0)),r&&(i=!0,o.setCellSelection(e,n),a.preventDefault())}),this.listenTo(t.editing.view.document,"mouseup",()=>{r=!1,i=!1,e=null,n=null}),this.listenTo(t.editing.view.document,"selectionChange",t=>{i&&t.stop()},{priority:"highest"})}_getModelTableCellFromDomEvent(t){const e=t.target,n=this.editor.editing.view.createPositionAt(e,0);return this.editor.editing.mapper.toModelPosition(n).parent.findAncestor("tableCell",{includeSelf:!0})}}function jg(t,e){return t.parent.parent==e.parent.parent}function Mg(t){const e=t.getSelectedElement();return e&&Vg(e)?e:null}function Cg(t){const e=function(t,e){let n=e.parent;for(;n;){if(n.name===t)return n;n=n.parent}}("table",t.getFirstPosition());return e&&Vg(e.parent)?e.parent:null}function Vg(t){return!!t.getCustomProperty("table")&&th(t)}n(96);var Sg=/[\\^$.*+?()[\]{}|]/g,xg=RegExp(Sg.source),Tg=function(t){return(t=Zn(t))&&xg.test(t)?t.replace(Sg,"\\$&"):t};const Pg={copyright:{from:"(c)",to:"©"},registeredTrademark:{from:"(r)",to:"®"},trademark:{from:"(tm)",to:"™"},oneHalf:{from:"1/2",to:"½"},oneThird:{from:"1/3",to:"⅓"},twoThirds:{from:"2/3",to:"⅔"},oneForth:{from:"1/4",to:"¼"},threeQuarters:{from:"3/4",to:"¾"},lessThanOrEqual:{from:"<=",to:"≤"},greaterThanOrEqual:{from:">=",to:"≥"},notEqual:{from:"!=",to:"≠"},arrowLeft:{from:"<-",to:"←"},arrowRight:{from:"->",to:"→"},horizontalEllipsis:{from:"...",to:"…"},enDash:{from:/(^| )(--)( )$/,to:[null,"–",null]},emDash:{from:/(^| )(---)( )$/,to:[null,"—",null]},quotesPrimary:{from:Fg('"'),to:[null,"“",null,"”"]},quotesSecondary:{from:Fg("'"),to:[null,"‘",null,"’"]},quotesPrimaryEnGb:{from:Fg("'"),to:[null,"‘",null,"’"]},quotesSecondaryEnGb:{from:Fg('"'),to:[null,"“",null,"”"]},quotesPrimaryPl:{from:Fg('"'),to:[null,"„",null,"”"]},quotesSecondaryPl:{from:Fg("'"),to:[null,"‚",null,"’"]}},Ig={symbols:["copyright","registeredTrademark","trademark"],mathematical:["oneHalf","oneThird","twoThirds","oneForth","threeQuarters","lessThanOrEqual","greaterThanOrEqual","notEqual","arrowLeft","arrowRight"],typography:["horizontalEllipsis","enDash","emDash"],quotes:["quotesPrimary","quotesSecondary"]},Eg=["symbols","mathematical","typography","quotes"];function Lg(t){return"string"==typeof t?new RegExp(`(${Tg(t)})$`):t}function Bg(t){return"string"==typeof t?()=>[t]:t instanceof Array?()=>t:t}function Hg(t){return(t.textNode?t.textNode:t.nodeAfter).getAttributes()}function Fg(t){return new RegExp(`(^|\\s)(${t})([^${t}]*)(${t})$`)}class Dg extends uu{}Dg.builtinPlugins=[class extends du{static get requires(){return[gu,zu,Iu,Cu,Yu,md]}static get pluginName(){return"Essentials"}},_d,class extends du{static get pluginName(){return"Autoformat"}afterInit(){this._addListAutoformats(),this._addBasicStylesAutoformats(),this._addHeadingAutoformats(),this._addBlockQuoteAutoformats(),this._addCodeBlockAutoformats(),this._addHorizontalLineAutoformats()}_addListAutoformats(){const t=this.editor.commands;t.get("bulletedList")&&Ad(this.editor,this,/^[*-]\s$/,"bulletedList"),t.get("numberedList")&&Ad(this.editor,this,/^1[.|)]\s$/,"numberedList"),t.get("todoList")&&Ad(this.editor,this,/^\[\s?\]\s$/,"todoList")}_addBasicStylesAutoformats(){const t=this.editor.commands;if(t.get("bold")){const t=Cd(this.editor,"bold");jd(this.editor,this,/(?:^|\s)(\*\*)([^*]+)(\*\*)$/g,t),jd(this.editor,this,/(?:^|\s)(__)([^_]+)(__)$/g,t)}if(t.get("italic")){const t=Cd(this.editor,"italic");jd(this.editor,this,/(?:^|\s)(\*)([^*_]+)(\*)$/g,t),jd(this.editor,this,/(?:^|\s)(_)([^_]+)(_)$/g,t)}if(t.get("code")){const t=Cd(this.editor,"code");jd(this.editor,this,/(`)([^`]+)(`)$/g,t)}if(t.get("strikethrough")){const t=Cd(this.editor,"strikethrough");jd(this.editor,this,/(~~)([^~]+)(~~)$/g,t)}}_addHeadingAutoformats(){const t=this.editor.commands.get("heading");t&&t.modelElements.filter(t=>t.match(/^heading[1-6]$/)).forEach(e=>{const n=e[7],r=new RegExp(`^(#{${n}})\\s$`);Ad(this.editor,this,r,()=>{if(!t.isEnabled||t.value===e)return!1;this.editor.execute("heading",{value:e})})})}_addBlockQuoteAutoformats(){this.editor.commands.get("blockQuote")&&Ad(this.editor,this,/^>\s$/,"blockQuote")}_addCodeBlockAutoformats(){this.editor.commands.get("codeBlock")&&Ad(this.editor,this,/^```$/,"codeBlock")}_addHorizontalLineAutoformats(){this.editor.commands.get("horizontalLine")&&Ad(this.editor,this,/^---$/,"horizontalLine")}},class extends du{static get requires(){return[Sd,xd]}static get pluginName(){return"Bold"}},class extends du{static get requires(){return[Td,Pd]}static get pluginName(){return"Italic"}},class extends du{static get requires(){return[Hd,Fd]}static get pluginName(){return"BlockQuote"}},class extends du{static get pluginName(){return"CKFinder"}static get requires(){return[cf,Dd,_d]}},class extends du{static get requires(){return[mf,Nf,ap]}static get pluginName(){return"EasyImage"}},class extends du{static get requires(){return[fp,mp]}static get pluginName(){return"Heading"}},Nf,class extends du{static get requires(){return[vp]}static get pluginName(){return"ImageCaption"}},class extends du{static get requires(){return[Pp,Ip]}static get pluginName(){return"ImageStyle"}},class extends du{static get requires(){return[Ep]}static get pluginName(){return"ImageToolbar"}afterInit(){const t=this.editor,e=t.t;t.plugins.get(Ep).register("image",{ariaLabel:e("Image toolbar"),items:t.config.get("image.toolbar")||[],getRelatedElement:ch})}},ap,class extends du{static get pluginName(){return"Indent"}static get requires(){return[Fp,Np]}},class extends du{static get requires(){return[ef,Wp,Xp]}static get pluginName(){return"Link"}},class extends du{static get requires(){return[Om,Am]}static get pluginName(){return"List"}},class extends du{static get requires(){return[Pm,Bm,Em,Of]}static get pluginName(){return"MediaEmbed"}},up,class extends du{static get pluginName(){return"PasteFromOffice"}static get requires(){return[gu]}init(){const t=this.editor,e=t.editing.view.document,n=[];n.push(new Km(e)),n.push(new $m(e)),t.plugins.get("Clipboard").on("inputTransformation",(t,e)=>{if(e.isTransformedWithPasteFromOffice)return;const r=e.dataTransfer.getData("text/html"),i=n.find(t=>t.isActive(r));i&&(i.execute(e),e.isTransformedWithPasteFromOffice=!0)},{priority:"high"})}},class extends du{static get requires(){return[hg,bg,vg,Ag,Og,wg,Of]}static get pluginName(){return"Table"}},class extends du{static get requires(){return[Ep]}static get pluginName(){return"TableToolbar"}afterInit(){const t=this.editor,e=t.t,n=t.plugins.get(Ep),r=t.config.get("table.contentToolbar"),i=t.config.get("table.tableToolbar");r&&n.register("tableContent",{ariaLabel:e("Table toolbar"),items:r,getRelatedElement:Cg}),i&&n.register("table",{ariaLabel:e("Table toolbar"),items:i,getRelatedElement:Mg})}},class extends du{static get pluginName(){return"TextTransformation"}constructor(t){super(t),t.config.define("typing",{transformations:{include:Eg}})}init(){const t=this.editor.model.document.selection;t.on("change:range",()=>{this.isEnabled=!t.anchor.parent.is("element","codeBlock")}),this._enableTransformationWatchers()}_enableTransformationWatchers(){const t=this.editor,e=t.model,n=t.plugins.get("Input"),r=function(t){const e=t.extra||[],n=t.remove||[],r=t=>!n.includes(t);return function(t){const e=new Set;for(const n of t)if(Ig[n])for(const t of Ig[n])e.add(t);else e.add(n);return Array.from(e)}(t.include.concat(e).filter(r)).filter(r).map(t=>Pg[t]||t).map(t=>({from:Lg(t.from),to:Bg(t.to)}))}(t.config.get("typing.transformations")),i=new Kp(t.model,t=>{for(const e of r)if(e.from.test(t))return{normalizedTransformation:e}});i.on("matched:data",(t,r)=>{if(!n.isInput(r.batch))return;const{from:i,to:o}=r.normalizedTransformation,a=i.exec(r.text),s=o(a.slice(1)),c=r.range;let l=a.index;e.enqueueChange(t=>{for(let n=1;n<a.length;n++){const r=a[n],i=s[n-1];if(null==i){l+=r.length;continue}const o=c.start.getShiftedBy(l),u=e.createRange(o,o.getShiftedBy(r.length)),d=Hg(o);e.insertContent(t.createText(i,d),u),l+=i.length}})}),i.bind("isEnabled").to(this)}}],Dg.defaultConfig={toolbar:{items:["heading","|","bold","italic","link","bulletedList","numberedList","|","indent","outdent","|","imageUpload","blockQuote","insertTable","mediaEmbed","undo","redo"]},image:{toolbar:["imageStyle:full","imageStyle:side","|","imageTextAlternative"]},table:{contentToolbar:["tableColumn","tableRow","mergeTableCells"]},language:"en"}}]).default}))}}]);
//# sourceMappingURL=chunk-vendors.20e928aa.js.map